(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    575679,      11488]
NotebookOptionsPosition[    563261,      11068]
NotebookOutlinePosition[    563693,      11087]
CellTagsIndexPosition[    563650,      11084]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["JGW-T1503259-v4: Analysis of the sweet spot for the coil", "Title",
 CellChangeTimes->{{3.662172198062398*^9, 3.662172215633911*^9}, {
  3.664595361728435*^9, 3.664595361991023*^9}, {3.665355362273085*^9, 
  3.66535536329115*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"useprecomputed", " ", "=", " ", "False"}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "whether", " ", "to", " ", "use", " ", "archived", " ", "values", " ", 
     "for", " ", "certain", " ", "time"}], "-", 
    RowBox[{"consuming", " ", "calculations"}]}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.480244231326439*^9, 3.48024423792516*^9}, {
  3.480703939177309*^9, 3.48070394080156*^9}, {3.481941928523884*^9, 
  3.481941957601687*^9}, {3.660964994226367*^9, 3.6609649946935883`*^9}, {
  3.66096874682955*^9, 3.6609687474895763`*^9}, {3.661118669904331*^9, 
  3.6611186704656057`*^9}, {3.661221869657711*^9, 3.6612218703816633`*^9}, {
  3.6612314549878483`*^9, 3.661231456910973*^9}, {3.66217223147058*^9, 
  3.6621722330013103`*^9}}],

Cell[CellGroupData[{

Cell["Instructions", "Section"],

Cell["\<\
1. Make sure that the notebook of utility functions for magnetic dipoles, \
MagDipole.nb, and the associated autosave file, MagDipole.m, are in the same \
directory as this notebook.
2. Edit the path setting statement in the Preliminaries section below to make \
it add this directory to the path. The directory name has to be specified in \
the correct format and the correct branch of the Switch[] statement for your \
system. Check the value of $System and add new branches if necessary.
3. Evaluate the Preliminaries section.
4. Evaluate the rest of the notebook and/or hack around to your heart's \
content.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Preliminaries", "Section",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Dependencies", "Subsection"],

Cell[CellGroupData[{

Cell["\<\
The path in which the support files are installed. 
**** EDIT THE PATHS AND/OR ADD CLAUSES FOR NEW SYSTEMS AS APPROPRIATE ****\
\>", "Subsubsection",
 CellChangeTimes->{{3.631843152959103*^9, 3.631843153884302*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Switch", "[", "\[IndentingNewLine]", "\t", 
   RowBox[{
   "$System", ",", "\[IndentingNewLine]", "\t", 
    "\"\<Mac OS X x86 (64-bit)\>\"", ",", 
    RowBox[{"$Path", " ", "=", " ", 
     RowBox[{"Append", "[", 
      RowBox[{
      "$Path", ",", "\"\</Users/mbarton/Work/KAGRA/Analysis/Magnets\>\""}], 
      "]"}]}]}], "\[IndentingNewLine]", "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.453747804876116*^9, 3.4537478086805983`*^9}, {
  3.6297593775602903`*^9, 3.6297594035095177`*^9}, {3.62975943796768*^9, 
  3.629759439163143*^9}}],

Cell["<<\"MagDipole.m\"", "Input"],

Cell["<<\"NewCoilTheory.m\"", "Input",
 CellChangeTimes->{3.631828660846888*^9}]
}, Open  ]]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<NumericalCalculus`\>\"", "]"}]], "Input"],

Cell[CellGroupData[{

Cell["Disable spell-checking", "Subsection"],

Cell[BoxData[
 RowBox[{"Off", "[", 
  RowBox[{
   RowBox[{"General", "::", "spell"}], ",", 
   RowBox[{"General", "::", "spell1"}]}], "]"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Functions for manipulating lists of substitutions", "Subsection"],

Cell[CellGroupData[{

Cell["Replace a single substitution", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Override", "[", 
   RowBox[{"oldsubs_", ",", "newsubs_"}], "]"}], " ", ":=", " ", 
  RowBox[{"oldsubs", "/.", 
   RowBox[{"(", 
    RowBox[{"newsubs", "/.", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"param_", "\[Rule]", "newval_"}], ")"}], "\[RuleDelayed]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"param", "\[Rule]", "oldval_"}], ")"}], "\[RuleDelayed]", 
        RowBox[{"(", 
         RowBox[{"param", "\[Rule]", "newval"}], ")"}]}], ")"}]}]}], 
    ")"}]}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
A function to reduce a substitution list to fully numerical form by applying \
it repeatedly to itself:\
\>", "Subsubsection",
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Recurse[sublist_List] := 
\tsublist//.(x_->y_):>(x->(y/.sublist))\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["A function to scale a substitution list:", "Subsubsection",
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
scale[sublist_List, factor_] := 
\tsublist/.(x_->y_):>(x->factor*y)\
\>", "Input",
 CellChangeTimes->{3.453749631833597*^9},
 ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Derive the axial and radial components of B in the dipole/dipole approximation\
\>", "Subsection",
 CellChangeTimes->{{3.6338378360549297`*^9, 3.633837845546673*^9}}],

Cell[CellGroupData[{

Cell["\<\
Baxial = Simplify[
\tTogether[
\t\tdipoleB[[3]]
\t\t/.dx->0
\t\t/.dy->0
\t\t/.dz->0
\t\t/.Xx->r
\t\t/.Yy->0
\t\t/.Zz->z
\t]
]
\
\>", "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{"mu0", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "m1z"}], " ", 
      SuperscriptBox["r", "2"]}], "+", 
     RowBox[{"3", " ", "m1x", " ", "r", " ", "z"}], "+", 
     RowBox[{"2", " ", "m1z", " ", 
      SuperscriptBox["z", "2"]}]}], ")"}]}], 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["r", "2"], "+", 
      SuperscriptBox["z", "2"]}], ")"}], 
    RowBox[{"5", "/", "2"}]]}]]], "Output",
 CellChangeTimes->{
  3.453747965547722*^9, 3.453749599994955*^9, 3.4638444535242777`*^9, {
   3.478894405842181*^9, 3.478894421027747*^9}, 3.478960340825461*^9, 
   3.479485741071822*^9, 3.479486052836144*^9, 3.4796583821237583`*^9, 
   3.480082564582583*^9, 3.4802436759582167`*^9, 3.4806922469034033`*^9, 
   3.481566005895687*^9, {3.4819409141959743`*^9, 3.48194093732237*^9}, 
   3.48194192328915*^9, 3.629759415051181*^9, 3.629767960982176*^9, 
   3.630209768388575*^9, 3.6302880141244392`*^9, 3.6302982167316837`*^9, 
   3.630319401081757*^9, 3.630469791945978*^9, 3.631828014669615*^9, 
   3.631828671749612*^9, 3.6338315593765593`*^9, 3.633832378708853*^9, 
   3.633833220308724*^9, {3.633833826289847*^9, 3.633833843175809*^9}, 
   3.649108795356412*^9, 3.649108828142324*^9, 3.66096499864192*^9, 
   3.66096880030812*^9, 3.660969234027224*^9, 3.661055895728656*^9, 
   3.661118714334754*^9, 3.661139341971727*^9, 3.661218304211833*^9, 
   3.6612316443902683`*^9, 3.6622458128332977`*^9, 3.6623275773336353`*^9, 
   3.662330890348151*^9, 3.662337497876278*^9, 3.664426734442122*^9, 
   3.664592534676702*^9, 3.665355467380103*^9, 3.665373550373541*^9, 
   3.682482697717854*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Baxial", "/.", 
  RowBox[{"r", "\[Rule]", "0"}]}]], "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{"m1z", " ", "mu0"}], 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     SuperscriptBox["z", "2"], ")"}], 
    RowBox[{"3", "/", "2"}]]}]]], "Output",
 CellChangeTimes->{
  3.4537479655831127`*^9, 3.453749600034116*^9, 3.4638444538148317`*^9, {
   3.478894405888887*^9, 3.478894421080052*^9}, 3.47896034086206*^9, 
   3.4794857411376143`*^9, 3.4794860528885927`*^9, 3.479658382192664*^9, 
   3.480082564654179*^9, 3.480243676115644*^9, 3.480692246945731*^9, 
   3.4815660059479713`*^9, {3.4819409142460823`*^9, 3.4819409373890877`*^9}, 
   3.4819419233788652`*^9, 3.62975941511008*^9, 3.6297679610363607`*^9, 
   3.6302097685477257`*^9, 3.6302880141874647`*^9, 3.6302982167975893`*^9, 
   3.630319401109314*^9, 3.630469791997346*^9, 3.631828014731904*^9, 
   3.631828671799406*^9, 3.633831559408112*^9, 3.63383237873632*^9, 
   3.6338332203606367`*^9, {3.633833826345573*^9, 3.6338338432313232`*^9}, 
   3.6491087953833447`*^9, 3.6491088281637573`*^9, 3.66096499869882*^9, 
   3.660968800334855*^9, 3.660969234090344*^9, 3.6610558957535353`*^9, 
   3.661118714403418*^9, 3.661139342039118*^9, 3.6612183042781487`*^9, 
   3.661231644442491*^9, 3.662245812881431*^9, 3.6623275773933077`*^9, 
   3.662330890382712*^9, 3.662337497935946*^9, 3.664426734496387*^9, 
   3.664592534723995*^9, 3.665355467436771*^9, 3.66537355044414*^9, 
   3.682482697751072*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Btransverse = Simplify[
\tTogether[
\t\tdipoleB[[1]]
\t\t/.dx->0
\t\t/.dy->0
\t\t/.dz->0
\t\t/.Xx->r
\t\t/.Yy->0
\t\t/.Zz->z
\t]
]\
\>", "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{"mu0", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", "m1x", " ", 
      SuperscriptBox["r", "2"]}], "+", 
     RowBox[{"3", " ", "m1z", " ", "r", " ", "z"}], "-", 
     RowBox[{"m1x", " ", 
      SuperscriptBox["z", "2"]}]}], ")"}]}], 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["r", "2"], "+", 
      SuperscriptBox["z", "2"]}], ")"}], 
    RowBox[{"5", "/", "2"}]]}]]], "Output",
 CellChangeTimes->{
  3.453747965615678*^9, 3.453749600077715*^9, 3.463844455487849*^9, {
   3.478894405942997*^9, 3.4788944211302834`*^9}, 3.478960340942863*^9, 
   3.479485741189885*^9, 3.4794860529295588`*^9, 3.4796583822416077`*^9, 
   3.480082564700638*^9, 3.48024367617673*^9, 3.480692246987156*^9, 
   3.481566005979335*^9, {3.481940914277701*^9, 3.481940937448995*^9}, 
   3.481941923414253*^9, 3.629759415158143*^9, 3.6297679610856237`*^9, 
   3.6302097686167717`*^9, 3.630288014252639*^9, 3.630298216862108*^9, 
   3.630319401168418*^9, 3.630469792046775*^9, 3.6318280147819643`*^9, 
   3.631828671850799*^9, 3.6338315594706373`*^9, 3.633832378789961*^9, 
   3.633833220410568*^9, {3.633833826394938*^9, 3.633833843282202*^9}, 
   3.649108795431487*^9, 3.64910882821459*^9, 3.660964998764786*^9, 
   3.660968800385165*^9, 3.660969234140252*^9, 3.661055895817093*^9, 
   3.661118714466037*^9, 3.661139342103462*^9, 3.661218304341613*^9, 
   3.661231644509912*^9, 3.6622458129299088`*^9, 3.662327577456159*^9, 
   3.66233089044236*^9, 3.662337497988986*^9, 3.664426734544085*^9, 
   3.664592534773574*^9, 3.665355467499732*^9, 3.665373550509433*^9, 
   3.68248269781641*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
force[Zz_] = Simplify[-mz \
D[dipoleBz,Zz]/.dx->0/.dy->0/.dz->0/.Xx->0/.Yy->0]/.powerfix\
\>", "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{"3", " ", "m1z", " ", "mu0", " ", "mz"}], 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SuperscriptBox["Zz", "4"]}]]], "Output",
 CellChangeTimes->{
  3.453747965823358*^9, 3.4537496001121492`*^9, 3.46384446080796*^9, {
   3.4788944059930553`*^9, 3.478894421180645*^9}, 3.47896034097888*^9, 
   3.4794857412398157`*^9, 3.479486052963105*^9, 3.479658382309431*^9, 
   3.4800825649222116`*^9, 3.480243676306188*^9, 3.48069224701851*^9, 
   3.4815660060302887`*^9, {3.481940914334242*^9, 3.481940937496923*^9}, 
   3.481941923466711*^9, 3.629759415208243*^9, 3.629767961135536*^9, 
   3.630209768680304*^9, 3.6302880143003073`*^9, 3.630298216930635*^9, 
   3.630319401235097*^9, 3.6304697920959473`*^9, 3.631828014831504*^9, 
   3.6318286719170933`*^9, 3.633831559710355*^9, 3.633832378856058*^9, 
   3.633833220459318*^9, {3.633833826447667*^9, 3.6338338433326187`*^9}, 
   3.649108795480233*^9, 3.6491088282685328`*^9, 3.66096499898549*^9, 
   3.660968800435987*^9, 3.660969234190186*^9, 3.6610558958800507`*^9, 
   3.661118714514512*^9, 3.661139342173164*^9, 3.661218304413344*^9, 
   3.661231644575989*^9, 3.662245813080386*^9, 3.662327577523871*^9, 
   3.6623308905103188`*^9, 3.662337498038474*^9, 3.6644267345985613`*^9, 
   3.664592534825116*^9, 3.6653554675827017`*^9, 3.665373550572506*^9, 
   3.682482697967306*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Basic constants", "Subsection",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
basicvals = Recurse[{
\tkB->1.38 10^-23,
\tT->295,
\tg->9.8,
\tmu0->4 N[Pi] 10^-7,
\trhoeAl->2.65 10^-8,\t\t\t(* Resistivity of Al *)
\trhoepianowire->30 rhoeAl,\t(* Resistivity of P.W., GUESSTIMATE *)
\tsigmaeAu->2.67,\t\t\t\t(* Resistivity of Au paint, measured *)
\tdipoleM->Bresid/mu0,\t\t(* Magnetization *)
\tmassSOS->0.25,\t\t\t\t(* Final design value *)
\tmassM->rhomM l N[Pi] a^2,
\tBresid->1.25,\t\t\t\t(* Residual field *)
\tPi->N[Pi],
\tl->0.003175,\t\t\t\t(* Length of magnets *)
\ta->0.0009525,\t\t\t\t(* Radius of magnets *)
\trhomM->7400,\t\t\t\t(* Mass density of magnets *)
\tztube->0.0155,\t\t\t\t(* Separation for magnet to push its own weight, \
measured *)
\tzpickup->0.018-l,\t\t\t(* Separation for magnet to pull its own weight, \
measured *)
\tmasspullapart->0.060\t\t(* Force (in kgf) to separate magnets *)
}];\
\>", "Input",
 AspectRatioFixed->True]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Coil calc for iKAGRA PR (also originally for SR, BS): \[CapitalOSlash]6 mm, 3 \
mm thick\
\>", "Section",
 CellChangeTimes->{{3.453751016056313*^9, 3.453751037487228*^9}, 
   3.463844192181329*^9, {3.478894850822432*^9, 3.478894851717502*^9}, {
   3.4788951705281897`*^9, 3.4788951754720497`*^9}, {3.4819407269664*^9, 
   3.481940736973164*^9}, {3.6302077654764643`*^9, 3.6302077702623034`*^9}, {
   3.630210588958201*^9, 3.630210589517418*^9}, {3.6318342427598057`*^9, 
   3.6318342433832703`*^9}, {3.660964871657391*^9, 3.660964871911765*^9}, {
   3.6612263617840633`*^9, 3.661226376523999*^9}, 3.68248169002827*^9, {
   3.682561167985977*^9, 3.6825611821827803`*^9}, {3.682561295102141*^9, 
   3.682561296021758*^9}, 3.682561358975897*^9}],

Cell[CellGroupData[{

Cell["\<\
bosemvalsKPR = Recurse[
\t{
\t\tkB->1.38 10^-23,
\t\tT->295,
\t\tg->9.8,
\t\tmu0->4 N[Pi] 10^-7,
\t\trhoeAl->2.65 10^-8,\t\t\t(* Resistivity of Al *)
\t\trhoepianowire->30 rhoeAl,\t(* Resistivity of P.W., GUESSTIMATE *)
\t\tsigmaeAu->2.67,\t\t\t\t(* Resistivity of Au paint, measured *)
\t\tmassSOS->0.25,\t\t\t\t(* Final design value *)
\t\tmassM->rhomM l N[Pi] a^2,
\t\tPi->N[Pi],
\t\trhomM->7400,\t\t\t\t(* Mass density of magnets *)
\t\tztube->0.0155,\t\t\t\t(* Separation for magnet to push its own weight, \
measured *)
\t\tzpickup->0.018-l,\t\t\t(* Separation for magnet to pull its own weight, \
measured *)
\t\tmasspullapart->0.060,\t\t(* Force (in kgf) to separate magnets *)
\t\t(* preferred value of small magnet dipole moment *)
\t\tmzpref->0.007945632135874319,
\t\t(* magnet moment per unit volume for magnet stuff, assumed the same for \
big and small, in M units: A/m *)
\t\tmz->mzpref/(lold*N[Pi]*aold^2),
\t\t(* magnet moment per unit volume for magnet stuff, in B units: T *)
\t\tmzB->mz*mu0, 
\t\tlold->0.003175,\t\t\t\t(* length of LIGO small magnets *)
\t\taold->0.0009525,\t\t\t(* radius of LIGO small magnets *)
\t\tl->0.003,\t\t\t\t(* length of big magnets *)
\t\ta->0.003,\t\t\t\t(* radius of big magnets *)
\t\tdipole -> mz*l*N[Pi]*a^2,
\t\tlayers -> 27, (* 10212-Gr.12-body BOSEM intermediate.pdf *)
\t\tturns -> 600, (* 10212-Gr.12-body BOSEM intermediate.pdf *)
\t\twirediam ->0.36*0.001, (* 10212-Gr.12-body BOSEM intermediate.pdf *)
\t\t(* coil length *)
\t\tcoillen->(11-3)*0.001,  (* 10212-Gr.12-body BOSEM intermediate.pdf *)
\t\t(* the ends of the coil relative to the centre of the coil *)
\t\tcoilz1->-coillen/2,
\t\tcoilz2->+coillen/2,
\t\t(* the inner and outer radii of the coil *)
\t\tcoilrad1->(18/2)*0.001, (* 10212-Gr.12-body BOSEM intermediate.pdf *)
\t\tcoilrad2->coilrad1+wirediam*layers, (* 10212-Gr.12-body BOSEM \
intermediate.pdf *)
\t\tcoildrad2max->(49/2)*0.001, (* 10212-Gr.12-body BOSEM intermediate.pdf *)
\t\t(* the number of turns *)
\t\tcoilturns->600, (* 10203-Gr.12-Osem intermediate mass.pdf *)
\t\tcoilsigma -> coilturns/((coilrad2 - coilrad1)*(coilz2 - coilz1)),
\t\tmagposactpromec->0.0074 (* Inventor, Promec, Fabian *)
\t}
]
vals[KPR] := bosemvalsKPR;\
\>", "Input",
 CellChangeTimes->{{3.453837228357688*^9, 3.453837230833909*^9}, {
   3.463844183252262*^9, 3.463844223147016*^9}, {3.478894862544446*^9, 
   3.4788948852377567`*^9}, {3.478894985619047*^9, 3.4788949913587503`*^9}, {
   3.4788950240972023`*^9, 3.478895025494358*^9}, {3.481940748223406*^9, 
   3.481940763510077*^9}, {3.6302077790327063`*^9, 3.630207779944365*^9}, {
   3.630208292557073*^9, 3.630208293170534*^9}, {3.6302085800514812`*^9, 
   3.630208649083247*^9}, {3.630209645346671*^9, 3.630209663817658*^9}, {
   3.630209701977907*^9, 3.6302097023837023`*^9}, 3.630209734594172*^9, 
   3.630210623319276*^9, {3.6302114423356447`*^9, 3.6302115422890863`*^9}, {
   3.630211579624671*^9, 3.630211581024807*^9}, {3.630211687932591*^9, 
   3.630211722300425*^9}, {3.6302984714100847`*^9, 3.630298473322809*^9}, {
   3.630361294367758*^9, 3.6303612947567253`*^9}, {3.6303613801867123`*^9, 
   3.6303613881298*^9}, {3.6318342637097387`*^9, 3.631834265518305*^9}, 
   3.631834943063822*^9, {3.631834997615004*^9, 3.6318350023087177`*^9}, {
   3.631839258309725*^9, 3.631839261092559*^9}, {3.631850413860784*^9, 
   3.631850414643579*^9}, {3.660964892951539*^9, 3.6609648945185223`*^9}, 
   3.661055741455657*^9, 3.661055781320374*^9, 3.661056067223044*^9, 
   3.661130760310165*^9, 3.661139095025859*^9, 3.661139202536747*^9, {
   3.6612264255469027`*^9, 3.66122645251295*^9}, {3.661229111429741*^9, 
   3.661229125569841*^9}, {3.682481723853467*^9, 3.6824817239256897`*^9}, 
   3.6824818626344147`*^9, {3.682561466176858*^9, 3.682561466222933*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"kB", "\[Rule]", "1.38`*^-23"}], ",", 
   RowBox[{"T", "\[Rule]", "295"}], ",", 
   RowBox[{"g", "\[Rule]", "9.8`"}], ",", 
   RowBox[{"mu0", "\[Rule]", "1.2566370614359173`*^-6"}], ",", 
   RowBox[{"rhoeAl", "\[Rule]", "2.65`*^-8"}], ",", 
   RowBox[{"rhoepianowire", "\[Rule]", "7.95`*^-7"}], ",", 
   RowBox[{"sigmaeAu", "\[Rule]", "2.67`"}], ",", 
   RowBox[{"massSOS", "\[Rule]", "0.25`"}], ",", 
   RowBox[{"massM", "\[Rule]", "0.0006276902121872406`"}], ",", 
   RowBox[{"\[Pi]", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"rhomM", "\[Rule]", "7400"}], ",", 
   RowBox[{"ztube", "\[Rule]", "0.0155`"}], ",", 
   RowBox[{"zpickup", "\[Rule]", "0.015`"}], ",", 
   RowBox[{"masspullapart", "\[Rule]", "0.06`"}], ",", 
   RowBox[{"mzpref", "\[Rule]", "0.00794563213587432`"}], ",", 
   RowBox[{"mz", "\[Rule]", "878020.9598010788`"}], ",", 
   RowBox[{"mzB", "\[Rule]", "1.1033536788035714`"}], ",", 
   RowBox[{"lold", "\[Rule]", "0.003175`"}], ",", 
   RowBox[{"aold", "\[Rule]", "0.0009525`"}], ",", 
   RowBox[{"l", "\[Rule]", "0.003`"}], ",", 
   RowBox[{"a", "\[Rule]", "0.003`"}], ",", 
   RowBox[{"dipole", "\[Rule]", "0.07447637331924106`"}], ",", 
   RowBox[{"layers", "\[Rule]", "27"}], ",", 
   RowBox[{"turns", "\[Rule]", "600"}], ",", 
   RowBox[{"wirediam", "\[Rule]", "0.00035999999999999997`"}], ",", 
   RowBox[{"coillen", "\[Rule]", "0.008`"}], ",", 
   RowBox[{"coilz1", "\[Rule]", 
    RowBox[{"-", "0.004`"}]}], ",", 
   RowBox[{"coilz2", "\[Rule]", "0.004`"}], ",", 
   RowBox[{"coilrad1", "\[Rule]", "0.009000000000000001`"}], ",", 
   RowBox[{"coilrad2", "\[Rule]", "0.01872`"}], ",", 
   RowBox[{"coildrad2max", "\[Rule]", "0.0245`"}], ",", 
   RowBox[{"coilturns", "\[Rule]", "600"}], ",", 
   RowBox[{"coilsigma", "\[Rule]", "7.716049382716049`*^6"}], ",", 
   RowBox[{"magposactpromec", "\[Rule]", "0.0074`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.661139702279356*^9, 3.6612185348155727`*^9, 
  3.66122645393834*^9, 3.661229128345133*^9, 3.661231644665721*^9, 
  3.662245813209215*^9, 3.662327577750882*^9, 3.662330890604761*^9, 
  3.662337498117524*^9, 3.664592535044819*^9, 3.6653735506771307`*^9, 
  3.682482698084114*^9, 3.682561479999387*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"optdata", "[", "KPR", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.12880088453359687`"}], ",", 
      RowBox[{"{", 
       RowBox[{"z", "\[Rule]", "0.00671881252925762`"}], "}"}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Minimize", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"fz", "[", 
          RowBox[{"KPR", ",", "z"}], "]"}]}], ",", " ", 
        RowBox[{"0.006", " ", "<", " ", "z", " ", "<", " ", "0.012"}]}], 
       "}"}], ",", " ", "z"}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.478970745257534*^9, 3.478970764425056*^9}, 
   3.4796619224973173`*^9, {3.480244382554545*^9, 3.480244405961742*^9}, {
   3.4819408015577917`*^9, 3.4819408027090397`*^9}, {3.481940979763582*^9, 
   3.481940981746011*^9}, {3.481941548420309*^9, 3.481941559738948*^9}, {
   3.630208310775996*^9, 3.6302083160559387`*^9}, 3.6302102241338043`*^9, {
   3.630210607856474*^9, 3.6302106082793016`*^9}, 3.630361338897683*^9, {
   3.631834266175609*^9, 3.631834266847229*^9}, {3.66096489538389*^9, 
   3.660964895912998*^9}, 3.662330695753613*^9, {3.682481866550468*^9, 
   3.682481867216487*^9}, {3.682561466230307*^9, 3.682561466236259*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.1288008845335968`"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", "\[Rule]", "0.006718812869426184`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.630361340786025*^9, 3.6303616440690804`*^9, 
  3.6303619723403873`*^9, 3.6304700727391043`*^9, 3.631828016987249*^9, 
  3.6318286721706467`*^9, 3.631835182694659*^9, 3.6318395262620773`*^9, 
  3.6338315632012978`*^9, 3.633834180737639*^9, 3.649109165341728*^9, 
  3.660965554607506*^9, 3.6609695597456284`*^9, 3.661056622460845*^9, 
  3.6611192766059313`*^9, 3.661130928174697*^9, 3.661139867081956*^9, 
  3.661218696462347*^9, 3.661231801590312*^9, 3.662245981319335*^9, 
  3.662327742862506*^9, 3.662331040771633*^9, 3.662337654997511*^9, 
  3.664592697381234*^9, 3.665373711649935*^9, 3.682482840589034*^9, 
  3.6825616241674023`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fzi", "[", "KPR", "]"}], " ", "=", " ", 
  RowBox[{"FunctionInterpolation", "[", 
   RowBox[{
    RowBox[{"fz", "[", 
     RowBox[{"KPR", ",", "z"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "0", ",", "0.013"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.661121231903079*^9, 3.661121302673418*^9}, {
   3.66112135471321*^9, 3.661121364047564*^9}, 3.661121573023286*^9, {
   3.661121981470016*^9, 3.661121984145525*^9}, {3.661122016670216*^9, 
   3.6611220263968563`*^9}, {3.661122422824706*^9, 3.661122440665392*^9}, {
   3.6611225257271423`*^9, 3.6611225561384287`*^9}, 3.661122943936385*^9, 
   3.661124072219921*^9, 3.661124107400278*^9, {3.66114125831656*^9, 
   3.6611412583250227`*^9}, {3.661218342420212*^9, 3.6612184052787037`*^9}, {
   3.661218496917082*^9, 3.661218498643498*^9}, {3.661218568716762*^9, 
   3.661218572408393*^9}, 3.6612187337963448`*^9, {3.661218857797194*^9, 
   3.6612188746198997`*^9}, 3.662246038931663*^9, {3.662246606578101*^9, 
   3.6622466290281973`*^9}, {3.662262652702455*^9, 3.662262654374928*^9}, {
   3.682481867992078*^9, 3.682481868617978*^9}, {3.6825614662417316`*^9, 
   3.682561466248541*^9}}],

Cell[BoxData[
 TagBox[
  TemplateBox[{RowBox[{
      StyleBox[
       TagBox["InterpolatingFunction", "SummaryHead"], 
       "NonInterpretableSummary"], 
      StyleBox["[", "NonInterpretableSummary"], 
      DynamicModuleBox[{Typeset`open$$ = False}, 
       PanelBox[
        PaneSelectorBox[{False -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquarePlusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = True), Appearance -> None,
                 Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{{{}, {}, {
                   Directive[
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1]], 
                   LineBox[CompressedData["
1:eJwVkHswGwYAh3OK7dqcU416LBrP1abOO1OS/s48m7AVrdaNcgjzmJI21SAV
SsQjaqtnp2zUjqvHcSQSIel2jOmmXJd5VLXUKk1VW07Hic3++N133933188q
7lIYS4dAIND29z83G6QUXtBrOoHAv3p379SphXamfHPUAYl3yo9ZJueiryVJ
R+8dDa9IsaEp5SIYZm0HVvL9MSCtqJheqkawhuY9lRAM9c/HRNnjDeDaX2CF
rIeC+rp5OMW4GR5eCUkRaefwfMUixCarFT/5CSU27pGYIQs1y8R23KZq7jBe
RmFNu2WyyO2A3PfMIsM5FrycuHrJrW4IVsU104ZxEF4o+PRecg9G5AGpaVPx
8NUbjFx/0osR3a2DbiUsWEQ+ufmI3gfL0z1TXyUmgaVkyTra+rEur+6vsUnG
pvGj5e/UYpg5CpRu+qnId3XkM1wGoHu4pka7mIazz0hkTbQUCbaTJbP16XAY
5Qe+jJPB0PzgdBktA81Hwzwyvx5E28n7a27kTGyshDsQg+RIP79HFhmwcdXh
/s6szRBIThM9ubtszKnsY1aeD4HTeOIcZ+4yZh/bhowVDuMAkUSkTFxBbUt5
dBhZgeDDlVNT9zjIrptVjVUrwHn4/a658CpqB9JGuTsKPBA5ehtnZeHhP6Zt
f36ixMJSuNA04hpYx5clqQwlPqIS1A8Cueit6jJySVDCy5fWbeKRjd/pu4ci
rihxZJVYmGqUgzozOvt2jhLmZfFpGTq5WORt6bD3fX7ki/jrS7kw/MVrzmO/
58nGFdbDPLRWRxU+S1QiuPM3p2sd16GxOq1Whyqh+iy2S1Wahz8CLnJ6PZUI
eEq33KDz4Xz07VKXiRJ5b6oz8rr4MCn1Kll7oUDbQv+GipwPyrdkbk29Aqvj
dYTiqnzExETPUGgK6OmMVnnrFkBwOYcytjAMz5Pi3iBeAXTfhTc0ZQwjKiT9
gNVmAUbtDGJ9/h1CdGfGvDbuBs5flG1LK/f/JVLpbvM3MLUsPcQgDSFF4v/x
N8xCkIw/PFLQIMeXsPicLS3ECaaPnYutHMxRyYtJ5yK0b5urdxoHYVvfQHL9
oQitK90VYstBkFL9Jl6ZCuDrtGdkXSPDpllfH/umAArXOvYqUYYeUrqdVisA
Q6E/6V4uRZGBhvKUU4ymykZ3OkEK6tneH39dKUbn8TMO1bwB7NXROj+IEWKy
xdwv4I0EYlmFxkglBD9Bv8wxUQKmvUOPtX8JbgX7iEz/FuN9VSmhbKgEd0Wb
XGaUGPwQ97/eO5bCk5lZO/O4H2+rqJeGm0qhZQlSgqL78R9H8MO7
                    
                    "]]}}}, {}, {}}, {
               DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
                AxesOrigin -> {0, 0}, 
                FrameTicks -> {{None, None}, {None, None}}, 
                GridLines -> {None, None}, DisplayFunction -> Identity, 
                PlotRangePadding -> {{
                   Scaled[0.1], 
                   Scaled[0.1]}, {
                   Scaled[0.1], 
                   Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
                All, DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                Directive[
                  Opacity[0.5], 
                  Thickness[Tiny], 
                  RGBColor[0.368417, 0.506779, 0.709798]], 
                FrameTicks -> {{None, None}, {None, None}}, 
                GridLines -> {None, None}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 
                Dynamic[{
                  Automatic, 3.5 CurrentValue["FontCapHeight"]/
                   AbsoluteCurrentValue[Magnification]}], 
                Method -> {
                 "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
                  AbsolutePointSize[6], "ScalingFunctions" -> None, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (
                    Part[{{Identity, Identity}, {Identity, Identity}}, 1, 
                    2][#]& )[
                    Part[#, 1]], 
                    (
                    Part[{{Identity, Identity}, {Identity, Identity}}, 2, 
                    2][#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 
                    2][#]& )[
                    Part[#, 1]], 
                    (
                    Part[{{Identity, Identity}, {Identity, Identity}}, 2, 
                    2][#]& )[
                    Part[#, 2]]}& )}}, 
                PlotRange -> {{0., 0.013}, {0., 0.12877207353649278`}}, 
                PlotRangeClipping -> True, PlotRangePadding -> {{
                   Scaled[0.1], 
                   Scaled[0.1]}, {
                   Scaled[0.1], 
                   Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"scalar\"", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}], True -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquareMinusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                None, Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{{{}, {}, {
                   Directive[
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1]], 
                   LineBox[CompressedData["
1:eJwVkHswGwYAh3OK7dqcU416LBrP1abOO1OS/s48m7AVrdaNcgjzmJI21SAV
SsQjaqtnp2zUjqvHcSQSIel2jOmmXJd5VLXUKk1VW07Hic3++N133933188q
7lIYS4dAIND29z83G6QUXtBrOoHAv3p379SphXamfHPUAYl3yo9ZJueiryVJ
R+8dDa9IsaEp5SIYZm0HVvL9MSCtqJheqkawhuY9lRAM9c/HRNnjDeDaX2CF
rIeC+rp5OMW4GR5eCUkRaefwfMUixCarFT/5CSU27pGYIQs1y8R23KZq7jBe
RmFNu2WyyO2A3PfMIsM5FrycuHrJrW4IVsU104ZxEF4o+PRecg9G5AGpaVPx
8NUbjFx/0osR3a2DbiUsWEQ+ufmI3gfL0z1TXyUmgaVkyTra+rEur+6vsUnG
pvGj5e/UYpg5CpRu+qnId3XkM1wGoHu4pka7mIazz0hkTbQUCbaTJbP16XAY
5Qe+jJPB0PzgdBktA81Hwzwyvx5E28n7a27kTGyshDsQg+RIP79HFhmwcdXh
/s6szRBIThM9ubtszKnsY1aeD4HTeOIcZ+4yZh/bhowVDuMAkUSkTFxBbUt5
dBhZgeDDlVNT9zjIrptVjVUrwHn4/a658CpqB9JGuTsKPBA5ehtnZeHhP6Zt
f36ixMJSuNA04hpYx5clqQwlPqIS1A8Cueit6jJySVDCy5fWbeKRjd/pu4ci
rihxZJVYmGqUgzozOvt2jhLmZfFpGTq5WORt6bD3fX7ki/jrS7kw/MVrzmO/
58nGFdbDPLRWRxU+S1QiuPM3p2sd16GxOq1Whyqh+iy2S1Wahz8CLnJ6PZUI
eEq33KDz4Xz07VKXiRJ5b6oz8rr4MCn1Kll7oUDbQv+GipwPyrdkbk29Aqvj
dYTiqnzExETPUGgK6OmMVnnrFkBwOYcytjAMz5Pi3iBeAXTfhTc0ZQwjKiT9
gNVmAUbtDGJ9/h1CdGfGvDbuBs5flG1LK/f/JVLpbvM3MLUsPcQgDSFF4v/x
N8xCkIw/PFLQIMeXsPicLS3ECaaPnYutHMxRyYtJ5yK0b5urdxoHYVvfQHL9
oQitK90VYstBkFL9Jl6ZCuDrtGdkXSPDpllfH/umAArXOvYqUYYeUrqdVisA
Q6E/6V4uRZGBhvKUU4ymykZ3OkEK6tneH39dKUbn8TMO1bwB7NXROj+IEWKy
xdwv4I0EYlmFxkglBD9Bv8wxUQKmvUOPtX8JbgX7iEz/FuN9VSmhbKgEd0Wb
XGaUGPwQ97/eO5bCk5lZO/O4H2+rqJeGm0qhZQlSgqL78R9H8MO7
                    
                    "]]}}}, {}, {}}, {
               DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
                AxesOrigin -> {0, 0}, 
                FrameTicks -> {{None, None}, {None, None}}, 
                GridLines -> {None, None}, DisplayFunction -> Identity, 
                PlotRangePadding -> {{
                   Scaled[0.1], 
                   Scaled[0.1]}, {
                   Scaled[0.1], 
                   Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
                All, DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                Directive[
                  Opacity[0.5], 
                  Thickness[Tiny], 
                  RGBColor[0.368417, 0.506779, 0.709798]], 
                FrameTicks -> {{None, None}, {None, None}}, 
                GridLines -> {None, None}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 
                Dynamic[{
                  Automatic, 3.5 CurrentValue["FontCapHeight"]/
                   AbsoluteCurrentValue[Magnification]}], 
                Method -> {
                 "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
                  AbsolutePointSize[6], "ScalingFunctions" -> None, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (
                    Part[{{Identity, Identity}, {Identity, Identity}}, 1, 
                    2][#]& )[
                    Part[#, 1]], 
                    (
                    Part[{{Identity, Identity}, {Identity, Identity}}, 2, 
                    2][#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (
                    Part[{{Identity, Identity}, {Identity, Identity}}, 1, 
                    2][#]& )[
                    Part[#, 1]], 
                    (
                    Part[{{Identity, Identity}, {Identity, Identity}}, 2, 
                    2][#]& )[
                    Part[#, 2]]}& )}}, 
                PlotRange -> {{0., 0.013}, {0., 0.12877207353649278`}}, 
                PlotRangeClipping -> True, PlotRangePadding -> {{
                   Scaled[0.1], 
                   Scaled[0.1]}, {
                   Scaled[0.1], 
                   Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"scalar\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["3", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"Hermite\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["False", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}]}, 
         Dynamic[Typeset`open$$], ImageSize -> Automatic], BaselinePosition -> 
        Baseline], DynamicModuleValues :> {}], 
      StyleBox["]", "NonInterpretableSummary"]}]},
   "CopyTag",
   DisplayFunction->(#& ),
   InterpretationFunction->("InterpolatingFunction[{{0., 0.013}}, <>]"& )],
  False,
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.662262660945747*^9, 3.6623277481278048`*^9, 
  3.662331045843033*^9, 3.662337660257972*^9, 3.664592702657907*^9, 
  3.665373716737364*^9, 3.682482845232329*^9, 3.6825616285864477`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"plot", "[", "KPR", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    GraphicsBox[{{{}, {}, 
       {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
        LineBox[CompressedData["
1:eJwV1nk4Vd0XB3BJGZIhEl5NKoQGTSrDl4oXoZSpkrlCyHS59557iVBd8qNQ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         "]]}}, {}, {}},
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->{True, True},
     AxesLabel->{None, None},
     AxesOrigin->{0, 0},
     DisplayFunction->Identity,
     Frame->{{False, False}, {False, False}},
     FrameLabel->{{None, None}, {None, None}},
     FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
     GridLines->{None, None},
     GridLinesStyle->Directive[
       GrayLevel[0.5, 0.4]],
     ImagePadding->All,
     Method->{
      "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
       AbsolutePointSize[6], "ScalingFunctions" -> None, 
       "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
            Part[#, 1]], 
           (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
            Part[#, 1]], 
           (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
            Part[#, 2]]}& )}},
     PlotRange->{{0, 0.013}, {0., 0.12880088237061282`}},
     PlotRangeClipping->True,
     PlotRangePadding->{{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}},
     Ticks->{Automatic, Automatic}], ",", "\[IndentingNewLine]", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"fz", "[", 
       RowBox[{"KPR", ",", "p"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"p", ",", "0", ",", "0.013"}], "}"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", "Black"}]}], "]"}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.4789618100364523`*^9, 3.478961850760915*^9}, 
   3.478969868098156*^9, 3.4789702271107073`*^9, {3.478971402742322*^9, 
   3.478971407269801*^9}, {3.478973436528585*^9, 3.4789734559838*^9}, {
   3.4794970273251*^9, 3.4794970280748262`*^9}, {3.479497850691868*^9, 
   3.479497851721608*^9}, {3.4802445496159487`*^9, 3.4802445841180058`*^9}, {
   3.4802446656757193`*^9, 3.4802446687524443`*^9}, {3.481940803363203*^9, 
   3.481940804034131*^9}, {3.481941063760079*^9, 3.4819410664063997`*^9}, {
   3.481941556057631*^9, 3.4819415664906*^9}, {3.630208312322345*^9, 
   3.63020831448879*^9}, 3.630209982122305*^9, 3.630210040824745*^9, {
   3.630210608691247*^9, 3.6302106091463537`*^9}, 3.6302116072117853`*^9, 
   3.6302119179137897`*^9, 3.6304701238527927`*^9, 3.631834820615905*^9, 
   3.649109628464219*^9, {3.649110363868889*^9, 3.649110366770886*^9}, {
   3.649110567151823*^9, 3.649110570373554*^9}, {3.661123689182354*^9, 
   3.661123723132988*^9}, 3.661123839830414*^9, {3.661123888550177*^9, 
   3.6611238924215937`*^9}, {3.661123959516914*^9, 3.661123970823284*^9}, {
   3.661124020120494*^9, 3.661124020504492*^9}, {3.661124084594274*^9, 
   3.66112408490854*^9}, {3.661124132485323*^9, 3.661124133744603*^9}, {
   3.661127129389042*^9, 3.6611271300441732`*^9}, {3.6611285421516657`*^9, 
   3.6611285486416283`*^9}, 3.661139350752645*^9, {3.661141258332346*^9, 
   3.661141258345943*^9}, {3.661218500125923*^9, 3.661218503251073*^9}, {
   3.662246691379507*^9, 3.662246718565319*^9}, {3.662246863148045*^9, 
   3.662246890689905*^9}, {3.662247012437896*^9, 3.6622470129339113`*^9}, {
   3.66232743322059*^9, 3.6623274340219593`*^9}, 3.662327815174901*^9, {
   3.66233080382358*^9, 3.662330813138308*^9}, {3.682481869260326*^9, 
   3.682481869925934*^9}, 3.682560438340075*^9, {3.682561466258531*^9, 
   3.6825614662629633`*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
     LineBox[CompressedData["
1:eJwV1nk4Vd0XB3BJGZIhEl5NKoQGTSrDl4oXoZSpkrlCyHS59557iVBd8qNQ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      "]]}}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 0.013}, {0., 0.12880088237061282`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.649109686790821*^9, 3.6491103787345247`*^9, 3.660965322933999*^9, 
   3.6609691450694323`*^9, 3.6610562264789333`*^9, 3.661118658026022*^9, 
   3.661119055121579*^9, {3.661123710650861*^9, 3.661123724289307*^9}, 
   3.661123847867857*^9, 3.661123892991621*^9, {3.661123960098845*^9, 
   3.66112397157833*^9}, 3.661124011481043*^9, 3.661124062306964*^9, 
   3.661124248993616*^9, 3.661124781109477*^9, 3.661127174324749*^9, 
   3.661128593139056*^9, 3.661139696344545*^9, 3.661205468105528*^9, 
   3.661218317171567*^9, 3.6612184134232492`*^9, 3.6612187208062153`*^9, 
   3.6612318252337723`*^9, 3.662246007088282*^9, 3.662246745054916*^9, 
   3.6622468830851097`*^9, 3.662246915217906*^9, 3.6623277730276623`*^9, 
   3.66233106855897*^9, 3.662337683983321*^9, 3.6645927268196583`*^9, 
   3.665373740668016*^9, 3.682482866634948*^9, 3.6825616505435038`*^9}]
}, Open  ]],

Cell["Check interpolated plot (red) coincides", "Text",
 CellChangeTimes->{{3.662246974984686*^9, 3.662247002606237*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"plot", "[", "KPR", "]"}], ",", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"fzi", "[", "KPR", "]"}], "[", "p", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"p", ",", "0", ",", "0.013"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.66224692523505*^9, 3.662246970049139*^9}, {
  3.682481870548046*^9, 3.6824818711661797`*^9}, {3.6825614662687483`*^9, 
  3.682561466275182*^9}}],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
      LineBox[CompressedData["
1:eJwV1nk4Vd0XB3BJGZIhEl5NKoQGTSrDl4oXoZSpkrlCyHS59557iVBd8qNQ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       "]]}}, {}, {}}, {{{}, {}, 
     {RGBColor[1, 0, 0], AbsoluteThickness[1.6], Opacity[1.], 
      LineBox[CompressedData["
1:eJwV1nk8VVsbB3AhZMhYhuiiDGlA9VaKflGEK2XuVuZkqITjHM7ZBxmiDnVT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       "]]}}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 0.013}, {0., 0.12880088237061282`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.662246962166266*^9, 3.66224697090763*^9}, 
   3.6623277731491947`*^9, 3.662331068933206*^9, 3.662337684317403*^9, 
   3.6645927270112133`*^9, 3.66537374074555*^9, 3.68248286671392*^9, 
   3.682561650602597*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"zmax", "[", "KPR", "]"}], "  ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{
    RowBox[{"optdata", "[", "KPR", "]"}], " ", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.478970786649661*^9, 3.478970802864567*^9}, {
   3.4796619220112333`*^9, 3.4796619454416037`*^9}, 3.479665671740583*^9, {
   3.48194080448247*^9, 3.481940804971867*^9}, {3.630208319233528*^9, 
   3.630208320862918*^9}, {3.630210609409204*^9, 3.6302106096880713`*^9}, {
   3.631834268382159*^9, 3.631834268966103*^9}, {3.660964897577401*^9, 
   3.6609648980982428`*^9}, {3.6824818719659777`*^9, 3.682481872423749*^9}, {
   3.682561466280718*^9, 3.6825614662875767`*^9}}],

Cell[BoxData["0.006718812869426184`"], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQA+KQpjXdc16/dFyUG2Mx481Lxxmm1slvgHRVmlDOOyDd
V36j8z2Qvu0kNBlE/39ZeoTz3UvHKOkVp58A6ZCHs3P7P7x0XPNepcTt40vH
A2Uu1SD61gOZzSDaKSPnPIjWPVjJ5Q6kK1Q3brPmfu0odHpRojDPa8eKhqen
QPQV5gtPQfRj87fpIkBaaZrYJEsg/Sz3xhsPIL1feuvmWCDddTW8ZhKQPmWk
3KbJD9S3juMGiD61jJFTF0hP+y6toQ/iX8y4+FvoteOGFTMk/gLpu3fXTJU3
ANqnFnZtj9trxwevv57dB6SPvb0V8BJIT5h28Cm7+2tHvflMM3mBdFlf9TdB
IL2VU6bEAki/EtG5ZQek5Vpf8Ol5vnaMCln2OxRI281YMD0cSM8W7LkUBaQj
Hj98tdz3taPW+xmuqv6vHTtiIsKO5792/Fcfcu4tkAYAvAjAkg==
  "]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"magposactpromec", "-", 
   RowBox[{"zmax", "[", "KPR", "]"}]}], "/.", 
  RowBox[{"vals", "[", "KPR", "]"}]}]], "Input",
 CellChangeTimes->{{3.631850926207306*^9, 3.631850980824053*^9}, {
   3.660964898627531*^9, 3.660964899139551*^9}, 3.661139095060607*^9, 
   3.6611392025561953`*^9, {3.682481873087632*^9, 3.682481873641712*^9}, {
   3.682561466293622*^9, 3.682561466299452*^9}}],

Cell[BoxData["0.0006811871305738163`"], "Output",
 CellChangeTimes->{{3.631850951545291*^9, 3.63185098135504*^9}, 
   3.63383156333751*^9, 3.63383418079591*^9, 3.649109165431679*^9, 
   3.660965554751844*^9, 3.660969583720545*^9, 3.66105664686804*^9, 
   3.6611192781065807`*^9, 3.6611309521076517`*^9, 3.661139891891814*^9, 
   3.661218720941321*^9, 3.661231825434506*^9, 3.662246007329948*^9, 
   3.662327773263053*^9, 3.662331069073143*^9, 3.662337684427704*^9, 
   3.6645927270899*^9, 3.665373740808846*^9, 3.68248286681973*^9, 
   3.682561650676546*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fmax", "[", "KPR", "]"}], "  ", "=", " ", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"optdata", "[", "KPR", "]"}], " ", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4789708091780043`*^9, 3.4789708248973703`*^9}, 
   3.479661922078005*^9, 3.4796619593447857`*^9, 3.479665787682528*^9, {
   3.481940805601218*^9, 3.481940806091435*^9}, {3.630208322616778*^9, 
   3.6302083244414253`*^9}, {3.63021060995541*^9, 3.63021061023507*^9}, {
   3.631834269559742*^9, 3.6318342700157347`*^9}, {3.660964899643673*^9, 
   3.660964900149706*^9}, {3.682481874186064*^9, 3.682481874689777*^9}, {
   3.682561466304851*^9, 3.6825614663114758`*^9}}],

Cell[BoxData["0.1288008845335968`"], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQA+KWPeu757x+6fjqVazFjDcvHYUybZLfAGlvBZGcd0Ca
KeVm53sgHccmNhlE2xwsO8L57qVjacnK00+AdOCkubn9H146Mm9SK3H7+NLx
yXfXahAtsEF2M4helpZ3HkS39VdzuQPp+Psbt1lzv3ZU+7UkUZjnteOEl99O
gejdWy88BdFOie/TRYD03WUSkyyB9I6mW288gHTHvG2bY4F06/nImklA+sN5
lTZN/teOZdO4boBo5hgmTl0g/fi9rIY+kJaKz7n4W+i14xK/WRJ/gfSpH+um
yhu8dny0OvLaHjeg/uYfZ/cBacWFdwJeAunbhy4/ZXd/7WjqzDKTF0hfOVj7
TRBI92oqlFgAaQNmg1t2QFpP8Q2fnudrR4tFq36HAum8nCXTw4G0QUz/pSgg
fe/741fLfV87njgz21XV/7XjNP+YsOP5QHccCjv3FkgDADSgv2U=
  "]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"deriv2", "[", "KPR", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"-", "2"}], "*", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"fzi", "[", "KPR", "]"}], "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{"zmax", "[", "KPR", "]"}], ",", "2"}], "}"}]}], "]"}], 
      "]"}], ",", 
     RowBox[{"z", "^", "2"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479660163969679*^9, 3.479660203608347*^9}, {
   3.479660334457396*^9, 3.479660335305067*^9}, {3.4796611591764927`*^9, 
   3.479661208701754*^9}, {3.479661250977075*^9, 3.479661305176928*^9}, {
   3.479661346153286*^9, 3.479661372928776*^9}, {3.479661851029785*^9, 
   3.479661859051705*^9}, 3.4796619463263597`*^9, 3.479662725037703*^9, 
   3.479665672610339*^9, {3.481940806550991*^9, 3.48194080744361*^9}, {
   3.630208325888165*^9, 3.6302083289679956`*^9}, {3.630210610460196*^9, 
   3.630210610874337*^9}, 3.6611229758725023`*^9, {3.6611412583941383`*^9, 
   3.6611412584082737`*^9}, {3.661141309779232*^9, 3.661141309788487*^9}, {
   3.661143055996151*^9, 3.661143061547195*^9}, {3.661143129145129*^9, 
   3.661143150309849*^9}, {3.661231154888709*^9, 3.661231159334008*^9}, 
   3.66123140853971*^9, {3.6612315267918673`*^9, 3.661231532575729*^9}, 
   3.662253434225093*^9, 3.662256174883844*^9, 3.662256454447321*^9, {
   3.6622576485489264`*^9, 3.6622576543643312`*^9}, {3.662259663815483*^9, 
   3.662259674101316*^9}, 3.662259713425989*^9, {3.662260002840063*^9, 
   3.662260003422638*^9}, {3.6824818757159758`*^9, 3.682481877767879*^9}, {
   3.682561466316862*^9, 3.682561466326223*^9}}],

Cell[BoxData["4723.921650343821`"], "Output",
 CellChangeTimes->{
  3.66123150538653*^9, 3.661231825570121*^9, 3.6622460074271603`*^9, 
   3.662246641563151*^9, 3.662255639636259*^9, 3.662256210598072*^9, 
   3.662256513985942*^9, {3.6622576493391542`*^9, 3.662257655351861*^9}, {
   3.6622596695441027`*^9, 3.662259674651012*^9}, 3.662259714075639*^9, 
   3.662260004808572*^9, 3.6623277733809*^9, 3.662331069205131*^9, 
   3.66233768452456*^9, 3.664592727161736*^9, 3.6653737409285507`*^9, 
   3.6824828669524612`*^9, 3.682561650742983*^9}]
}, Open  ]],

Cell["Check second derivative", "Text",
 CellChangeTimes->{{3.662247035240644*^9, 3.662247059134865*^9}}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"0.0067", ",", "0.00673"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.6622556122910337`*^9, 3.662255614424631*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"plot", "[", "KPR", "]"}], ",", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"fmax", "[", "KPR", "]"}], "-", 
      RowBox[{"0.5", "*", 
       RowBox[{"deriv2", "[", "KPR", "]"}], "*", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"p", "-", 
          RowBox[{"zmax", "[", "KPR", "]"}]}], ")"}], "^", "2"}]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"p", ",", "0.", ",", "0.013"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Black", ",", "Red"}], "}"}]}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.66224692523505*^9, 3.662246970049139*^9}, {
   3.6622470798293657`*^9, 3.662247143593774*^9}, {3.66224749751495*^9, 
   3.6622475122269783`*^9}, {3.662247551586426*^9, 3.662247591202095*^9}, {
   3.662247623031026*^9, 3.662247763257119*^9}, {3.662251046755311*^9, 
   3.662251221801083*^9}, {3.662252973683614*^9, 3.6622530734486856`*^9}, {
   3.662253103864985*^9, 3.662253136327422*^9}, {3.662253167574163*^9, 
   3.6622532724867*^9}, 3.662253434242627*^9, {3.662255589372203*^9, 
   3.662255630288435*^9}, {3.662255669518676*^9, 3.6622556904937677`*^9}, {
   3.662255798233357*^9, 3.6622557992283154`*^9}, {3.662259719290337*^9, 
   3.662259728098154*^9}, {3.6622600085014467`*^9, 3.662260010294861*^9}, {
   3.662261295233617*^9, 3.662261300617079*^9}, {3.662327855032322*^9, 
   3.662327877406282*^9}, {3.682481879306047*^9, 3.6824818810999126`*^9}, {
   3.682561466331592*^9, 3.68256146634415*^9}}],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
      LineBox[CompressedData["
1:eJwV1nk4Vd0XB3BJGZIhEl5NKoQGTSrDl4oXoZSpkrlCyHS59557iVBd8qNQ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       "]]}}, {}, {}}, {{{}, {}, 
     {RGBColor[1, 0, 0], AbsoluteThickness[1.6], Opacity[1.], 
      LineBox[CompressedData["
1:eJwV1nk4lG8XB3CRCKGULRUqbfJLKVt8bUmFENFmi4qym2HmGYYJ1SRvyhJa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       "]]}}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 0.013}, {0., 0.12880088237061282`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.662247755756023*^9, 3.662247763826311*^9}, {
   3.662251055415514*^9, 3.6622512231798964`*^9}, {3.662252996577107*^9, 
   3.662253073828041*^9}, {3.662253104307506*^9, 3.6622531367553463`*^9}, {
   3.662253199030999*^9, 3.66225327329182*^9}, 3.662255592043687*^9, {
   3.662255630869121*^9, 3.662255671632409*^9}, 3.662255716290309*^9, 
   3.662255823726226*^9, 3.662259703266612*^9, 3.662259752969811*^9, 
   3.6622600344956617`*^9, 3.662261325288904*^9, 3.6623277986013813`*^9, 
   3.662328359102607*^9, 3.662331069317165*^9, 3.6623376845988894`*^9, 
   3.664592727213608*^9, 3.665373741030381*^9, 3.682482867043868*^9, 
   3.682561650788809*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"z95plus", "[", "KPR", "]"}], " ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{"FindRoot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"fz", "[", 
       RowBox[{"KPR", ",", "z"}], "]"}], "-", 
      RowBox[{"0.95", "*", 
       RowBox[{"fmax", "[", "KPR", "]"}]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", 
       RowBox[{
        RowBox[{"zmax", "[", "KPR", "]"}], "+", "0.001"}], ",", 
       RowBox[{"zmax", "[", "KPR", "]"}], ",", 
       RowBox[{
        RowBox[{"zmax", "[", "KPR", "]"}], "+", "0.005"}]}], "}"}]}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479658613425561*^9, 3.4796587501410933`*^9}, {
   3.479658790462825*^9, 3.4796587993088913`*^9}, {3.479658852062684*^9, 
   3.479658891629363*^9}, {3.4796589431729183`*^9, 3.479658948798299*^9}, {
   3.479658987032153*^9, 3.47965898990287*^9}, {3.479659310386307*^9, 
   3.4796593125701933`*^9}, {3.479661624172262*^9, 3.479661679901505*^9}, {
   3.479661945541445*^9, 3.4796619594445953`*^9}, {3.4796656734658623`*^9, 
   3.479665674680963*^9}, 3.47966578778349*^9, {3.481940808072547*^9, 
   3.4819408112927933`*^9}, {3.630208331202548*^9, 3.630208340512887*^9}, {
   3.6302106111156588`*^9, 3.630210612620454*^9}, {3.631834272292122*^9, 
   3.631834275423791*^9}, {3.660964902295938*^9, 3.660964904267434*^9}, 
   3.6623341356030903`*^9, {3.682481882141803*^9, 3.682481884817882*^9}, {
   3.682561466349937*^9, 3.682561466369788*^9}}],

Cell[BoxData["0.008529888500699315`"], "Output",
 CellChangeTimes->{{3.479659290207419*^9, 3.4796593177022877`*^9}, {
   3.479661644377719*^9, 3.4796616514833097`*^9}, 3.479661686065053*^9, 
   3.4796634593803263`*^9, 3.479665745824663*^9, 3.4796658197389708`*^9, 
   3.480243751933235*^9, 3.480692320796873*^9, 3.4815660640155077`*^9, 
   3.4819408973674994`*^9, 3.481940954361327*^9, 3.481941402301373*^9, 
   3.481941628781619*^9, 3.481942101498692*^9, 3.629768118581479*^9, 
   3.630209825967379*^9, 3.63021064809335*^9, 3.630210863735273*^9, 
   3.6302119044786863`*^9, 3.630288029600463*^9, 3.630319474859651*^9, 
   3.630362016214836*^9, 3.63047011744707*^9, 3.631828018334545*^9, 
   3.631828673603425*^9, 3.631835209527664*^9, 3.631839554443227*^9, 
   3.6338315761916437`*^9, 3.633834181637607*^9, 3.649109166248088*^9, 
   3.6609655556857033`*^9, 3.660969585228065*^9, 3.661056648356412*^9, 
   3.661119278891127*^9, 3.6611309535044317`*^9, 3.661139893341815*^9, 
   3.661218722362886*^9, 3.661231826701318*^9, 3.662246008600046*^9, 
   3.66232780003985*^9, 3.662331070418768*^9, 3.662337363887047*^9, 
   3.6623376857576933`*^9, 3.6645927283914137`*^9, 3.6653737421868773`*^9, 
   3.682482868057333*^9, 3.682561651839567*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"z95minus", "[", "KPR", "]"}], " ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{"FindRoot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"fz", "[", 
       RowBox[{"KPR", ",", "z"}], "]"}], "-", 
      RowBox[{"0.95", "*", 
       RowBox[{"fmax", "[", "KPR", "]"}]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", 
       RowBox[{
        RowBox[{"zmax", "[", "KPR", "]"}], "-", "0.001"}], ",", 
       RowBox[{
        RowBox[{"zmax", "[", "KPR", "]"}], "-", "0.005"}], ",", 
       RowBox[{"zmax", "[", "KPR", "]"}]}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479658613425561*^9, 3.4796587501410933`*^9}, {
   3.479658790462825*^9, 3.4796587993088913`*^9}, {3.479658852062684*^9, 
   3.479658891629363*^9}, {3.4796589431729183`*^9, 3.479658948798299*^9}, {
   3.479658997678957*^9, 3.4796590027188377`*^9}, {3.479659318794853*^9, 
   3.479659344898431*^9}, {3.479661657421668*^9, 3.4796616780054293`*^9}, {
   3.479661945775414*^9, 3.479661959545474*^9}, {3.479665675209929*^9, 
   3.479665676278386*^9}, 3.4796657878831253`*^9, {3.481940812147341*^9, 
   3.481940829419257*^9}, {3.6302083429611607`*^9, 3.6302083515364437`*^9}, {
   3.630210612999134*^9, 3.630210615553306*^9}, {3.6318342761199827`*^9, 
   3.631834277785796*^9}, {3.660964904795537*^9, 3.660964907383277*^9}, 
   3.662334135620826*^9, {3.682481885425557*^9, 3.6824818879814262`*^9}, {
   3.682561466376143*^9, 3.682561466395314*^9}}],

Cell[BoxData["0.005168826141405982`"], "Output",
 CellChangeTimes->{
  3.479659290545846*^9, {3.479659322545879*^9, 3.479659348979048*^9}, {
   3.4796616661527233`*^9, 3.479661689555737*^9}, 3.479663462870864*^9, 
   3.479665749329587*^9, 3.479665823257647*^9, 3.480243756605932*^9, 
   3.480692324819867*^9, 3.481566067504561*^9, 3.4819408974084797`*^9, 
   3.481940954404307*^9, 3.481941404076367*^9, 3.481941630539411*^9, 
   3.481942103389555*^9, 3.629768120026389*^9, 3.630209826676588*^9, 
   3.630210648265239*^9, 3.630210865289218*^9, 3.6302119056902*^9, 
   3.630288030116592*^9, 3.630319475441311*^9, 3.630362019145561*^9, 
   3.6304701204629717`*^9, 3.631828019522635*^9, 3.631828674839793*^9, 
   3.631835211501787*^9, 3.63183955652999*^9, 3.6338315764567127`*^9, 
   3.633834200417728*^9, 3.649109185050705*^9, 3.6609655738717422`*^9, 
   3.6609695873164682`*^9, 3.6610566503171988`*^9, 3.6611192790656967`*^9, 
   3.661130955412754*^9, 3.661139895338929*^9, 3.661218724269143*^9, 
   3.66123182866267*^9, 3.662246010719604*^9, 3.6623278022295628`*^9, 
   3.662331072504764*^9, 3.662337366066951*^9, 3.662337687860222*^9, 
   3.6645927304701157`*^9, 3.6653737441304703`*^9, 3.682482869836278*^9, 
   3.682561653559126*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"plot", "[", "KPR", "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Graphics", "[", 
    RowBox[{"Line", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"zmax", "[", "KPR", "]"}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"zmax", "[", "KPR", "]"}], ",", 
         RowBox[{"1.1", "*", 
          RowBox[{"fmax", "[", "KPR", "]"}]}]}], "}"}]}], "}"}], "]"}], "]"}],
    ",", "\[IndentingNewLine]", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{"Red", ",", 
      RowBox[{"Line", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"magposactpromec", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"magposactpromec", ",", 
            RowBox[{"1.1", "*", 
             RowBox[{"fmax", "[", "KPR", "]"}]}]}], "}"}]}], "}"}], "/.", 
        RowBox[{"vals", "[", "KPR", "]"}]}], "]"}]}], "}"}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{"Gray", ",", 
      RowBox[{"Line", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"z95minus", "[", "KPR", "]"}], ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"z95minus", "[", "KPR", "]"}], ",", 
            RowBox[{"1.1", "*", 
             RowBox[{"fmax", "[", "KPR", "]"}]}]}], "}"}]}], "}"}], "/.", 
        RowBox[{"vals", "[", "KPR", "]"}]}], "]"}]}], "}"}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{"Gray", ",", 
      RowBox[{"Line", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"z95plus", "[", "KPR", "]"}], ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"z95plus", "[", "KPR", "]"}], ",", 
            RowBox[{"1.1", "*", 
             RowBox[{"fmax", "[", "KPR", "]"}]}]}], "}"}]}], "}"}], "/.", 
        RowBox[{"vals", "[", "KPR", "]"}]}], "]"}]}], "}"}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<z (m)\>\"", ",", "\"\<F (N/A)\>\""}], "}"}]}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.453823397414776*^9, 3.453823397824687*^9}, {
   3.453838538440839*^9, 3.453838572806719*^9}, 3.463844247723119*^9, 
   3.478894943196905*^9, 3.4788950132010527`*^9, {3.478961709433363*^9, 
   3.47896175216029*^9}, {3.478961842569364*^9, 3.478961894377494*^9}, {
   3.4789619830038633`*^9, 3.478961984506156*^9}, {3.4789699280628653`*^9, 
   3.478969982243393*^9}, {3.478970021389124*^9, 3.478970165180615*^9}, {
   3.478970224319232*^9, 3.478970261501657*^9}, {3.4789703108875017`*^9, 
   3.478970348344078*^9}, 3.478970398020482*^9, {3.478970871122594*^9, 
   3.47897087265033*^9}, {3.478971414854863*^9, 3.4789714317583723`*^9}, {
   3.4789723334965277`*^9, 3.4789723911200447`*^9}, {3.478973525233735*^9, 
   3.47897352833882*^9}, {3.479495227181163*^9, 3.4794952662789087`*^9}, {
   3.4794954131043873`*^9, 3.4794954161349077`*^9}, {3.479497883443406*^9, 
   3.479497887306903*^9}, {3.4794980354692507`*^9, 3.479498036795588*^9}, 
   3.4794982488155937`*^9, {3.479662131489229*^9, 3.479662133377276*^9}, 
   3.479665540471899*^9, {3.4802459792714577`*^9, 3.480245981573744*^9}, {
   3.4802525542284737`*^9, 3.4802525884311867`*^9}, {3.48194087775911*^9, 
   3.481940886937986*^9}, 3.630208353429995*^9, 3.6302106162586517`*^9, 
   3.631834278469103*^9, {3.631835050283194*^9, 3.631835119871463*^9}, {
   3.631838204428006*^9, 3.631838423237857*^9}, {3.66096490787176*^9, 
   3.6609649094976053`*^9}, {3.661139095070483*^9, 3.661139095077957*^9}, {
   3.661139202563195*^9, 3.6611392025683517`*^9}, {3.662332549865168*^9, 
   3.6623325883346243`*^9}, {3.662334135638215*^9, 3.662334135669765*^9}, {
   3.6824818894471817`*^9, 3.682481892683713*^9}, {3.6825604781551247`*^9, 
   3.682560485010635*^9}, {3.682561466400958*^9, 3.682561466465889*^9}}],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
      LineBox[CompressedData["
1:eJwV1nk4Vd0XB3BJGZIhEl5NKoQGTSrDl4oXoZSpkrlCyHS59557iVBd8qNQ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       "]]}}, {}, {}}, 
   LineBox[{{0.006718812869426184, 0}, {0.006718812869426184, 
     0.1416809729869565}}], 
   {RGBColor[1, 0, 0], 
    LineBox[{{0.0074, 0}, {0.0074, 0.1416809729869565}}]}, 
   {GrayLevel[0.5], 
    LineBox[{{0.005168826141405982, 0}, {0.005168826141405982, 
      0.1416809729869565}}]}, 
   {GrayLevel[0.5], 
    LineBox[{{0.008529888500699315, 0}, {0.008529888500699315, 
      0.1416809729869565}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"z (m)\"", TraditionalForm], 
    FormBox["\"F (N/A)\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 0.013}, {0., 0.12880088237061282`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.6318384165109577`*^9, 3.6318384237975817`*^9}, 
   3.631839267885446*^9, 3.631839556562364*^9, 3.631845627638177*^9, 
   3.631850423414908*^9, 3.6338315765020027`*^9, 3.633834200455875*^9, 
   3.649109185142632*^9, 3.660965573944757*^9, 3.6609695873712063`*^9, 
   3.6610566503558083`*^9, 3.661119279145019*^9, 3.6611309554464417`*^9, 
   3.661139895386891*^9, 3.661218724343892*^9, 3.66121888746214*^9, 
   3.661231828746014*^9, 3.662246010839802*^9, 3.6623278023820047`*^9, 
   3.662331072745317*^9, 3.6623325893693237`*^9, 3.662337687977683*^9, 
   3.662353663753284*^9, 3.6645927305311317`*^9, 3.665373744212297*^9, 
   3.682482869936767*^9, 3.6825604859791822`*^9, 3.682561653599627*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Coil calc for bKAGRA SR: \[CapitalOSlash]2 mm, 5 mm long", "Section",
 CellChangeTimes->{{3.453751016056313*^9, 3.453751037487228*^9}, 
   3.463844192181329*^9, {3.478894850822432*^9, 3.478894851717502*^9}, {
   3.4788951705281897`*^9, 3.4788951754720497`*^9}, {3.4819407269664*^9, 
   3.481940736973164*^9}, {3.6302077654764643`*^9, 3.6302077702623034`*^9}, {
   3.630210588958201*^9, 3.630210589517418*^9}, {3.6318342427598057`*^9, 
   3.6318342433832703`*^9}, {3.660964871657391*^9, 3.660964871911765*^9}, {
   3.6612263617840633`*^9, 3.661226376523999*^9}, 3.68248169002827*^9, {
   3.682481772487479*^9, 3.682481772982185*^9}, 3.682481934489442*^9, {
   3.682482249788019*^9, 3.682482250146654*^9}, 3.682482367850279*^9, 
   3.68248247180059*^9, {3.682561321148703*^9, 3.68256136674371*^9}}],

Cell[CellGroupData[{

Cell["\<\
bosemvalsKSR = Recurse[
\t{
\t\tkB->1.38 10^-23,
\t\tT->295,
\t\tg->9.8,
\t\tmu0->4 N[Pi] 10^-7,
\t\trhoeAl->2.65 10^-8,\t\t\t(* Resistivity of Al *)
\t\trhoepianowire->30 rhoeAl,\t(* Resistivity of P.W., GUESSTIMATE *)
\t\tsigmaeAu->2.67,\t\t\t\t(* Resistivity of Au paint, measured *)
\t\tmassSOS->0.25,\t\t\t\t(* Final design value *)
\t\tmassM->rhomM l N[Pi] a^2,
\t\tPi->N[Pi],
\t\trhomM->7400,\t\t\t\t(* Mass density of magnets *)
\t\tztube->0.0155,\t\t\t\t(* Separation for magnet to push its own weight, \
measured *)
\t\tzpickup->0.018-l,\t\t\t(* Separation for magnet to pull its own weight, \
measured *)
\t\tmasspullapart->0.060,\t\t(* Force (in kgf) to separate magnets *)
\t\t(* preferred value of small magnet dipole moment *)
\t\tmzpref->0.007945632135874319,
\t\t(* magnet moment per unit volume for magnet stuff, assumed the same for \
big and small, in M units: A/m *)
\t\tmz->mzpref/(lold*N[Pi]*aold^2),
\t\t(* magnet moment per unit volume for magnet stuff, in B units: T *)
\t\tmzB->mz*mu0, 
\t\tlold->0.003175,\t\t\t\t(* length of LIGO small magnets *)
\t\taold->0.0009525,\t\t\t(* radius of LIGO small magnets *)
\t\tl->0.005,\t\t\t\t(* length of magnets *)
\t\ta->0.001,\t\t\t\t(* radius of magnets *)
\t\tdipole -> mz*l*N[Pi]*a^2,
\t\tlayers -> 27, (* 10212-Gr.12-body BOSEM intermediate.pdf *)
\t\tturns -> 600, (* 10212-Gr.12-body BOSEM intermediate.pdf *)
\t\twirediam ->0.36*0.001, (* 10212-Gr.12-body BOSEM intermediate.pdf *)
\t\t(* coil length *)
\t\tcoillen->(11-3)*0.001,  (* 10212-Gr.12-body BOSEM intermediate.pdf *)
\t\t(* the ends of the coil relative to the centre of the coil *)
\t\tcoilz1->-coillen/2,
\t\tcoilz2->+coillen/2,
\t\t(* the inner and outer radii of the coil *)
\t\tcoilrad1->(18/2)*0.001, (* 10212-Gr.12-body BOSEM intermediate.pdf *)
\t\tcoilrad2->coilrad1+wirediam*layers, (* 10212-Gr.12-body BOSEM \
intermediate.pdf *)
\t\tcoildrad2max->(49/2)*0.001, (* 10212-Gr.12-body BOSEM intermediate.pdf *)
\t\t(* the number of turns *)
\t\tcoilturns->600, (* 10203-Gr.12-Osem intermediate mass.pdf *)
\t\tcoilsigma -> coilturns/((coilrad2 - coilrad1)*(coilz2 - coilz1)),
\t\tmagposactpromec->0.0074 (* Inventor, Promec, Fabian *)
\t}
]
vals[KSR] := bosemvalsKSR;\
\>", "Input",
 CellChangeTimes->{{3.453837228357688*^9, 3.453837230833909*^9}, {
   3.463844183252262*^9, 3.463844223147016*^9}, {3.478894862544446*^9, 
   3.4788948852377567`*^9}, {3.478894985619047*^9, 3.4788949913587503`*^9}, {
   3.4788950240972023`*^9, 3.478895025494358*^9}, {3.481940748223406*^9, 
   3.481940763510077*^9}, {3.6302077790327063`*^9, 3.630207779944365*^9}, {
   3.630208292557073*^9, 3.630208293170534*^9}, {3.6302085800514812`*^9, 
   3.630208649083247*^9}, {3.630209645346671*^9, 3.630209663817658*^9}, {
   3.630209701977907*^9, 3.6302097023837023`*^9}, 3.630209734594172*^9, 
   3.630210623319276*^9, {3.6302114423356447`*^9, 3.6302115422890863`*^9}, {
   3.630211579624671*^9, 3.630211581024807*^9}, {3.630211687932591*^9, 
   3.630211722300425*^9}, {3.6302984714100847`*^9, 3.630298473322809*^9}, {
   3.630361294367758*^9, 3.6303612947567253`*^9}, {3.6303613801867123`*^9, 
   3.6303613881298*^9}, {3.6318342637097387`*^9, 3.631834265518305*^9}, 
   3.631834943063822*^9, {3.631834997615004*^9, 3.6318350023087177`*^9}, {
   3.631839258309725*^9, 3.631839261092559*^9}, {3.631850413860784*^9, 
   3.631850414643579*^9}, {3.660964892951539*^9, 3.6609648945185223`*^9}, 
   3.661055741455657*^9, 3.661055781320374*^9, 3.661056067223044*^9, 
   3.661130760310165*^9, 3.661139095025859*^9, 3.661139202536747*^9, {
   3.6612264255469027`*^9, 3.66122645251295*^9}, {3.661229111429741*^9, 
   3.661229125569841*^9}, {3.682481723853467*^9, 3.6824817239256897`*^9}, {
   3.68248178078985*^9, 3.6824818115159492`*^9}, {3.68248199429735*^9, 
   3.682482029940184*^9}, {3.682482264461503*^9, 3.6824822851509542`*^9}, {
   3.682561517369851*^9, 3.682561517395466*^9}, {3.682623102346257*^9, 
   3.682623107436693*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"kB", "\[Rule]", "1.38`*^-23"}], ",", 
   RowBox[{"T", "\[Rule]", "295"}], ",", 
   RowBox[{"g", "\[Rule]", "9.8`"}], ",", 
   RowBox[{"mu0", "\[Rule]", "1.2566370614359173`*^-6"}], ",", 
   RowBox[{"rhoeAl", "\[Rule]", "2.65`*^-8"}], ",", 
   RowBox[{"rhoepianowire", "\[Rule]", "7.95`*^-7"}], ",", 
   RowBox[{"sigmaeAu", "\[Rule]", "2.67`"}], ",", 
   RowBox[{"massSOS", "\[Rule]", "0.25`"}], ",", 
   RowBox[{"massM", "\[Rule]", "0.00011623892818282234`"}], ",", 
   RowBox[{"\[Pi]", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"rhomM", "\[Rule]", "7400"}], ",", 
   RowBox[{"ztube", "\[Rule]", "0.0155`"}], ",", 
   RowBox[{"zpickup", "\[Rule]", "0.012999999999999998`"}], ",", 
   RowBox[{"masspullapart", "\[Rule]", "0.06`"}], ",", 
   RowBox[{"mzpref", "\[Rule]", "0.00794563213587432`"}], ",", 
   RowBox[{"mz", "\[Rule]", "878020.9598010788`"}], ",", 
   RowBox[{"mzB", "\[Rule]", "1.1033536788035714`"}], ",", 
   RowBox[{"lold", "\[Rule]", "0.003175`"}], ",", 
   RowBox[{"aold", "\[Rule]", "0.0009525`"}], ",", 
   RowBox[{"l", "\[Rule]", "0.005`"}], ",", 
   RowBox[{"a", "\[Rule]", "0.001`"}], ",", 
   RowBox[{"dipole", "\[Rule]", "0.01379192098504464`"}], ",", 
   RowBox[{"layers", "\[Rule]", "27"}], ",", 
   RowBox[{"turns", "\[Rule]", "600"}], ",", 
   RowBox[{"wirediam", "\[Rule]", "0.00035999999999999997`"}], ",", 
   RowBox[{"coillen", "\[Rule]", "0.008`"}], ",", 
   RowBox[{"coilz1", "\[Rule]", 
    RowBox[{"-", "0.004`"}]}], ",", 
   RowBox[{"coilz2", "\[Rule]", "0.004`"}], ",", 
   RowBox[{"coilrad1", "\[Rule]", "0.009000000000000001`"}], ",", 
   RowBox[{"coilrad2", "\[Rule]", "0.01872`"}], ",", 
   RowBox[{"coildrad2max", "\[Rule]", "0.0245`"}], ",", 
   RowBox[{"coilturns", "\[Rule]", "600"}], ",", 
   RowBox[{"coilsigma", "\[Rule]", "7.716049382716049`*^6"}], ",", 
   RowBox[{"magposactpromec", "\[Rule]", "0.0074`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.661139702279356*^9, 3.6612185348155727`*^9, 
  3.66122645393834*^9, 3.661229128345133*^9, 3.661231644665721*^9, 
  3.662245813209215*^9, 3.662327577750882*^9, 3.662330890604761*^9, 
  3.662337498117524*^9, 3.664592535044819*^9, 3.6653735506771307`*^9, 
  3.682483043831209*^9, 3.6825616536377497`*^9, 3.6826231296547337`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"optdata", "[", "KSR", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.12880088453359687`"}], ",", 
      RowBox[{"{", 
       RowBox[{"z", "\[Rule]", "0.00671881252925762`"}], "}"}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Minimize", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"fz", "[", 
          RowBox[{"KSR", ",", "z"}], "]"}]}], ",", " ", 
        RowBox[{"0.006", " ", "<", " ", "z", " ", "<", " ", "0.012"}]}], 
       "}"}], ",", " ", "z"}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.478970745257534*^9, 3.478970764425056*^9}, 
   3.4796619224973173`*^9, {3.480244382554545*^9, 3.480244405961742*^9}, {
   3.4819408015577917`*^9, 3.4819408027090397`*^9}, {3.481940979763582*^9, 
   3.481940981746011*^9}, {3.481941548420309*^9, 3.481941559738948*^9}, {
   3.630208310775996*^9, 3.6302083160559387`*^9}, 3.6302102241338043`*^9, {
   3.630210607856474*^9, 3.6302106082793016`*^9}, 3.630361338897683*^9, {
   3.631834266175609*^9, 3.631834266847229*^9}, {3.66096489538389*^9, 
   3.660964895912998*^9}, 3.662330695753613*^9, {3.682482286509556*^9, 
   3.6824822874058228`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.02251089264362962`"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", "\[Rule]", "0.007150489898592264`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.630361340786025*^9, 3.6303616440690804`*^9, 
  3.6303619723403873`*^9, 3.6304700727391043`*^9, 3.631828016987249*^9, 
  3.6318286721706467`*^9, 3.631835182694659*^9, 3.6318395262620773`*^9, 
  3.6338315632012978`*^9, 3.633834180737639*^9, 3.649109165341728*^9, 
  3.660965554607506*^9, 3.6609695597456284`*^9, 3.661056622460845*^9, 
  3.6611192766059313`*^9, 3.661130928174697*^9, 3.661139867081956*^9, 
  3.661218696462347*^9, 3.661231801590312*^9, 3.662245981319335*^9, 
  3.662327742862506*^9, 3.662331040771633*^9, 3.662337654997511*^9, 
  3.664592697381234*^9, 3.665373711649935*^9, 3.682483188039215*^9, 
  3.682561796324354*^9, 3.682623184651937*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fzi", "[", "KSR", "]"}], " ", "=", " ", 
  RowBox[{"FunctionInterpolation", "[", 
   RowBox[{
    RowBox[{"fz", "[", 
     RowBox[{"KSR", ",", "z"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "0", ",", "0.013"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.661121231903079*^9, 3.661121302673418*^9}, {
   3.66112135471321*^9, 3.661121364047564*^9}, 3.661121573023286*^9, {
   3.661121981470016*^9, 3.661121984145525*^9}, {3.661122016670216*^9, 
   3.6611220263968563`*^9}, {3.661122422824706*^9, 3.661122440665392*^9}, {
   3.6611225257271423`*^9, 3.6611225561384287`*^9}, 3.661122943936385*^9, 
   3.661124072219921*^9, 3.661124107400278*^9, {3.66114125831656*^9, 
   3.6611412583250227`*^9}, {3.661218342420212*^9, 3.6612184052787037`*^9}, {
   3.661218496917082*^9, 3.661218498643498*^9}, {3.661218568716762*^9, 
   3.661218572408393*^9}, 3.6612187337963448`*^9, {3.661218857797194*^9, 
   3.6612188746198997`*^9}, 3.662246038931663*^9, {3.662246606578101*^9, 
   3.6622466290281973`*^9}, {3.662262652702455*^9, 3.662262654374928*^9}, {
   3.6824822879918203`*^9, 3.682482288535698*^9}}],

Cell[BoxData[
 TagBox[
  TemplateBox[{RowBox[{
      StyleBox[
       TagBox["InterpolatingFunction", "SummaryHead"], 
       "NonInterpretableSummary"], 
      StyleBox["[", "NonInterpretableSummary"], 
      DynamicModuleBox[{Typeset`open$$ = False}, 
       PanelBox[
        PaneSelectorBox[{False -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquarePlusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = True), Appearance -> None,
                 Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{{{}, {}, {
                   Directive[
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1]], 
                   LineBox[CompressedData["
1:eJwVkXsw2wcAx3Neu6rrKdmtTEdbc+15tBqinl+3UhXJtnqtyjCPiiZDTZrW
otJ4Joog+aFrqzvdhtUjJBwJnbsxzyPZ6nnm0a5l6abI9LqTmv3xvc99/v18
jySkhyYbkEgkn739T93dbtuc83/7kkh8h0upZL+FxhCVbtAR5OX0nzcUoZDX
pxgYb/rgpVpeVHstEebcN0FifiAG43iyzSk26Fofb3USHS2tzw2d3mTixvGL
yYz1C1gf2m+VPcuFu1dSSiQ7Aq6eu5fjwnj4PqC465hbFESpl8hMER93qNp7
tD9joNzSmz5QC6A6++ki7VQ8IhvuKL2e5qNwtZPQmCfARclUOpsXYUB1jsVW
J4K/r2X3jIkQA0bbphRhMtLrGdt1SyLYBcvU0ZdTwLPrlOvGb2NdJVUQx1Kx
Nkjq8y0og5Vz4U8UExbaKLwdpb0YRgcJQr/IxuYPOxqTbTGS7CeEs7VpSP4i
Or+1uQLm1qaaEp8MZNsayWZSKtHg2f8XxeYq2KMbHf77qpD22Vub0gOZyIp1
jRY0VYF8clTG28lEVL/MZNFLAs59pwjO3FeocZicc1FIYGhGNrMdzQKVkTND
cZKCflCsVv/IwTqjxn+sTArO5Dc71sXXQGM96vn1qRRjpc7e73K5YD4+vepH
IbCwElZ8KPI6Uvp7HzZdJfA+lbQ2FnQDv7n9Th9qIOB11qf1PfdsrLWbQqUh
YLlqls+y+BrTJq600HUC1iWJ7AwDHk7cGwmEYTXmBz5OvLnCQ6nwYvju/mrk
9Aw/PtqXg3PDTNeRPac3j5y8/ugmqkPdgz0NqjHlEd8yJcoFZyhsbPMVgXNL
vnZbvnxUhFxgNj0hkPtKmpHbwociXfNPh5xAw4Jia8rmFiwKJkTTpQRWh2tI
RZJbGA+ea3sWQ8DYYFDibSRA2/IVEfMEgTOene3ncwRwemGaOKqVIoaRZnhE
J0BUfJ3LcqMUnzdnzOsT8hBDo8wYMvd6mVF9KfN5aMwPoEbYSHGlK9Dhy5B8
EMoJkodGgk9w+KPM7nwISh8u3i+UIGSw68XEqQKwynoU3a4S2NfeJZ9+UICR
zecJHkt7/7ECRl8eKoRyotFBXlAFnZVcnlleiKxxT62lYxVk5LQP9fpCBC4m
dfk/qUTBAa3tEqcIsfX/kiy5laCGt3/7yx9F8AvXB7E/qMTbGp/md+KKoeoN
chrrrUBnT5nWYqoYh2ccO5piKxBy3FF2NFCIPG3oyqxxBV5LRKSSXiFGHIe4
8u/E4DPcpl87i8CR0aIC6GJsSKjpfXUiTOq6FsufleM/5EvFAw==
                    
                    "]]}}}, {}, {}}, {
               DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
                AxesOrigin -> {0, 0}, 
                FrameTicks -> {{None, None}, {None, None}}, 
                GridLines -> {None, None}, DisplayFunction -> Identity, 
                PlotRangePadding -> {{
                   Scaled[0.1], 
                   Scaled[0.1]}, {
                   Scaled[0.1], 
                   Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
                All, DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                Directive[
                  Opacity[0.5], 
                  Thickness[Tiny], 
                  RGBColor[0.368417, 0.506779, 0.709798]], 
                FrameTicks -> {{None, None}, {None, None}}, 
                GridLines -> {None, None}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 
                Dynamic[{
                  Automatic, 3.5 CurrentValue["FontCapHeight"]/
                   AbsoluteCurrentValue[Magnification]}], 
                Method -> {
                 "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
                  AbsolutePointSize[6], "ScalingFunctions" -> None, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (
                    Part[{{Identity, Identity}, {Identity, Identity}}, 1, 
                    2][#]& )[
                    Part[#, 1]], 
                    (
                    Part[{{Identity, Identity}, {Identity, Identity}}, 2, 
                    2][#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 
                    2][#]& )[
                    Part[#, 1]], 
                    (
                    Part[{{Identity, Identity}, {Identity, Identity}}, 2, 
                    2][#]& )[
                    Part[#, 2]]}& )}}, 
                PlotRange -> {{0., 0.013}, {0., 0.022506703875600876`}}, 
                PlotRangeClipping -> True, PlotRangePadding -> {{
                   Scaled[0.1], 
                   Scaled[0.1]}, {
                   Scaled[0.1], 
                   Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"scalar\"", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}], True -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquareMinusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                None, Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{{{}, {}, {
                   Directive[
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1]], 
                   LineBox[CompressedData["
1:eJwVkXsw2wcAx3Neu6rrKdmtTEdbc+15tBqinl+3UhXJtnqtyjCPiiZDTZrW
otJ4Joog+aFrqzvdhtUjJBwJnbsxzyPZ6nnm0a5l6abI9LqTmv3xvc99/v18
jySkhyYbkEgkn739T93dbtuc83/7kkh8h0upZL+FxhCVbtAR5OX0nzcUoZDX
pxgYb/rgpVpeVHstEebcN0FifiAG43iyzSk26Fofb3USHS2tzw2d3mTixvGL
yYz1C1gf2m+VPcuFu1dSSiQ7Aq6eu5fjwnj4PqC465hbFESpl8hMER93qNp7
tD9joNzSmz5QC6A6++ki7VQ8IhvuKL2e5qNwtZPQmCfARclUOpsXYUB1jsVW
J4K/r2X3jIkQA0bbphRhMtLrGdt1SyLYBcvU0ZdTwLPrlOvGb2NdJVUQx1Kx
Nkjq8y0og5Vz4U8UExbaKLwdpb0YRgcJQr/IxuYPOxqTbTGS7CeEs7VpSP4i
Or+1uQLm1qaaEp8MZNsayWZSKtHg2f8XxeYq2KMbHf77qpD22Vub0gOZyIp1
jRY0VYF8clTG28lEVL/MZNFLAs59pwjO3FeocZicc1FIYGhGNrMdzQKVkTND
cZKCflCsVv/IwTqjxn+sTArO5Dc71sXXQGM96vn1qRRjpc7e73K5YD4+vepH
IbCwElZ8KPI6Uvp7HzZdJfA+lbQ2FnQDv7n9Th9qIOB11qf1PfdsrLWbQqUh
YLlqls+y+BrTJq600HUC1iWJ7AwDHk7cGwmEYTXmBz5OvLnCQ6nwYvju/mrk
9Aw/PtqXg3PDTNeRPac3j5y8/ugmqkPdgz0NqjHlEd8yJcoFZyhsbPMVgXNL
vnZbvnxUhFxgNj0hkPtKmpHbwociXfNPh5xAw4Jia8rmFiwKJkTTpQRWh2tI
RZJbGA+ea3sWQ8DYYFDibSRA2/IVEfMEgTOene3ncwRwemGaOKqVIoaRZnhE
J0BUfJ3LcqMUnzdnzOsT8hBDo8wYMvd6mVF9KfN5aMwPoEbYSHGlK9Dhy5B8
EMoJkodGgk9w+KPM7nwISh8u3i+UIGSw68XEqQKwynoU3a4S2NfeJZ9+UICR
zecJHkt7/7ECRl8eKoRyotFBXlAFnZVcnlleiKxxT62lYxVk5LQP9fpCBC4m
dfk/qUTBAa3tEqcIsfX/kiy5laCGt3/7yx9F8AvXB7E/qMTbGp/md+KKoeoN
chrrrUBnT5nWYqoYh2ccO5piKxBy3FF2NFCIPG3oyqxxBV5LRKSSXiFGHIe4
8u/E4DPcpl87i8CR0aIC6GJsSKjpfXUiTOq6FsufleM/5EvFAw==
                    
                    "]]}}}, {}, {}}, {
               DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
                AxesOrigin -> {0, 0}, 
                FrameTicks -> {{None, None}, {None, None}}, 
                GridLines -> {None, None}, DisplayFunction -> Identity, 
                PlotRangePadding -> {{
                   Scaled[0.1], 
                   Scaled[0.1]}, {
                   Scaled[0.1], 
                   Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
                All, DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                Directive[
                  Opacity[0.5], 
                  Thickness[Tiny], 
                  RGBColor[0.368417, 0.506779, 0.709798]], 
                FrameTicks -> {{None, None}, {None, None}}, 
                GridLines -> {None, None}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 
                Dynamic[{
                  Automatic, 3.5 CurrentValue["FontCapHeight"]/
                   AbsoluteCurrentValue[Magnification]}], 
                Method -> {
                 "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
                  AbsolutePointSize[6], "ScalingFunctions" -> None, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (
                    Part[{{Identity, Identity}, {Identity, Identity}}, 1, 
                    2][#]& )[
                    Part[#, 1]], 
                    (
                    Part[{{Identity, Identity}, {Identity, Identity}}, 2, 
                    2][#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (
                    Part[{{Identity, Identity}, {Identity, Identity}}, 1, 
                    2][#]& )[
                    Part[#, 1]], 
                    (
                    Part[{{Identity, Identity}, {Identity, Identity}}, 2, 
                    2][#]& )[
                    Part[#, 2]]}& )}}, 
                PlotRange -> {{0., 0.013}, {0., 0.022506703875600876`}}, 
                PlotRangeClipping -> True, PlotRangePadding -> {{
                   Scaled[0.1], 
                   Scaled[0.1]}, {
                   Scaled[0.1], 
                   Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"scalar\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["3", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"Hermite\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["False", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}]}, 
         Dynamic[Typeset`open$$], ImageSize -> Automatic], BaselinePosition -> 
        Baseline], DynamicModuleValues :> {}], 
      StyleBox["]", "NonInterpretableSummary"]}]},
   "CopyTag",
   DisplayFunction->(#& ),
   InterpretationFunction->("InterpolatingFunction[{{0., 0.013}}, <>]"& )],
  False,
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.662262660945747*^9, 3.6623277481278048`*^9, 
  3.662331045843033*^9, 3.662337660257972*^9, 3.664592702657907*^9, 
  3.665373716737364*^9, 3.6824831927405033`*^9, 3.682561800711113*^9, 
  3.682623185970243*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"plot", "[", "KSR", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    GraphicsBox[{{}, {}, 
      {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
       LineBox[CompressedData["
1:eJwV1nk4VWsbBnBEDhlSKKUMfTQQIjTgjuakDCWUhMzzvPde26zBbjgikiFk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        "]]}},
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->{True, True},
     AxesLabel->{None, None},
     AxesOrigin->{0, 0},
     DisplayFunction->Identity,
     Frame->{{False, False}, {False, False}},
     FrameLabel->{{None, None}, {None, None}},
     FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
     GridLines->{None, None},
     GridLinesStyle->Directive[
       GrayLevel[0.5, 0.4]],
     Method->{
      "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
       AbsolutePointSize[6], "ScalingFunctions" -> None},
     PlotRange->{{0, 0.013}, {0., 0.12880088236937143`}},
     PlotRangeClipping->True,
     PlotRangePadding->{{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}},
     Ticks->{Automatic, Automatic}], ",", "\[IndentingNewLine]", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"fz", "[", 
       RowBox[{"KSR", ",", "p"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"p", ",", "0", ",", "0.013"}], "}"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", "Black"}]}], "]"}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.4789618100364523`*^9, 3.478961850760915*^9}, 
   3.478969868098156*^9, 3.4789702271107073`*^9, {3.478971402742322*^9, 
   3.478971407269801*^9}, {3.478973436528585*^9, 3.4789734559838*^9}, {
   3.4794970273251*^9, 3.4794970280748262`*^9}, {3.479497850691868*^9, 
   3.479497851721608*^9}, {3.4802445496159487`*^9, 3.4802445841180058`*^9}, {
   3.4802446656757193`*^9, 3.4802446687524443`*^9}, {3.481940803363203*^9, 
   3.481940804034131*^9}, {3.481941063760079*^9, 3.4819410664063997`*^9}, {
   3.481941556057631*^9, 3.4819415664906*^9}, {3.630208312322345*^9, 
   3.63020831448879*^9}, 3.630209982122305*^9, 3.630210040824745*^9, {
   3.630210608691247*^9, 3.6302106091463537`*^9}, 3.6302116072117853`*^9, 
   3.6302119179137897`*^9, 3.6304701238527927`*^9, 3.631834820615905*^9, 
   3.649109628464219*^9, {3.649110363868889*^9, 3.649110366770886*^9}, {
   3.649110567151823*^9, 3.649110570373554*^9}, {3.661123689182354*^9, 
   3.661123723132988*^9}, 3.661123839830414*^9, {3.661123888550177*^9, 
   3.6611238924215937`*^9}, {3.661123959516914*^9, 3.661123970823284*^9}, {
   3.661124020120494*^9, 3.661124020504492*^9}, {3.661124084594274*^9, 
   3.66112408490854*^9}, {3.661124132485323*^9, 3.661124133744603*^9}, {
   3.661127129389042*^9, 3.6611271300441732`*^9}, {3.6611285421516657`*^9, 
   3.6611285486416283`*^9}, 3.661139350752645*^9, {3.661141258332346*^9, 
   3.661141258345943*^9}, {3.661218500125923*^9, 3.661218503251073*^9}, {
   3.662246691379507*^9, 3.662246718565319*^9}, {3.662246863148045*^9, 
   3.662246890689905*^9}, {3.662247012437896*^9, 3.6622470129339113`*^9}, {
   3.66232743322059*^9, 3.6623274340219593`*^9}, 3.662327815174901*^9, {
   3.66233080382358*^9, 3.662330813138308*^9}, {3.682482289129282*^9, 
   3.682482289738995*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
     LineBox[CompressedData["
1:eJwV13k8VO8XB3BbyL6nokUl31Ii9dWiT1RKIS0kfVXIlohkm5k7xhojTJar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      "]]}}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 0.013}, {0., 0.02251089256451512}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.649109686790821*^9, 3.6491103787345247`*^9, 3.660965322933999*^9, 
   3.6609691450694323`*^9, 3.6610562264789333`*^9, 3.661118658026022*^9, 
   3.661119055121579*^9, {3.661123710650861*^9, 3.661123724289307*^9}, 
   3.661123847867857*^9, 3.661123892991621*^9, {3.661123960098845*^9, 
   3.66112397157833*^9}, 3.661124011481043*^9, 3.661124062306964*^9, 
   3.661124248993616*^9, 3.661124781109477*^9, 3.661127174324749*^9, 
   3.661128593139056*^9, 3.661139696344545*^9, 3.661205468105528*^9, 
   3.661218317171567*^9, 3.6612184134232492`*^9, 3.6612187208062153`*^9, 
   3.6612318252337723`*^9, 3.662246007088282*^9, 3.662246745054916*^9, 
   3.6622468830851097`*^9, 3.662246915217906*^9, 3.6623277730276623`*^9, 
   3.66233106855897*^9, 3.662337683983321*^9, 3.6645927268196583`*^9, 
   3.665373740668016*^9, 3.682483214276472*^9, 3.682561822651601*^9, 
   3.6826231944351883`*^9}]
}, Open  ]],

Cell["Check interpolated plot (red) coincides", "Text",
 CellChangeTimes->{{3.662246974984686*^9, 3.662247002606237*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"plot", "[", "KSR", "]"}], ",", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"fzi", "[", "KSR", "]"}], "[", "p", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"p", ",", "0", ",", "0.013"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.66224692523505*^9, 3.662246970049139*^9}, {
  3.682482290194755*^9, 3.682482290689666*^9}}],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
      LineBox[CompressedData["
1:eJwV13k8VO8XB3BbyL6nokUl31Ii9dWiT1RKIS0kfVXIlohkm5k7xhojTJar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       
       "]]}}, {}, {}}, {{{}, {}, 
     {RGBColor[1, 0, 0], AbsoluteThickness[1.6], Opacity[1.], 
      LineBox[CompressedData["
1:eJwV13k0Vd0bB3BTCCGFlF5KLw1Kc1H6pqQS0iTlJTNJg7i4w7n3GtNVueKe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       "]]}}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 0.013}, {0., 0.02251089256451512}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.662246962166266*^9, 3.66224697090763*^9}, 
   3.6623277731491947`*^9, 3.662331068933206*^9, 3.662337684317403*^9, 
   3.6645927270112133`*^9, 3.66537374074555*^9, 3.6824832143565197`*^9, 
   3.682561822778717*^9, 3.6826231945145063`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"zmax", "[", "KSR", "]"}], "  ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{
    RowBox[{"optdata", "[", "KSR", "]"}], " ", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.478970786649661*^9, 3.478970802864567*^9}, {
   3.4796619220112333`*^9, 3.4796619454416037`*^9}, 3.479665671740583*^9, {
   3.48194080448247*^9, 3.481940804971867*^9}, {3.630208319233528*^9, 
   3.630208320862918*^9}, {3.630210609409204*^9, 3.6302106096880713`*^9}, {
   3.631834268382159*^9, 3.631834268966103*^9}, {3.660964897577401*^9, 
   3.6609648980982428`*^9}, {3.682482291177512*^9, 3.682482291691648*^9}}],

Cell[BoxData["0.007150489898592264`"], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQB+KQpjXdc16/dFyUG2Mx481Lxxmm1slvgHRVmlDOOyDd
V36j8z2Qvu0kNBlE/39ZeoTz3UvHKOkVp58A6ZCHs3P7P7x0XPNepcTt40vH
A2Uu1SD61gOZzSDaKSPnPIjWPVjJ5Q6kK1Q3brPmfu0odHpRojDPa8eKhqen
QPQV5gtPQfRj87fpIkBaaZrYJEsg/Sz3xhsPIL1feuvmWCDddTW8ZhKQPmWk
3KbJD9S3juMGiD61jJFTF0hP+y6toQ/iX8y4+FvoteOGFTMk/gLpu3fXTJU3
ANqnFnZtj9trxwevv57dB6SPvb0V8BJIT5h28Cm7+2tHvflMM3mBdFlf9TdB
IL2VU6bEAki/EtG5ZQek5Vpf8Ol5vnaMCln2OxRI281YMD0cSM8W7LkUBaQj
Hj98tdz3taPW+xmuqv6vHVtWn2k8nv/aMUPt9uO3QLomLug2d8FrRwDgusTY

  "]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"magposactpromec", "-", 
   RowBox[{"zmax", "[", "KSR", "]"}]}], "/.", 
  RowBox[{"vals", "[", "KSR", "]"}]}]], "Input",
 CellChangeTimes->{{3.631850926207306*^9, 3.631850980824053*^9}, {
   3.660964898627531*^9, 3.660964899139551*^9}, 3.661139095060607*^9, 
   3.6611392025561953`*^9, {3.682482292123403*^9, 3.682482292651243*^9}}],

Cell[BoxData["0.00024951010140773604`"], "Output",
 CellChangeTimes->{{3.631850951545291*^9, 3.63185098135504*^9}, 
   3.63383156333751*^9, 3.63383418079591*^9, 3.649109165431679*^9, 
   3.660965554751844*^9, 3.660969583720545*^9, 3.66105664686804*^9, 
   3.6611192781065807`*^9, 3.6611309521076517`*^9, 3.661139891891814*^9, 
   3.661218720941321*^9, 3.661231825434506*^9, 3.662246007329948*^9, 
   3.662327773263053*^9, 3.662331069073143*^9, 3.662337684427704*^9, 
   3.6645927270899*^9, 3.665373740808846*^9, 3.6824832144549313`*^9, 
   3.68256182291315*^9, 3.682623194642951*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fmax", "[", "KSR", "]"}], "  ", "=", " ", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"optdata", "[", "KSR", "]"}], " ", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4789708091780043`*^9, 3.4789708248973703`*^9}, 
   3.479661922078005*^9, 3.4796619593447857`*^9, 3.479665787682528*^9, {
   3.481940805601218*^9, 3.481940806091435*^9}, {3.630208322616778*^9, 
   3.6302083244414253`*^9}, {3.63021060995541*^9, 3.63021061023507*^9}, {
   3.631834269559742*^9, 3.6318342700157347`*^9}, {3.660964899643673*^9, 
   3.660964900149706*^9}, {3.682482293110538*^9, 3.682482293589432*^9}}],

Cell[BoxData["0.02251089264362962`"], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQB+KWPeu757x+6fjqVazFjDcvHYUybZLfAGlvBZGcd0Ca
KeVm53sgHccmNhlE2xwsO8L57qVjacnK00+AdOCkubn9H146Mm9SK3H7+NLx
yXfXahAtsEF2M4helpZ3HkS39VdzuQPp+Psbt1lzv3ZU+7UkUZjnteOEl99O
gejdWy88BdFOie/TRYD03WUSkyyB9I6mW288gHTHvG2bY4F06/nImklA+sN5
lTZN/teOZdO4boBo5hgmTl0g/fi9rIY+kJaKz7n4W+i14xK/WRJ/gfSpH+um
yhu8dny0OvLaHjeg/uYfZ/cBacWFdwJeAunbhy4/ZXd/7WjqzDKTF0hfOVj7
TRBI92oqlFgAaQNmg1t2QFpP8Q2fnudrR4tFq36HAum8nCXTw4G0QUz/pSgg
fe/741fLfV87njgz21XVH6jO+0Lj8fzXjrsy7z9+C6RTdoXd5i547QgATL3D
9A==
  "]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"deriv2", "[", "KSR", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"-", "2"}], "*", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"fzi", "[", "KSR", "]"}], "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{"zmax", "[", "KSR", "]"}], ",", "2"}], "}"}]}], "]"}], 
      "]"}], ",", 
     RowBox[{"z", "^", "2"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479660163969679*^9, 3.479660203608347*^9}, {
   3.479660334457396*^9, 3.479660335305067*^9}, {3.4796611591764927`*^9, 
   3.479661208701754*^9}, {3.479661250977075*^9, 3.479661305176928*^9}, {
   3.479661346153286*^9, 3.479661372928776*^9}, {3.479661851029785*^9, 
   3.479661859051705*^9}, 3.4796619463263597`*^9, 3.479662725037703*^9, 
   3.479665672610339*^9, {3.481940806550991*^9, 3.48194080744361*^9}, {
   3.630208325888165*^9, 3.6302083289679956`*^9}, {3.630210610460196*^9, 
   3.630210610874337*^9}, 3.6611229758725023`*^9, {3.6611412583941383`*^9, 
   3.6611412584082737`*^9}, {3.661141309779232*^9, 3.661141309788487*^9}, {
   3.661143055996151*^9, 3.661143061547195*^9}, {3.661143129145129*^9, 
   3.661143150309849*^9}, {3.661231154888709*^9, 3.661231159334008*^9}, 
   3.66123140853971*^9, {3.6612315267918673`*^9, 3.661231532575729*^9}, 
   3.662253434225093*^9, 3.662256174883844*^9, 3.662256454447321*^9, {
   3.6622576485489264`*^9, 3.6622576543643312`*^9}, {3.662259663815483*^9, 
   3.662259674101316*^9}, 3.662259713425989*^9, {3.662260002840063*^9, 
   3.662260003422638*^9}, {3.6824822941177073`*^9, 3.6824822951204357`*^9}}],

Cell[BoxData["738.5450415183287`"], "Output",
 CellChangeTimes->{
  3.66123150538653*^9, 3.661231825570121*^9, 3.6622460074271603`*^9, 
   3.662246641563151*^9, 3.662255639636259*^9, 3.662256210598072*^9, 
   3.662256513985942*^9, {3.6622576493391542`*^9, 3.662257655351861*^9}, {
   3.6622596695441027`*^9, 3.662259674651012*^9}, 3.662259714075639*^9, 
   3.662260004808572*^9, 3.6623277733809*^9, 3.662331069205131*^9, 
   3.66233768452456*^9, 3.664592727161736*^9, 3.6653737409285507`*^9, 
   3.68248321457209*^9, 3.6825618230499372`*^9, 3.682623194775032*^9}]
}, Open  ]],

Cell["Check second derivative", "Text",
 CellChangeTimes->{{3.662247035240644*^9, 3.662247059134865*^9}}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"0.0067", ",", "0.00673"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.6622556122910337`*^9, 3.662255614424631*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"plot", "[", "KSR", "]"}], ",", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"fmax", "[", "KSR", "]"}], "-", 
      RowBox[{"0.5", "*", 
       RowBox[{"deriv2", "[", "KSR", "]"}], "*", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"p", "-", 
          RowBox[{"zmax", "[", "KSR", "]"}]}], ")"}], "^", "2"}]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"p", ",", "0.", ",", "0.013"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Black", ",", "Red"}], "}"}]}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.66224692523505*^9, 3.662246970049139*^9}, {
   3.6622470798293657`*^9, 3.662247143593774*^9}, {3.66224749751495*^9, 
   3.6622475122269783`*^9}, {3.662247551586426*^9, 3.662247591202095*^9}, {
   3.662247623031026*^9, 3.662247763257119*^9}, {3.662251046755311*^9, 
   3.662251221801083*^9}, {3.662252973683614*^9, 3.6622530734486856`*^9}, {
   3.662253103864985*^9, 3.662253136327422*^9}, {3.662253167574163*^9, 
   3.6622532724867*^9}, 3.662253434242627*^9, {3.662255589372203*^9, 
   3.662255630288435*^9}, {3.662255669518676*^9, 3.6622556904937677`*^9}, {
   3.662255798233357*^9, 3.6622557992283154`*^9}, {3.662259719290337*^9, 
   3.662259728098154*^9}, {3.6622600085014467`*^9, 3.662260010294861*^9}, {
   3.662261295233617*^9, 3.662261300617079*^9}, {3.662327855032322*^9, 
   3.662327877406282*^9}, {3.682482295663357*^9, 3.682482297210249*^9}}],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
      LineBox[CompressedData["
1:eJwV13k8VO8XB3BbyL6nokUl31Ii9dWiT1RKIS0kfVXIlohkm5k7xhojTJar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       
       "]]}}, {}, {}}, {{{}, {}, 
     {RGBColor[1, 0, 0], AbsoluteThickness[1.6], Opacity[1.], 
      LineBox[CompressedData["
1:eJwV13k4VG8bB3CkyJaQpZSttKkkqURf0qpIuxKJCNnKOsuZhSFNJcKxpZAk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       "]]}}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 0.013}, {0., 0.02251089256451512}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.662247755756023*^9, 3.662247763826311*^9}, {
   3.662251055415514*^9, 3.6622512231798964`*^9}, {3.662252996577107*^9, 
   3.662253073828041*^9}, {3.662253104307506*^9, 3.6622531367553463`*^9}, {
   3.662253199030999*^9, 3.66225327329182*^9}, 3.662255592043687*^9, {
   3.662255630869121*^9, 3.662255671632409*^9}, 3.662255716290309*^9, 
   3.662255823726226*^9, 3.662259703266612*^9, 3.662259752969811*^9, 
   3.6622600344956617`*^9, 3.662261325288904*^9, 3.6623277986013813`*^9, 
   3.662328359102607*^9, 3.662331069317165*^9, 3.6623376845988894`*^9, 
   3.664592727213608*^9, 3.665373741030381*^9, 3.6824832146488*^9, 
   3.682561823147798*^9, 3.68262319486064*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"z95plus", "[", "KSR", "]"}], " ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{"FindRoot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"fz", "[", 
       RowBox[{"KSR", ",", "z"}], "]"}], "-", 
      RowBox[{"0.95", "*", 
       RowBox[{"fmax", "[", "KSR", "]"}]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", 
       RowBox[{
        RowBox[{"zmax", "[", "KSR", "]"}], "+", "0.001"}], ",", 
       RowBox[{"zmax", "[", "KSR", "]"}], ",", 
       RowBox[{
        RowBox[{"zmax", "[", "KSR", "]"}], "+", "0.005"}]}], "}"}]}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479658613425561*^9, 3.4796587501410933`*^9}, {
   3.479658790462825*^9, 3.4796587993088913`*^9}, {3.479658852062684*^9, 
   3.479658891629363*^9}, {3.4796589431729183`*^9, 3.479658948798299*^9}, {
   3.479658987032153*^9, 3.47965898990287*^9}, {3.479659310386307*^9, 
   3.4796593125701933`*^9}, {3.479661624172262*^9, 3.479661679901505*^9}, {
   3.479661945541445*^9, 3.4796619594445953`*^9}, {3.4796656734658623`*^9, 
   3.479665674680963*^9}, 3.47966578778349*^9, {3.481940808072547*^9, 
   3.4819408112927933`*^9}, {3.630208331202548*^9, 3.630208340512887*^9}, {
   3.6302106111156588`*^9, 3.630210612620454*^9}, {3.631834272292122*^9, 
   3.631834275423791*^9}, {3.660964902295938*^9, 3.660964904267434*^9}, 
   3.6623341356030903`*^9, {3.682482297864437*^9, 3.682482300341604*^9}}],

Cell[BoxData["0.009048096481669156`"], "Output",
 CellChangeTimes->{{3.479659290207419*^9, 3.4796593177022877`*^9}, {
   3.479661644377719*^9, 3.4796616514833097`*^9}, 3.479661686065053*^9, 
   3.4796634593803263`*^9, 3.479665745824663*^9, 3.4796658197389708`*^9, 
   3.480243751933235*^9, 3.480692320796873*^9, 3.4815660640155077`*^9, 
   3.4819408973674994`*^9, 3.481940954361327*^9, 3.481941402301373*^9, 
   3.481941628781619*^9, 3.481942101498692*^9, 3.629768118581479*^9, 
   3.630209825967379*^9, 3.63021064809335*^9, 3.630210863735273*^9, 
   3.6302119044786863`*^9, 3.630288029600463*^9, 3.630319474859651*^9, 
   3.630362016214836*^9, 3.63047011744707*^9, 3.631828018334545*^9, 
   3.631828673603425*^9, 3.631835209527664*^9, 3.631839554443227*^9, 
   3.6338315761916437`*^9, 3.633834181637607*^9, 3.649109166248088*^9, 
   3.6609655556857033`*^9, 3.660969585228065*^9, 3.661056648356412*^9, 
   3.661119278891127*^9, 3.6611309535044317`*^9, 3.661139893341815*^9, 
   3.661218722362886*^9, 3.661231826701318*^9, 3.662246008600046*^9, 
   3.66232780003985*^9, 3.662331070418768*^9, 3.662337363887047*^9, 
   3.6623376857576933`*^9, 3.6645927283914137`*^9, 3.6653737421868773`*^9, 
   3.682483215663686*^9, 3.682561824240136*^9, 3.682623195332403*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"z95minus", "[", "KSR", "]"}], " ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{"FindRoot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"fz", "[", 
       RowBox[{"KSR", ",", "z"}], "]"}], "-", 
      RowBox[{"0.95", "*", 
       RowBox[{"fmax", "[", "KSR", "]"}]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", 
       RowBox[{
        RowBox[{"zmax", "[", "KSR", "]"}], "-", "0.001"}], ",", 
       RowBox[{
        RowBox[{"zmax", "[", "KSR", "]"}], "-", "0.005"}], ",", 
       RowBox[{"zmax", "[", "KSR", "]"}]}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479658613425561*^9, 3.4796587501410933`*^9}, {
   3.479658790462825*^9, 3.4796587993088913`*^9}, {3.479658852062684*^9, 
   3.479658891629363*^9}, {3.4796589431729183`*^9, 3.479658948798299*^9}, {
   3.479658997678957*^9, 3.4796590027188377`*^9}, {3.479659318794853*^9, 
   3.479659344898431*^9}, {3.479661657421668*^9, 3.4796616780054293`*^9}, {
   3.479661945775414*^9, 3.479661959545474*^9}, {3.479665675209929*^9, 
   3.479665676278386*^9}, 3.4796657878831253`*^9, {3.481940812147341*^9, 
   3.481940829419257*^9}, {3.6302083429611607`*^9, 3.6302083515364437`*^9}, {
   3.630210612999134*^9, 3.630210615553306*^9}, {3.6318342761199827`*^9, 
   3.631834277785796*^9}, {3.660964904795537*^9, 3.660964907383277*^9}, 
   3.662334135620826*^9, {3.682482300901289*^9, 3.682482303517332*^9}}],

Cell[BoxData["0.005506713887423707`"], "Output",
 CellChangeTimes->{
  3.479659290545846*^9, {3.479659322545879*^9, 3.479659348979048*^9}, {
   3.4796616661527233`*^9, 3.479661689555737*^9}, 3.479663462870864*^9, 
   3.479665749329587*^9, 3.479665823257647*^9, 3.480243756605932*^9, 
   3.480692324819867*^9, 3.481566067504561*^9, 3.4819408974084797`*^9, 
   3.481940954404307*^9, 3.481941404076367*^9, 3.481941630539411*^9, 
   3.481942103389555*^9, 3.629768120026389*^9, 3.630209826676588*^9, 
   3.630210648265239*^9, 3.630210865289218*^9, 3.6302119056902*^9, 
   3.630288030116592*^9, 3.630319475441311*^9, 3.630362019145561*^9, 
   3.6304701204629717`*^9, 3.631828019522635*^9, 3.631828674839793*^9, 
   3.631835211501787*^9, 3.63183955652999*^9, 3.6338315764567127`*^9, 
   3.633834200417728*^9, 3.649109185050705*^9, 3.6609655738717422`*^9, 
   3.6609695873164682`*^9, 3.6610566503171988`*^9, 3.6611192790656967`*^9, 
   3.661130955412754*^9, 3.661139895338929*^9, 3.661218724269143*^9, 
   3.66123182866267*^9, 3.662246010719604*^9, 3.6623278022295628`*^9, 
   3.662331072504764*^9, 3.662337366066951*^9, 3.662337687860222*^9, 
   3.6645927304701157`*^9, 3.6653737441304703`*^9, 3.682483217412228*^9, 
   3.6825618260896378`*^9, 3.682623195940887*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"plot", "[", "KSR", "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Graphics", "[", 
    RowBox[{"Line", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"zmax", "[", "KSR", "]"}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"zmax", "[", "KSR", "]"}], ",", 
         RowBox[{"1.1", "*", 
          RowBox[{"fmax", "[", "KSR", "]"}]}]}], "}"}]}], "}"}], "]"}], "]"}],
    ",", "\[IndentingNewLine]", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{"Gray", ",", 
      RowBox[{"Line", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"z95minus", "[", "KSR", "]"}], ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"z95minus", "[", "KSR", "]"}], ",", 
            RowBox[{"1.1", "*", 
             RowBox[{"fmax", "[", "KSR", "]"}]}]}], "}"}]}], "}"}], "/.", 
        RowBox[{"vals", "[", "KSR", "]"}]}], "]"}]}], "}"}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{"Gray", ",", 
      RowBox[{"Line", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"z95plus", "[", "KSR", "]"}], ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"z95plus", "[", "KSR", "]"}], ",", 
            RowBox[{"1.1", "*", 
             RowBox[{"fmax", "[", "KSR", "]"}]}]}], "}"}]}], "}"}], "/.", 
        RowBox[{"vals", "[", "KSR", "]"}]}], "]"}]}], "}"}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<z (m)\>\"", ",", "\"\<F (N/A)\>\""}], "}"}]}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.453823397414776*^9, 3.453823397824687*^9}, {
   3.453838538440839*^9, 3.453838572806719*^9}, 3.463844247723119*^9, 
   3.478894943196905*^9, 3.4788950132010527`*^9, {3.478961709433363*^9, 
   3.47896175216029*^9}, {3.478961842569364*^9, 3.478961894377494*^9}, {
   3.4789619830038633`*^9, 3.478961984506156*^9}, {3.4789699280628653`*^9, 
   3.478969982243393*^9}, {3.478970021389124*^9, 3.478970165180615*^9}, {
   3.478970224319232*^9, 3.478970261501657*^9}, {3.4789703108875017`*^9, 
   3.478970348344078*^9}, 3.478970398020482*^9, {3.478970871122594*^9, 
   3.47897087265033*^9}, {3.478971414854863*^9, 3.4789714317583723`*^9}, {
   3.4789723334965277`*^9, 3.4789723911200447`*^9}, {3.478973525233735*^9, 
   3.47897352833882*^9}, {3.479495227181163*^9, 3.4794952662789087`*^9}, {
   3.4794954131043873`*^9, 3.4794954161349077`*^9}, {3.479497883443406*^9, 
   3.479497887306903*^9}, {3.4794980354692507`*^9, 3.479498036795588*^9}, 
   3.4794982488155937`*^9, {3.479662131489229*^9, 3.479662133377276*^9}, 
   3.479665540471899*^9, {3.4802459792714577`*^9, 3.480245981573744*^9}, {
   3.4802525542284737`*^9, 3.4802525884311867`*^9}, {3.48194087775911*^9, 
   3.481940886937986*^9}, 3.630208353429995*^9, 3.6302106162586517`*^9, 
   3.631834278469103*^9, {3.631835050283194*^9, 3.631835119871463*^9}, {
   3.631838204428006*^9, 3.631838423237857*^9}, {3.66096490787176*^9, 
   3.6609649094976053`*^9}, {3.661139095070483*^9, 3.661139095077957*^9}, {
   3.661139202563195*^9, 3.6611392025683517`*^9}, {3.662332549865168*^9, 
   3.6623325883346243`*^9}, {3.662334135638215*^9, 3.662334135669765*^9}, {
   3.682482304416662*^9, 3.682482310399343*^9}, {3.682561563324711*^9, 
   3.682561579891128*^9}}],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
      LineBox[CompressedData["
1:eJwV13k8VO8XB3BbyL6nokUl31Ii9dWiT1RKIS0kfVXIlohkm5k7xhojTJar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       "]]}}, {}, {}}, 
   LineBox[{{0.007150489898592264, 0}, {0.007150489898592264, 
     0.024761981907992583`}}], 
   {GrayLevel[0.5], 
    LineBox[{{0.005506713887423707, 0}, {0.005506713887423707, 
      0.024761981907992583`}}]}, 
   {GrayLevel[0.5], 
    LineBox[{{0.009048096481669156, 0}, {0.009048096481669156, 
      0.024761981907992583`}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"z (m)\"", TraditionalForm], 
    FormBox["\"F (N/A)\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 0.013}, {0., 0.02251089256451512}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.6318384165109577`*^9, 3.6318384237975817`*^9}, 
   3.631839267885446*^9, 3.631839556562364*^9, 3.631845627638177*^9, 
   3.631850423414908*^9, 3.6338315765020027`*^9, 3.633834200455875*^9, 
   3.649109185142632*^9, 3.660965573944757*^9, 3.6609695873712063`*^9, 
   3.6610566503558083`*^9, 3.661119279145019*^9, 3.6611309554464417`*^9, 
   3.661139895386891*^9, 3.661218724343892*^9, 3.66121888746214*^9, 
   3.661231828746014*^9, 3.662246010839802*^9, 3.6623278023820047`*^9, 
   3.662331072745317*^9, 3.6623325893693237`*^9, 3.662337687977683*^9, 
   3.662353663753284*^9, 3.6645927305311317`*^9, 3.665373744212297*^9, 
   3.682483217501822*^9, 3.6825618261424427`*^9, 3.6826231960272093`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Coil calc for KAGRA BS: \[CapitalOSlash]2 mm, 3 mm long", "Section",
 CellChangeTimes->{{3.453751016056313*^9, 3.453751037487228*^9}, 
   3.463844192181329*^9, {3.478894850822432*^9, 3.478894851717502*^9}, {
   3.4788951705281897`*^9, 3.4788951754720497`*^9}, {3.4819407269664*^9, 
   3.481940736973164*^9}, {3.6302077654764643`*^9, 3.6302077702623034`*^9}, {
   3.630210588958201*^9, 3.630210589517418*^9}, {3.6318342427598057`*^9, 
   3.6318342433832703`*^9}, {3.6609655928396063`*^9, 3.660965593278862*^9}, {
   3.660966178597251*^9, 3.660966184571169*^9}, 3.682482352961383*^9, 
   3.682482475328929*^9, {3.6825613736960697`*^9, 3.68256138548776*^9}}],

Cell[CellGroupData[{

Cell["\<\
bosemvalsKBS = Recurse[
{
\t\tkB->1.38 10^-23,
\t\tT->295,
\t\tg->9.8,
\t\tmu0->4 N[Pi] 10^-7,
\t\trhoeAl->2.65 10^-8,\t\t\t(* Resistivity of Al *)
\t\trhoepianowire->30 rhoeAl,\t(* Resistivity of P.W., GUESSTIMATE *)
\t\tsigmaeAu->2.67,\t\t\t\t(* Resistivity of Au paint, measured *)
\t\tmassSOS->0.25,\t\t\t\t(* Final design value *)
\t\tmassM->rhomM l N[Pi] a^2,
\t\tPi->N[Pi],
\t\trhomM->7400,\t\t\t\t(* Mass density of magnets *)
\t\tztube->0.0155,\t\t\t\t(* Separation for magnet to push its own weight, \
measured *)
\t\tzpickup->0.018-l,\t\t\t(* Separation for magnet to pull its own weight, \
measured *)
\t\tmasspullapart->0.060,\t\t(* Force (in kgf) to separate magnets *)
\t\t(* preferred value of small magnet dipole moment, A.m^2 *)
\t\tmzpref->0.007945632135874319,
\t\t(* magnet moment per unit volume for magnet stuff, assumed the same for \
big and small, in M units: A/m *)
\t\tmz->mzpref/(lold*N[Pi]*aold^2),
\t\t(* magnet moment per unit volume for magnet stuff, in B units: T *)
\t\tmzB->mz*mu0, 
\t\tlold->0.003175,\t\t\t\t(* length of LIGO small magnets *)
\t\taold->0.0009525,\t\t\t(* radius of LIGO small magnets *)
\t\tl->0.003,\t\t\t\t(* length of big magnets *)
\t\ta->0.001,\t\t\t\t(* radius of big magnets *)
\t\tdipole -> mz*l*N[Pi]*a^2,
\t\tlayers -> 27, (* 10212-Gr.12-body BOSEM intermediate.pdf *)
\t\tturns -> 600, (* 10212-Gr.12-body BOSEM intermediate.pdf *)
\t\twirediam ->0.36*0.001, (* 10212-Gr.12-body BOSEM intermediate.pdf *)
\t\t(* coil length *)
\t\tcoillen->(11-3)*0.001,  (* 10212-Gr.12-body BOSEM intermediate.pdf *)
\t\t(* the ends of the coil relative to the centre of the coil *)
\t\tcoilz1->-coillen/2,
\t\tcoilz2->+coillen/2,
\t\t(* the inner and outer radii of the coil *)
\t\tcoilrad1->(18/2)*0.001, (* 10212-Gr.12-body BOSEM intermediate.pdf *)
\t\tcoilrad2->coilrad1+wirediam*layers, (* 10212-Gr.12-body BOSEM \
intermediate.pdf *)
\t\tcoildrad2max->(49/2)*0.001, (* 10212-Gr.12-body BOSEM intermediate.pdf *)
\t\t(* the number of turns *)
\t\tcoilturns->600, (* 10203-Gr.12-Osem intermediate mass.pdf *)
\t\tcoilsigma -> coilturns/((coilrad2 - coilrad1)*(coilz2 - coilz1)),
\t\tmagposactpromec->0.0074, (* Inventor, Promec, Fabian *)
\t\tmagposactv2->zmax[KPR] 
\t}
]
vals[KBS] := bosemvalsKBS;\
\>", "Input",
 CellChangeTimes->{{3.453837228357688*^9, 3.453837230833909*^9}, {
   3.463844183252262*^9, 3.463844223147016*^9}, {3.478894862544446*^9, 
   3.4788948852377567`*^9}, {3.478894985619047*^9, 3.4788949913587503`*^9}, {
   3.4788950240972023`*^9, 3.478895025494358*^9}, {3.481940748223406*^9, 
   3.481940763510077*^9}, {3.6302077790327063`*^9, 3.630207779944365*^9}, {
   3.630208292557073*^9, 3.630208293170534*^9}, {3.6302085800514812`*^9, 
   3.630208649083247*^9}, {3.630209645346671*^9, 3.630209663817658*^9}, {
   3.630209701977907*^9, 3.6302097023837023`*^9}, 3.630209734594172*^9, 
   3.630210623319276*^9, {3.6302114423356447`*^9, 3.6302115422890863`*^9}, {
   3.630211579624671*^9, 3.630211581024807*^9}, {3.630211687932591*^9, 
   3.630211722300425*^9}, {3.6302984714100847`*^9, 3.630298473322809*^9}, {
   3.630361294367758*^9, 3.6303612947567253`*^9}, {3.6303613801867123`*^9, 
   3.6303613881298*^9}, {3.6318342637097387`*^9, 3.631834265518305*^9}, 
   3.631834943063822*^9, {3.631834997615004*^9, 3.6318350023087177`*^9}, {
   3.631839258309725*^9, 3.631839261092559*^9}, {3.631850413860784*^9, 
   3.631850414643579*^9}, {3.660964929330432*^9, 3.660964930507349*^9}, {
   3.6609659120081673`*^9, 3.660965913870233*^9}, {3.661032653716414*^9, 
   3.6610326614655447`*^9}, {3.661034434941803*^9, 3.6610344855908623`*^9}, {
   3.661034533527267*^9, 3.661034560199753*^9}, {3.661034660140182*^9, 
   3.661034763606357*^9}, 3.661050883526635*^9, {3.661050914400351*^9, 
   3.66105096115602*^9}, {3.661054587253252*^9, 3.661054587852759*^9}, 
   3.6610557414106913`*^9, 3.661055781287154*^9, 3.6611306147905912`*^9, {
   3.661131476713114*^9, 3.661131482574223*^9}, 3.661139095093113*^9, {
   3.661139150981187*^9, 3.661139157171829*^9}, {3.6611392024219837`*^9, 
   3.661139245368763*^9}, 3.661226525785656*^9, {3.6612266529333878`*^9, 
   3.66122668360991*^9}, 3.6653554519615*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"kB", "\[Rule]", "1.38`*^-23"}], ",", 
   RowBox[{"T", "\[Rule]", "295"}], ",", 
   RowBox[{"g", "\[Rule]", "9.8`"}], ",", 
   RowBox[{"mu0", "\[Rule]", "1.2566370614359173`*^-6"}], ",", 
   RowBox[{"rhoeAl", "\[Rule]", "2.65`*^-8"}], ",", 
   RowBox[{"rhoepianowire", "\[Rule]", "7.95`*^-7"}], ",", 
   RowBox[{"sigmaeAu", "\[Rule]", "2.67`"}], ",", 
   RowBox[{"massSOS", "\[Rule]", "0.25`"}], ",", 
   RowBox[{"massM", "\[Rule]", "0.0000697433569096934`"}], ",", 
   RowBox[{"\[Pi]", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"rhomM", "\[Rule]", "7400"}], ",", 
   RowBox[{"ztube", "\[Rule]", "0.0155`"}], ",", 
   RowBox[{"zpickup", "\[Rule]", "0.015`"}], ",", 
   RowBox[{"masspullapart", "\[Rule]", "0.06`"}], ",", 
   RowBox[{"mzpref", "\[Rule]", "0.00794563213587432`"}], ",", 
   RowBox[{"mz", "\[Rule]", "878020.9598010788`"}], ",", 
   RowBox[{"mzB", "\[Rule]", "1.1033536788035714`"}], ",", 
   RowBox[{"lold", "\[Rule]", "0.003175`"}], ",", 
   RowBox[{"aold", "\[Rule]", "0.0009525`"}], ",", 
   RowBox[{"l", "\[Rule]", "0.003`"}], ",", 
   RowBox[{"a", "\[Rule]", "0.001`"}], ",", 
   RowBox[{"dipole", "\[Rule]", "0.008275152591026784`"}], ",", 
   RowBox[{"layers", "\[Rule]", "27"}], ",", 
   RowBox[{"turns", "\[Rule]", "600"}], ",", 
   RowBox[{"wirediam", "\[Rule]", "0.00035999999999999997`"}], ",", 
   RowBox[{"coillen", "\[Rule]", "0.008`"}], ",", 
   RowBox[{"coilz1", "\[Rule]", 
    RowBox[{"-", "0.004`"}]}], ",", 
   RowBox[{"coilz2", "\[Rule]", "0.004`"}], ",", 
   RowBox[{"coilrad1", "\[Rule]", "0.009000000000000001`"}], ",", 
   RowBox[{"coilrad2", "\[Rule]", "0.01872`"}], ",", 
   RowBox[{"coildrad2max", "\[Rule]", "0.0245`"}], ",", 
   RowBox[{"coilturns", "\[Rule]", "600"}], ",", 
   RowBox[{"coilsigma", "\[Rule]", "7.716049382716049`*^6"}], ",", 
   RowBox[{"magposactpromec", "\[Rule]", "0.0074`"}], ",", 
   RowBox[{"magposactv2", "\[Rule]", "0.006718812869426184`"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.661139895443305*^9, 3.6612197637586393`*^9, 
  3.661226528308082*^9, 3.66123117027153*^9, 3.6612312047457733`*^9, 
  3.661231445410605*^9, 3.661341351033556*^9, 3.662246358338625*^9, 
  3.662328160805382*^9, 3.662331411024106*^9, 3.662338028367997*^9, 
  3.664593081416539*^9, 3.665355473107885*^9, 3.6653740931347647`*^9, 
  3.682483217544427*^9, 3.682561826302165*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"optdata", "[", "KBS", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.031252674531264006`"}], ",", 
      RowBox[{"{", 
       RowBox[{"z", "\[Rule]", "0.0069342498594803965`"}], "}"}]}], "}"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"Minimize", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"fz", "[", 
          RowBox[{"KBS", ",", "z"}], "]"}]}], ",", " ", 
        RowBox[{"0.006", " ", "<", " ", "z", " ", "<", " ", "0.012"}]}], 
       "}"}], ",", " ", "z"}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.478970745257534*^9, 3.478970764425056*^9}, 
   3.4796619224973173`*^9, {3.480244382554545*^9, 3.480244405961742*^9}, {
   3.4819408015577917`*^9, 3.4819408027090397`*^9}, {3.481940979763582*^9, 
   3.481940981746011*^9}, {3.481941548420309*^9, 3.481941559738948*^9}, {
   3.630208310775996*^9, 3.6302083160559387`*^9}, 3.6302102241338043`*^9, {
   3.630210607856474*^9, 3.6302106082793016`*^9}, 3.630361338897683*^9, {
   3.631834266175609*^9, 3.631834266847229*^9}, {3.660964930738454*^9, 
   3.6609649309705153`*^9}, {3.662330765190806*^9, 3.662330775806217*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.013815486037444383`"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", "\[Rule]", "0.006973987296222758`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.630361340786025*^9, 3.6303616440690804`*^9, 3.6303619723403873`*^9, 
   3.6304700727391043`*^9, 3.631828016987249*^9, 3.6318286721706467`*^9, 
   3.631835182694659*^9, 3.6318395262620773`*^9, 3.6338315632012978`*^9, 
   3.633834180737639*^9, 3.649109165341728*^9, 3.660965574035901*^9, 
   3.660965944918187*^9, 3.660968309086734*^9, 3.660968613523533*^9, 
   3.660969237910781*^9, 3.6609693377302094`*^9, 3.661056650484016*^9, 
   3.661119279410141*^9, 3.661130597695014*^9, 3.661130716319398*^9, 
   3.661139973806657*^9, 3.661219841012673*^9, {3.66123118485662*^9, 
   3.661231204928143*^9}, 3.661231452503765*^9, 3.661341428200305*^9, 
   3.6622464370171556`*^9, 3.662328242363803*^9, 3.662331488525536*^9, 
   3.6623381034821243`*^9, 3.664593157738793*^9, 3.665355544692668*^9, 
   3.665374165416979*^9, 3.682483281483121*^9, 3.682561889238224*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fzi", "[", "KBS", "]"}], " ", "=", " ", 
   RowBox[{"FunctionInterpolation", "[", 
    RowBox[{
     RowBox[{"fz", "[", 
      RowBox[{"KBS", ",", "z"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", "0", ",", "0.013"}], "}"}]}], "]"}]}], ";"}]], "Input",\

 CellChangeTimes->{{3.661121231903079*^9, 3.661121302673418*^9}, {
   3.66112135471321*^9, 3.661121364047564*^9}, 3.661121573023286*^9, {
   3.661121981470016*^9, 3.661121984145525*^9}, {3.661122016670216*^9, 
   3.6611220263968563`*^9}, {3.661122422824706*^9, 3.661122440665392*^9}, {
   3.6611225257271423`*^9, 3.6611225561384287`*^9}, 3.661122943936385*^9, 
   3.661124072219921*^9, 3.661124107400278*^9, {3.66114125831656*^9, 
   3.6611412583250227`*^9}, {3.6611413097183743`*^9, 3.661141309722828*^9}, {
   3.661142955018881*^9, 3.661142976745582*^9}, 3.6612189023455*^9, {
   3.6612189588266687`*^9, 3.6612189659137297`*^9}, 3.661219472807549*^9, {
   3.661219548644806*^9, 3.661219555082078*^9}, {3.661219665411684*^9, 
   3.661219677299014*^9}, 3.661219955608039*^9, {3.661231280097413*^9, 
   3.661231299243288*^9}, {3.661231343507148*^9, 3.66123134446735*^9}, {
   3.662262672841395*^9, 3.662262682169732*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"plot", "[", "KBS", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    GraphicsBox[{{}, {}, 
      {RGBColor[1, 0, 0], AbsoluteThickness[1.6], Opacity[1.], 
       LineBox[CompressedData["
1:eJwV13c8lf0bB3Cj8pAoiZLMaKBIhPAppWGmgRSeSOgpe51z7nOMY+Tcdwup
UMhIRVEoMiqjEI/2+DWMRDJ7GhT1+/rrvN6v17nv+zuu6/peX1UP/+1eIkJC
QmLCQkJTv9UyHUe3rf1iJiSk0r5zUMrc8b3MddeKdvOo4CZWhtuAeWpd4Frj
ig7zqOz5/zi7TZiXG6gKLakYMY/qqFTUcpNE41BE16IKIQjtkRX64aoIu5bc
HQsqZkNXWMk33lUbSRUmkvIVKmj3O3pq1V5TlBbH9c2r0EUGz/XOaScbDASM
blM7vB6Ty/ZYjoS4QmO+bfJo91bMX/NNPbDFC84NCzqV5zugb614mVjWIYyq
FIfantmF/WkJec2jgXgrumgytWU3DmiYKBuvC4WieJFwr7MbjE6KvSqriICI
yXpzjs8+GMgcGZcQpaCiL/9tNs8Tx3g39NP+48Gnmtd/6Y4XPpz9b/De7yi4
0A6v2t9449fTs+t8HWOgIrmZ7zTki/4/tfVyKXxIK7X906l9CDYNdg3Tnsei
IPiO7fhGP8Tu+31tz0AcDHTU1khYBiBdry5tlXAChNnfcjd7BIJVPKrl9yMB
F3x40jaHgiAjkr1koOEIXihvW/CYCUb3pPqRQiYRnREvlJXTQjC6WGvpqRUC
+FT4uVw9HwLD4olhFT0BhsannzLLCcGSX+Nzr+gL8JO9WmJvYQjeT58WWGkk
gCz35NczNSHY4K3Fb7AQYEu0dZNMdwialII1jzoKUJxYGzRDOxQuRza6dVMC
RKVdbBisDsXcmA6zG/UCHFIpq/W+FwqFY4krWhsFcM6/V9HZGIprJt+Teh4I
oHv9bdGzf0NhoJl5c06rAJ1Nc1OrO0NxbGF7sNMzASzGIw8cnR4Ge82yp2d6
BJjm7CymYxuGC4avEoam0UicJ7710JswJHkdW/PdnMZEoLj72Y4wbNTbKHti
HY2ANvHQxg9hqIxcfGGpBQ3HBIlslcEwrNSVfbzLksbi8ZnjTyfD8L2ISsiy
pnHnjdQlM+VwHE966ffDicZYjqy4tEc4BguHPQr9aRwSmqdseiAcGzdMVigG
0ni/d56B78FwbC8vuU8H0WicJ7evLigcrdU1YgdCaaQkyFeE88MxrmKoPJND
Q/cfBd+O3HA8KBJ6LB9Pw3uVSlNJbzhwzIhtmk7GX3Kux2ggHKJ9flGZGTSS
9BaK3BkJx/UH38SFz9Oo0ZVb2zYejlOvnl6szaIht1KyqH9mBOp3fpfVyqdR
rzV2Ql03AgL6Zk9lMQ0VjXbnUxER8MvkyFXX0yjPtQ1V5EZA/aKO3kgDDZvF
LSdzoiMQkJbwXPU+jXD1xuYSQQT6frrdi2qi0aZaZdqWEYGHua2aOm00uEoF
KmJ3I8AvMNm/7gWN1/JRfRHiLOxqf1K9vY/Gj8MjKjdmsdAneZa16RMN2fq/
dw/OYaGmUnrMqJ+GXcD65n0KLLBcppsrDNCoeyBSaKXFwgLT6q+twzQKWXH+
irYs+MhXWfz8ToP3P8H32hMsZF96PdNnGkPy4NeKnyks3Aj4nrx6OoNbCf94
rz7LgqmW58c/xF/0bV4WZLPw46D65yQxBt7MrMqT11kQu9jPvizBYJvZCa7n
UxaGs0b6MmczUMs8NU1sPhvr5Wsv5S1kkGdCTWgpsvGFpVCyRZHB0uceX7ep
sHHZc3FqP7HOLN0PaUvZWJe37OdyJQZGnOa6FcZsRLRb6J5XYWDn9CfG0YWN
Uosf8XYaDB596WFz3Nh4ELc89j3xzmMPg7I82NAozfHw12Swu+GsR/9BNlqv
2NbTSxjs119tweOwYfn9gcrNZQw40r7C+RlssIJzA17qMPh92X68OYuNQ2PJ
3k4rGERtMhwdziXj++qQ+5Q4nivaaVzEhk/dkwctKxkkfT53p7WajfamZQ2F
egwK7j+O/PaODXr8R72xAQMtz4pwhW42bsnmB+UTX/2d6Y9eNsn3ZjEZQwY3
DA67Jw6zEaDG+9RDXJMjhkVCHMwRbj0ZZcTgaaTp742qHBS867gWvZYByzxr
ok6Dg9fPr+d9IFaaFP1lsZyDeXlmjptMGfiwW36s0+fgvOe/fdPNGEyGuIya
WnLw5oHS21BzBhf0a4Zvb+VgxaMvJW3EW76oDpnYcRA5rLZRE2Q+/p/6jZw4
mC/1KfsRsebBiA+rfTkQ099is2A9g5alb7puHCbPWxvN8yEO6EXnqiAOrCqW
nC8jrtwv9k6Xw4HrGsdRGwsG9u6pL7SPctCuoJN/aAODiJ2lzYtLOOjknksO
sGSwaO78ppwyDh6Vzo29QnzvEee+WiUHOXf/Ne4hlrTfUK9Sx8GniYPfd25i
kL31cbXiMw66dvtWa2xmsOkvw6r0Vxw0ZG7tdCQeaDxbqfCOg5hfMq3xxIYb
992c38tBdMr1yS7iZvORYtlxDjiFfz9ktjDwn9xxLXmSzE+4waiUWLbqZpGM
CAXPK2X+r4ndjCMvz55JIT77qLn6VgaiY10Fx6UpWFUvemFJXFC+6aKULIVX
bfRa761T+SGVK7mIwq7gHb75xKe/BF6gVSng+S79emLTkmdZEpoUhtsSmjuI
41ecO/fXSgqZqg/3yVmReBkUykjQp5BhneCxkrj9yv60GUYUXK7U6W0mXrhM
+/S09RTmF84xCybeUhNTYmhJgX9Ud1k8cciOVy0+Wym01HtJniHO6lv5Mc2W
gk3/t48FxA+58UKtDhTcUzUqbhGPybxV+LOLeJ8x/z6xRoG+gZ4LhYLuUMtn
xNvNBPaebhRSypSFuoh5jzt8T3lQ4PlzbgwSX/ZeE3v/AIXaS63uY8QvJo6e
Hz9IoXTCZbqINYNpSR9uaflTuCnkkytBrLtk7RPXYArqdsZmMsR7q04OHg+n
4MCd2z6fONGhT+weh8J5zbWuSsTlH83VvkZS2N/19YMacRfnlKlmLIWJLXHe
msRScwYcnY9QqP+i27OUeG2+RaCAoSAbYeq2nNhn7Vm66gSFLYEDj6ec0j6c
N5RCoTIsbsOU73htuqNylkKDik3x1PODPzNebz9H3icWt2Dq/Qon/vsam01B
pj4kcur7mzSspG/mURAfcu9aRBxUmbXs0yUK05Roi6nxZ9r/2LDwKgW3AZOs
OcQPP9i62V6nEDh645c48RgrNyKynMKZBpNdwsSLpX8llVRSWCksW/SDrN+2
XIei7hoKx01jRafWlzIuuD+vjsLc2e3OncSX2n53br5PQV7WtOgp8XPPXROs
FgpfOySFp/ZPZPyKXOG/FGZIJ+yc2l8X9d3Ws19S0B9J/HWaOP7WNS+LNxRE
n6bbT8XLDdsZUSEdFILZvrlT8SQZcaP0ZR+F9AArB2tio1kS/0oMkvmOfrxk
QOx14e9PpqMUYk45TFMmrnk4Syl7nMLvKzm1QySeA1R9EnwluBCvuO0UQ5xR
XpOdLsXFTVGrxv3ETdbzqlpluLA0aDHaRKwWdm9EbyEXh6/eWj6D+GmzostP
LS6eX7izlU3yT+jv4BBtXS6C2g6830ms863pmNtqLupzFnNWEMcrh9fdM+Xi
a+F4wzuS32tCHmnTtlyEdScW6xPHa+fZym/nQknb75II8dMPEX45jlxcqreP
bCf1JGiXSvFtdy7MDH3qfIivGvrrDwRyIefAKadJ/ZkcstgZEcZFmt2LLAdi
m4tyodM4XOSbfT4oR/xJvqZcMZaLZevPZGZsJPs5Lmlim8pFxtyUlHRS74JL
OlxepXGh9sQ03pn4nm8pxyuTi2cazi6yxO6v91RzC7hIebbhyhFSL9NuX153
tZIL4xRq3JPU09m8LZul33Ohbvo2uYfUa3dDRZ/0bi5UL55/doL46tDwkSV9
XJzq2/zHhNja/XQzRrkoxbWZDKn/8es+2gaI8sCEuMmokvNhQiR256MlPFzK
L1CXN2bQl1C7LzmAh7YM4wqDVWS/4sQtJEJ5sHVa2n6HnGcO/B1q0SweHgzl
dlsRV/J6u/xieHhsmiS8V5cBEyq93yqFBwmpzWpB5Hxc6el+QPgWD3etveG3
nEGY+Z+D/n94+Og7srxAlcFy063WH0Uj0Xi9NHgu8XvjZC3XvyJxesGeOi45
37cYLBmwmhMJN4YKt1dmsEDb/rCmeiRmH99m2Ev6g6oFmf5vN0ViM3M8sk+e
1ONv5iHWxyIxKraXv3oWA/MmTkBoUiSCrZT2HpVkwD5361BmaiR4hSpePTNJ
fbZc5fXf+UgErf/yVzLpVzpSNRzTr0Xiapty5gfSz9QYSRp9bo+EX6jrun0i
DMxqBrgN4lGo+Lxc+x7pl8aFK9d72URhyMjOSe8tjYJJuQ0X7cg9ZGf9f5Zv
aDiPB2/8tC0KCQsvX9v9P9IPjuhsPrwrCqclFibwXtEIep9tE+oWhczxoerq
ZzT6qxKd4gKiIM5sSJUh/d/r8N2H81KI/6rbMr+Gxu3BsTM9b6JQK1jjl0/6
V+/LSX5NntGoj1iz+/t2Gg/mfls1vS8abwYWKCqL0Ajp/NUYHR6DtVzTaz+z
BJCIcn21bzIGwnE3svXMBfgc43k75hgft6XYP7a1JKLcsX6hmFwsztw6Udi1
OxGGLwYPdqfFQinIIE/94xEIV91OFNKKI32D59hDzyMoD/ygGV0SB0s779xD
HxNQRpckW2yIJ+tqrhy0JwEHt28e3vM4HjHbs2KXPIqHeP+appdOCdideLpX
YEf+1/MwKLUvAedDM9Lv1saROKhKu+l/BH8k1Vb0GsfBXju0RPfrEcia/lYs
Ko+FmsTj0/38RMj1RVNvl8ai41bihJiEAOurmgzP5vGhbW733E1SgMOicau3
5/ARUSdTXCYlgJ7OYoeZ2XzMaUv39JwrwEjh3V5uBh8W3UXNNYoCeE7sO74/
mY/cWY/PhK4k96wn1PCaaD58PRQMuncKELl0g87YXj7Ke99JmTgJIP/Jz63M
hQ+Rwzl9J3YL0HJNoTTImY+0cO0MczcBvj7Jax3cwcdDxlw0zVsAF7ngmh4r
Plbc9Hi0jU3uedSKmjdGfLBNl1y5SO5xcer7bTIM+Wi8+zn2N0+AJ129wntX
8+H+MMSokC9AkM7R7v+t5ONEZ3ym2FEBXp1cE/9Wk483B6xZbscFwOnGHecX
87F0QHpH2UkBPKolrNzV+Lj7/cwMz1QB7Ea8SjoX8SFFuXZUnBHAvva5Ws5C
PlyE1Spnp5P56RdX71/AR378x2TvcwKM6SjHaMrz8WXmlcM1mQI8P74toE+W
j/8DAF2BgQ==
        "]]}, 
      {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
       LineBox[CompressedData["
1:eJwV13k8VN8bB3BbiSylLEmFCoUikrJ8LElIRWUrFF9LIktjm7kzlrHOXKWS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        "]]}},
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->{True, True},
     AxesLabel->{None, None},
     AxesOrigin->{0, 0},
     DisplayFunction->Identity,
     Frame->{{False, False}, {False, False}},
     FrameLabel->{{None, None}, {None, None}},
     FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
     GridLines->{None, None},
     GridLinesStyle->Directive[
       GrayLevel[0.5, 0.4]],
     Method->{
      "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
       AbsolutePointSize[6], "ScalingFunctions" -> None},
     PlotRange->{{0, 0.013}, {0., 0.013815486037351908`}},
     PlotRangeClipping->True,
     PlotRangePadding->{{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}},
     Ticks->{Automatic, Automatic}], ",", "\[IndentingNewLine]", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"fzi", "[", "KBS", "]"}], "[", "p", "]"}], ",", 
        RowBox[{"fz", "[", 
         RowBox[{"KBS", ",", "p"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"p", ",", "0", ",", "0.013"}], "}"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Red", ",", "Black"}], "}"}]}]}], "]"}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.4789618100364523`*^9, 3.478961850760915*^9}, 
   3.478969868098156*^9, 3.4789702271107073`*^9, {3.478971402742322*^9, 
   3.478971407269801*^9}, {3.478973436528585*^9, 3.4789734559838*^9}, {
   3.4794970273251*^9, 3.4794970280748262`*^9}, {3.479497850691868*^9, 
   3.479497851721608*^9}, {3.4802445496159487`*^9, 3.4802445841180058`*^9}, {
   3.4802446656757193`*^9, 3.4802446687524443`*^9}, {3.481940803363203*^9, 
   3.481940804034131*^9}, {3.481941063760079*^9, 3.4819410664063997`*^9}, {
   3.481941556057631*^9, 3.4819415664906*^9}, {3.630208312322345*^9, 
   3.63020831448879*^9}, 3.630209982122305*^9, 3.630210040824745*^9, {
   3.630210608691247*^9, 3.6302106091463537`*^9}, 3.6302116072117853`*^9, 
   3.6302119179137897`*^9, 3.6304701238527927`*^9, 3.631834820615905*^9, 
   3.649109628464219*^9, {3.649110363868889*^9, 3.649110366770886*^9}, {
   3.649110567151823*^9, 3.649110570373554*^9}, {3.661123689182354*^9, 
   3.661123723132988*^9}, 3.661123839830414*^9, {3.661123888550177*^9, 
   3.6611238924215937`*^9}, {3.661123959516914*^9, 3.661123970823284*^9}, {
   3.661124020120494*^9, 3.661124020504492*^9}, {3.661124084594274*^9, 
   3.66112408490854*^9}, {3.661124132485323*^9, 3.661124133744603*^9}, {
   3.661127129389042*^9, 3.6611271300441732`*^9}, {3.6611285421516657`*^9, 
   3.6611285486416283`*^9}, 3.661139350752645*^9, {3.661141258332346*^9, 
   3.661141258345943*^9}, {3.661218500125923*^9, 3.661218503251073*^9}, {
   3.661219741762664*^9, 3.661219744937758*^9}, {3.662327413173229*^9, 
   3.6623274145575047`*^9}, 3.662328917013859*^9, {3.662330851583359*^9, 
   3.662330851967507*^9}, {3.6653556759941263`*^9, 3.665355676592997*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {RGBColor[1, 0, 0], AbsoluteThickness[1.6], Opacity[1.], 
     LineBox[CompressedData["
1:eJwV13k8VVsUB3BJKYTwTKmkkhdlLgo/Q6SBJFOKXqhQ5vnec+/lXsS9Vwkp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      "]]}, 
    {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
     LineBox[CompressedData["
1:eJwV13k4lF8bB3DJloQoWyq8haSyl8KXikSEIimKSlKhGGZ5xjJjnZmKkn4S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      "]]}}, {}, {}},
  
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 0.013}, {0., 0.013815486037354552`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.649109686790821*^9, 3.6491103787345247`*^9, 3.660965322933999*^9, 
   3.6609691450694323`*^9, 3.6610562264789333`*^9, 3.661118658026022*^9, 
   3.661119055121579*^9, {3.661123710650861*^9, 3.661123724289307*^9}, 
   3.661123847867857*^9, 3.661123892991621*^9, {3.661123960098845*^9, 
   3.66112397157833*^9}, 3.661124011481043*^9, 3.661124062306964*^9, 
   3.661124248993616*^9, 3.661124781109477*^9, 3.661127174324749*^9, 
   3.661128593139056*^9, 3.661139696344545*^9, 3.661205468105528*^9, 
   3.661218317171567*^9, 3.6612184134232492`*^9, 3.6612187208062153`*^9, 
   3.661219853430214*^9, 3.661231205016076*^9, 3.661341441545279*^9, 
   3.662246450738008*^9, 3.662328256461569*^9, 3.662331501781601*^9, 
   3.662338116211164*^9, 3.664593170747657*^9, 3.665355555906435*^9, 
   3.6653741765630007`*^9, 3.682483291360566*^9, 3.6825618992236767`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"zmax", "[", "KBS", "]"}], "  ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{
    RowBox[{"optdata", "[", "KBS", "]"}], " ", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.478970786649661*^9, 3.478970802864567*^9}, {
   3.4796619220112333`*^9, 3.4796619454416037`*^9}, 3.479665671740583*^9, {
   3.48194080448247*^9, 3.481940804971867*^9}, {3.630208319233528*^9, 
   3.630208320862918*^9}, {3.630210609409204*^9, 3.6302106096880713`*^9}, {
   3.631834268382159*^9, 3.631834268966103*^9}, {3.66096493160435*^9, 
   3.660964931820117*^9}}],

Cell[BoxData["0.006973987296222758`"], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGAwAeKQpjXdc16/dFyUG2Mx481Lxxmm1slvgHRVmlDOOyDd
V36j8z2Qvu0kNBlE/39ZeoTz3UvHKOkVp58A6ZCHs3P7P7x0XPNepcTt40vH
A2Uu1SD61gOZzSDaKSPnPIjWPVjJ5Q6kK1Q3brPmfu0odHpRojDPa8eKhqen
QPQV5gtPQfRj87fpIkBaaZrYJEsg/Sz3xhsPIL1feuvmWCDddTW8ZhKQPmWk
3KbJD9S3juMGiD61jJFTF0hP+y6toQ/iX8y4+FvoteOGFTMk/gLpu3fXTJU3
eO1Y0Hb4xh63146H9suz7wXS8i1L9PYB6TTB/YtAtNafbRtA9Jy2gMCXQPrC
9fdP2d1fO8YY7sjhBdKdHBy1ILrtmjKTEJC+83ADoyWQLnqzsMcOSMvMMkoo
AdICnFFuep6vHd2EBCzCgPSktn1nw4F00a0OjmggXXYgUmmF72vHD++aU2T8
gfZuE65RBdLb3+d0H89/7bgmL+PtWyANADr003A=
  "]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"magposactpromec", "-", 
   RowBox[{"zmax", "[", "KBS", "]"}]}], "/.", 
  RowBox[{"vals", "[", "KBS", "]"}]}]], "Input",
 CellChangeTimes->{{3.631850926207306*^9, 3.631850980824053*^9}, {
   3.6609649320201817`*^9, 3.660964932219471*^9}, 3.6611390951225233`*^9, 
   3.661139202438587*^9}],

Cell[BoxData["0.00042601270377724213`"], "Output",
 CellChangeTimes->{{3.631850951545291*^9, 3.63185098135504*^9}, 
   3.63383156333751*^9, 3.63383418079591*^9, 3.649109165431679*^9, 
   3.6609655741379547`*^9, 3.6609659450527773`*^9, 3.660968309189497*^9, 
   3.66096923802045*^9, 3.6609693497617607`*^9, 3.661056650541357*^9, 
   3.6611192795571537`*^9, 3.661130597821911*^9, 3.661130728313856*^9, 
   3.661139985162601*^9, 3.6612198535816717`*^9, 3.661231205124145*^9, 
   3.6613414416259327`*^9, 3.6622464508864717`*^9, 3.662328256544293*^9, 
   3.662331502028411*^9, 3.662338116327446*^9, 3.664593170851795*^9, 
   3.665355556174018*^9, 3.665374176660561*^9, 3.682483291457554*^9, 
   3.6825618993362637`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fmax", "[", "KBS", "]"}], "  ", "=", " ", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"optdata", "[", "KBS", "]"}], " ", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4789708091780043`*^9, 3.4789708248973703`*^9}, 
   3.479661922078005*^9, 3.4796619593447857`*^9, 3.479665787682528*^9, {
   3.481940805601218*^9, 3.481940806091435*^9}, {3.630208322616778*^9, 
   3.6302083244414253`*^9}, {3.63021060995541*^9, 3.63021061023507*^9}, {
   3.631834269559742*^9, 3.6318342700157347`*^9}, {3.6609649324265423`*^9, 
   3.660964932644462*^9}}],

Cell[BoxData["0.013815486037444383`"], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGAwAeKWPeu757x+6fjqVazFjDcvHYUybZLfAGlvBZGcd0Ca
KeVm53sgHccmNhlE2xwsO8L57qVjacnK00+AdOCkubn9H146Mm9SK3H7+NLx
yXfXahAtsEF2M4helpZ3HkS39VdzuQPp+Psbt1lzv3ZU+7UkUZjnteOEl99O
gejdWy88BdFOie/TRYD03WUSkyyB9I6mW288gHTHvG2bY4F06/nImklA+sN5
lTZN/teOZdO4boBo5hgmTl0g/fi9rIY+kJaKz7n4W+i14xK/WRJ/gfSpH+um
yhu8drzCcOzGHrfXjuIeyux7gbTaquV6+4D0fKtDi0D0i587N4DoPrmgwJdA
OmT656fs7kB3TNiTwwukMyR5akH0pVVqTEJAmslyC6MlkF4rvqzHDkivm2Ga
UAKkv9XGuel5vnaseShkEQakH/EePhsO4hv3cEQD6be7YpRW+L52bPZvT5Hx
B7pju1iNKpBWOVzQfTwfGA6Hc96+BdIA5YnQSg==
  "]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"deriv2", "[", "KBS", "]"}], " ", "=", "  ", 
  RowBox[{
   RowBox[{"-", "2"}], "*", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"fzi", "[", "KBS", "]"}], "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{"zmax", "[", "KBS", "]"}], ",", "2"}], "}"}]}], "]"}], 
      "]"}], ",", 
     RowBox[{"z", "^", "2"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479660163969679*^9, 3.479660203608347*^9}, {
   3.479660334457396*^9, 3.479660335305067*^9}, {3.4796611591764927`*^9, 
   3.479661208701754*^9}, {3.479661250977075*^9, 3.479661305176928*^9}, {
   3.479661346153286*^9, 3.479661372928776*^9}, {3.479661851029785*^9, 
   3.479661859051705*^9}, 3.4796619463263597`*^9, 3.479662725037703*^9, 
   3.479665672610339*^9, {3.481940806550991*^9, 3.48194080744361*^9}, {
   3.630208325888165*^9, 3.6302083289679956`*^9}, {3.630210610460196*^9, 
   3.630210610874337*^9}, 3.6611229758725023`*^9, {3.6611412583941383`*^9, 
   3.6611412584082737`*^9}, {3.661141309779232*^9, 3.661141309788487*^9}, {
   3.661143055996151*^9, 3.661143061547195*^9}, {3.661143129145129*^9, 
   3.661143150309849*^9}, {3.661231154888709*^9, 3.661231159334008*^9}, 
   3.66123140853971*^9, 3.662253434291039*^9, 3.662262516305318*^9, {
   3.66233327493519*^9, 3.662333282887865*^9}}],

Cell[BoxData["472.780089408755`"], "Output",
 CellChangeTimes->{3.66123150538653*^9, 3.661341441777945*^9, 
  3.6622464510594473`*^9, 3.6623282566394587`*^9, 3.662331502162277*^9, 
  3.662333283663262*^9, 3.6623381164351463`*^9, 3.664593170948761*^9, 
  3.665355556287858*^9, 3.665374176759691*^9, 3.682483291588749*^9, 
  3.682561899466426*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"z95plus", "[", "KBS", "]"}], " ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{"FindRoot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"fz", "[", 
       RowBox[{"KBS", ",", "z"}], "]"}], "-", 
      RowBox[{"0.95", "*", 
       RowBox[{"fmax", "[", "KBS", "]"}]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", 
       RowBox[{
        RowBox[{"zmax", "[", "KBS", "]"}], "+", "0.001"}], ",", 
       RowBox[{"zmax", "[", "KBS", "]"}], ",", 
       RowBox[{
        RowBox[{"zmax", "[", "KBS", "]"}], "+", "0.005"}]}], "}"}]}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479658613425561*^9, 3.4796587501410933`*^9}, {
   3.479658790462825*^9, 3.4796587993088913`*^9}, {3.479658852062684*^9, 
   3.479658891629363*^9}, {3.4796589431729183`*^9, 3.479658948798299*^9}, {
   3.479658987032153*^9, 3.47965898990287*^9}, {3.479659310386307*^9, 
   3.4796593125701933`*^9}, {3.479661624172262*^9, 3.479661679901505*^9}, {
   3.479661945541445*^9, 3.4796619594445953`*^9}, {3.4796656734658623`*^9, 
   3.479665674680963*^9}, 3.47966578778349*^9, {3.481940808072547*^9, 
   3.4819408112927933`*^9}, {3.630208331202548*^9, 3.630208340512887*^9}, {
   3.6302106111156588`*^9, 3.630210612620454*^9}, {3.631834272292122*^9, 
   3.631834275423791*^9}, {3.660964933550774*^9, 3.660964934686805*^9}, 
   3.662334135769147*^9}],

Cell[BoxData["0.008838882166757347`"], "Output",
 CellChangeTimes->{{3.479659290207419*^9, 3.4796593177022877`*^9}, {
   3.479661644377719*^9, 3.4796616514833097`*^9}, 3.479661686065053*^9, 
   3.4796634593803263`*^9, 3.479665745824663*^9, 3.4796658197389708`*^9, 
   3.480243751933235*^9, 3.480692320796873*^9, 3.4815660640155077`*^9, 
   3.4819408973674994`*^9, 3.481940954361327*^9, 3.481941402301373*^9, 
   3.481941628781619*^9, 3.481942101498692*^9, 3.629768118581479*^9, 
   3.630209825967379*^9, 3.63021064809335*^9, 3.630210863735273*^9, 
   3.6302119044786863`*^9, 3.630288029600463*^9, 3.630319474859651*^9, 
   3.630362016214836*^9, 3.63047011744707*^9, 3.631828018334545*^9, 
   3.631828673603425*^9, 3.631835209527664*^9, 3.631839554443227*^9, 
   3.6338315761916437`*^9, 3.633834181637607*^9, 3.649109166248088*^9, 
   3.6609655749502296`*^9, 3.660965945562953*^9, 3.660968309694571*^9, 
   3.6609692385501957`*^9, 3.6609693505923347`*^9, 3.661056651074237*^9, 
   3.6611192956141233`*^9, 3.661130614471345*^9, 3.661130729128159*^9, 
   3.661139986045722*^9, 3.661219854453026*^9, 3.661231205656358*^9, 
   3.6613414423732347`*^9, 3.662246451691223*^9, 3.662328257276907*^9, 
   3.662331502769552*^9, 3.6623373377086573`*^9, 3.662338117054502*^9, 
   3.664593171546112*^9, 3.665355556792857*^9, 3.665374177279813*^9, 
   3.682483292060499*^9, 3.6825618999320602`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"z95minus", "[", "KBS", "]"}], " ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{"FindRoot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"fz", "[", 
       RowBox[{"KBS", ",", "z"}], "]"}], "-", 
      RowBox[{"0.95", "*", 
       RowBox[{"fmax", "[", "KBS", "]"}]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", 
       RowBox[{
        RowBox[{"zmax", "[", "KBS", "]"}], "-", "0.001"}], ",", 
       RowBox[{
        RowBox[{"zmax", "[", "KBS", "]"}], "-", "0.005"}], ",", 
       RowBox[{"zmax", "[", "KBS", "]"}]}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479658613425561*^9, 3.4796587501410933`*^9}, {
   3.479658790462825*^9, 3.4796587993088913`*^9}, {3.479658852062684*^9, 
   3.479658891629363*^9}, {3.4796589431729183`*^9, 3.479658948798299*^9}, {
   3.479658997678957*^9, 3.4796590027188377`*^9}, {3.479659318794853*^9, 
   3.479659344898431*^9}, {3.479661657421668*^9, 3.4796616780054293`*^9}, {
   3.479661945775414*^9, 3.479661959545474*^9}, {3.479665675209929*^9, 
   3.479665676278386*^9}, 3.4796657878831253`*^9, {3.481940812147341*^9, 
   3.481940829419257*^9}, {3.6302083429611607`*^9, 3.6302083515364437`*^9}, {
   3.630210612999134*^9, 3.630210615553306*^9}, {3.6318342761199827`*^9, 
   3.631834277785796*^9}, {3.660964934904317*^9, 3.660964935954105*^9}, {
   3.660968688340294*^9, 3.660968693115794*^9}, {3.661220236123904*^9, 
   3.6612202369311447`*^9}, {3.66233157709514*^9, 3.6623316020167513`*^9}, 
   3.662334135784853*^9}],

Cell[BoxData["0.00536687751360837`"], "Output",
 CellChangeTimes->{
  3.479659290545846*^9, {3.479659322545879*^9, 3.479659348979048*^9}, {
   3.4796616661527233`*^9, 3.479661689555737*^9}, 3.479663462870864*^9, 
   3.479665749329587*^9, 3.479665823257647*^9, 3.480243756605932*^9, 
   3.480692324819867*^9, 3.481566067504561*^9, 3.4819408974084797`*^9, 
   3.481940954404307*^9, 3.481941404076367*^9, 3.481941630539411*^9, 
   3.481942103389555*^9, 3.629768120026389*^9, 3.630209826676588*^9, 
   3.630210648265239*^9, 3.630210865289218*^9, 3.6302119056902*^9, 
   3.630288030116592*^9, 3.630319475441311*^9, 3.630362019145561*^9, 
   3.6304701204629717`*^9, 3.631828019522635*^9, 3.631828674839793*^9, 
   3.631835211501787*^9, 3.63183955652999*^9, 3.6338315764567127`*^9, 
   3.633834200417728*^9, 3.649109185050705*^9, 3.660965593642951*^9, 
   3.660965953891083*^9, 3.6609683175027514`*^9, {3.660968694777547*^9, 
   3.660968703627112*^9}, 3.660969238803543*^9, 3.6609693508732367`*^9, 
   3.661056651349106*^9, 3.661119295894168*^9, 3.661130614756443*^9, 
   3.661130729384685*^9, 3.661139986345305*^9, 3.661219854806848*^9, 
   3.661220237758685*^9, 3.661231212515348*^9, 3.661341442555441*^9, 
   3.662246451886777*^9, 3.662328257478434*^9, 3.662331502957535*^9, 
   3.662331993642603*^9, 3.662337338762288*^9, 3.662338117980036*^9, 
   3.664593172442532*^9, 3.665355557484095*^9, 3.665374178020587*^9, 
   3.682483292704982*^9, 3.682561900577341*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"plot", "[", "KBS", "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Graphics", "[", 
    RowBox[{"Line", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"zmax", "[", "KBS", "]"}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"zmax", "[", "KBS", "]"}], ",", 
         RowBox[{"1.1", "*", 
          RowBox[{"fmax", "[", "KBS", "]"}]}]}], "}"}]}], "}"}], "]"}], "]"}],
    ",", "\[IndentingNewLine]", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{"Green", ",", 
      RowBox[{"Line", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"magposactv2", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"magposactv2", ",", 
            RowBox[{"1.1", "*", 
             RowBox[{"fmax", "[", "KBS", "]"}]}]}], "}"}]}], "}"}], "/.", 
        RowBox[{"vals", "[", "KBS", "]"}]}], "]"}]}], "}"}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{"Gray", ",", 
      RowBox[{"Line", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"z95minus", "[", "KBS", "]"}], ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"z95minus", "[", "KBS", "]"}], ",", 
            RowBox[{"1.1", "*", 
             RowBox[{"fmax", "[", "KBS", "]"}]}]}], "}"}]}], "}"}], "/.", 
        RowBox[{"vals", "[", "KBS", "]"}]}], "]"}]}], "}"}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{"Gray", ",", 
      RowBox[{"Line", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"z95plus", "[", "KBS", "]"}], ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"z95plus", "[", "KBS", "]"}], ",", 
            RowBox[{"1.1", "*", 
             RowBox[{"fmax", "[", "KBS", "]"}]}]}], "}"}]}], "}"}], "/.", 
        RowBox[{"vals", "[", "KBS", "]"}]}], "]"}]}], "}"}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<z (m)\>\"", ",", "\"\<F (N/A)\>\""}], "}"}]}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.453823397414776*^9, 3.453823397824687*^9}, {
   3.453838538440839*^9, 3.453838572806719*^9}, 3.463844247723119*^9, 
   3.478894943196905*^9, 3.4788950132010527`*^9, {3.478961709433363*^9, 
   3.47896175216029*^9}, {3.478961842569364*^9, 3.478961894377494*^9}, {
   3.4789619830038633`*^9, 3.478961984506156*^9}, {3.4789699280628653`*^9, 
   3.478969982243393*^9}, {3.478970021389124*^9, 3.478970165180615*^9}, {
   3.478970224319232*^9, 3.478970261501657*^9}, {3.4789703108875017`*^9, 
   3.478970348344078*^9}, 3.478970398020482*^9, {3.478970871122594*^9, 
   3.47897087265033*^9}, {3.478971414854863*^9, 3.4789714317583723`*^9}, {
   3.4789723334965277`*^9, 3.4789723911200447`*^9}, {3.478973525233735*^9, 
   3.47897352833882*^9}, {3.479495227181163*^9, 3.4794952662789087`*^9}, {
   3.4794954131043873`*^9, 3.4794954161349077`*^9}, {3.479497883443406*^9, 
   3.479497887306903*^9}, {3.4794980354692507`*^9, 3.479498036795588*^9}, 
   3.4794982488155937`*^9, {3.479662131489229*^9, 3.479662133377276*^9}, 
   3.479665540471899*^9, {3.4802459792714577`*^9, 3.480245981573744*^9}, {
   3.4802525542284737`*^9, 3.4802525884311867`*^9}, {3.48194087775911*^9, 
   3.481940886937986*^9}, 3.630208353429995*^9, 3.6302106162586517`*^9, 
   3.631834278469103*^9, {3.631835050283194*^9, 3.631835119871463*^9}, {
   3.631838204428006*^9, 3.631838423237857*^9}, {3.660964936154292*^9, 
   3.660964936844556*^9}, {3.661139071251378*^9, 3.661139094913784*^9}, {
   3.661139202444158*^9, 3.6611392024606323`*^9}, {3.661139255808626*^9, 
   3.661139268574685*^9}, {3.662331631178034*^9, 3.662331676016757*^9}, {
   3.6623324247563972`*^9, 3.662332450033599*^9}, {3.662334135802022*^9, 
   3.662334135831188*^9}, 3.6825616138118553`*^9}],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     {RGBColor[1, 0, 0], AbsoluteThickness[1.6], Opacity[1.], 
      LineBox[CompressedData["
1:eJwV13k8VVsUB3BJKYTwTKmkkhdlLgo/Q6SBJFOKXqhQ5vnec+/lXsS9Vwkp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       "]]}, 
     {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
      LineBox[CompressedData["
1:eJwV13k4lF8bB3DJloQoWyq8haSyl8KXikSEIimKSlKhGGZ5xjJjnZmKkn4S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       
       "]]}}, {}, {}}, 
   LineBox[{{0.006973987296222758, 0}, {0.006973987296222758, 
     0.015197034641188822`}}], 
   {RGBColor[0, 1, 0], 
    LineBox[{{0.006718812869426184, 0}, {0.006718812869426184, 
      0.015197034641188822`}}]}, 
   {GrayLevel[0.5], 
    LineBox[{{0.00536687751360837, 0}, {0.00536687751360837, 
      0.015197034641188822`}}]}, 
   {GrayLevel[0.5], 
    LineBox[{{0.008838882166757347, 0}, {0.008838882166757347, 
      0.015197034641188822`}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"z (m)\"", TraditionalForm], 
    FormBox["\"F (N/A)\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 0.013}, {0., 0.013815486037354552`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.6318384165109577`*^9, 3.6318384237975817`*^9}, 
   3.631839267885446*^9, 3.631839556562364*^9, 3.631845627638177*^9, 
   3.631850423414908*^9, 3.6338315765020027`*^9, 3.633834200455875*^9, 
   3.649109185142632*^9, 3.660965593736925*^9, 3.660965953993675*^9, 
   3.66096831759861*^9, 3.6609692389591637`*^9, 3.660969350905325*^9, 
   3.6610566514599524`*^9, 3.6611192959467077`*^9, 3.661130614872768*^9, 
   3.661130729481743*^9, 3.661131490231123*^9, 3.661139986403316*^9, 
   3.661219854868188*^9, 3.661231212598123*^9, 3.6613414425809507`*^9, 
   3.6622464519518957`*^9, 3.662328257542721*^9, 3.6623315030295553`*^9, 
   3.662331993733387*^9, 3.6623324543696547`*^9, 3.662338118040475*^9, 
   3.664593172522275*^9, 3.665355557685069*^9, 3.665357077838202*^9, 
   3.665374178081009*^9, 3.6824832927724648`*^9, 3.682561900694021*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Coil calc for KAGRA BS IM (double magnets, no discs; for comparison)\
\>", "Section",
 CellChangeTimes->{{3.453751016056313*^9, 3.453751037487228*^9}, 
   3.463844192181329*^9, {3.478894850822432*^9, 3.478894851717502*^9}, {
   3.4788951705281897`*^9, 3.4788951754720497`*^9}, {3.4819407269664*^9, 
   3.481940736973164*^9}, {3.6302077654764643`*^9, 3.6302077702623034`*^9}, {
   3.630210588958201*^9, 3.630210589517418*^9}, {3.661141232361245*^9, 
   3.661141232942458*^9}, {3.661141276086359*^9, 3.661141285892767*^9}, {
   3.6824823832480707`*^9, 3.682482385206027*^9}, {3.682482458596457*^9, 
   3.682482459721465*^9}, {3.682561427221917*^9, 3.682561431525819*^9}, {
   3.682583807610358*^9, 3.682583809624868*^9}}],

Cell[CellGroupData[{

Cell["\<\
bosemvalsKBSIM = Recurse[
\t{
\t\tkB->1.38 10^-23,
\t\tT->295,
\t\tg->9.8,
\t\tmu0->4 N[Pi] 10^-7,
\t\trhoeAl->2.65 10^-8,\t\t\t(* Resistivity of Al *)
\t\trhoepianowire->30 rhoeAl,\t(* Resistivity of P.W., GUESSTIMATE *)
\t\tsigmaeAu->2.67,\t\t\t\t(* Resistivity of Au paint, measured *)
\t\tmassSOS->0.25,\t\t\t\t(* Final design value *)
\t\tmassM->rhomM l N[Pi] a^2,
\t\tPi->N[Pi],
\t\trhomM->7400,\t\t\t\t(* Mass density of magnets *)
\t\tztube->0.0155,\t\t\t\t(* Separation for magnet to push its own weight, \
measured *)
\t\tzpickup->0.018-l,\t\t\t(* Separation for magnet to pull its own weight, \
measured *)
\t\tmasspullapart->0.060,\t\t(* Force (in kgf) to separate magnets *)
\t\t(* preferred value of small magnet dipole moment *)
\t\tmzpref->0.007945632135874319,
\t\t(* magnet moment per unit volume for magnet stuff, assumed the same for \
big and small *)
\t\tmz->mzpref/(lold*N[Pi]*aold^2),
\t\tlold->0.003175,\t\t\t\t(* length of LIGO small magnets *)
\t\taold->0.0009525,\t\t\t(* radius of LIGO small magnets *)
\t\tl->0.010,\t\t\t\t(* length of big magnets *)
\t\ta->0.005,\t\t\t\t(* radius of big magnets *)
\t\tdipole -> mz*l*N[Pi]*a^2,
\t\tlayers -> 27, (* 10212-Gr.12-body BOSEM intermediate.pdf *)
\t\tturns -> 600, (* 10212-Gr.12-body BOSEM intermediate.pdf *)
\t\twirediam ->0.36*0.001, (* 10212-Gr.12-body BOSEM intermediate.pdf *)
\t\t(* coil length *)
\t\tcoillen->(11-3)*0.001,  (* 10212-Gr.12-body BOSEM intermediate.pdf *)
\t\t(* the ends of the coil relative to the centre of the coil *)
\t\tcoilz1->-coillen/2,
\t\tcoilz2->+coillen/2,
\t\t(* the inner and outer radii of the coil *)
\t\tcoilrad1->(18/2)*0.001, (* 10212-Gr.12-body BOSEM intermediate.pdf *)
\t\tcoilrad2->coilrad1+wirediam*layers, (* 10212-Gr.12-body BOSEM \
intermediate.pdf *)
\t\tcoildrad2max->(49/2)*0.001, (* 10212-Gr.12-body BOSEM intermediate.pdf *)
\t\t(* the number of turns *)
\t\tcoilturns->600, (* 10203-Gr.12-Osem intermediate mass.pdf *)
\t\tcoilsigma -> coilturns/((coilrad2 - coilrad1)*(coilz2 - coilz1)),
\t\tmagposactpromec->0.0079, (* Inventor, Promec, Fabian *)
\t\tmagposactv2->zmax[KPR], 
\t\tpairoffset->0.0652
\t}
]
vals[KBSIM] := bosemvalsKBSIM;\
\>", "Input",
 CellChangeTimes->{{3.453837228357688*^9, 3.453837230833909*^9}, {
   3.463844183252262*^9, 3.463844223147016*^9}, {3.478894862544446*^9, 
   3.4788948852377567`*^9}, {3.478894985619047*^9, 3.4788949913587503`*^9}, {
   3.4788950240972023`*^9, 3.478895025494358*^9}, {3.481940748223406*^9, 
   3.481940763510077*^9}, {3.6302077790327063`*^9, 3.630207779944365*^9}, {
   3.630208292557073*^9, 3.630208293170534*^9}, {3.6302085800514812`*^9, 
   3.630208649083247*^9}, {3.630209645346671*^9, 3.630209663817658*^9}, {
   3.630209701977907*^9, 3.6302097023837023`*^9}, 3.630209734594172*^9, 
   3.630210623319276*^9, {3.6302114423356447`*^9, 3.6302115422890863`*^9}, {
   3.630211579624671*^9, 3.630211581024807*^9}, {3.630211687932591*^9, 
   3.630211722300425*^9}, {3.6302984714100847`*^9, 3.630298473322809*^9}, {
   3.630361294367758*^9, 3.6303612947567253`*^9}, {3.6303613801867123`*^9, 
   3.6303613881298*^9}, {3.631834762263462*^9, 3.631834791379961*^9}, 
   3.661055741435896*^9, 3.6610557813045607`*^9, 3.6610560671992607`*^9, 
   3.661118651388139*^9, 3.661139094945122*^9, 3.661139202476098*^9, {
   3.661141235734417*^9, 3.661141258292121*^9}, {3.661141309672125*^9, 
   3.661141309700727*^9}, {3.661141356555216*^9, 3.661141380002549*^9}, {
   3.661141638842251*^9, 3.661141681335253*^9}, {3.6611432431036263`*^9, 
   3.661143250501958*^9}, {3.661143295718404*^9, 3.661143300484091*^9}, 
   3.66122654686482*^9, {3.661226643717907*^9, 3.661226646163519*^9}, {
   3.664504635625209*^9, 3.664504636127944*^9}, {3.6825847244571857`*^9, 
   3.682584725071711*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"kB", "\[Rule]", "1.38`*^-23"}], ",", 
   RowBox[{"T", "\[Rule]", "295"}], ",", 
   RowBox[{"g", "\[Rule]", "9.8`"}], ",", 
   RowBox[{"mu0", "\[Rule]", "1.2566370614359173`*^-6"}], ",", 
   RowBox[{"rhoeAl", "\[Rule]", "2.65`*^-8"}], ",", 
   RowBox[{"rhoepianowire", "\[Rule]", "7.95`*^-7"}], ",", 
   RowBox[{"sigmaeAu", "\[Rule]", "2.67`"}], ",", 
   RowBox[{"massSOS", "\[Rule]", "0.25`"}], ",", 
   RowBox[{"massM", "\[Rule]", "0.005811946409141117`"}], ",", 
   RowBox[{"\[Pi]", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"rhomM", "\[Rule]", "7400"}], ",", 
   RowBox[{"ztube", "\[Rule]", "0.0155`"}], ",", 
   RowBox[{"zpickup", "\[Rule]", "0.007999999999999998`"}], ",", 
   RowBox[{"masspullapart", "\[Rule]", "0.06`"}], ",", 
   RowBox[{"mzpref", "\[Rule]", "0.00794563213587432`"}], ",", 
   RowBox[{"mz", "\[Rule]", "878020.9598010788`"}], ",", 
   RowBox[{"lold", "\[Rule]", "0.003175`"}], ",", 
   RowBox[{"aold", "\[Rule]", "0.0009525`"}], ",", 
   RowBox[{"l", "\[Rule]", "0.01`"}], ",", 
   RowBox[{"a", "\[Rule]", "0.005`"}], ",", 
   RowBox[{"dipole", "\[Rule]", "0.6895960492522322`"}], ",", 
   RowBox[{"layers", "\[Rule]", "27"}], ",", 
   RowBox[{"turns", "\[Rule]", "600"}], ",", 
   RowBox[{"wirediam", "\[Rule]", "0.00035999999999999997`"}], ",", 
   RowBox[{"coillen", "\[Rule]", "0.008`"}], ",", 
   RowBox[{"coilz1", "\[Rule]", 
    RowBox[{"-", "0.004`"}]}], ",", 
   RowBox[{"coilz2", "\[Rule]", "0.004`"}], ",", 
   RowBox[{"coilrad1", "\[Rule]", "0.009000000000000001`"}], ",", 
   RowBox[{"coilrad2", "\[Rule]", "0.01872`"}], ",", 
   RowBox[{"coildrad2max", "\[Rule]", "0.0245`"}], ",", 
   RowBox[{"coilturns", "\[Rule]", "600"}], ",", 
   RowBox[{"coilsigma", "\[Rule]", "7.716049382716049`*^6"}], ",", 
   RowBox[{"magposactpromec", "\[Rule]", "0.0079`"}], ",", 
   RowBox[{"magposactv2", "\[Rule]", "0.006718812869426184`"}], ",", 
   RowBox[{"pairoffset", "\[Rule]", "0.0652`"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.661139342263995*^9, {3.661141667258052*^9, 3.661141684384678*^9}, 
   3.661143334994034*^9, 3.661218923863595*^9, 3.661226547848268*^9, 
   3.661341442616219*^9, 3.66224645200333*^9, 3.662328257588792*^9, 
   3.6623315030483637`*^9, 3.662338118106715*^9, 3.664504783037726*^9, 
   3.664593172555337*^9, 3.665374178132749*^9, 3.682483292813438*^9, 
   3.6825847325760393`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"optdata", "[", "KBSIM", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "1.111966329240739`"}], ",", 
      RowBox[{"{", 
       RowBox[{"z", "\[Rule]", "0.007442577658800806`"}], "}"}]}], "}"}], ",",
     "\[IndentingNewLine]", 
    RowBox[{"Minimize", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          RowBox[{"fz", "[", 
           RowBox[{"KBSIM", ",", "z"}], "]"}]}], "+", 
         RowBox[{"fz", "[", 
          RowBox[{"KBSIM", ",", 
           RowBox[{
            RowBox[{"z", "+", "pairoffset"}], "/.", 
            RowBox[{"vals", "[", "KBSIM", "]"}]}]}], "]"}]}], ",", " ", 
        RowBox[{"0.006", " ", "<", " ", "z", " ", "<", " ", "0.012"}]}], 
       "}"}], ",", " ", "z"}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.478970745257534*^9, 3.478970764425056*^9}, 
   3.4796619224973173`*^9, {3.480244382554545*^9, 3.480244405961742*^9}, {
   3.4819408015577917`*^9, 3.4819408027090397`*^9}, {3.481940979763582*^9, 
   3.481940981746011*^9}, {3.481941548420309*^9, 3.481941559738948*^9}, {
   3.630208310775996*^9, 3.6302083160559387`*^9}, 3.6302102241338043`*^9, {
   3.630210607856474*^9, 3.6302106082793016`*^9}, 3.630361338897683*^9, 
   3.660965340441757*^9, {3.6611412583009977`*^9, 3.6611412583096*^9}, {
   3.6611413097075777`*^9, 3.661141309712214*^9}, {3.6611413410526447`*^9, 
   3.661141347091383*^9}, {3.6611416926384974`*^9, 3.66114170977668*^9}, 
   3.661219512896727*^9, 3.662329456445507*^9, {3.662329520779831*^9, 
   3.662329542539156*^9}, 3.664595313652255*^9, 3.665363661213686*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "1.1119932085941195`"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", "\[Rule]", "0.007442538880671186`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.6623299493259478`*^9, 3.6623318864112988`*^9, 
  3.662338510736121*^9, 3.664505119784628*^9, 3.664593503282202*^9, 
  3.665374511777615*^9, 3.6824835913718643`*^9, 3.682585014515765*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"optdata", "[", "KPRIM", "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"for", " ", "comparison"}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.6611417897464647`*^9, 3.6611417951142797`*^9}, {
   3.6612035835908327`*^9, 3.6612036047716*^9}, 3.662329142361154*^9, {
   3.662330001250415*^9, 3.662330001672842*^9}, {3.6623300489374743`*^9, 
   3.662330049507196*^9}}],

Cell[BoxData[
 RowBox[{"optdata", "[", "KPRIM", "]"}]], "Output",
 CellChangeTimes->{3.662330002511826*^9, 3.662330050048687*^9, 
  3.66233188678736*^9, 3.6623385110669613`*^9, 3.664505120003056*^9, 
  3.664593503434946*^9, 3.6653745119305563`*^9, 3.6824835915774307`*^9, 
  3.68258501471692*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fzi", "[", "KBSIM", "]"}], " ", "=", " ", 
  RowBox[{"FunctionInterpolation", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"fz", "[", 
      RowBox[{"KBSIM", ",", "z"}], "]"}], "-", 
     RowBox[{"fz", "[", 
      RowBox[{"KBSIM", ",", 
       RowBox[{
        RowBox[{"z", "+", "pairoffset"}], "/.", 
        RowBox[{"vals", "[", "KBSIM", "]"}]}]}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "0", ",", "0.013"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.661121231903079*^9, 3.661121302673418*^9}, {
   3.66112135471321*^9, 3.661121364047564*^9}, 3.661121573023286*^9, {
   3.661121981470016*^9, 3.661121984145525*^9}, {3.661122016670216*^9, 
   3.6611220263968563`*^9}, {3.661122422824706*^9, 3.661122440665392*^9}, {
   3.6611225257271423`*^9, 3.6611225561384287`*^9}, 3.661122943936385*^9, 
   3.661124072219921*^9, 3.661124107400278*^9, {3.66114125831656*^9, 
   3.6611412583250227`*^9}, {3.6611413097183743`*^9, 3.661141309722828*^9}, {
   3.661142955018881*^9, 3.661142976745582*^9}, 3.6612189023455*^9, {
   3.6612189588266687`*^9, 3.6612189659137297`*^9}, 3.661219472807549*^9, {
   3.661219548644806*^9, 3.661219555082078*^9}, {3.662262695279645*^9, 
   3.662262697461714*^9}}],

Cell[BoxData[
 TagBox[
  TemplateBox[{RowBox[{
      StyleBox[
       TagBox["InterpolatingFunction", "SummaryHead"], 
       "NonInterpretableSummary"], 
      StyleBox["[", "NonInterpretableSummary"], 
      DynamicModuleBox[{Typeset`open$$ = False}, 
       PanelBox[
        PaneSelectorBox[{False -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquarePlusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = True), Appearance -> None,
                 Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{{{}, {}, {
                   Directive[
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1]], 
                   LineBox[CompressedData["
1:eJwV0G0w2wcAx/FcsN5MnVhMRXbxVOvNtOoh9ZD4XVXEPFRrw7ZW59ltnlIP
xUqlHiOm7ErG6IOzth6Gpqcc9bROmIcb0Y2ReVwREkn+uDp3uHUvvvd5/zWP
SAqMJpNIJNbb/ne3touR7a1iC1R/6AqycvrnG317dodsQNda1moSP0F7fSxZ
Z5uFqoAfj6cOd8MgfZ9bzufgRaPog6eXB+GnYLlJo/ww+dWbpq3jY8g89UW0
v/oyugvkzQxLKZxco2KD44MwGKd9diL1Tzz2FHRaOn4JyukoD93DGfzEVNzz
2byKZWXwC164DD0XLi362IXBlJTB0MtYQKG8QzRlEAHj7Tmn/X+WIOnxiouX
RqItRNzGDV6BRPuNrkNxNFbD5idP9vwLs0/F0isxsahc8+Ra2a9C3VP5XGT5
DcjOTUH7/DWY2BYOOLwTB1rN35vDsnVoU0Siw8V43CTbOXsyNhBlNVE8W52I
2nUyy5u9CQOa7lQJi4eBmp+71OEKNLj8uuVAv469x3XX3SOUSAw5opfqJ0MS
99c1bvQWqGfGxFkHyTh2T9KScEmFtPufBKXNpcCndEeVR1NDS4+qxxhLRVLI
Vn3Tihp+lHKptDkNnGsx3jKOBmmTNQc0wQ3sSOjm4eUajJfauhmlp8NGWRWl
ntFgfuUzwYngDAwfsFwMDAmYMkkb49xMNL6bHjvAJeB6gdVm7PQd4l+f9rFL
IfC+XC8/zvAmrJsvMkR3CdBKIuN55Cz0xuz2GbYSkEkuRt5ayYKneuTlah+B
7O6Rfou+bFAqX7kyfyfg1zJ6JuOXWwinjarLRglMnwtrnRbmIHSwQf83CQGv
JbbZDpsP1SuzK9wuAjmaSl5OKx8rapG72RMCDfPPd6bptzFB73D/oYyAfKSK
VFRxG0Y3Uhb2kgjokIcq3LRzwVzWMbPxJ+Ds0vHMOzsXCR+3VtAsCFz1T9Qy
383Fg7Up37ltDUJbeLLDiDzkeQWe63759pcek+0gy8N44UfUUqEG33ZyrBN8
88G2PwroD9QgAB96JHflY3/WxMXdRAPfoc71CbsCRDd5uTo+VcOqupZq/7AA
dnyXEmt7NahxnmPKE4UwGst5HfpIhV2T9vbkskK4DzpPPjJWQUxNPHl4WIjq
pcVMZfkWCvQVjKW0Ijw875Rx/0AJ5ufP6oZXixBOXzCt5ylxVMVqOfa1AMN1
XenjMwp0dN9RGE4LQMtcKH7vvAK+p2zEFpxicChEgk37JvYqhKSS3mJ4zJp4
3DXdBN/fcWbPVog78rMRJaUbICqYSX0PhKB8X9crPJLjP5X3z9s=
                    
                    "]]}}}, {}, {}}, {
               DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
                AxesOrigin -> {0, 0}, 
                FrameTicks -> {{None, None}, {None, None}}, 
                GridLines -> {None, None}, DisplayFunction -> Identity, 
                PlotRangePadding -> {{
                   Scaled[0.1], 
                   Scaled[0.1]}, {
                   Scaled[0.1], 
                   Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
                All, DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                Directive[
                  Opacity[0.5], 
                  Thickness[Tiny], 
                  RGBColor[0.368417, 0.506779, 0.709798]], 
                FrameTicks -> {{None, None}, {None, None}}, 
                GridLines -> {None, None}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 
                Dynamic[{
                  Automatic, 3.5 CurrentValue["FontCapHeight"]/
                   AbsoluteCurrentValue[Magnification]}], 
                Method -> {
                 "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
                  AbsolutePointSize[6], "ScalingFunctions" -> None, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (
                    Part[{{Identity, Identity}, {Identity, Identity}}, 1, 
                    2][#]& )[
                    Part[#, 1]], 
                    (
                    Part[{{Identity, Identity}, {Identity, Identity}}, 2, 
                    2][#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 
                    2][#]& )[
                    Part[#, 1]], 
                    (
                    Part[{{Identity, Identity}, {Identity, Identity}}, 2, 
                    2][#]& )[
                    Part[#, 2]]}& )}}, 
                PlotRange -> {{0., 0.013}, {-0.007687121786996827, 
                 1.1119536749626138`}}, PlotRangeClipping -> True, 
                PlotRangePadding -> {{
                   Scaled[0.1], 
                   Scaled[0.1]}, {
                   Scaled[0.1], 
                   Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"scalar\"", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}], True -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquareMinusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                None, Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{{{}, {}, {
                   Directive[
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1]], 
                   LineBox[CompressedData["
1:eJwV0G0w2wcAx/FcsN5MnVhMRXbxVOvNtOoh9ZD4XVXEPFRrw7ZW59ltnlIP
xUqlHiOm7ErG6IOzth6Gpqcc9bROmIcb0Y2ReVwREkn+uDp3uHUvvvd5/zWP
SAqMJpNIJNbb/ne3touR7a1iC1R/6AqycvrnG317dodsQNda1moSP0F7fSxZ
Z5uFqoAfj6cOd8MgfZ9bzufgRaPog6eXB+GnYLlJo/ww+dWbpq3jY8g89UW0
v/oyugvkzQxLKZxco2KD44MwGKd9diL1Tzz2FHRaOn4JyukoD93DGfzEVNzz
2byKZWXwC164DD0XLi362IXBlJTB0MtYQKG8QzRlEAHj7Tmn/X+WIOnxiouX
RqItRNzGDV6BRPuNrkNxNFbD5idP9vwLs0/F0isxsahc8+Ra2a9C3VP5XGT5
DcjOTUH7/DWY2BYOOLwTB1rN35vDsnVoU0Siw8V43CTbOXsyNhBlNVE8W52I
2nUyy5u9CQOa7lQJi4eBmp+71OEKNLj8uuVAv469x3XX3SOUSAw5opfqJ0MS
99c1bvQWqGfGxFkHyTh2T9KScEmFtPufBKXNpcCndEeVR1NDS4+qxxhLRVLI
Vn3Tihp+lHKptDkNnGsx3jKOBmmTNQc0wQ3sSOjm4eUajJfauhmlp8NGWRWl
ntFgfuUzwYngDAwfsFwMDAmYMkkb49xMNL6bHjvAJeB6gdVm7PQd4l+f9rFL
IfC+XC8/zvAmrJsvMkR3CdBKIuN55Cz0xuz2GbYSkEkuRt5ayYKneuTlah+B
7O6Rfou+bFAqX7kyfyfg1zJ6JuOXWwinjarLRglMnwtrnRbmIHSwQf83CQGv
JbbZDpsP1SuzK9wuAjmaSl5OKx8rapG72RMCDfPPd6bptzFB73D/oYyAfKSK
VFRxG0Y3Uhb2kgjokIcq3LRzwVzWMbPxJ+Ds0vHMOzsXCR+3VtAsCFz1T9Qy
383Fg7Up37ltDUJbeLLDiDzkeQWe63759pcek+0gy8N44UfUUqEG33ZyrBN8
88G2PwroD9QgAB96JHflY3/WxMXdRAPfoc71CbsCRDd5uTo+VcOqupZq/7AA
dnyXEmt7NahxnmPKE4UwGst5HfpIhV2T9vbkskK4DzpPPjJWQUxNPHl4WIjq
pcVMZfkWCvQVjKW0Ijw875Rx/0AJ5ufP6oZXixBOXzCt5ylxVMVqOfa1AMN1
XenjMwp0dN9RGE4LQMtcKH7vvAK+p2zEFpxicChEgk37JvYqhKSS3mJ4zJp4
3DXdBN/fcWbPVog78rMRJaUbICqYSX0PhKB8X9crPJLjP5X3z9s=
                    
                    "]]}}}, {}, {}}, {
               DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
                AxesOrigin -> {0, 0}, 
                FrameTicks -> {{None, None}, {None, None}}, 
                GridLines -> {None, None}, DisplayFunction -> Identity, 
                PlotRangePadding -> {{
                   Scaled[0.1], 
                   Scaled[0.1]}, {
                   Scaled[0.1], 
                   Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
                All, DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                Directive[
                  Opacity[0.5], 
                  Thickness[Tiny], 
                  RGBColor[0.368417, 0.506779, 0.709798]], 
                FrameTicks -> {{None, None}, {None, None}}, 
                GridLines -> {None, None}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 
                Dynamic[{
                  Automatic, 3.5 CurrentValue["FontCapHeight"]/
                   AbsoluteCurrentValue[Magnification]}], 
                Method -> {
                 "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
                  AbsolutePointSize[6], "ScalingFunctions" -> None, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (
                    Part[{{Identity, Identity}, {Identity, Identity}}, 1, 
                    2][#]& )[
                    Part[#, 1]], 
                    (
                    Part[{{Identity, Identity}, {Identity, Identity}}, 2, 
                    2][#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (
                    Part[{{Identity, Identity}, {Identity, Identity}}, 1, 
                    2][#]& )[
                    Part[#, 1]], 
                    (
                    Part[{{Identity, Identity}, {Identity, Identity}}, 2, 
                    2][#]& )[
                    Part[#, 2]]}& )}}, 
                PlotRange -> {{0., 0.013}, {-0.007687121786996827, 
                 1.1119536749626138`}}, PlotRangeClipping -> True, 
                PlotRangePadding -> {{
                   Scaled[0.1], 
                   Scaled[0.1]}, {
                   Scaled[0.1], 
                   Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"scalar\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["3", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"Hermite\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["False", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}]}, 
         Dynamic[Typeset`open$$], ImageSize -> Automatic], BaselinePosition -> 
        Baseline], DynamicModuleValues :> {}], 
      StyleBox["]", "NonInterpretableSummary"]}]},
   "CopyTag",
   DisplayFunction->(#& ),
   InterpretationFunction->("InterpolatingFunction[{{0., 0.013}}, <>]"& )],
  False,
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.662262712038498*^9, 3.6623282717784853`*^9, 
  3.662330086345646*^9, 3.662331901127619*^9, 3.662338525385553*^9, 
  3.664505134111497*^9, 3.664593516858684*^9, 3.66537452590746*^9, 
  3.68248360417701*^9, 3.6825850265103407`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"plot", "[", "KBSIM", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    GraphicsBox[{{}, {}, 
      {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
       LineBox[CompressedData["
1:eJwV1nlYTG8bB/AWr5QQSqVQ0aaQUCR9aVEkkkpFpaJNm/bZzkw7Y1+KNiSF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        "]]}},
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->{True, True},
     AxesLabel->{None, None},
     AxesOrigin->{0, 0},
     DisplayFunction->Identity,
     Frame->{{False, False}, {False, False}},
     FrameLabel->{{None, None}, {None, None}},
     FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
     GridLines->{None, None},
     GridLinesStyle->Directive[
       GrayLevel[0.5, 0.4]],
     Method->{
      "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
       AbsolutePointSize[6], "ScalingFunctions" -> None},
     PlotRange->{{0, 0.013}, {-0.007731757609815486, 1.1119662715577647`}},
     PlotRangeClipping->True,
     PlotRangePadding->{{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}},
     Ticks->{Automatic, Automatic}], ",", "\[IndentingNewLine]", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"fz", "[", 
         RowBox[{"KBSIM", ",", "p"}], "]"}], "-", 
        RowBox[{"fz", "[", 
         RowBox[{"KBSIM", ",", 
          RowBox[{
           RowBox[{"p", "+", "pairoffset"}], "/.", 
           RowBox[{"vals", "[", "KBSIM", "]"}]}]}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"p", ",", "0", ",", "0.013"}], "}"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", "Black", "}"}]}]}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.4789618100364523`*^9, 3.478961850760915*^9}, 
   3.478969868098156*^9, 3.4789702271107073`*^9, {3.478971402742322*^9, 
   3.478971407269801*^9}, {3.478973436528585*^9, 3.4789734559838*^9}, {
   3.4794970273251*^9, 3.4794970280748262`*^9}, {3.479497850691868*^9, 
   3.479497851721608*^9}, {3.4802445496159487`*^9, 3.4802445841180058`*^9}, {
   3.4802446656757193`*^9, 3.4802446687524443`*^9}, {3.481940803363203*^9, 
   3.481940804034131*^9}, {3.481941063760079*^9, 3.4819410664063997`*^9}, {
   3.481941556057631*^9, 3.4819415664906*^9}, {3.630208312322345*^9, 
   3.63020831448879*^9}, 3.630209982122305*^9, 3.630210040824745*^9, {
   3.630210608691247*^9, 3.6302106091463537`*^9}, 3.6302116072117853`*^9, 
   3.6302119179137897`*^9, 3.6304701238527927`*^9, 3.631834820615905*^9, 
   3.649109628464219*^9, {3.649110363868889*^9, 3.649110366770886*^9}, {
   3.649110567151823*^9, 3.649110570373554*^9}, {3.661123689182354*^9, 
   3.661123723132988*^9}, 3.661123839830414*^9, {3.661123888550177*^9, 
   3.6611238924215937`*^9}, {3.661123959516914*^9, 3.661123970823284*^9}, {
   3.661124020120494*^9, 3.661124020504492*^9}, {3.661124084594274*^9, 
   3.66112408490854*^9}, {3.661124132485323*^9, 3.661124133744603*^9}, {
   3.661127129389042*^9, 3.6611271300441732`*^9}, {3.6611285421516657`*^9, 
   3.6611285486416283`*^9}, 3.661139350752645*^9, {3.661141258332346*^9, 
   3.661141258345943*^9}, {3.661141309730465*^9, 3.6611413097415237`*^9}, {
   3.661142929646887*^9, 3.6611429309305487`*^9}, {3.661143000502679*^9, 
   3.6611430183305893`*^9}, 3.6611430889631033`*^9, {3.661202692295169*^9, 
   3.6612027456074247`*^9}, {3.6612032345320673`*^9, 
   3.6612032350121202`*^9}, {3.661203641247325*^9, 3.6612036470219383`*^9}, {
   3.661204651133306*^9, 3.6612046566907873`*^9}, {3.661205020492955*^9, 
   3.661205021421957*^9}, {3.662327449381301*^9, 3.662327449845611*^9}, 
   3.662327486588072*^9, {3.662327534038128*^9, 3.662327534215892*^9}, 
   3.662328936644876*^9, {3.662330873366127*^9, 3.662330873678608*^9}, {
   3.6645953288983994`*^9, 3.6645953299856052`*^9}, {3.665363668118861*^9, 
   3.665363668959805*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
     LineBox[CompressedData["
1:eJwV1nlYTdsbB/BKPyU0S1ESbhkyZ05fKUWDokmGKNI80HimfU5zTiRKJYpo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      "]]}}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 0.013}, {-0.007687110331871783, 1.1119931477589993`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.661219709246232*^9, 3.661341532375228*^9, 
  3.66224654204303*^9, 3.662328317212946*^9, 3.662331948563867*^9, 
  3.6623385721286287`*^9, 3.664505182468782*^9, 3.664593561710854*^9, 
  3.665374572571253*^9, 3.6824836466990023`*^9, 3.6825850653731127`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"plot1", "[", "KBSIM", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    GraphicsBox[{{}, {}, 
      {RGBColor[1, 1, 0], AbsoluteThickness[1.6], Opacity[1.], 
       LineBox[CompressedData["
1:eJwV13k81NsbB3CDrkihqGRNWlxuaUOST0lJKNmKQvGTyJZ9tu/MyDppk1xr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        "]]}},
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->{True, True},
     AxesLabel->{None, None},
     AxesOrigin->{0, 0},
     DisplayFunction->Identity,
     Frame->{{False, False}, {False, False}},
     FrameLabel->{{None, None}, {None, None}},
     FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
     GridLines->{None, None},
     GridLinesStyle->Directive[
       GrayLevel[0.5, 0.4]],
     Method->{
      "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
       AbsolutePointSize[6], "ScalingFunctions" -> None},
     PlotRange->{{0, 0.013}, {0., 1.117094553614166}},
     PlotRangeClipping->True,
     PlotRangePadding->{{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}},
     Ticks->{Automatic, Automatic}], ",", "\[IndentingNewLine]", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"fz", "[", 
        RowBox[{"KBSIM", ",", "p"}], "]"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"p", ",", "0", ",", "0.013"}], "}"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", "Yellow", "}"}]}]}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.4789618100364523`*^9, 3.478961850760915*^9}, 
   3.478969868098156*^9, 3.4789702271107073`*^9, {3.478971402742322*^9, 
   3.478971407269801*^9}, {3.478973436528585*^9, 3.4789734559838*^9}, {
   3.4794970273251*^9, 3.4794970280748262`*^9}, {3.479497850691868*^9, 
   3.479497851721608*^9}, {3.4802445496159487`*^9, 3.4802445841180058`*^9}, {
   3.4802446656757193`*^9, 3.4802446687524443`*^9}, {3.481940803363203*^9, 
   3.481940804034131*^9}, {3.481941063760079*^9, 3.4819410664063997`*^9}, {
   3.481941556057631*^9, 3.4819415664906*^9}, {3.630208312322345*^9, 
   3.63020831448879*^9}, 3.630209982122305*^9, 3.630210040824745*^9, {
   3.630210608691247*^9, 3.6302106091463537`*^9}, 3.6302116072117853`*^9, 
   3.6302119179137897`*^9, 3.6304701238527927`*^9, 3.631834820615905*^9, 
   3.649109628464219*^9, {3.649110363868889*^9, 3.649110366770886*^9}, {
   3.649110567151823*^9, 3.649110570373554*^9}, {3.661123689182354*^9, 
   3.661123723132988*^9}, 3.661123839830414*^9, {3.661123888550177*^9, 
   3.6611238924215937`*^9}, {3.661123959516914*^9, 3.661123970823284*^9}, {
   3.661124020120494*^9, 3.661124020504492*^9}, {3.661124084594274*^9, 
   3.66112408490854*^9}, {3.661124132485323*^9, 3.661124133744603*^9}, {
   3.661127129389042*^9, 3.6611271300441732`*^9}, {3.6611285421516657`*^9, 
   3.6611285486416283`*^9}, 3.661139350752645*^9, {3.661141258332346*^9, 
   3.661141258345943*^9}, {3.661141309730465*^9, 3.6611413097415237`*^9}, {
   3.661142929646887*^9, 3.6611429309305487`*^9}, {3.661143000502679*^9, 
   3.6611430183305893`*^9}, 3.6611430889631033`*^9, {3.661202692295169*^9, 
   3.6612027456074247`*^9}, {3.6612032345320673`*^9, 
   3.6612032350121202`*^9}, {3.661203641247325*^9, 3.6612036470219383`*^9}, {
   3.661204651133306*^9, 3.6612046566907873`*^9}, {3.661205020492955*^9, 
   3.661205021421957*^9}, {3.662327449381301*^9, 3.662327449845611*^9}, {
   3.662327486588072*^9, 3.662327537553957*^9}, 3.662329110982596*^9, {
   3.662330878119421*^9, 3.6623308785345497`*^9}, {3.662354069937125*^9, 
   3.6623540788907948`*^9}, {3.662354134271152*^9, 3.662354134562495*^9}, {
   3.6623543100422163`*^9, 3.66235431077297*^9}, {3.6623544217834806`*^9, 
   3.66235444697696*^9}, {3.6623545334028597`*^9, 3.6623545384531507`*^9}, 
   3.66459533903401*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {RGBColor[1, 1, 0], AbsoluteThickness[1.6], Opacity[1.], 
     LineBox[CompressedData["
1:eJwV13k8VG0bB3C0kGxFtoSWR5Q27Sq/pCRlyRKpKNGCkH1mzJkZW5pECoko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      "]]}}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 0.013}, {0., 1.1170945536080175`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.6623544902729063`*^9, 3.662354581947805*^9, 
  3.664505224666029*^9, 3.664593601802726*^9, 3.665374613829009*^9, 
  3.682483684670988*^9, 3.682585101292568*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"plot", "[", "KBSIM", "]"}], ",", 
   RowBox[{"plot1", "[", "KBSIM", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.662331982056473*^9, 3.662331997565082*^9}}],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
      LineBox[CompressedData["
1:eJwV1nlYTdsbB/BKPyU0S1ESbhkyZ05fKUWDokmGKNI80HimfU5zTiRKJYpo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       "]]}}, {}, {}}, {{{}, {}, 
     {RGBColor[1, 1, 0], AbsoluteThickness[1.6], Opacity[1.], 
      LineBox[CompressedData["
1:eJwV13k8VG0bB3C0kGxFtoSWR5Q27Sq/pCRlyRKpKNGCkH1mzJkZW5pECoko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       "]]}}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 0.013}, {-0.007687110331871783, 1.1119931477589993`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.662331998472492*^9, 3.662338613133938*^9, 
  3.662354352954232*^9, 3.662354490649448*^9, 3.662354582330501*^9, 
  3.6645052247482653`*^9, 3.664593601970983*^9, 3.6653746139220047`*^9, 
  3.682483684778611*^9, 3.6825851013807096`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"zmax", "[", "KBSIM", "]"}], "  ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{
    RowBox[{"optdata", "[", "KBSIM", "]"}], "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.478970786649661*^9, 3.478970802864567*^9}, {
   3.4796619220112333`*^9, 3.4796619454416037`*^9}, 3.479665671740583*^9, {
   3.48194080448247*^9, 3.481940804971867*^9}, {3.630208319233528*^9, 
   3.630208320862918*^9}, {3.630210609409204*^9, 3.6302106096880713`*^9}, {
   3.661141258353458*^9, 3.6611412583619328`*^9}, {3.661141309747707*^9, 
   3.661141309752261*^9}, 3.662329128518359*^9}],

Cell[BoxData["0.007442538880671186`"], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGAwAOKQpjXdc16/dFyUG2Mx481Lxxmm1slvgHRVmlDOOyDd
V36j8z2Qvu0kNBlE/39ZeoTz3UvHKOkVp58A6ZCHs3P7P7x0XPNepcTt40vH
A2Uu1SD61gOZzSDaKSPnPIjWPVjJ5Q6kK1Q3brPmfu0odHpRojDPa8eKhqen
QPQV5gtPQfRj87fpIkBaaZrYJEsg/Sz3xhsPIL1feuvmWCDddTW8ZhKQPmWk
3KbJD9S3juMGiA54v/OiHpC+M9/64m+h147Xtt4U/wuk13i+miJv8Nrx0+KU
nXvcXjv6iGtM3wek77wIkXkJpP+lecxgd3/tWMT74iSInnFE8J4gkE6+6Ngv
DKTtIidnlwDpJ7vPBOp5vnb8/WKJSxiQ1nA2XQqiGTxXyIUDaad1O7kigPQ2
r+Vu0UD6xzsJw1rf144/bRwjVgDphS37Nqn6v3aMrJ6153j+a8dvfOscfwJp
ABghxx8=
  "]]
}, Open  ]],

Cell["Old", "Text",
 CellChangeTimes->{{3.664504814383862*^9, 3.6645048149428377`*^9}}],

Cell[BoxData["0.007445493581544137`"], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQBuKQpjXdc16/dFyUG2Mx481Lxxmm1slvgHRVmlDOOyDd
V36j8z2Qvu0kNBlE/39ZeoTz3UvHKOkVp58A6ZCHs3P7P7x0XPNepcTt40vH
A2Uu1SD61gOZzSDaKSPnPIjWPVjJ5Q6kK1Q3brPmfu0odHpRojDPa8eKhqen
QPQV5gtPQfRj87fpIkBaaZrYJEsg/Sz3xhsPIL1feuvmWCDddTW8ZhKQPmWk
3KbJD9S3juMGiA54v/OiHpC+M9/64m+h147Xtt4U/wuk13i+miJv8Nrx0+KU
nXvcXjv6iGtM3wek77wIkXkJpP+lecxgd3/tWMT74iSInnFE8J4gkE6+6Ngv
DKTtIidnlwDpJ7vPBOp5vnb8/WKJSxiQ1nA2XQqiGTxXyIUDaad1O7kigPQ2
r+Vu0UAaAJqYsb4=
  "]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"magposactpromec", "-", 
   RowBox[{"zmax", "[", "KBSIM", "]"}]}], "/.", 
  RowBox[{"vals", "[", "KBSIM", "]"}]}]], "Input",
 CellChangeTimes->{{3.631850926207306*^9, 3.631850980824053*^9}, {
   3.631851019732378*^9, 3.631851023974328*^9}, 3.661139094984755*^9, 
   3.6611392025019712`*^9, {3.661141258367827*^9, 3.661141258374606*^9}, {
   3.661141309758286*^9, 3.661141309762734*^9}}],

Cell[BoxData["0.00045746111932881434`"], "Output",
 CellChangeTimes->{{3.631850951545291*^9, 3.63185098135504*^9}, 
   3.631851024795751*^9, 3.633831562056611*^9, 3.6338341748264236`*^9, 
   3.649109159364168*^9, 3.6609653231946507`*^9, 3.6609691453050213`*^9, 
   3.661056226711844*^9, 3.6611186583295813`*^9, 3.66111905527409*^9, 
   3.6611396965979853`*^9, 3.6611431650138903`*^9, 3.6613415326304903`*^9, 
   3.66224654244606*^9, 3.6623283572045794`*^9, 3.662330101462863*^9, 
   3.662331989861638*^9, 3.6623386132889023`*^9, 3.664505224827629*^9, 
   3.664593602099378*^9, 3.665374614010365*^9, 3.6824836848836803`*^9, 
   3.682585101510922*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fmax", "[", "KBSIM", "]"}], "  ", "=", " ", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"optdata", "[", "KBSIM", "]"}], " ", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4789708091780043`*^9, 3.4789708248973703`*^9}, 
   3.479661922078005*^9, 3.4796619593447857`*^9, 3.479665787682528*^9, {
   3.481940805601218*^9, 3.481940806091435*^9}, {3.630208322616778*^9, 
   3.6302083244414253`*^9}, {3.63021060995541*^9, 3.63021061023507*^9}, {
   3.661141258380653*^9, 3.661141258387753*^9}, {3.661141309768797*^9, 
   3.661141309773177*^9}}],

Cell[BoxData["1.1119932085941195`"], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQB+KWPeu757x+6fjqVazFjDcvHYUybZLfAGlvBZGcd0Ca
KeVm53sgHccmNhlE2xwsO8L57qVjacnK00+AdOCkubn9H146Mm9SK3H7+NLx
yXfXahAtsEF2M4helpZ3HkS39VdzuQPp+Psbt1lzv3ZU+7UkUZjnteOEl99O
gejdWy88BdFOie/TRYD03WUSkyyB9I6mW288gHTHvG2bY4F06/nImklA+sN5
lTZN/teOZdO4boDoad27L+oB6cqJARd/C712rNC8Lf4XSE9yfjtF3uC146GL
6Tv3uAHtjdWevg9Ix4REyLwE0lOsAmawu792zG94eRJE394ick8QSD/wfdwv
DKQvnpmaXQKk25IvBOp5As2VW+ESBqQfnNogFw6k9XT3ckUA6SKj1W7RQHqC
sYxhre9rR6bHLhErgPQ81kObVP1fO25rmbfneP5rR5PKTY4/gTQAf1nApg==

  "]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"deriv2", "[", "KBSIM", "]"}], " ", "=", "  ", 
  RowBox[{
   RowBox[{"-", "2"}], "*", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"fzi", "[", "KPR", "]"}], "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{"zmax", "[", "KPR", "]"}], ",", "2"}], "}"}]}], "]"}], 
      "]"}], ",", 
     RowBox[{"z", "^", "2"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479660163969679*^9, 3.479660203608347*^9}, {
   3.479660334457396*^9, 3.479660335305067*^9}, {3.4796611591764927`*^9, 
   3.479661208701754*^9}, {3.479661250977075*^9, 3.479661305176928*^9}, {
   3.479661346153286*^9, 3.479661372928776*^9}, {3.479661851029785*^9, 
   3.479661859051705*^9}, 3.4796619463263597`*^9, 3.479662725037703*^9, 
   3.479665672610339*^9, {3.481940806550991*^9, 3.48194080744361*^9}, {
   3.630208325888165*^9, 3.6302083289679956`*^9}, {3.630210610460196*^9, 
   3.630210610874337*^9}, 3.6611229758725023`*^9, {3.6611412583941383`*^9, 
   3.6611412584082737`*^9}, {3.661141309779232*^9, 3.661141309788487*^9}, {
   3.661143055996151*^9, 3.661143061547195*^9}, {3.661143129145129*^9, 
   3.661143150309849*^9}, 3.662253434311702*^9, 3.662262524114635*^9}],

Cell[BoxData["4723.921650343821`"], "Output",
 CellChangeTimes->{
  3.4796611607361183`*^9, 3.479661209333243*^9, {3.4796612702637243`*^9, 
   3.47966130570842*^9}, 3.479661373421825*^9, 3.479661471574224*^9, 
   3.479661860947604*^9, {3.479662726071348*^9, 3.47966274404876*^9}, 
   3.479663512851673*^9, 3.479665743087571*^9, 3.4796658169851303`*^9, 
   3.4802437481454697`*^9, 3.480692317637856*^9, 3.481566061244952*^9, 
   3.4819408972419558`*^9, 3.4819409542455378`*^9, 3.481941401101359*^9, 
   3.4819416276185503`*^9, 3.481942100030518*^9, 3.6297681177567453`*^9, 
   3.630209805425727*^9, 3.6302106479180737`*^9, 3.6302108627485523`*^9, 
   3.63021190367418*^9, 3.630288017033553*^9, 3.630319463059012*^9, 
   3.630362014021439*^9, 3.63047011514816*^9, 3.631828017512751*^9, 
   3.631828672853829*^9, 3.631838862188128*^9, 3.63383156257211*^9, 
   3.63383417516654*^9, 3.6491091597267933`*^9, 3.66096532357506*^9, 
   3.660969145695554*^9, 3.661056227053145*^9, 3.661118658556089*^9, 
   3.661119055617577*^9, 3.66112298417872*^9, 3.661139696737555*^9, {
   3.661143136068817*^9, 3.661143169405212*^9}, 3.661341532717312*^9, 
   3.662246542618259*^9, 3.662328357304565*^9, 3.66233010158547*^9, 
   3.662331989985965*^9, 3.662338613418449*^9, 3.664505224929468*^9, 
   3.664593602215114*^9, 3.665374614114143*^9, 3.682483685019483*^9, 
   3.682585101643714*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"z95plus", "[", "KBSIM", "]"}], " ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{"FindRoot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"fz", "[", 
       RowBox[{"KBSIM", ",", "z"}], "]"}], "-", 
      RowBox[{"0.95", "*", 
       RowBox[{"fmax", "[", "KBSIM", "]"}]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", 
       RowBox[{
        RowBox[{"zmax", "[", "KBSIM", "]"}], "+", "0.001"}], ",", 
       RowBox[{"zmax", "[", "KBSIM", "]"}], ",", 
       RowBox[{
        RowBox[{"zmax", "[", "KBSIM", "]"}], "+", "0.005"}]}], "}"}]}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479658613425561*^9, 3.4796587501410933`*^9}, {
   3.479658790462825*^9, 3.4796587993088913`*^9}, {3.479658852062684*^9, 
   3.479658891629363*^9}, {3.4796589431729183`*^9, 3.479658948798299*^9}, {
   3.479658987032153*^9, 3.47965898990287*^9}, {3.479659310386307*^9, 
   3.4796593125701933`*^9}, {3.479661624172262*^9, 3.479661679901505*^9}, {
   3.479661945541445*^9, 3.4796619594445953`*^9}, {3.4796656734658623`*^9, 
   3.479665674680963*^9}, 3.47966578778349*^9, {3.481940808072547*^9, 
   3.4819408112927933`*^9}, {3.630208331202548*^9, 3.630208340512887*^9}, {
   3.6302106111156588`*^9, 3.630210612620454*^9}, {3.631834272292122*^9, 
   3.631834275423791*^9}, {3.660964933550774*^9, 3.660964934686805*^9}, {
   3.662329034693089*^9, 3.662329042196556*^9}, 3.662334135563291*^9}],

Cell[BoxData["0.009391637619473092`"], "Output",
 CellChangeTimes->{{3.479659290207419*^9, 3.4796593177022877`*^9}, {
   3.479661644377719*^9, 3.4796616514833097`*^9}, 3.479661686065053*^9, 
   3.4796634593803263`*^9, 3.479665745824663*^9, 3.4796658197389708`*^9, 
   3.480243751933235*^9, 3.480692320796873*^9, 3.4815660640155077`*^9, 
   3.4819408973674994`*^9, 3.481940954361327*^9, 3.481941402301373*^9, 
   3.481941628781619*^9, 3.481942101498692*^9, 3.629768118581479*^9, 
   3.630209825967379*^9, 3.63021064809335*^9, 3.630210863735273*^9, 
   3.6302119044786863`*^9, 3.630288029600463*^9, 3.630319474859651*^9, 
   3.630362016214836*^9, 3.63047011744707*^9, 3.631828018334545*^9, 
   3.631828673603425*^9, 3.631835209527664*^9, 3.631839554443227*^9, 
   3.6338315761916437`*^9, 3.633834181637607*^9, 3.649109166248088*^9, 
   3.6609655749502296`*^9, 3.660965945562953*^9, 3.660968309694571*^9, 
   3.6609692385501957`*^9, 3.6609693505923347`*^9, 3.661056651074237*^9, 
   3.6611192956141233`*^9, 3.661130614471345*^9, 3.661130729128159*^9, 
   3.661139986045722*^9, 3.661219854453026*^9, 3.661231205656358*^9, 
   3.6613414423732347`*^9, 3.662246451691223*^9, 3.662328257276907*^9, 
   3.662329076444454*^9, 3.662330103708742*^9, 3.662331992000602*^9, 
   3.6623372437215033`*^9, 3.662338615581056*^9, 3.6645052270037937`*^9, 
   3.6645936042399483`*^9, 3.66537461617911*^9, 3.6824836869550734`*^9, 
   3.682585103462288*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"z95minus", "[", "KBSIM", "]"}], " ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{"FindRoot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"fz", "[", 
       RowBox[{"KBSIM", ",", "z"}], "]"}], "-", 
      RowBox[{"0.95", "*", 
       RowBox[{"fmax", "[", "KBSIM", "]"}]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", 
       RowBox[{
        RowBox[{"zmax", "[", "KBSIM", "]"}], "-", "0.001"}], ",", 
       RowBox[{
        RowBox[{"zmax", "[", "KBSIM", "]"}], "-", "0.005"}], ",", 
       RowBox[{"zmax", "[", "KBSIM", "]"}]}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479658613425561*^9, 3.4796587501410933`*^9}, {
   3.479658790462825*^9, 3.4796587993088913`*^9}, {3.479658852062684*^9, 
   3.479658891629363*^9}, {3.4796589431729183`*^9, 3.479658948798299*^9}, {
   3.479658997678957*^9, 3.4796590027188377`*^9}, {3.479659318794853*^9, 
   3.479659344898431*^9}, {3.479661657421668*^9, 3.4796616780054293`*^9}, {
   3.479661945775414*^9, 3.479661959545474*^9}, {3.479665675209929*^9, 
   3.479665676278386*^9}, 3.4796657878831253`*^9, {3.481940812147341*^9, 
   3.481940829419257*^9}, {3.6302083429611607`*^9, 3.6302083515364437`*^9}, {
   3.630210612999134*^9, 3.630210615553306*^9}, {3.6318342761199827`*^9, 
   3.631834277785796*^9}, {3.660964934904317*^9, 3.660964935954105*^9}, {
   3.660968688340294*^9, 3.660968693115794*^9}, {3.661220236123904*^9, 
   3.6612202369311447`*^9}, {3.6623290444123*^9, 3.662329072977393*^9}, 
   3.6623341355722446`*^9, {3.662337264381858*^9, 3.66233728414599*^9}}],

Cell[BoxData["0.005702178752449814`"], "Output",
 CellChangeTimes->{3.662337287443143*^9, 3.662338618554626*^9, 
  3.6645052299971657`*^9, 3.664593607157412*^9, 3.6653746190995626`*^9, 
  3.682483689592637*^9, 3.6825851060660667`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"plot", "[", "KBSIM", "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"plot1", "[", "KBSIM", "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Graphics", "[", 
    RowBox[{"Line", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"zmax", "[", "KBSIM", "]"}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"zmax", "[", "KBSIM", "]"}], ",", 
         RowBox[{"1.1", "*", 
          RowBox[{"fmax", "[", "KBSIM", "]"}]}]}], "}"}]}], "}"}], "]"}], 
    "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{"Red", ",", 
      RowBox[{"Line", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"magposactpromec", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"magposactpromec", ",", 
            RowBox[{"1.1", "*", 
             RowBox[{"fmax", "[", "KBSIM", "]"}]}]}], "}"}]}], "}"}], "/.", 
        RowBox[{"vals", "[", "KBSIM", "]"}]}], "]"}]}], "}"}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{"Gray", ",", 
      RowBox[{"Line", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"z95minus", "[", "KBSIM", "]"}], ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"z95minus", "[", "KBSIM", "]"}], ",", 
            RowBox[{"1.1", "*", 
             RowBox[{"fmax", "[", "KBSIM", "]"}]}]}], "}"}]}], "}"}], "/.", 
        RowBox[{"vals", "[", "KBS", "]"}]}], "]"}]}], "}"}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{"Gray", ",", 
      RowBox[{"Line", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"z95plus", "[", "KBSIM", "]"}], ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"z95plus", "[", "KBSIM", "]"}], ",", 
            RowBox[{"1.1", "*", 
             RowBox[{"fmax", "[", "KBSIM", "]"}]}]}], "}"}]}], "}"}], "/.", 
        RowBox[{"vals", "[", "KBS", "]"}]}], "]"}]}], "}"}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<z (m)\>\"", ",", "\"\<F (N/A)\>\""}], "}"}]}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.453823397414776*^9, 3.453823397824687*^9}, {
   3.453838538440839*^9, 3.453838572806719*^9}, 3.463844247723119*^9, 
   3.478894943196905*^9, 3.4788950132010527`*^9, {3.478961709433363*^9, 
   3.47896175216029*^9}, {3.478961842569364*^9, 3.478961894377494*^9}, {
   3.4789619830038633`*^9, 3.478961984506156*^9}, {3.4789699280628653`*^9, 
   3.478969982243393*^9}, {3.478970021389124*^9, 3.478970165180615*^9}, {
   3.478970224319232*^9, 3.478970261501657*^9}, {3.4789703108875017`*^9, 
   3.478970348344078*^9}, 3.478970398020482*^9, {3.478970871122594*^9, 
   3.47897087265033*^9}, {3.478971414854863*^9, 3.4789714317583723`*^9}, {
   3.4789723334965277`*^9, 3.4789723911200447`*^9}, {3.478973525233735*^9, 
   3.47897352833882*^9}, {3.479495227181163*^9, 3.4794952662789087`*^9}, {
   3.4794954131043873`*^9, 3.4794954161349077`*^9}, {3.479497883443406*^9, 
   3.479497887306903*^9}, {3.4794980354692507`*^9, 3.479498036795588*^9}, 
   3.4794982488155937`*^9, {3.479662131489229*^9, 3.479662133377276*^9}, 
   3.479665540471899*^9, {3.4802459792714577`*^9, 3.480245981573744*^9}, {
   3.4802525542284737`*^9, 3.4802525884311867`*^9}, {3.48194087775911*^9, 
   3.481940886937986*^9}, 3.630208353429995*^9, 3.6302106162586517`*^9, 
   3.631834278469103*^9, {3.631835050283194*^9, 3.631835119871463*^9}, {
   3.631838204428006*^9, 3.631838423237857*^9}, {3.6318384686026077`*^9, 
   3.631838479273821*^9}, {3.6318392214551907`*^9, 3.631839229661147*^9}, {
   3.661139094999187*^9, 3.6611390950093946`*^9}, {3.661139202513871*^9, 
   3.661139202520485*^9}, {3.6611412584795847`*^9, 3.6611412584963713`*^9}, {
   3.6611413098586197`*^9, 3.661141309872466*^9}, {3.661143315366548*^9, 
   3.6611433270441647`*^9}, {3.662332301064869*^9, 3.662332380309093*^9}, {
   3.6623341355802917`*^9, 3.662334135592721*^9}, {3.662354326401864*^9, 
   3.662354329985043*^9}, {3.682628153838578*^9, 3.682628169123475*^9}}],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
      LineBox[CompressedData["
1:eJwV1nlYTdsbB/BKPyU0S1ESbhkyZ05fKUWDokmGKNI80HimfU5zTiRKJYpo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       "]]}}, {}, {}}, {{{}, {}, 
     {RGBColor[1, 1, 0], AbsoluteThickness[1.6], Opacity[1.], 
      LineBox[CompressedData["
1:eJwV13k8VG0bB3C0kGxFtoSWR5Q27Sq/pCRlyRKpKNGCkH1mzJkZW5pECoko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       "]]}}, {}, {}}, 
   LineBox[{{0.007442538880671186, 0}, {0.007442538880671186, 
     1.2231925294535315`}}], 
   {RGBColor[1, 0, 0], LineBox[{{0.0079, 0}, {0.0079, 1.2231925294535315`}}]}, 
   {GrayLevel[0.5], 
    LineBox[{{0.005702178752449814, 0}, {0.005702178752449814, 
      1.2231925294535315`}}]}, 
   {GrayLevel[0.5], 
    LineBox[{{0.009391637619473092, 0}, {0.009391637619473092, 
      1.2231925294535315`}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"z (m)\"", TraditionalForm], 
    FormBox["\"F (N/A)\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 0.013}, {-0.007687110331871783, 1.1119931477589993`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.661143339013616*^9, 3.6613415331386127`*^9, 3.662246543123845*^9, 
   3.662328357735825*^9, 3.6623301043833427`*^9, 3.662331992642704*^9, 
   3.662332313093595*^9, {3.662332357700629*^9, 3.662332372084869*^9}, {
   3.662337270050414*^9, 3.6623372917742653`*^9}, 3.6623386186212387`*^9, 
   3.662354353022257*^9, 3.662354642187873*^9, 3.664505230090001*^9, 
   3.664593607255026*^9, 3.665374619169465*^9, 3.6824836896752787`*^9, 
   3.6825851061700983`*^9, 3.682628169649007*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Coil calc for KAGRA BS IM (double magnets, discs)", "Section",
 CellChangeTimes->{{3.453751016056313*^9, 3.453751037487228*^9}, 
   3.463844192181329*^9, {3.478894850822432*^9, 3.478894851717502*^9}, {
   3.4788951705281897`*^9, 3.4788951754720497`*^9}, {3.4819407269664*^9, 
   3.481940736973164*^9}, {3.6302077654764643`*^9, 3.6302077702623034`*^9}, {
   3.630210588958201*^9, 3.630210589517418*^9}, {3.661141232361245*^9, 
   3.661141232942458*^9}, {3.661141276086359*^9, 3.661141285892767*^9}, {
   3.664425907321329*^9, 3.664425910542931*^9}, {3.682482462513555*^9, 
   3.682482463401539*^9}, 3.682561412918161*^9}],

Cell[CellGroupData[{

Cell["\<\
bosemvalsKBSIMD = Recurse[
\t{
\t\tkB->1.38 10^-23,
\t\tT->295,
\t\tg->9.8,
\t\tmu0->4 N[Pi] 10^-7,
\t\trhoeAl->2.65 10^-8,\t\t\t(* Resistivity of Al *)
\t\trhoepianowire->30 rhoeAl,\t(* Resistivity of P.W., GUESSTIMATE *)
\t\tsigmaeAu->2.67,\t\t\t\t(* Resistivity of Au paint, measured *)
\t\tmassSOS->0.25,\t\t\t\t(* Final design value *)
\t\tmassM->rhomM l N[Pi] a^2,
\t\tPi->N[Pi],
\t\trhomM->7400,\t\t\t\t(* Mass density of magnets *)
\t\tztube->0.0155,\t\t\t\t(* Separation for magnet to push its own weight, \
measured *)
\t\tzpickup->0.018-l,\t\t\t(* Separation for magnet to pull its own weight, \
measured *)
\t\tmasspullapart->0.060,\t\t(* Force (in kgf) to separate magnets *)
\t\t(* preferred value of small magnet dipole moment *)
\t\tmzpref->0.007945632135874319,
\t\t(* magnet moment per unit volume for magnet stuff, assumed the same for \
big and small *)
\t\tmz->mzpref/(lold*N[Pi]*aold^2),
\t\tlold->0.003175,\t\t\t\t(* length of LIGO small magnets *)
\t\taold->0.0009525,\t\t\t(* radius of LIGO small magnets *)
\t\tlmagnetonly->0.010,\t\t\t\t(* length of magnets *)
\t\tl->0.010+2*0.001,\t\t\t\t(* length of magnets plus discs *)
\t\ta->0.005,\t\t\t\t(* radius of big magnets *)
\t\tdipole -> mz*lmagnetonly*N[Pi]*a^2,
\t\tlayers -> 27, (* 10212-Gr.12-body BOSEM intermediate.pdf *)
\t\tturns -> 600, (* 10212-Gr.12-body BOSEM intermediate.pdf *)
\t\twirediam ->0.36*0.001, (* 10212-Gr.12-body BOSEM intermediate.pdf *)
\t\t(* coil length *)
\t\tcoillen->(11-3)*0.001,  (* 10212-Gr.12-body BOSEM intermediate.pdf *)
\t\t(* the ends of the coil relative to the centre of the coil *)
\t\tcoilz1->-coillen/2,
\t\tcoilz2->+coillen/2,
\t\t(* the inner and outer radii of the coil *)
\t\tcoilrad1->(18/2)*0.001, (* 10212-Gr.12-body BOSEM intermediate.pdf *)
\t\tcoilrad2->coilrad1+wirediam*layers, (* 10212-Gr.12-body BOSEM \
intermediate.pdf *)
\t\tcoildrad2max->(49/2)*0.001, (* 10212-Gr.12-body BOSEM intermediate.pdf *)
\t\t(* the number of turns *)
\t\tcoilturns->600, (* 10203-Gr.12-Osem intermediate mass.pdf *)
\t\tcoilsigma -> coilturns/((coilrad2 - coilrad1)*(coilz2 - coilz1)),
\t\tmagposactpromec->0.0079, (* Inventor, Promec, Fabian *)
\t\tmagposactv2->zmax[KPR], 
\t\tpairoffset->0.0652
\t}
]
vals[KBSIMD] := bosemvalsKBSIMD;\
\>", "Input",
 CellChangeTimes->{{3.453837228357688*^9, 3.453837230833909*^9}, {
   3.463844183252262*^9, 3.463844223147016*^9}, {3.478894862544446*^9, 
   3.4788948852377567`*^9}, {3.478894985619047*^9, 3.4788949913587503`*^9}, {
   3.4788950240972023`*^9, 3.478895025494358*^9}, {3.481940748223406*^9, 
   3.481940763510077*^9}, {3.6302077790327063`*^9, 3.630207779944365*^9}, {
   3.630208292557073*^9, 3.630208293170534*^9}, {3.6302085800514812`*^9, 
   3.630208649083247*^9}, {3.630209645346671*^9, 3.630209663817658*^9}, {
   3.630209701977907*^9, 3.6302097023837023`*^9}, 3.630209734594172*^9, 
   3.630210623319276*^9, {3.6302114423356447`*^9, 3.6302115422890863`*^9}, {
   3.630211579624671*^9, 3.630211581024807*^9}, {3.630211687932591*^9, 
   3.630211722300425*^9}, {3.6302984714100847`*^9, 3.630298473322809*^9}, {
   3.630361294367758*^9, 3.6303612947567253`*^9}, {3.6303613801867123`*^9, 
   3.6303613881298*^9}, {3.631834762263462*^9, 3.631834791379961*^9}, 
   3.661055741435896*^9, 3.6610557813045607`*^9, 3.6610560671992607`*^9, 
   3.661118651388139*^9, 3.661139094945122*^9, 3.661139202476098*^9, {
   3.661141235734417*^9, 3.661141258292121*^9}, {3.661141309672125*^9, 
   3.661141309700727*^9}, {3.661141356555216*^9, 3.661141380002549*^9}, {
   3.661141638842251*^9, 3.661141681335253*^9}, {3.6611432431036263`*^9, 
   3.661143250501958*^9}, {3.661143295718404*^9, 3.661143300484091*^9}, 
   3.66122654686482*^9, {3.661226643717907*^9, 3.661226646163519*^9}, {
   3.664425954869774*^9, 3.664425956573142*^9}, {3.664426626286175*^9, 
   3.66442670322782*^9}, {3.66450422749352*^9, 3.66450423317286*^9}, 
   3.68248240052384*^9, {3.682583263891856*^9, 3.68258326446968*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"kB", "\[Rule]", "1.38`*^-23"}], ",", 
   RowBox[{"T", "\[Rule]", "295"}], ",", 
   RowBox[{"g", "\[Rule]", "9.8`"}], ",", 
   RowBox[{"mu0", "\[Rule]", "1.2566370614359173`*^-6"}], ",", 
   RowBox[{"rhoeAl", "\[Rule]", "2.65`*^-8"}], ",", 
   RowBox[{"rhoepianowire", "\[Rule]", "7.95`*^-7"}], ",", 
   RowBox[{"sigmaeAu", "\[Rule]", "2.67`"}], ",", 
   RowBox[{"massSOS", "\[Rule]", "0.25`"}], ",", 
   RowBox[{"massM", "\[Rule]", "0.006974335690969341`"}], ",", 
   RowBox[{"\[Pi]", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"rhomM", "\[Rule]", "7400"}], ",", 
   RowBox[{"ztube", "\[Rule]", "0.0155`"}], ",", 
   RowBox[{"zpickup", "\[Rule]", "0.005999999999999998`"}], ",", 
   RowBox[{"masspullapart", "\[Rule]", "0.06`"}], ",", 
   RowBox[{"mzpref", "\[Rule]", "0.00794563213587432`"}], ",", 
   RowBox[{"mz", "\[Rule]", "878020.9598010788`"}], ",", 
   RowBox[{"lold", "\[Rule]", "0.003175`"}], ",", 
   RowBox[{"aold", "\[Rule]", "0.0009525`"}], ",", 
   RowBox[{"lmagnetonly", "\[Rule]", "0.01`"}], ",", 
   RowBox[{"l", "\[Rule]", "0.012`"}], ",", 
   RowBox[{"a", "\[Rule]", "0.005`"}], ",", 
   RowBox[{"dipole", "\[Rule]", "0.6895960492522322`"}], ",", 
   RowBox[{"layers", "\[Rule]", "27"}], ",", 
   RowBox[{"turns", "\[Rule]", "600"}], ",", 
   RowBox[{"wirediam", "\[Rule]", "0.00035999999999999997`"}], ",", 
   RowBox[{"coillen", "\[Rule]", "0.008`"}], ",", 
   RowBox[{"coilz1", "\[Rule]", 
    RowBox[{"-", "0.004`"}]}], ",", 
   RowBox[{"coilz2", "\[Rule]", "0.004`"}], ",", 
   RowBox[{"coilrad1", "\[Rule]", "0.009000000000000001`"}], ",", 
   RowBox[{"coilrad2", "\[Rule]", "0.01872`"}], ",", 
   RowBox[{"coildrad2max", "\[Rule]", "0.0245`"}], ",", 
   RowBox[{"coilturns", "\[Rule]", "600"}], ",", 
   RowBox[{"coilsigma", "\[Rule]", "7.716049382716049`*^6"}], ",", 
   RowBox[{"magposactpromec", "\[Rule]", "0.0079`"}], ",", 
   RowBox[{"magposactv2", "\[Rule]", "0.006718812869426184`"}], ",", 
   RowBox[{"pairoffset", "\[Rule]", "0.0652`"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.661139342263995*^9, {3.661141667258052*^9, 3.661141684384678*^9}, 
   3.661143334994034*^9, 3.661218923863595*^9, 3.661226547848268*^9, 
   3.661341442616219*^9, 3.66224645200333*^9, 3.662328257588792*^9, 
   3.6623315030483637`*^9, 3.662338118106715*^9, 3.664426744188464*^9, 
   3.6645042435163717`*^9, 3.6645936072886753`*^9, 3.6653746192000523`*^9, 
   3.682483689713348*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"optdata", "[", "KBSIMD", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "1.2598187348550502`"}], ",", 
      RowBox[{"{", 
       RowBox[{"z", "\[Rule]", "0.007994036795544876`"}], "}"}]}], "}"}], ",",
     "\[IndentingNewLine]", 
    RowBox[{"Minimize", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          RowBox[{"fz", "[", 
           RowBox[{"KBSIMD", ",", "z"}], "]"}]}], "+", 
         RowBox[{"fz", "[", 
          RowBox[{"KBSIMD", ",", 
           RowBox[{
            RowBox[{"z", "+", "pairoffset"}], "/.", 
            RowBox[{"vals", "[", "KBSIMD", "]"}]}]}], "]"}]}], ",", " ", 
        RowBox[{"0.006", " ", "<", " ", "z", " ", "<", " ", "0.012"}]}], 
       "}"}], ",", " ", "z"}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.478970745257534*^9, 3.478970764425056*^9}, 
   3.4796619224973173`*^9, {3.480244382554545*^9, 3.480244405961742*^9}, {
   3.4819408015577917`*^9, 3.4819408027090397`*^9}, {3.481940979763582*^9, 
   3.481940981746011*^9}, {3.481941548420309*^9, 3.481941559738948*^9}, {
   3.630208310775996*^9, 3.6302083160559387`*^9}, 3.6302102241338043`*^9, {
   3.630210607856474*^9, 3.6302106082793016`*^9}, 3.630361338897683*^9, 
   3.660965340441757*^9, {3.6611412583009977`*^9, 3.6611412583096*^9}, {
   3.6611413097075777`*^9, 3.661141309712214*^9}, {3.6611413410526447`*^9, 
   3.661141347091383*^9}, {3.6611416926384974`*^9, 3.66114170977668*^9}, 
   3.661219512896727*^9, 3.662329456445507*^9, {3.662329520779831*^9, 
   3.662329542539156*^9}, {3.664425958246834*^9, 3.664425960009359*^9}, 
   3.6645953911025553`*^9, 3.665363625248659*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "1.2598187348550516`"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", "\[Rule]", "0.007994036894390839`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.6623299493259478`*^9, 3.6623318864112988`*^9, 
  3.662338510736121*^9, 3.664427056962029*^9, 3.664504679164015*^9, 
  3.664594027470549*^9, 3.665375056023589*^9, 3.682484026695292*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"optdata", "[", "KBSIM", "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"for", " ", "comparison"}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.6611417897464647`*^9, 3.6611417951142797`*^9}, {
   3.6612035835908327`*^9, 3.6612036047716*^9}, 3.662329142361154*^9, {
   3.662330001250415*^9, 3.662330001672842*^9}, {3.6623300489374743`*^9, 
   3.662330049507196*^9}, {3.682583328108655*^9, 3.682583329697834*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "1.1119663292416933`"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", "\[Rule]", "0.007442586205061097`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.662330002511826*^9, 3.662330050048687*^9, 
  3.66233188678736*^9, 3.6623385110669613`*^9, 3.664427057162121*^9, 
  3.664504679224824*^9, 3.664594027715934*^9, 3.6653750561714697`*^9, 
  3.682484026781452*^9, 3.682583331650846*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fzi", "[", "KBSIMD", "]"}], " ", "=", " ", 
  RowBox[{"FunctionInterpolation", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"fz", "[", 
      RowBox[{"KBSIMD", ",", "z"}], "]"}], "-", 
     RowBox[{"fz", "[", 
      RowBox[{"KBSIMD", ",", 
       RowBox[{
        RowBox[{"z", "+", "pairoffset"}], "/.", 
        RowBox[{"vals", "[", "KBSIMD", "]"}]}]}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "0", ",", "0.013"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.661121231903079*^9, 3.661121302673418*^9}, {
   3.66112135471321*^9, 3.661121364047564*^9}, 3.661121573023286*^9, {
   3.661121981470016*^9, 3.661121984145525*^9}, {3.661122016670216*^9, 
   3.6611220263968563`*^9}, {3.661122422824706*^9, 3.661122440665392*^9}, {
   3.6611225257271423`*^9, 3.6611225561384287`*^9}, 3.661122943936385*^9, 
   3.661124072219921*^9, 3.661124107400278*^9, {3.66114125831656*^9, 
   3.6611412583250227`*^9}, {3.6611413097183743`*^9, 3.661141309722828*^9}, {
   3.661142955018881*^9, 3.661142976745582*^9}, 3.6612189023455*^9, {
   3.6612189588266687`*^9, 3.6612189659137297`*^9}, 3.661219472807549*^9, {
   3.661219548644806*^9, 3.661219555082078*^9}, {3.662262695279645*^9, 
   3.662262697461714*^9}, {3.6644259606161537`*^9, 3.6644259621772823`*^9}}],

Cell[BoxData[
 TagBox[
  TemplateBox[{RowBox[{
      StyleBox[
       TagBox["InterpolatingFunction", "SummaryHead"], 
       "NonInterpretableSummary"], 
      StyleBox["[", "NonInterpretableSummary"], 
      DynamicModuleBox[{Typeset`open$$ = False}, 
       PanelBox[
        PaneSelectorBox[{False -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquarePlusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = True), Appearance -> None,
                 Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{{{}, {}, {
                   Directive[
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1]], 
                   LineBox[CompressedData["
1:eJwVxXsw2wcAB/BMPXo5FI1Sj6VKo1hGaaOIfjfisYYWK7qbpYqUTTxqjfcj
nglaXIfRtdVd18420mm963lHVtVRXUsNR22eWUny+226nbhtf3zuYxWVFMLX
oFAo7P/8P3m9i57jv+GpsJi91bi7sH/uO24PKXMAKfUinR58i9bbsRpaKjZG
+T9f6PV8CIO0v/2qRD6gJv341EY2hAA522MiJgD6Krvxf3pHkXH4LD9wMxgx
e7gOyhsTOOYeExsmCEWI68Wz00YvcJcj6bA++hGmnjOs+4de4hpLfuPkegQq
OXHMjdBZ9HgHzZ90isSOH6tB+9o8Slbba58ZRIFMffBnn+QVhnt84wUT0RgQ
B2aYWv6GYc2/qC6lfPCKCmX8ht9x4IOWiY8vxMJNjz7CYy1js6emrdb6U1gj
7Kr8zgr2M0sGXLTjYW+fp+fOWIOmYW2tel4Aw3DX7vSqdcTYjJdO1yfCgCYX
v/dcDgMz6rNydjJ4+gucLOvXaHQbfO1icRH1LqmOSwEbSAzfsbiin4J3L9eV
PcrZBM1xtCV7OwU32+sCy7kKCG++Eyr89XP4LtUFlcoU2KVL06WPXkJ/iujS
kJcSAYZVExM/CHHIpsdon1QJ4dOvts0kqWBQc21N96jw5ArTwzgtDV4cjrtp
kgpzix9KTMPSYb/+xni7XwVzFmXtiV8G6I3TVKY+AXdv9j2TY5kIel9aGRVM
YO+qblG8URYKdgb16sUEzMqjBcka2XjrpaSJ3UVgZvhUdO5iNpxPez80mSeQ
0z3Sf7AvBydsO0+d3yYQ0PzYMb0pF2YWkW5X95KYdI2UTpblYSxBdCTUioTv
gucBwlMEE2dbjWVbEnmKmuQ8qQhvmqaCEhgkGufaiEmLfLglMC3N3yaxOlJH
EVfnY3dmgvY9PRJaGrJqD80CnKBL9Dq3CBx3a7/vn1OAuyE8C91pAhGBibus
yAK84LxqO9dK4JPm5Bl1VCGCGdPffH+ZgFCX5ekyUwg9/HJGO4LAZx0+jARu
Ee7ojCwN2BE4DUuvlK4iZI55a/mTKnBlHSvjTsWoCNGxU7epYFN/neZ8qxi8
fY8qPNJVoMVzRv8wLUGOgL/af0QFcn9ra0plCcbPxy3GrSnRQks8pFaXoCx9
1izrthLF+nL6glCM/OOxtPBQJVhn7n/905IYldIQXg1ViZ06drPOOQmMY4wF
ZIcC7d0VcqNJCTS+eDxYxFeAe9ih5aBPKXKj1cadJgpsVZdRyntLITUfcuUV
b0IUeHRqi1mGsS+Fi4NLG1BWs5L6GsrQ17WyPO+9gX8BLNrCDA==
                    
                    "]]}}}, {}, {}}, {
               DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
                AxesOrigin -> {0, 0}, 
                FrameTicks -> {{None, None}, {None, None}}, 
                GridLines -> {None, None}, DisplayFunction -> Identity, 
                PlotRangePadding -> {{
                   Scaled[0.1], 
                   Scaled[0.1]}, {
                   Scaled[0.1], 
                   Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
                All, DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                Directive[
                  Opacity[0.5], 
                  Thickness[Tiny], 
                  RGBColor[0.368417, 0.506779, 0.709798]], 
                FrameTicks -> {{None, None}, {None, None}}, 
                GridLines -> {None, None}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 
                Dynamic[{
                  Automatic, 3.5 CurrentValue["FontCapHeight"]/
                   AbsoluteCurrentValue[Magnification]}], 
                Method -> {
                 "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
                  AbsolutePointSize[6], "ScalingFunctions" -> None, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (
                    Part[{{Identity, Identity}, {Identity, Identity}}, 1, 
                    2][#]& )[
                    Part[#, 1]], 
                    (
                    Part[{{Identity, Identity}, {Identity, Identity}}, 2, 
                    2][#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 
                    2][#]& )[
                    Part[#, 1]], 
                    (
                    Part[{{Identity, Identity}, {Identity, Identity}}, 2, 
                    2][#]& )[
                    Part[#, 2]]}& )}}, 
                PlotRange -> {{0., 0.013}, {-0.009293858918239611, 
                 1.259740837488726}}, PlotRangeClipping -> True, 
                PlotRangePadding -> {{
                   Scaled[0.1], 
                   Scaled[0.1]}, {
                   Scaled[0.1], 
                   Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"scalar\"", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}], True -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquareMinusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                None, Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{{{}, {}, {
                   Directive[
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1]], 
                   LineBox[CompressedData["
1:eJwVxXsw2wcAB/BMPXo5FI1Sj6VKo1hGaaOIfjfisYYWK7qbpYqUTTxqjfcj
nglaXIfRtdVd18420mm963lHVtVRXUsNR22eWUny+226nbhtf3zuYxWVFMLX
oFAo7P/8P3m9i57jv+GpsJi91bi7sH/uO24PKXMAKfUinR58i9bbsRpaKjZG
+T9f6PV8CIO0v/2qRD6gJv341EY2hAA522MiJgD6Krvxf3pHkXH4LD9wMxgx
e7gOyhsTOOYeExsmCEWI68Wz00YvcJcj6bA++hGmnjOs+4de4hpLfuPkegQq
OXHMjdBZ9HgHzZ90isSOH6tB+9o8Slbba58ZRIFMffBnn+QVhnt84wUT0RgQ
B2aYWv6GYc2/qC6lfPCKCmX8ht9x4IOWiY8vxMJNjz7CYy1js6emrdb6U1gj
7Kr8zgr2M0sGXLTjYW+fp+fOWIOmYW2tel4Aw3DX7vSqdcTYjJdO1yfCgCYX
v/dcDgMz6rNydjJ4+gucLOvXaHQbfO1icRH1LqmOSwEbSAzfsbiin4J3L9eV
PcrZBM1xtCV7OwU32+sCy7kKCG++Eyr89XP4LtUFlcoU2KVL06WPXkJ/iujS
kJcSAYZVExM/CHHIpsdon1QJ4dOvts0kqWBQc21N96jw5ArTwzgtDV4cjrtp
kgpzix9KTMPSYb/+xni7XwVzFmXtiV8G6I3TVKY+AXdv9j2TY5kIel9aGRVM
YO+qblG8URYKdgb16sUEzMqjBcka2XjrpaSJ3UVgZvhUdO5iNpxPez80mSeQ
0z3Sf7AvBydsO0+d3yYQ0PzYMb0pF2YWkW5X95KYdI2UTpblYSxBdCTUioTv
gucBwlMEE2dbjWVbEnmKmuQ8qQhvmqaCEhgkGufaiEmLfLglMC3N3yaxOlJH
EVfnY3dmgvY9PRJaGrJqD80CnKBL9Dq3CBx3a7/vn1OAuyE8C91pAhGBibus
yAK84LxqO9dK4JPm5Bl1VCGCGdPffH+ZgFCX5ekyUwg9/HJGO4LAZx0+jARu
Ee7ojCwN2BE4DUuvlK4iZI55a/mTKnBlHSvjTsWoCNGxU7epYFN/neZ8qxi8
fY8qPNJVoMVzRv8wLUGOgL/af0QFcn9ra0plCcbPxy3GrSnRQks8pFaXoCx9
1izrthLF+nL6glCM/OOxtPBQJVhn7n/905IYldIQXg1ViZ06drPOOQmMY4wF
ZIcC7d0VcqNJCTS+eDxYxFeAe9ih5aBPKXKj1cadJgpsVZdRyntLITUfcuUV
b0IUeHRqi1mGsS+Fi4NLG1BWs5L6GsrQ17WyPO+9gX8BLNrCDA==
                    
                    "]]}}}, {}, {}}, {
               DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
                AxesOrigin -> {0, 0}, 
                FrameTicks -> {{None, None}, {None, None}}, 
                GridLines -> {None, None}, DisplayFunction -> Identity, 
                PlotRangePadding -> {{
                   Scaled[0.1], 
                   Scaled[0.1]}, {
                   Scaled[0.1], 
                   Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
                All, DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                Directive[
                  Opacity[0.5], 
                  Thickness[Tiny], 
                  RGBColor[0.368417, 0.506779, 0.709798]], 
                FrameTicks -> {{None, None}, {None, None}}, 
                GridLines -> {None, None}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 
                Dynamic[{
                  Automatic, 3.5 CurrentValue["FontCapHeight"]/
                   AbsoluteCurrentValue[Magnification]}], 
                Method -> {
                 "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
                  AbsolutePointSize[6], "ScalingFunctions" -> None, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (
                    Part[{{Identity, Identity}, {Identity, Identity}}, 1, 
                    2][#]& )[
                    Part[#, 1]], 
                    (
                    Part[{{Identity, Identity}, {Identity, Identity}}, 2, 
                    2][#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (
                    Part[{{Identity, Identity}, {Identity, Identity}}, 1, 
                    2][#]& )[
                    Part[#, 1]], 
                    (
                    Part[{{Identity, Identity}, {Identity, Identity}}, 2, 
                    2][#]& )[
                    Part[#, 2]]}& )}}, 
                PlotRange -> {{0., 0.013}, {-0.009293858918239611, 
                 1.259740837488726}}, PlotRangeClipping -> True, 
                PlotRangePadding -> {{
                   Scaled[0.1], 
                   Scaled[0.1]}, {
                   Scaled[0.1], 
                   Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"scalar\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["3", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"Hermite\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["False", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}]}, 
         Dynamic[Typeset`open$$], ImageSize -> Automatic], BaselinePosition -> 
        Baseline], DynamicModuleValues :> {}], 
      StyleBox["]", "NonInterpretableSummary"]}]},
   "CopyTag",
   DisplayFunction->(#& ),
   InterpretationFunction->("InterpolatingFunction[{{0., 0.013}}, <>]"& )],
  False,
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.664427070348568*^9, 3.664504692297626*^9, 
  3.664594040012186*^9, 3.665375068816485*^9, 3.6824840383347*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"plot", "[", "KBSIMD", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    GraphicsBox[{{}, {}, 
      {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
       LineBox[CompressedData["
1:eJwV1nk8VN0fB3BSj0jZSZZQJIQS0jKfsiTJkkSpKLKGEIUZM3fGlqk8lUJU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        "]]}},
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->{True, True},
     AxesLabel->{None, None},
     AxesOrigin->{0, 0},
     DisplayFunction->Identity,
     Frame->{{False, False}, {False, False}},
     FrameLabel->{{None, None}, {None, None}},
     FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
     GridLines->{None, None},
     GridLinesStyle->Directive[
       GrayLevel[0.5, 0.4]],
     Method->{
      "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
       AbsolutePointSize[6], "ScalingFunctions" -> None},
     PlotRange->{{0, 0.013}, {-0.009293847122732027, 1.2598186985921493`}},
     PlotRangeClipping->True,
     PlotRangePadding->{{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}},
     Ticks->{Automatic, Automatic}], ",", "\[IndentingNewLine]", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"fz", "[", 
         RowBox[{"KBSIMD", ",", "p"}], "]"}], "-", 
        RowBox[{"fz", "[", 
         RowBox[{"KBSIMD", ",", 
          RowBox[{
           RowBox[{"p", "+", "pairoffset"}], "/.", 
           RowBox[{"vals", "[", "KBSIMD", "]"}]}]}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"p", ",", "0", ",", "0.013"}], "}"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", "Black", "}"}]}]}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.4789618100364523`*^9, 3.478961850760915*^9}, 
   3.478969868098156*^9, 3.4789702271107073`*^9, {3.478971402742322*^9, 
   3.478971407269801*^9}, {3.478973436528585*^9, 3.4789734559838*^9}, {
   3.4794970273251*^9, 3.4794970280748262`*^9}, {3.479497850691868*^9, 
   3.479497851721608*^9}, {3.4802445496159487`*^9, 3.4802445841180058`*^9}, {
   3.4802446656757193`*^9, 3.4802446687524443`*^9}, {3.481940803363203*^9, 
   3.481940804034131*^9}, {3.481941063760079*^9, 3.4819410664063997`*^9}, {
   3.481941556057631*^9, 3.4819415664906*^9}, {3.630208312322345*^9, 
   3.63020831448879*^9}, 3.630209982122305*^9, 3.630210040824745*^9, {
   3.630210608691247*^9, 3.6302106091463537`*^9}, 3.6302116072117853`*^9, 
   3.6302119179137897`*^9, 3.6304701238527927`*^9, 3.631834820615905*^9, 
   3.649109628464219*^9, {3.649110363868889*^9, 3.649110366770886*^9}, {
   3.649110567151823*^9, 3.649110570373554*^9}, {3.661123689182354*^9, 
   3.661123723132988*^9}, 3.661123839830414*^9, {3.661123888550177*^9, 
   3.6611238924215937`*^9}, {3.661123959516914*^9, 3.661123970823284*^9}, {
   3.661124020120494*^9, 3.661124020504492*^9}, {3.661124084594274*^9, 
   3.66112408490854*^9}, {3.661124132485323*^9, 3.661124133744603*^9}, {
   3.661127129389042*^9, 3.6611271300441732`*^9}, {3.6611285421516657`*^9, 
   3.6611285486416283`*^9}, 3.661139350752645*^9, {3.661141258332346*^9, 
   3.661141258345943*^9}, {3.661141309730465*^9, 3.6611413097415237`*^9}, {
   3.661142929646887*^9, 3.6611429309305487`*^9}, {3.661143000502679*^9, 
   3.6611430183305893`*^9}, 3.6611430889631033`*^9, {3.661202692295169*^9, 
   3.6612027456074247`*^9}, {3.6612032345320673`*^9, 
   3.6612032350121202`*^9}, {3.661203641247325*^9, 3.6612036470219383`*^9}, {
   3.661204651133306*^9, 3.6612046566907873`*^9}, {3.661205020492955*^9, 
   3.661205021421957*^9}, {3.662327449381301*^9, 3.662327449845611*^9}, 
   3.662327486588072*^9, {3.662327534038128*^9, 3.662327534215892*^9}, 
   3.662328936644876*^9, {3.662330873366127*^9, 3.662330873678608*^9}, {
   3.664425962748343*^9, 3.664425964357788*^9}, {3.664426029168276*^9, 
   3.66442603113202*^9}, 3.664595419822204*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
     LineBox[CompressedData["
1:eJwV1nk4VO0bB3CkLJWQtddOkiyJeFG+llKpNIkslaQkiQi9zJiZM2OfNhWS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      "]]}}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 0.013}, {-0.009293847122732027, 1.2598186986093889`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.661219709246232*^9, 3.661341532375228*^9, 
  3.66224654204303*^9, 3.662328317212946*^9, 3.662331948563867*^9, 
  3.6623385721286287`*^9, 3.6644271173032503`*^9, 3.6645047378913527`*^9, 
  3.664594083413208*^9, 3.665375113354527*^9, 3.682484079501937*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"plot1", "[", "KBSIMD", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    GraphicsBox[{{}, {}, 
      {RGBColor[1, 1, 0], AbsoluteThickness[1.6], Opacity[1.], 
       LineBox[CompressedData["
1:eJwV1nk0Vd0bB3BSyVCUEKlQopKUIkO+pkIipQGFIiGUMcPl3nNNcVVvEUlJ
ZWg2lDKkfpUQlfCmImUMoWs4p8Gb4bf746yzPmvts/az197n+W4l12M73acJ
CAhMkOfv+/G89lO2+qObtH1yc87mBBjuaZt3z6m03lBKa87eJvkdSK3w19ct
bTd0StyTlS9/EA83KAmolg4b6oiF7Lso748qfmjnolIBKPmzOYnyXNi8yraT
K5WE1oB/oY/8WSSV6onLlipi+sjaWkH5qygqiO2TLtUE79f0g84LCjHoN2Kr
7GuMmZ09h96/fAaVBdbJI12WWC1pPhTrWAv7SrmOJQt24M2mqX+T9zRgRLEg
2DptN1I+veVavWrCZ6FFE6mvHKCpZ6vM6WyGgshdwV57ZwRn3DbL1fuCaXrG
hizPgzC/nfGzb20HFLVkf0iy3aD4UExNQ7oLno/Z/TefusPIZUVWneRXOCbu
aK5v9UAuP3fHh+YeKIqbR+/le0G7qHJNXXwfJBbXeXeo++C6Yk3fT/N+3Ah8
aj1mdhSLD36v6343gA2rlXVEN/uh9U8i0+b9HYLhP7LNXf1xvzOqvqWTj2ue
bIltPgGwqDE5x58/jA9LbOUaTwYiUudwVXzpMDpCPyxZkh4EmdY72+gtI6DS
r1d+fxyM7zZSA1mNI0iQFrH0aT2OlMEDRoPWo/BYp1hT2BsCkY9UdkjRKFpk
qb5QkTAku8nMFZahoZyZMl14QThO3lDJ2n+IRo5exPgqhXAoRaz3DHGnofbe
lbFVDMdkgLb/2cM0Vs/W7E5XC0eBi872Ck8aG1m1FRq64Ugtf6m/2JeGzd6p
qD2O4Uj5Xfm5IJgGS8JLMPdSOBb/UWBZxtF4xzGYNFNiYUQ5Y8Qyh0aY4ZXx
ChUWqvIvD1vm0lg8IfTHZCULpnX/zre8TsMz/NUvIy0WFAPE35jdpDER5Dhi
sJkF+4Flk2vv0lh+JLR7vRcLSQ5JR7uKaITuKqpdVsgC977Ut2sVNBZJLajJ
esDCh+yGGyde0HjewKpWLmPh4dmQf7wraYhvN32hWMFCe0ZPg2Y1jauWjY8V
mlgYv1m3srCWRq3hcMH8MRbu/LhlmtBAY+EK9fPTjSOg+1E28vwXGhZPogq1
N0eg5rdElV0bjSC75leelhHYbPbETqKdxuvIOIE3OyIQ5hS2KaaDBrux3SvF
NQJFO2gr924anawUg+UxEfjeeODg9H4aN+smO8yrIyDjbfzuIUPjvdvu8bBX
EWgVlK3f94PGtLHbMnfeRuDU/PB5Aj9pOC51sJL8GIHDj5d7b/lF1hN6v+hj
XwQkbfi+tWM0/JQ8T3iJRsJiaktV/iQNnaAG9UTrSKias9cPCzOIU8+xlt0Z
iQvrvkwkzGLwrjv0aNaeSGw1fjOkLMIgYLdiwSOXSMQ9z7feKcogT/uY1qB/
JJpzBulccQbLxsT1rFMjcaz73oTqXAaSbAtzibZIfIm4ciNBjoGLtoLnxa5I
+Gg458+SJ9/zh+JV+yIROBnTEUds5XK+FiORGF+x6yW1kNRj1GPtJ8SGeNr6
rCOLGIxPi9nVoMrG+FTYNRklBn0n/ncw2Y+NAGZ6cL0qg0uxIiaiwWzYWy4y
01JjsCPaTpkbxoZA5A7LFOIydm/n0Sg2Zlr4/dyzgsHJYIlDW8+xcTzB5kv9
SgZr3FwOC5awEdix6L/Lqxl0H7i5JbScDRXWDe0fxGnO9PKhp2wIWnTc2qrB
QMDxRG9rDRvXDV7o0cSNtvmeJZ/YoB6o/tHTZHDccOrIsSk2ar3nSOesY7DS
wNKqR4iDjKvXP/KJ23STVznN4mD4WnKTjhYDiw2qg1vncqBc9JxVTSynvt13
+VIOmovZEZ/XMyiXyzz2eQsHLNUFHt3aDPxkv23fZcWBi5PDayUdBirSWpqv
tnOwbOCSjzPxacnq4RJ7DgILLzg3ER8QHvI/d4SDgapAsbKNDIR+GAZZneag
okjjqrMeA8Mall9wEgdb7/FYJ4nDM0p8MlM5mNkjdqeUeHTzOnf6MgfvW1ok
5ukzaE9V2XMxn4M/O/W+lhEreLvurLzPgdmdbYFdxPbItBkq5iDeBPZiBgze
9i4wN33KQVb8UlUH4icbxTcO1HNQIxz3aZD4P3HL9dJNHBTqrF0quYmBdkes
Jpo5eFSo+Xwd8d2EKbXkDlLPnwnh48SXWkbl9Ec5EDzue58h/pi3Rsb9Jxnv
drtsniGD+dE+8/75j4Pi6zbymsRV0oGx/oIUVNcKd3kSb3oyGFkpQqHu26KM
RmJHNbGIFjEKF+qmvAaIQ5NWhA/NppB8ZvoZITAoOnz4uNw8CtpHm3vXEjfW
xwRpzKfgIPxJzoJ4WC8rwFSGQr+ma44TsbpE+1FfeQomCw7XxBFvDZv0iVKg
MNpf7JtO7Nml4H1+MfEnmwN3ibOLHTyeKVPYkpJh10C88MC/LtKrKCRdoYLn
GjHYWDvitHI1Bc8p3fYlxHvWS+7HGgqXtfNyVhMnzbK299KiwHkrbGxOXBDg
vYe9gYLk+uWydsR1rQm7knUoyHS4WDgTixZW2T7Wp+Aqca48gFht4Vebxk0U
3o7nT7GIt8QKWfeCQmyI1eUY4kNDSlbjxqReIyrtJHGUg5HlXDMKTSqe/GTi
KxXO5su3UCiZVLiSTvxkdeRmfQsKL/NK7l4hbj1/0dR2K4UQld2yucRjgmXG
7tsoyDqJf75FfGNCxvS6DYVjGxps84ntxwLNvtlS2Ph1wfT7xMI/6jevsiP1
qgj8ekD8cHi1ue9uCnGZt1aUELsP8izy91LQeq57qZR4fl+v5YgDBZ7YW5sy
4oouMyut/RQERU4a/3VA29Vtwc4U9OyTgv6OV/o0aV18gIJCrlBfMXH9+33b
x1wpKOcLXvo7H6exxFbfnUIh8s7cI9aok94Z6UEhQmtVVR7x55oAu/95UbjE
SjP4u56TlW93CfpQKJ6hwGQT6z9T32N6lEJj+Zy6y8T95Ql7Y/3I+ahZOiuN
+EJJj311AAXfY/ejzxBbFJk6igRTyOxrM4on/pV/ZZ9VCNmPokpwiHNvT+w/
FUYh/0kSFUy8+7qj81sWBelsNyFv4ulZxS5z2RQ6O/e+dCF2Tfd3TYmiYBBs
Kvf3fMxNrXP7EEPhmmhkji7x07Or3OVOUEjz8ghaRbw44atHRiLZz7vvW8SJ
38SYeLWdomBknB0wTs5nBJV5ROkMhSl/N+sB4pYQB9+ccxRmbHn0poo4IfDh
0d5UCjMvbA28T7zxmJTfiguknp9Z+zOJUw+/CbibQcHlp9GfIOKdu41DH+RS
uL2O7y1LLLjjctivGxSkZlzTmiT/Y8G2P+G6tylAWs+om3iO2YPIx/nkf+vM
Ucsjrl23IrqyhMy/3F5PlzhMIy5G+BGFxAC51fLEaiu7Yi0fU7D0+eL+H+kX
cUoZ8W+eUdhdI3yrhNhEcu7pploKVyZLKXXiR99/p31tpdAr/OzECOlnebu2
qwm2URC5vvVrDfGVRznFCh0UxFdEx1wljkvY+d7uK4X9Wmu6bIhtVe5IPf9O
4QjzeNk10j979rucvjxJwf03+9+VugyaKx4sKhPgol7/+ZIx0o9frxS/2zSN
C7eY5jdVxIW/S16JC3OxYsbU9gPEEefmibAkuCg/Gz+USPr53NeV0XsVuZhV
3fqwcgPZby0FqUBlLt538TV4xD8vBFw7vYyLxbI1ojbErR5LnlWqcbHUawf/
X5InuUJhk1pruRjgqnl+JHljoK8eJmnCRYfuK5MXaxl43Eo6WuPGRf/OliA1
kn/i67OdWty5+LYgd90ndQb3Hj/YNuDBxa6Nq5xPEU/Wf1w524cL6tLw5NAq
Bud+Le61DeJCxj7vSB7J16dmt10+xnDR2W8+U5Lk8YK2CtveHC7wNXilhzLp
F55N+H2dCznLm63CxG6jPRoit7h4dPOkwA2S93kzRGevyuMiNJPc0BQZmKnb
1hx9yEXKQst1TktIHoa1Gv+s4sJk9MiXNQoMXkr9WDejj4uK8q1qPtIMpjQ2
q5j2c7HwbHTeyHySL1tTZLmDXJSMCSQdJ86iNoyPD3PRFX7Iny3FgP09uJIZ
48Jd4Z/UOHKf0ar+ubdbLArf0jsyQ2czuBz+O6JiTRRynDe0dk9nENTxp4ob
EoU3z/6J7x2hwffYbH4hLAoynZVnbIm9+KerC1hRmLa+ZX7pMA3nP0ov2zhR
uJGpQXaUhrm0Rc2m+Ci4JyQ6K32nIW957tVYWhQMvrn46PXR+F+Ber1/GZlP
V8NejNw3RSmn5oMTUZAWnZat+ZLGQJTbo6jT0WBJdfrbJtF4uOfFQmGZGPyW
nPJOtKeh/eH7ka70GERrO9qckqMhWP4oQWBVLFQq9us11Y3ioX/3cm5hLPSt
Gzoqo0fxILEw2cQ0DsnqLuEHV4/iyE7zoX2NcXiR366y5t0IRPp1aj7uPYE7
jlWu9yJHMPr1dUBq3wn4v+4aHlcYQdW98vTiY/FI0+25FfV0GNvVgws1mXgk
HFaTtjw0DGXRxvP90QkQz/Z2oyeG0F6SMC4sysPY/ZBBNwxB3dDmvbM4Dyd1
rX/MMRhCaMW8ggdzeHgu+X24dOMQ5tZddHOT4sEvaM0ziXVDMOm6W/tEgYfy
9F+vy5YNIXt2Y1rwGh6CvVKr54gOwctVfkPXLh7ujY7y89/x8bD3yxy9vTy8
0+l74dDAxzTfrL4zDjwwAktShOr4SA9Rv2TozMOPa3oqe6v5eH3SUCjdgweL
qDjRyVI+NIpdG2zDeXAKEVWwyuQj3ED19vUIHvYtsyhgLvJR9WwgZpLNQ36f
nenlND5cXgdtvBPNw3yJdreRs3yc6YjLFD7FA/Xi7bnzMXy0HrYKc/6HB/eT
QkuMuXyoDUrYPThL6lF8d6M/ko9nP9NmuqXyMKEqXb4phI85EU7tpWk8COwX
3dIbyIejoHKZ5EUeDKvD68/48ZEb15PskcHDgycZ+/R8+RgVu+37JJOHJ6xb
vV1efPwfX/yfcw==
        "]]}},
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->{True, True},
     AxesLabel->{None, None},
     AxesOrigin->{0, 0},
     DisplayFunction->Identity,
     Frame->{{False, False}, {False, False}},
     FrameLabel->{{None, None}, {None, None}},
     FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
     GridLines->{None, None},
     GridLinesStyle->Directive[
       GrayLevel[0.5, 0.4]],
     Method->{
      "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
       AbsolutePointSize[6], "ScalingFunctions" -> None},
     PlotRange->{{0, 0.013}, {0., 1.2658026770083972`}},
     PlotRangeClipping->True,
     PlotRangePadding->{{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}},
     Ticks->{Automatic, Automatic}], ",", "\[IndentingNewLine]", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"fz", "[", 
        RowBox[{"KBSIMD", ",", "p"}], "]"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"p", ",", "0", ",", "0.013"}], "}"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", "Yellow", "}"}]}]}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.4789618100364523`*^9, 3.478961850760915*^9}, 
   3.478969868098156*^9, 3.4789702271107073`*^9, {3.478971402742322*^9, 
   3.478971407269801*^9}, {3.478973436528585*^9, 3.4789734559838*^9}, {
   3.4794970273251*^9, 3.4794970280748262`*^9}, {3.479497850691868*^9, 
   3.479497851721608*^9}, {3.4802445496159487`*^9, 3.4802445841180058`*^9}, {
   3.4802446656757193`*^9, 3.4802446687524443`*^9}, {3.481940803363203*^9, 
   3.481940804034131*^9}, {3.481941063760079*^9, 3.4819410664063997`*^9}, {
   3.481941556057631*^9, 3.4819415664906*^9}, {3.630208312322345*^9, 
   3.63020831448879*^9}, 3.630209982122305*^9, 3.630210040824745*^9, {
   3.630210608691247*^9, 3.6302106091463537`*^9}, 3.6302116072117853`*^9, 
   3.6302119179137897`*^9, 3.6304701238527927`*^9, 3.631834820615905*^9, 
   3.649109628464219*^9, {3.649110363868889*^9, 3.649110366770886*^9}, {
   3.649110567151823*^9, 3.649110570373554*^9}, {3.661123689182354*^9, 
   3.661123723132988*^9}, 3.661123839830414*^9, {3.661123888550177*^9, 
   3.6611238924215937`*^9}, {3.661123959516914*^9, 3.661123970823284*^9}, {
   3.661124020120494*^9, 3.661124020504492*^9}, {3.661124084594274*^9, 
   3.66112408490854*^9}, {3.661124132485323*^9, 3.661124133744603*^9}, {
   3.661127129389042*^9, 3.6611271300441732`*^9}, {3.6611285421516657`*^9, 
   3.6611285486416283`*^9}, 3.661139350752645*^9, {3.661141258332346*^9, 
   3.661141258345943*^9}, {3.661141309730465*^9, 3.6611413097415237`*^9}, {
   3.661142929646887*^9, 3.6611429309305487`*^9}, {3.661143000502679*^9, 
   3.6611430183305893`*^9}, 3.6611430889631033`*^9, {3.661202692295169*^9, 
   3.6612027456074247`*^9}, {3.6612032345320673`*^9, 
   3.6612032350121202`*^9}, {3.661203641247325*^9, 3.6612036470219383`*^9}, {
   3.661204651133306*^9, 3.6612046566907873`*^9}, {3.661205020492955*^9, 
   3.661205021421957*^9}, {3.662327449381301*^9, 3.662327449845611*^9}, {
   3.662327486588072*^9, 3.662327537553957*^9}, 3.662329110982596*^9, {
   3.662330878119421*^9, 3.6623308785345497`*^9}, {3.662354069937125*^9, 
   3.6623540788907948`*^9}, {3.662354134271152*^9, 3.662354134562495*^9}, {
   3.6623543100422163`*^9, 3.66235431077297*^9}, {3.6623544217834806`*^9, 
   3.66235444697696*^9}, {3.6623545334028597`*^9, 3.6623545384531507`*^9}, {
   3.6644259648635597`*^9, 3.664425965343483*^9}, {3.664426023889195*^9, 
   3.664426024820571*^9}, 3.66459542548556*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {RGBColor[1, 1, 0], AbsoluteThickness[1.6], Opacity[1.], 
     LineBox[CompressedData["
1:eJwV1nlYTdsbB/BKV4OQNP8SQkKlgRtR3zIkISfRSCVFs0al0zlnn1NSJ9yI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      "]]}}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 0.013}, {0., 1.265802677031688}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.664427158034647*^9, 3.6645047772775583`*^9, 
  3.6645941213003483`*^9, 3.665375151859668*^9, 3.682484115768304*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"plot", "[", "KBSIMD", "]"}], ",", 
   RowBox[{"plot1", "[", "KBSIMD", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.662331982056473*^9, 3.662331997565082*^9}, {
  3.6644259658935747`*^9, 3.6644259664708233`*^9}}],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
      LineBox[CompressedData["
1:eJwV1nk4VO0bB3CkLJWQtddOkiyJeFG+llKpNIkslaQkiQi9zJiZM2OfNhWS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       "]]}}, {}, {}}, {{{}, {}, 
     {RGBColor[1, 1, 0], AbsoluteThickness[1.6], Opacity[1.], 
      LineBox[CompressedData["
1:eJwV1nlYTdsbB/BKV4OQNP8SQkKlgRtR3zIkISfRSCVFs0al0zlnn1NSJ9yI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       "]]}}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 0.013}, {-0.009293847122732027, 1.2598186986093889`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.66442715811832*^9, 3.6645047773283052`*^9, 
  3.664594121372748*^9, 3.6653751519492188`*^9, 3.682484115885777*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"zmax", "[", "KBSIMD", "]"}], "  ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{
    RowBox[{"optdata", "[", "KBSIMD", "]"}], "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.478970786649661*^9, 3.478970802864567*^9}, {
   3.4796619220112333`*^9, 3.4796619454416037`*^9}, 3.479665671740583*^9, {
   3.48194080448247*^9, 3.481940804971867*^9}, {3.630208319233528*^9, 
   3.630208320862918*^9}, {3.630210609409204*^9, 3.6302106096880713`*^9}, {
   3.661141258353458*^9, 3.6611412583619328`*^9}, {3.661141309747707*^9, 
   3.661141309752261*^9}, 3.662329128518359*^9, {3.664425967055423*^9, 
   3.6644259676175013`*^9}}],

Cell[BoxData["0.007994036894390839`"], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGAwAOKQpjXdc16/dFyUG2Mx481Lxxmm1slvgHRVmlDOOyDd
V36j8z2Qvu0kNBlE/39ZeoTz3UvHKOkVp58A6ZCHs3P7P7x0XPNepcTt40vH
A2Uu1SD61gOZzSDaKSPnPIjWPVjJ5Q6kK1Q3brPmfu0odHpRojDPa8eKhqen
QPQV5gtPQfRj87fpIkBaaZrYJEsg/Sz3xhsPIL1feuvmWCDddTW8ZhKQPmWk
3KbJD9S3juMGiA54v/OiHpC+M9/64m+h147Xtt4U/wuk13i+miJv8Nrx0+KU
nXvcXjv6iGtM3wek77wIkXkJpP+lecxgd3/tWMT74iSInnFE8J4gkE6+6Ngv
DKTtIidnlwDpJ7vPBOp5vnb8/WKJSxiQ1nA2XQqiGTxXyIUDaad1O7kigPQ2
r+Vu0UDa490RoXBfoLl/tX/WAGmWrzozVwBpncL/X1X9ge7dVffpeP5rRwAR
uMcT
  "]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"magposactpromec", "-", 
   RowBox[{"zmax", "[", "KBSIMD", "]"}]}], "/.", 
  RowBox[{"vals", "[", "KBSIMD", "]"}]}]], "Input",
 CellChangeTimes->{{3.631850926207306*^9, 3.631850980824053*^9}, {
   3.631851019732378*^9, 3.631851023974328*^9}, 3.661139094984755*^9, 
   3.6611392025019712`*^9, {3.661141258367827*^9, 3.661141258374606*^9}, {
   3.661141309758286*^9, 3.661141309762734*^9}, {3.664425968161345*^9, 
   3.664425968705267*^9}}],

Cell[BoxData[
 RowBox[{"-", "0.0000940368943908379`"}]], "Output",
 CellChangeTimes->{{3.631850951545291*^9, 3.63185098135504*^9}, 
   3.631851024795751*^9, 3.633831562056611*^9, 3.6338341748264236`*^9, 
   3.649109159364168*^9, 3.6609653231946507`*^9, 3.6609691453050213`*^9, 
   3.661056226711844*^9, 3.6611186583295813`*^9, 3.66111905527409*^9, 
   3.6611396965979853`*^9, 3.6611431650138903`*^9, 3.6613415326304903`*^9, 
   3.66224654244606*^9, 3.6623283572045794`*^9, 3.662330101462863*^9, 
   3.662331989861638*^9, 3.6623386132889023`*^9, 3.664427158190177*^9, 
   3.6645047774111433`*^9, 3.66459412146596*^9, 3.6653751520391273`*^9, 
   3.6824841160315523`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fmax", "[", "KBSIMD", "]"}], "  ", "=", " ", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"optdata", "[", "KBSIMD", "]"}], " ", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4789708091780043`*^9, 3.4789708248973703`*^9}, 
   3.479661922078005*^9, 3.4796619593447857`*^9, 3.479665787682528*^9, {
   3.481940805601218*^9, 3.481940806091435*^9}, {3.630208322616778*^9, 
   3.6302083244414253`*^9}, {3.63021060995541*^9, 3.63021061023507*^9}, {
   3.661141258380653*^9, 3.661141258387753*^9}, {3.661141309768797*^9, 
   3.661141309773177*^9}, {3.66442596917734*^9, 3.664425969691185*^9}}],

Cell[BoxData["1.2598187348550516`"], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQB+KWPeu757x+6fjqVazFjDcvHYUybZLfAGlvBZGcd0Ca
KeVm53sgHccmNhlE2xwsO8L57qVjacnK00+AdOCkubn9H146Mm9SK3H7+NLx
yXfXahAtsEF2M4helpZ3HkS39VdzuQPp+Psbt1lzv3ZU+7UkUZjnteOEl99O
gejdWy88BdFOie/TRYD03WUSkyyB9I6mW288gHTHvG2bY4F06/nImklA+sN5
lTZN/teOZdO4boDoad27L+oB6cqJARd/C712rNC8Lf4XSE9yfjtF3uC146GL
6Tv3uAHtjdWevg9Ix4REyLwE0lOsAmawu792zG94eRJE394ick8QSD/wfdwv
DKQvnpmaXQKk25IvBOp5As2VW+ESBqQfnNogFw6k9XT3ckUA6SKj1W7RQFpq
9nGhcN/Xjotm6v2sAdIH5hnMXAGkHRuYv6n6v3a8pdT86Xj+a0cAnPXBRw==

  "]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"deriv2", "[", "KBSIMD", "]"}], " ", "=", "  ", 
  RowBox[{
   RowBox[{"-", "2"}], "*", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"fzi", "[", "KPR", "]"}], "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{"zmax", "[", "KPR", "]"}], ",", "2"}], "}"}]}], "]"}], 
      "]"}], ",", 
     RowBox[{"z", "^", "2"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479660163969679*^9, 3.479660203608347*^9}, {
   3.479660334457396*^9, 3.479660335305067*^9}, {3.4796611591764927`*^9, 
   3.479661208701754*^9}, {3.479661250977075*^9, 3.479661305176928*^9}, {
   3.479661346153286*^9, 3.479661372928776*^9}, {3.479661851029785*^9, 
   3.479661859051705*^9}, 3.4796619463263597`*^9, 3.479662725037703*^9, 
   3.479665672610339*^9, {3.481940806550991*^9, 3.48194080744361*^9}, {
   3.630208325888165*^9, 3.6302083289679956`*^9}, {3.630210610460196*^9, 
   3.630210610874337*^9}, 3.6611229758725023`*^9, {3.6611412583941383`*^9, 
   3.6611412584082737`*^9}, {3.661141309779232*^9, 3.661141309788487*^9}, {
   3.661143055996151*^9, 3.661143061547195*^9}, {3.661143129145129*^9, 
   3.661143150309849*^9}, 3.662253434311702*^9, 3.662262524114635*^9, 
   3.664425970211187*^9}],

Cell[BoxData["4723.921650343821`"], "Output",
 CellChangeTimes->{
  3.4796611607361183`*^9, 3.479661209333243*^9, {3.4796612702637243`*^9, 
   3.47966130570842*^9}, 3.479661373421825*^9, 3.479661471574224*^9, 
   3.479661860947604*^9, {3.479662726071348*^9, 3.47966274404876*^9}, 
   3.479663512851673*^9, 3.479665743087571*^9, 3.4796658169851303`*^9, 
   3.4802437481454697`*^9, 3.480692317637856*^9, 3.481566061244952*^9, 
   3.4819408972419558`*^9, 3.4819409542455378`*^9, 3.481941401101359*^9, 
   3.4819416276185503`*^9, 3.481942100030518*^9, 3.6297681177567453`*^9, 
   3.630209805425727*^9, 3.6302106479180737`*^9, 3.6302108627485523`*^9, 
   3.63021190367418*^9, 3.630288017033553*^9, 3.630319463059012*^9, 
   3.630362014021439*^9, 3.63047011514816*^9, 3.631828017512751*^9, 
   3.631828672853829*^9, 3.631838862188128*^9, 3.63383156257211*^9, 
   3.63383417516654*^9, 3.6491091597267933`*^9, 3.66096532357506*^9, 
   3.660969145695554*^9, 3.661056227053145*^9, 3.661118658556089*^9, 
   3.661119055617577*^9, 3.66112298417872*^9, 3.661139696737555*^9, {
   3.661143136068817*^9, 3.661143169405212*^9}, 3.661341532717312*^9, 
   3.662246542618259*^9, 3.662328357304565*^9, 3.66233010158547*^9, 
   3.662331989985965*^9, 3.662338613418449*^9, 3.6644271582742243`*^9, 
   3.664504777493836*^9, 3.664594121587071*^9, 3.665375152173341*^9, 
   3.682484116164433*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"z95plus", "[", "KBSIMD", "]"}], " ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{"FindRoot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"fz", "[", 
       RowBox[{"KBSIMD", ",", "z"}], "]"}], "-", 
      RowBox[{"0.95", "*", 
       RowBox[{"fmax", "[", "KBSIMD", "]"}]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", 
       RowBox[{
        RowBox[{"zmax", "[", "KBSIMD", "]"}], "+", "0.001"}], ",", 
       RowBox[{"zmax", "[", "KBSIMD", "]"}], ",", 
       RowBox[{
        RowBox[{"zmax", "[", "KBSIMD", "]"}], "+", "0.005"}]}], "}"}]}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479658613425561*^9, 3.4796587501410933`*^9}, {
   3.479658790462825*^9, 3.4796587993088913`*^9}, {3.479658852062684*^9, 
   3.479658891629363*^9}, {3.4796589431729183`*^9, 3.479658948798299*^9}, {
   3.479658987032153*^9, 3.47965898990287*^9}, {3.479659310386307*^9, 
   3.4796593125701933`*^9}, {3.479661624172262*^9, 3.479661679901505*^9}, {
   3.479661945541445*^9, 3.4796619594445953`*^9}, {3.4796656734658623`*^9, 
   3.479665674680963*^9}, 3.47966578778349*^9, {3.481940808072547*^9, 
   3.4819408112927933`*^9}, {3.630208331202548*^9, 3.630208340512887*^9}, {
   3.6302106111156588`*^9, 3.630210612620454*^9}, {3.631834272292122*^9, 
   3.631834275423791*^9}, {3.660964933550774*^9, 3.660964934686805*^9}, {
   3.662329034693089*^9, 3.662329042196556*^9}, 3.662334135563291*^9, {
   3.664425970779209*^9, 3.664425973583028*^9}}],

Cell[BoxData["0.010012000527601395`"], "Output",
 CellChangeTimes->{{3.479659290207419*^9, 3.4796593177022877`*^9}, {
   3.479661644377719*^9, 3.4796616514833097`*^9}, 3.479661686065053*^9, 
   3.4796634593803263`*^9, 3.479665745824663*^9, 3.4796658197389708`*^9, 
   3.480243751933235*^9, 3.480692320796873*^9, 3.4815660640155077`*^9, 
   3.4819408973674994`*^9, 3.481940954361327*^9, 3.481941402301373*^9, 
   3.481941628781619*^9, 3.481942101498692*^9, 3.629768118581479*^9, 
   3.630209825967379*^9, 3.63021064809335*^9, 3.630210863735273*^9, 
   3.6302119044786863`*^9, 3.630288029600463*^9, 3.630319474859651*^9, 
   3.630362016214836*^9, 3.63047011744707*^9, 3.631828018334545*^9, 
   3.631828673603425*^9, 3.631835209527664*^9, 3.631839554443227*^9, 
   3.6338315761916437`*^9, 3.633834181637607*^9, 3.649109166248088*^9, 
   3.6609655749502296`*^9, 3.660965945562953*^9, 3.660968309694571*^9, 
   3.6609692385501957`*^9, 3.6609693505923347`*^9, 3.661056651074237*^9, 
   3.6611192956141233`*^9, 3.661130614471345*^9, 3.661130729128159*^9, 
   3.661139986045722*^9, 3.661219854453026*^9, 3.661231205656358*^9, 
   3.6613414423732347`*^9, 3.662246451691223*^9, 3.662328257276907*^9, 
   3.662329076444454*^9, 3.662330103708742*^9, 3.662331992000602*^9, 
   3.6623372437215033`*^9, 3.662338615581056*^9, 3.664427160593852*^9, 
   3.6645047798193502`*^9, 3.664594123762166*^9, 3.6653751543997917`*^9, 
   3.682484118226993*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"z95minus", "[", "KBSIMD", "]"}], " ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{"FindRoot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"fz", "[", 
       RowBox[{"KBSIMD", ",", "z"}], "]"}], "-", 
      RowBox[{"0.95", "*", 
       RowBox[{"fmax", "[", "KBSIMD", "]"}]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", 
       RowBox[{
        RowBox[{"zmax", "[", "KBSIMD", "]"}], "-", "0.001"}], ",", 
       RowBox[{
        RowBox[{"zmax", "[", "KBSIMD", "]"}], "-", "0.005"}], ",", 
       RowBox[{"zmax", "[", "KBSIMD", "]"}]}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479658613425561*^9, 3.4796587501410933`*^9}, {
   3.479658790462825*^9, 3.4796587993088913`*^9}, {3.479658852062684*^9, 
   3.479658891629363*^9}, {3.4796589431729183`*^9, 3.479658948798299*^9}, {
   3.479658997678957*^9, 3.4796590027188377`*^9}, {3.479659318794853*^9, 
   3.479659344898431*^9}, {3.479661657421668*^9, 3.4796616780054293`*^9}, {
   3.479661945775414*^9, 3.479661959545474*^9}, {3.479665675209929*^9, 
   3.479665676278386*^9}, 3.4796657878831253`*^9, {3.481940812147341*^9, 
   3.481940829419257*^9}, {3.6302083429611607`*^9, 3.6302083515364437`*^9}, {
   3.630210612999134*^9, 3.630210615553306*^9}, {3.6318342761199827`*^9, 
   3.631834277785796*^9}, {3.660964934904317*^9, 3.660964935954105*^9}, {
   3.660968688340294*^9, 3.660968693115794*^9}, {3.661220236123904*^9, 
   3.6612202369311447`*^9}, {3.6623290444123*^9, 3.662329072977393*^9}, 
   3.6623341355722446`*^9, {3.662337264381858*^9, 3.66233728414599*^9}, {
   3.664425974264805*^9, 3.664425976906748*^9}}],

Cell[BoxData["0.006162673053098947`"], "Output",
 CellChangeTimes->{3.662337287443143*^9, 3.662338618554626*^9, 
  3.66442716364495*^9, 3.664504782842551*^9, 3.6645941265566683`*^9, 
  3.66537515719246*^9, 3.682484120853293*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"plot", "[", "KBSIMD", "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"plot1", "[", "KBSIMD", "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Graphics", "[", 
    RowBox[{"Line", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"zmax", "[", "KBSIMD", "]"}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"zmax", "[", "KBSIMD", "]"}], ",", 
         RowBox[{"1.1", "*", 
          RowBox[{"fmax", "[", "KBSIMD", "]"}]}]}], "}"}]}], "}"}], "]"}], 
    "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{"Gray", ",", 
      RowBox[{"Line", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"z95minus", "[", "KBSIMD", "]"}], ",", "0"}], "}"}], ",", 
          
          RowBox[{"{", 
           RowBox[{
            RowBox[{"z95minus", "[", "KBSIMD", "]"}], ",", 
            RowBox[{"1.1", "*", 
             RowBox[{"fmax", "[", "KBSIMD", "]"}]}]}], "}"}]}], "}"}], "/.", 
        RowBox[{"vals", "[", "KBS", "]"}]}], "]"}]}], "}"}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{"Gray", ",", 
      RowBox[{"Line", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"z95plus", "[", "KBSIMD", "]"}], ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"z95plus", "[", "KBSIMD", "]"}], ",", 
            RowBox[{"1.1", "*", 
             RowBox[{"fmax", "[", "KBSIMD", "]"}]}]}], "}"}]}], "}"}], "/.", 
        RowBox[{"vals", "[", "KBS", "]"}]}], "]"}]}], "}"}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<z (m)\>\"", ",", "\"\<F (N/A)\>\""}], "}"}]}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.453823397414776*^9, 3.453823397824687*^9}, {
   3.453838538440839*^9, 3.453838572806719*^9}, 3.463844247723119*^9, 
   3.478894943196905*^9, 3.4788950132010527`*^9, {3.478961709433363*^9, 
   3.47896175216029*^9}, {3.478961842569364*^9, 3.478961894377494*^9}, {
   3.4789619830038633`*^9, 3.478961984506156*^9}, {3.4789699280628653`*^9, 
   3.478969982243393*^9}, {3.478970021389124*^9, 3.478970165180615*^9}, {
   3.478970224319232*^9, 3.478970261501657*^9}, {3.4789703108875017`*^9, 
   3.478970348344078*^9}, 3.478970398020482*^9, {3.478970871122594*^9, 
   3.47897087265033*^9}, {3.478971414854863*^9, 3.4789714317583723`*^9}, {
   3.4789723334965277`*^9, 3.4789723911200447`*^9}, {3.478973525233735*^9, 
   3.47897352833882*^9}, {3.479495227181163*^9, 3.4794952662789087`*^9}, {
   3.4794954131043873`*^9, 3.4794954161349077`*^9}, {3.479497883443406*^9, 
   3.479497887306903*^9}, {3.4794980354692507`*^9, 3.479498036795588*^9}, 
   3.4794982488155937`*^9, {3.479662131489229*^9, 3.479662133377276*^9}, 
   3.479665540471899*^9, {3.4802459792714577`*^9, 3.480245981573744*^9}, {
   3.4802525542284737`*^9, 3.4802525884311867`*^9}, {3.48194087775911*^9, 
   3.481940886937986*^9}, 3.630208353429995*^9, 3.6302106162586517`*^9, 
   3.631834278469103*^9, {3.631835050283194*^9, 3.631835119871463*^9}, {
   3.631838204428006*^9, 3.631838423237857*^9}, {3.6318384686026077`*^9, 
   3.631838479273821*^9}, {3.6318392214551907`*^9, 3.631839229661147*^9}, {
   3.661139094999187*^9, 3.6611390950093946`*^9}, {3.661139202513871*^9, 
   3.661139202520485*^9}, {3.6611412584795847`*^9, 3.6611412584963713`*^9}, {
   3.6611413098586197`*^9, 3.661141309872466*^9}, {3.661143315366548*^9, 
   3.6611433270441647`*^9}, {3.662332301064869*^9, 3.662332380309093*^9}, {
   3.6623341355802917`*^9, 3.662334135592721*^9}, {3.662354326401864*^9, 
   3.662354329985043*^9}, {3.664425977645124*^9, 3.664425983190798*^9}, {
   3.6825835063391027`*^9, 3.682583515457065*^9}}],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
      LineBox[CompressedData["
1:eJwV1nk4VO0bB3CkLJWQtddOkiyJeFG+llKpNIkslaQkiQi9zJiZM2OfNhWS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       "]]}}, {}, {}}, {{{}, {}, 
     {RGBColor[1, 1, 0], AbsoluteThickness[1.6], Opacity[1.], 
      LineBox[CompressedData["
1:eJwV1nlYTdsbB/BKV4OQNP8SQkKlgRtR3zIkISfRSCVFs0al0zlnn1NSJ9yI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       "]]}}, {}, {}}, 
   LineBox[{{0.007994036894390839, 0}, {0.007994036894390839, 
     1.385800608340557}}], 
   {GrayLevel[0.5], 
    LineBox[{{0.006162673053098947, 0}, {0.006162673053098947, 
      1.385800608340557}}]}, 
   {GrayLevel[0.5], 
    LineBox[{{0.010012000527601395`, 0}, {0.010012000527601395`, 
      1.385800608340557}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"z (m)\"", TraditionalForm], 
    FormBox["\"F (N/A)\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 0.013}, {-0.009293847122732027, 1.2598186986093889`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.661143339013616*^9, 3.6613415331386127`*^9, 3.662246543123845*^9, 
   3.662328357735825*^9, 3.6623301043833427`*^9, 3.662331992642704*^9, 
   3.662332313093595*^9, {3.662332357700629*^9, 3.662332372084869*^9}, {
   3.662337270050414*^9, 3.6623372917742653`*^9}, 3.6623386186212387`*^9, 
   3.662354353022257*^9, 3.662354642187873*^9, 3.664427163774837*^9, 
   3.664504782944879*^9, 3.6645941266721478`*^9, 3.665375157293741*^9, 
   3.68248412094681*^9, {3.6825835072591887`*^9, 3.6825835166288157`*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Coil calc for KAGRA PR/SR IM (double magnets, discs)", "Section",
 CellChangeTimes->{{3.453751016056313*^9, 3.453751037487228*^9}, 
   3.463844192181329*^9, {3.478894850822432*^9, 3.478894851717502*^9}, {
   3.4788951705281897`*^9, 3.4788951754720497`*^9}, {3.4819407269664*^9, 
   3.481940736973164*^9}, {3.6302077654764643`*^9, 3.6302077702623034`*^9}, {
   3.630210588958201*^9, 3.630210589517418*^9}, {3.661141232361245*^9, 
   3.661141232942458*^9}, {3.661141276086359*^9, 3.661141285892767*^9}, {
   3.664425907321329*^9, 3.664425910542931*^9}, {3.682482462513555*^9, 
   3.682482493431525*^9}, 3.682561418022368*^9}],

Cell[CellGroupData[{

Cell["\<\
bosemvalsKXRIMD = Recurse[
\t{
\t\tkB->1.38 10^-23,
\t\tT->295,
\t\tg->9.8,
\t\tmu0->4 N[Pi] 10^-7,
\t\trhoeAl->2.65 10^-8,\t\t\t(* Resistivity of Al *)
\t\trhoepianowire->30 rhoeAl,\t(* Resistivity of P.W., GUESSTIMATE *)
\t\tsigmaeAu->2.67,\t\t\t\t(* Resistivity of Au paint, measured *)
\t\tmassSOS->0.25,\t\t\t\t(* Final design value *)
\t\tmassM->rhomM l N[Pi] a^2,
\t\tPi->N[Pi],
\t\trhomM->7400,\t\t\t\t(* Mass density of magnets *)
\t\tztube->0.0155,\t\t\t\t(* Separation for magnet to push its own weight, \
measured *)
\t\tzpickup->0.018-l,\t\t\t(* Separation for magnet to pull its own weight, \
measured *)
\t\tmasspullapart->0.060,\t\t(* Force (in kgf) to separate magnets *)
\t\t(* preferred value of small magnet dipole moment *)
\t\tmzpref->0.007945632135874319,
\t\t(* magnet moment per unit volume for magnet stuff, assumed the same for \
big and small *)
\t\tmz->mzpref/(lold*N[Pi]*aold^2),
\t\tlold->0.003175,\t\t\t\t(* length of LIGO small magnets *)
\t\taold->0.0009525,\t\t\t(* radius of LIGO small magnets *)
\t\tlmagnetonly->0.010,\t\t\t\t(* length of big magnets *)
\t\tl->0.010+2*0.001,\t\t\t\t(* length of magnets plus discs *)
\t\ta->0.005,\t\t\t\t(* radius of big magnets *)
\t\tdipole -> mz*lmagnetonly*N[Pi]*a^2,
\t\tlayers -> 27, (* 10212-Gr.12-body BOSEM intermediate.pdf *)
\t\tturns -> 600, (* 10212-Gr.12-body BOSEM intermediate.pdf *)
\t\twirediam ->0.36*0.001, (* 10212-Gr.12-body BOSEM intermediate.pdf *)
\t\t(* coil length *)
\t\tcoillen->(11-3)*0.001,  (* 10212-Gr.12-body BOSEM intermediate.pdf *)
\t\t(* the ends of the coil relative to the centre of the coil *)
\t\tcoilz1->-coillen/2,
\t\tcoilz2->+coillen/2,
\t\t(* the inner and outer radii of the coil *)
\t\tcoilrad1->(18/2)*0.001, (* 10212-Gr.12-body BOSEM intermediate.pdf *)
\t\tcoilrad2->coilrad1+wirediam*layers, (* 10212-Gr.12-body BOSEM \
intermediate.pdf *)
\t\tcoildrad2max->(49/2)*0.001, (* 10212-Gr.12-body BOSEM intermediate.pdf *)
\t\t(* the number of turns *)
\t\tcoilturns->600, (* 10203-Gr.12-Osem intermediate mass.pdf *)
\t\tcoilsigma -> coilturns/((coilrad2 - coilrad1)*(coilz2 - coilz1)),
\t\tmagposactpromec->0.0079, (* Inventor, Promec, Fabian *)
\t\tmagposactv2->zmax[KPR], 
\t\tpairoffset->0.046
\t}
]
vals[KXRIMD] := bosemvalsKXRIMD;\
\>", "Input",
 CellChangeTimes->{{3.453837228357688*^9, 3.453837230833909*^9}, {
   3.463844183252262*^9, 3.463844223147016*^9}, {3.478894862544446*^9, 
   3.4788948852377567`*^9}, {3.478894985619047*^9, 3.4788949913587503`*^9}, {
   3.4788950240972023`*^9, 3.478895025494358*^9}, {3.481940748223406*^9, 
   3.481940763510077*^9}, {3.6302077790327063`*^9, 3.630207779944365*^9}, {
   3.630208292557073*^9, 3.630208293170534*^9}, {3.6302085800514812`*^9, 
   3.630208649083247*^9}, {3.630209645346671*^9, 3.630209663817658*^9}, {
   3.630209701977907*^9, 3.6302097023837023`*^9}, 3.630209734594172*^9, 
   3.630210623319276*^9, {3.6302114423356447`*^9, 3.6302115422890863`*^9}, {
   3.630211579624671*^9, 3.630211581024807*^9}, {3.630211687932591*^9, 
   3.630211722300425*^9}, {3.6302984714100847`*^9, 3.630298473322809*^9}, {
   3.630361294367758*^9, 3.6303612947567253`*^9}, {3.6303613801867123`*^9, 
   3.6303613881298*^9}, {3.631834762263462*^9, 3.631834791379961*^9}, 
   3.661055741435896*^9, 3.6610557813045607`*^9, 3.6610560671992607`*^9, 
   3.661118651388139*^9, 3.661139094945122*^9, 3.661139202476098*^9, {
   3.661141235734417*^9, 3.661141258292121*^9}, {3.661141309672125*^9, 
   3.661141309700727*^9}, {3.661141356555216*^9, 3.661141380002549*^9}, {
   3.661141638842251*^9, 3.661141681335253*^9}, {3.6611432431036263`*^9, 
   3.661143250501958*^9}, {3.661143295718404*^9, 3.661143300484091*^9}, 
   3.66122654686482*^9, {3.661226643717907*^9, 3.661226646163519*^9}, {
   3.664425954869774*^9, 3.664425956573142*^9}, {3.664426626286175*^9, 
   3.66442670322782*^9}, {3.66450422749352*^9, 3.66450423317286*^9}, 
   3.68248240052384*^9, {3.682482515689863*^9, 3.6824825456846323`*^9}, {
   3.682583754761623*^9, 3.682583755320155*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"kB", "\[Rule]", "1.38`*^-23"}], ",", 
   RowBox[{"T", "\[Rule]", "295"}], ",", 
   RowBox[{"g", "\[Rule]", "9.8`"}], ",", 
   RowBox[{"mu0", "\[Rule]", "1.2566370614359173`*^-6"}], ",", 
   RowBox[{"rhoeAl", "\[Rule]", "2.65`*^-8"}], ",", 
   RowBox[{"rhoepianowire", "\[Rule]", "7.95`*^-7"}], ",", 
   RowBox[{"sigmaeAu", "\[Rule]", "2.67`"}], ",", 
   RowBox[{"massSOS", "\[Rule]", "0.25`"}], ",", 
   RowBox[{"massM", "\[Rule]", "0.006974335690969341`"}], ",", 
   RowBox[{"\[Pi]", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"rhomM", "\[Rule]", "7400"}], ",", 
   RowBox[{"ztube", "\[Rule]", "0.0155`"}], ",", 
   RowBox[{"zpickup", "\[Rule]", "0.005999999999999998`"}], ",", 
   RowBox[{"masspullapart", "\[Rule]", "0.06`"}], ",", 
   RowBox[{"mzpref", "\[Rule]", "0.00794563213587432`"}], ",", 
   RowBox[{"mz", "\[Rule]", "878020.9598010788`"}], ",", 
   RowBox[{"lold", "\[Rule]", "0.003175`"}], ",", 
   RowBox[{"aold", "\[Rule]", "0.0009525`"}], ",", 
   RowBox[{"lmagnetonly", "\[Rule]", "0.01`"}], ",", 
   RowBox[{"l", "\[Rule]", "0.012`"}], ",", 
   RowBox[{"a", "\[Rule]", "0.005`"}], ",", 
   RowBox[{"dipole", "\[Rule]", "0.6895960492522322`"}], ",", 
   RowBox[{"layers", "\[Rule]", "27"}], ",", 
   RowBox[{"turns", "\[Rule]", "600"}], ",", 
   RowBox[{"wirediam", "\[Rule]", "0.00035999999999999997`"}], ",", 
   RowBox[{"coillen", "\[Rule]", "0.008`"}], ",", 
   RowBox[{"coilz1", "\[Rule]", 
    RowBox[{"-", "0.004`"}]}], ",", 
   RowBox[{"coilz2", "\[Rule]", "0.004`"}], ",", 
   RowBox[{"coilrad1", "\[Rule]", "0.009000000000000001`"}], ",", 
   RowBox[{"coilrad2", "\[Rule]", "0.01872`"}], ",", 
   RowBox[{"coildrad2max", "\[Rule]", "0.0245`"}], ",", 
   RowBox[{"coilturns", "\[Rule]", "600"}], ",", 
   RowBox[{"coilsigma", "\[Rule]", "7.716049382716049`*^6"}], ",", 
   RowBox[{"magposactpromec", "\[Rule]", "0.0079`"}], ",", 
   RowBox[{"magposactv2", "\[Rule]", "0.006718812869426184`"}], ",", 
   RowBox[{"pairoffset", "\[Rule]", "0.046`"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.661139342263995*^9, {3.661141667258052*^9, 3.661141684384678*^9}, 
   3.661143334994034*^9, 3.661218923863595*^9, 3.661226547848268*^9, 
   3.661341442616219*^9, 3.66224645200333*^9, 3.662328257588792*^9, 
   3.6623315030483637`*^9, 3.662338118106715*^9, 3.664426744188464*^9, 
   3.6645042435163717`*^9, 3.6645936072886753`*^9, 3.6653746192000523`*^9, 
   3.682484121010944*^9, 3.682583830847578*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"optdata", "[", "KXRIMD", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "1.2598187348550502`"}], ",", 
      RowBox[{"{", 
       RowBox[{"z", "\[Rule]", "0.007994036795544876`"}], "}"}]}], "}"}], ",",
     "\[IndentingNewLine]", 
    RowBox[{"Minimize", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          RowBox[{"fz", "[", 
           RowBox[{"KXRIMD", ",", "z"}], "]"}]}], "+", 
         RowBox[{"fz", "[", 
          RowBox[{"KXRIMD", ",", 
           RowBox[{
            RowBox[{"z", "+", "pairoffset"}], "/.", 
            RowBox[{"vals", "[", "KXRIMD", "]"}]}]}], "]"}]}], ",", " ", 
        RowBox[{"0.006", " ", "<", " ", "z", " ", "<", " ", "0.012"}]}], 
       "}"}], ",", " ", "z"}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.478970745257534*^9, 3.478970764425056*^9}, 
   3.4796619224973173`*^9, {3.480244382554545*^9, 3.480244405961742*^9}, {
   3.4819408015577917`*^9, 3.4819408027090397`*^9}, {3.481940979763582*^9, 
   3.481940981746011*^9}, {3.481941548420309*^9, 3.481941559738948*^9}, {
   3.630208310775996*^9, 3.6302083160559387`*^9}, 3.6302102241338043`*^9, {
   3.630210607856474*^9, 3.6302106082793016`*^9}, 3.630361338897683*^9, 
   3.660965340441757*^9, {3.6611412583009977`*^9, 3.6611412583096*^9}, {
   3.6611413097075777`*^9, 3.661141309712214*^9}, {3.6611413410526447`*^9, 
   3.661141347091383*^9}, {3.6611416926384974`*^9, 3.66114170977668*^9}, 
   3.661219512896727*^9, 3.662329456445507*^9, {3.662329520779831*^9, 
   3.662329542539156*^9}, {3.664425958246834*^9, 3.664425960009359*^9}, 
   3.6645953911025553`*^9, 3.665363625248659*^9, {3.682482546741352*^9, 
   3.682482548505953*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "1.2469914875060015`"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", "\[Rule]", "0.008019336317460981`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.6623299493259478`*^9, 3.6623318864112988`*^9, 
  3.662338510736121*^9, 3.664427056962029*^9, 3.664504679164015*^9, 
  3.664594027470549*^9, 3.665375056023589*^9, 3.682484464392555*^9, 
  3.682584385883998*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"optdata", "[", "KBSIM", "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"for", " ", "comparison"}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.6611417897464647`*^9, 3.6611417951142797`*^9}, {
   3.6612035835908327`*^9, 3.6612036047716*^9}, 3.662329142361154*^9, {
   3.662330001250415*^9, 3.662330001672842*^9}, {3.6623300489374743`*^9, 
   3.662330049507196*^9}, {3.682583381034285*^9, 3.6825833828498087`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "1.1119663292416933`"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", "\[Rule]", "0.007442586205061097`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.662330002511826*^9, 3.662330050048687*^9, 
  3.66233188678736*^9, 3.6623385110669613`*^9, 3.664427057162121*^9, 
  3.664504679224824*^9, 3.664594027715934*^9, 3.6653750561714697`*^9, 
  3.6824844645871983`*^9, 3.682583384188196*^9, 3.682584386130033*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fzi", "[", "KXRIMD", "]"}], " ", "=", " ", 
  RowBox[{"FunctionInterpolation", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"fz", "[", 
      RowBox[{"KXRIMD", ",", "z"}], "]"}], "-", 
     RowBox[{"fz", "[", 
      RowBox[{"KXRIMD", ",", 
       RowBox[{
        RowBox[{"z", "+", "pairoffset"}], "/.", 
        RowBox[{"vals", "[", "KXRIMD", "]"}]}]}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "0", ",", "0.013"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.661121231903079*^9, 3.661121302673418*^9}, {
   3.66112135471321*^9, 3.661121364047564*^9}, 3.661121573023286*^9, {
   3.661121981470016*^9, 3.661121984145525*^9}, {3.661122016670216*^9, 
   3.6611220263968563`*^9}, {3.661122422824706*^9, 3.661122440665392*^9}, {
   3.6611225257271423`*^9, 3.6611225561384287`*^9}, 3.661122943936385*^9, 
   3.661124072219921*^9, 3.661124107400278*^9, {3.66114125831656*^9, 
   3.6611412583250227`*^9}, {3.6611413097183743`*^9, 3.661141309722828*^9}, {
   3.661142955018881*^9, 3.661142976745582*^9}, 3.6612189023455*^9, {
   3.6612189588266687`*^9, 3.6612189659137297`*^9}, 3.661219472807549*^9, {
   3.661219548644806*^9, 3.661219555082078*^9}, {3.662262695279645*^9, 
   3.662262697461714*^9}, {3.6644259606161537`*^9, 3.6644259621772823`*^9}, {
   3.682482549122178*^9, 3.6824825509020157`*^9}}],

Cell[BoxData[
 TagBox[
  TemplateBox[{RowBox[{
      StyleBox[
       TagBox["InterpolatingFunction", "SummaryHead"], 
       "NonInterpretableSummary"], 
      StyleBox["[", "NonInterpretableSummary"], 
      DynamicModuleBox[{Typeset`open$$ = False}, 
       PanelBox[
        PaneSelectorBox[{False -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquarePlusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = True), Appearance -> None,
                 Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{{{}, {}, {
                   Directive[
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1]], 
                   LineBox[CompressedData["
1:eJwVxXlU0wUAB/DJ4Xg4fUCDhFBUDiHcA0LGNfpmgICAZobhQzm3KIbj0DUw
kGsMxhIpkQeKFfHkoYE145A7jBsCBjWPSfKGPpFxbL8fSOKm1R+f99kdn/Ix
R49CobD+8/+r1W022cHLfk/euDWMB9T0zNwI7VwdcEbfnJGhfLoCTbWJeoYE
C5uXLt4XejbDRPAyqCw3EPYLWqlqshdhKpavjB2G6uRvHpjLh5DpGMkJXzmK
KxaINnWbhIcPO/F4cgTinafGeQ3TqAsobrXdfwLkscxIBucerjBV1w4tnIRI
8HJwWfsQnf4fPT7kGos/NJt2UoP+hmi+pWLKJB55MQoHnnIW/Z0HucmyBET9
M+z0S6YS/QYvjN3FHJTS8z4fej2HXSFSWdRnicidfSK/U/kUK52Xmytsv0C6
mUXYK+NnsGSIfnPfzMWPY7wJp9J5GJhWVOgeJ6Oo+3Cs86vnYNtNiB9U8eBU
4N+fcUAFEyvjKQkrFZJhjXPcpUXUe/cuuVunQRsd1+HXswTep6+tL2xLR1rO
2kIbsQy6y6g0S5sOxtr1E/5UNfjf7YvgPzyDqTPdLpwCNfRpdJrN6Fkorkd7
yykahJmWyWQ/8RE8TvXyP60Bf/Kq1qr4S9S/21YXMaHB2AWGr7lAgDVtGlPg
SmBGeax4+/EM2B1Z60rIJ/AOk/J8LCgTv+4YvtMoI+Djz/r5bY9z2Cq0jNGY
k3hrnibkmn0FaTZ/dGc4CStJQnKqXhbcR93uD+WQUPQfTjivzELUm9QXl+pI
ZLcP9+zpzkYv0R7d10cirHHEJaPhPMwSzv618IiE3DP2lrwkBwKrkLhSFYmD
s367SL9c1IwM/bmVJJGjvpyacysX34ZYfZ1CkKifaSbl1nnwrnLhriyQmB+u
pBSV5+Gu9oO78QoShnoD5b4G+ehKrPfzGiDh5d1yOzg7HxKWQSGnnsTJcJ7+
7tV8GO7dsCgRkjjVmKrQxRdgqsOBWX6KBJ/G9HNXFMCD2+vRwSCR1BrocDpU
CIGKqnLREjiCHR+mtwnxe2StY9IggdCB1mcTroVg3qQRM2ICdlXV9Pd+KAR1
S5ViJIwAnRswurhdhAP2wb1GVAKrlk1N6RdFaJu+cZTdo4GUzrPX6USIXtRt
WJ7ToHCbymaWXwTl4Lqydp8GzE9u1ww+LUKPHi0jT6nG60pWIzWmGIGZ3Efi
MjVa2ktVZvJisC28fLreVyPU0Vm6J1AMG/2bDVvmVrBeXkKRdIkRZbmX7emz
gtzw/ffWGSWQGF2z7b66DE05M6X7+xJEWW9K0m0s4V9XINeJ
                    
                    "]]}}}, {}, {}}, {
               DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
                AxesOrigin -> {0, 0}, 
                FrameTicks -> {{None, None}, {None, None}}, 
                GridLines -> {None, None}, DisplayFunction -> Identity, 
                PlotRangePadding -> {{
                   Scaled[0.1], 
                   Scaled[0.1]}, {
                   Scaled[0.1], 
                   Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
                All, DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                Directive[
                  Opacity[0.5], 
                  Thickness[Tiny], 
                  RGBColor[0.368417, 0.506779, 0.709798]], 
                FrameTicks -> {{None, None}, {None, None}}, 
                GridLines -> {None, None}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 
                Dynamic[{
                  Automatic, 3.5 CurrentValue["FontCapHeight"]/
                   AbsoluteCurrentValue[Magnification]}], 
                Method -> {
                 "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
                  AbsolutePointSize[6], "ScalingFunctions" -> None, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (
                    Part[{{Identity, Identity}, {Identity, Identity}}, 1, 
                    2][#]& )[
                    Part[#, 1]], 
                    (
                    Part[{{Identity, Identity}, {Identity, Identity}}, 2, 
                    2][#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 
                    2][#]& )[
                    Part[#, 1]], 
                    (
                    Part[{{Identity, Identity}, {Identity, Identity}}, 2, 
                    2][#]& )[
                    Part[#, 2]]}& )}}, 
                PlotRange -> {{0., 0.013}, {-0.03372808315270939, 
                 1.2468393623245577`}}, PlotRangeClipping -> True, 
                PlotRangePadding -> {{
                   Scaled[0.1], 
                   Scaled[0.1]}, {
                   Scaled[0.1], 
                   Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"scalar\"", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}], True -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquareMinusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                None, Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{{{}, {}, {
                   Directive[
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1]], 
                   LineBox[CompressedData["
1:eJwVxXlU0wUAB/DJ4Xg4fUCDhFBUDiHcA0LGNfpmgICAZobhQzm3KIbj0DUw
kGsMxhIpkQeKFfHkoYE145A7jBsCBjWPSfKGPpFxbL8fSOKm1R+f99kdn/Ix
R49CobD+8/+r1W022cHLfk/euDWMB9T0zNwI7VwdcEbfnJGhfLoCTbWJeoYE
C5uXLt4XejbDRPAyqCw3EPYLWqlqshdhKpavjB2G6uRvHpjLh5DpGMkJXzmK
KxaINnWbhIcPO/F4cgTinafGeQ3TqAsobrXdfwLkscxIBucerjBV1w4tnIRI
8HJwWfsQnf4fPT7kGos/NJt2UoP+hmi+pWLKJB55MQoHnnIW/Z0HucmyBET9
M+z0S6YS/QYvjN3FHJTS8z4fej2HXSFSWdRnicidfSK/U/kUK52Xmytsv0C6
mUXYK+NnsGSIfnPfzMWPY7wJp9J5GJhWVOgeJ6Oo+3Cs86vnYNtNiB9U8eBU
4N+fcUAFEyvjKQkrFZJhjXPcpUXUe/cuuVunQRsd1+HXswTep6+tL2xLR1rO
2kIbsQy6y6g0S5sOxtr1E/5UNfjf7YvgPzyDqTPdLpwCNfRpdJrN6Fkorkd7
yykahJmWyWQ/8RE8TvXyP60Bf/Kq1qr4S9S/21YXMaHB2AWGr7lAgDVtGlPg
SmBGeax4+/EM2B1Z60rIJ/AOk/J8LCgTv+4YvtMoI+Djz/r5bY9z2Cq0jNGY
k3hrnibkmn0FaTZ/dGc4CStJQnKqXhbcR93uD+WQUPQfTjivzELUm9QXl+pI
ZLcP9+zpzkYv0R7d10cirHHEJaPhPMwSzv618IiE3DP2lrwkBwKrkLhSFYmD
s367SL9c1IwM/bmVJJGjvpyacysX34ZYfZ1CkKifaSbl1nnwrnLhriyQmB+u
pBSV5+Gu9oO78QoShnoD5b4G+ehKrPfzGiDh5d1yOzg7HxKWQSGnnsTJcJ7+
7tV8GO7dsCgRkjjVmKrQxRdgqsOBWX6KBJ/G9HNXFMCD2+vRwSCR1BrocDpU
CIGKqnLREjiCHR+mtwnxe2StY9IggdCB1mcTroVg3qQRM2ICdlXV9Pd+KAR1
S5ViJIwAnRswurhdhAP2wb1GVAKrlk1N6RdFaJu+cZTdo4GUzrPX6USIXtRt
WJ7ToHCbymaWXwTl4Lqydp8GzE9u1ww+LUKPHi0jT6nG60pWIzWmGIGZ3Efi
MjVa2ktVZvJisC28fLreVyPU0Vm6J1AMG/2bDVvmVrBeXkKRdIkRZbmX7emz
gtzw/ffWGSWQGF2z7b66DE05M6X7+xJEWW9K0m0s4V9XINeJ
                    
                    "]]}}}, {}, {}}, {
               DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
                AxesOrigin -> {0, 0}, 
                FrameTicks -> {{None, None}, {None, None}}, 
                GridLines -> {None, None}, DisplayFunction -> Identity, 
                PlotRangePadding -> {{
                   Scaled[0.1], 
                   Scaled[0.1]}, {
                   Scaled[0.1], 
                   Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
                All, DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                Directive[
                  Opacity[0.5], 
                  Thickness[Tiny], 
                  RGBColor[0.368417, 0.506779, 0.709798]], 
                FrameTicks -> {{None, None}, {None, None}}, 
                GridLines -> {None, None}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 
                Dynamic[{
                  Automatic, 3.5 CurrentValue["FontCapHeight"]/
                   AbsoluteCurrentValue[Magnification]}], 
                Method -> {
                 "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
                  AbsolutePointSize[6], "ScalingFunctions" -> None, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (
                    Part[{{Identity, Identity}, {Identity, Identity}}, 1, 
                    2][#]& )[
                    Part[#, 1]], 
                    (
                    Part[{{Identity, Identity}, {Identity, Identity}}, 2, 
                    2][#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (
                    Part[{{Identity, Identity}, {Identity, Identity}}, 1, 
                    2][#]& )[
                    Part[#, 1]], 
                    (
                    Part[{{Identity, Identity}, {Identity, Identity}}, 2, 
                    2][#]& )[
                    Part[#, 2]]}& )}}, 
                PlotRange -> {{0., 0.013}, {-0.03372808315270939, 
                 1.2468393623245577`}}, PlotRangeClipping -> True, 
                PlotRangePadding -> {{
                   Scaled[0.1], 
                   Scaled[0.1]}, {
                   Scaled[0.1], 
                   Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"scalar\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["3", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"Hermite\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["False", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}]}, 
         Dynamic[Typeset`open$$], ImageSize -> Automatic], BaselinePosition -> 
        Baseline], DynamicModuleValues :> {}], 
      StyleBox["]", "NonInterpretableSummary"]}]},
   "CopyTag",
   DisplayFunction->(#& ),
   InterpretationFunction->("InterpolatingFunction[{{0., 0.013}}, <>]"& )],
  False,
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.664427070348568*^9, 3.664504692297626*^9, 
  3.664594040012186*^9, 3.665375068816485*^9, 3.682484476161442*^9, 
  3.6825843977281923`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"plot", "[", "KXRIMD", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    GraphicsBox[{{}, {}, 
      {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
       LineBox[CompressedData["
1:eJwV1nk8VN0fB3BSj0jZSZZQJIQS0jKfsiTJkkSpKLKGEIUZM3fGlqk8lUJU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        "]]}},
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->{True, True},
     AxesLabel->{None, None},
     AxesOrigin->{0, 0},
     DisplayFunction->Identity,
     Frame->{{False, False}, {False, False}},
     FrameLabel->{{None, None}, {None, None}},
     FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
     GridLines->{None, None},
     GridLinesStyle->Directive[
       GrayLevel[0.5, 0.4]],
     Method->{
      "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
       AbsolutePointSize[6], "ScalingFunctions" -> None},
     PlotRange->{{0, 0.013}, {-0.009293847122732027, 1.2598186985921493`}},
     PlotRangeClipping->True,
     PlotRangePadding->{{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}},
     Ticks->{Automatic, Automatic}], ",", "\[IndentingNewLine]", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"fz", "[", 
         RowBox[{"KXRIMD", ",", "p"}], "]"}], "-", 
        RowBox[{"fz", "[", 
         RowBox[{"KXRIMD", ",", 
          RowBox[{
           RowBox[{"p", "+", "pairoffset"}], "/.", 
           RowBox[{"vals", "[", "KXRIMD", "]"}]}]}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"p", ",", "0", ",", "0.013"}], "}"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", "Black", "}"}]}]}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.4789618100364523`*^9, 3.478961850760915*^9}, 
   3.478969868098156*^9, 3.4789702271107073`*^9, {3.478971402742322*^9, 
   3.478971407269801*^9}, {3.478973436528585*^9, 3.4789734559838*^9}, {
   3.4794970273251*^9, 3.4794970280748262`*^9}, {3.479497850691868*^9, 
   3.479497851721608*^9}, {3.4802445496159487`*^9, 3.4802445841180058`*^9}, {
   3.4802446656757193`*^9, 3.4802446687524443`*^9}, {3.481940803363203*^9, 
   3.481940804034131*^9}, {3.481941063760079*^9, 3.4819410664063997`*^9}, {
   3.481941556057631*^9, 3.4819415664906*^9}, {3.630208312322345*^9, 
   3.63020831448879*^9}, 3.630209982122305*^9, 3.630210040824745*^9, {
   3.630210608691247*^9, 3.6302106091463537`*^9}, 3.6302116072117853`*^9, 
   3.6302119179137897`*^9, 3.6304701238527927`*^9, 3.631834820615905*^9, 
   3.649109628464219*^9, {3.649110363868889*^9, 3.649110366770886*^9}, {
   3.649110567151823*^9, 3.649110570373554*^9}, {3.661123689182354*^9, 
   3.661123723132988*^9}, 3.661123839830414*^9, {3.661123888550177*^9, 
   3.6611238924215937`*^9}, {3.661123959516914*^9, 3.661123970823284*^9}, {
   3.661124020120494*^9, 3.661124020504492*^9}, {3.661124084594274*^9, 
   3.66112408490854*^9}, {3.661124132485323*^9, 3.661124133744603*^9}, {
   3.661127129389042*^9, 3.6611271300441732`*^9}, {3.6611285421516657`*^9, 
   3.6611285486416283`*^9}, 3.661139350752645*^9, {3.661141258332346*^9, 
   3.661141258345943*^9}, {3.661141309730465*^9, 3.6611413097415237`*^9}, {
   3.661142929646887*^9, 3.6611429309305487`*^9}, {3.661143000502679*^9, 
   3.6611430183305893`*^9}, 3.6611430889631033`*^9, {3.661202692295169*^9, 
   3.6612027456074247`*^9}, {3.6612032345320673`*^9, 
   3.6612032350121202`*^9}, {3.661203641247325*^9, 3.6612036470219383`*^9}, {
   3.661204651133306*^9, 3.6612046566907873`*^9}, {3.661205020492955*^9, 
   3.661205021421957*^9}, {3.662327449381301*^9, 3.662327449845611*^9}, 
   3.662327486588072*^9, {3.662327534038128*^9, 3.662327534215892*^9}, 
   3.662328936644876*^9, {3.662330873366127*^9, 3.662330873678608*^9}, {
   3.664425962748343*^9, 3.664425964357788*^9}, {3.664426029168276*^9, 
   3.66442603113202*^9}, 3.664595419822204*^9, {3.682482551440742*^9, 
   3.6824825528349667`*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
     LineBox[CompressedData["
1:eJwV1nk4VF0cB/AhRSohkpIkkTYqbcTXUpKQtCClyJKyhsJsd8YSk0QhEQkh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      "]]}}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 0.013}, {-0.03372807126330621, 1.2469914741994346`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.661219709246232*^9, 3.661341532375228*^9, 
  3.66224654204303*^9, 3.662328317212946*^9, 3.662331948563867*^9, 
  3.6623385721286287`*^9, 3.6644271173032503`*^9, 3.6645047378913527`*^9, 
  3.664594083413208*^9, 3.665375113354527*^9, 3.682484517545776*^9, 
  3.682584438376484*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"plot1", "[", "KXRIMD", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    GraphicsBox[{{}, {}, 
      {RGBColor[1, 1, 0], AbsoluteThickness[1.6], Opacity[1.], 
       LineBox[CompressedData["
1:eJwV1nk0Vd0bB3BSyVCUEKlQopKUIkO+pkIipQGFIiGUMcPl3nNNcVVvEUlJ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        "]]}},
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->{True, True},
     AxesLabel->{None, None},
     AxesOrigin->{0, 0},
     DisplayFunction->Identity,
     Frame->{{False, False}, {False, False}},
     FrameLabel->{{None, None}, {None, None}},
     FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
     GridLines->{None, None},
     GridLinesStyle->Directive[
       GrayLevel[0.5, 0.4]],
     Method->{
      "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
       AbsolutePointSize[6], "ScalingFunctions" -> None},
     PlotRange->{{0, 0.013}, {0., 1.2658026770083972`}},
     PlotRangeClipping->True,
     PlotRangePadding->{{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}},
     Ticks->{Automatic, Automatic}], ",", "\[IndentingNewLine]", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"fz", "[", 
        RowBox[{"KXRIMD", ",", "p"}], "]"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"p", ",", "0", ",", "0.013"}], "}"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", "Yellow", "}"}]}]}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.4789618100364523`*^9, 3.478961850760915*^9}, 
   3.478969868098156*^9, 3.4789702271107073`*^9, {3.478971402742322*^9, 
   3.478971407269801*^9}, {3.478973436528585*^9, 3.4789734559838*^9}, {
   3.4794970273251*^9, 3.4794970280748262`*^9}, {3.479497850691868*^9, 
   3.479497851721608*^9}, {3.4802445496159487`*^9, 3.4802445841180058`*^9}, {
   3.4802446656757193`*^9, 3.4802446687524443`*^9}, {3.481940803363203*^9, 
   3.481940804034131*^9}, {3.481941063760079*^9, 3.4819410664063997`*^9}, {
   3.481941556057631*^9, 3.4819415664906*^9}, {3.630208312322345*^9, 
   3.63020831448879*^9}, 3.630209982122305*^9, 3.630210040824745*^9, {
   3.630210608691247*^9, 3.6302106091463537`*^9}, 3.6302116072117853`*^9, 
   3.6302119179137897`*^9, 3.6304701238527927`*^9, 3.631834820615905*^9, 
   3.649109628464219*^9, {3.649110363868889*^9, 3.649110366770886*^9}, {
   3.649110567151823*^9, 3.649110570373554*^9}, {3.661123689182354*^9, 
   3.661123723132988*^9}, 3.661123839830414*^9, {3.661123888550177*^9, 
   3.6611238924215937`*^9}, {3.661123959516914*^9, 3.661123970823284*^9}, {
   3.661124020120494*^9, 3.661124020504492*^9}, {3.661124084594274*^9, 
   3.66112408490854*^9}, {3.661124132485323*^9, 3.661124133744603*^9}, {
   3.661127129389042*^9, 3.6611271300441732`*^9}, {3.6611285421516657`*^9, 
   3.6611285486416283`*^9}, 3.661139350752645*^9, {3.661141258332346*^9, 
   3.661141258345943*^9}, {3.661141309730465*^9, 3.6611413097415237`*^9}, {
   3.661142929646887*^9, 3.6611429309305487`*^9}, {3.661143000502679*^9, 
   3.6611430183305893`*^9}, 3.6611430889631033`*^9, {3.661202692295169*^9, 
   3.6612027456074247`*^9}, {3.6612032345320673`*^9, 
   3.6612032350121202`*^9}, {3.661203641247325*^9, 3.6612036470219383`*^9}, {
   3.661204651133306*^9, 3.6612046566907873`*^9}, {3.661205020492955*^9, 
   3.661205021421957*^9}, {3.662327449381301*^9, 3.662327449845611*^9}, {
   3.662327486588072*^9, 3.662327537553957*^9}, 3.662329110982596*^9, {
   3.662330878119421*^9, 3.6623308785345497`*^9}, {3.662354069937125*^9, 
   3.6623540788907948`*^9}, {3.662354134271152*^9, 3.662354134562495*^9}, {
   3.6623543100422163`*^9, 3.66235431077297*^9}, {3.6623544217834806`*^9, 
   3.66235444697696*^9}, {3.6623545334028597`*^9, 3.6623545384531507`*^9}, {
   3.6644259648635597`*^9, 3.664425965343483*^9}, {3.664426023889195*^9, 
   3.664426024820571*^9}, 3.66459542548556*^9, {3.6824825533851633`*^9, 
   3.6824825538188133`*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {RGBColor[1, 1, 0], AbsoluteThickness[1.6], Opacity[1.], 
     LineBox[CompressedData["
1:eJwV1nlYTdsbB/BKV4OQNP8SQkKlgRtR3zIkISfRSCVFs0al0zlnn1NSJ9yI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      "]]}}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 0.013}, {0., 1.265802677031688}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.664427158034647*^9, 3.6645047772775583`*^9, 
  3.6645941213003483`*^9, 3.665375151859668*^9, 3.682484553222961*^9, 
  3.682584473619458*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"plot", "[", "KXRIMD", "]"}], ",", 
   RowBox[{"plot1", "[", "KXRIMD", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.662331982056473*^9, 3.662331997565082*^9}, {
  3.6644259658935747`*^9, 3.6644259664708233`*^9}, {3.682482554257682*^9, 
  3.6824825547212763`*^9}}],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
      LineBox[CompressedData["
1:eJwV1nk4VF0cB/AhRSohkpIkkTYqbcTXUpKQtCClyJKyhsJsd8YSk0QhEQkh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       "]]}}, {}, {}}, {{{}, {}, 
     {RGBColor[1, 1, 0], AbsoluteThickness[1.6], Opacity[1.], 
      LineBox[CompressedData["
1:eJwV1nlYTdsbB/BKV4OQNP8SQkKlgRtR3zIkISfRSCVFs0al0zlnn1NSJ9yI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       "]]}}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 0.013}, {-0.03372807126330621, 1.2469914741994346`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.66442715811832*^9, 3.6645047773283052`*^9, 
  3.664594121372748*^9, 3.6653751519492188`*^9, 3.682484553297822*^9, 
  3.682584473767017*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"zmax", "[", "KXRIMD", "]"}], "  ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{
    RowBox[{"optdata", "[", "KXRIMD", "]"}], "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.478970786649661*^9, 3.478970802864567*^9}, {
   3.4796619220112333`*^9, 3.4796619454416037`*^9}, 3.479665671740583*^9, {
   3.48194080448247*^9, 3.481940804971867*^9}, {3.630208319233528*^9, 
   3.630208320862918*^9}, {3.630210609409204*^9, 3.6302106096880713`*^9}, {
   3.661141258353458*^9, 3.6611412583619328`*^9}, {3.661141309747707*^9, 
   3.661141309752261*^9}, 3.662329128518359*^9, {3.664425967055423*^9, 
   3.6644259676175013`*^9}, {3.682482555219154*^9, 3.682482555675714*^9}}],

Cell[BoxData["0.008019336317460981`"], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGAwBOKQpjXdc16/dFyUG2Mx481Lxxmm1slvgHRVmlDOOyDd
V36j8z2Qvu0kNBlE/39ZeoTz3UvHKOkVp58A6ZCHs3P7P7x0XPNepcTt40vH
A2Uu1SD61gOZzSDaKSPnPIjWPVjJ5Q6kK1Q3brPmfu0odHpRojDPa8eKhqen
QPQV5gtPQfRj87fpIkBaaZrYJEsg/Sz3xhsPIL1feuvmWCDddTW8ZhKQPmWk
3KbJD9S3juMGiA54v/OiHpC+M9/64m+h147Xtt4U/wuk13i+miJv8Nrx0+KU
nXvcXjv6iGtM3wek77wIkXkJpP+lecxgd3/tWMT74iSInnFE8J4gkE6+6Ngv
DKTtIidnlwDpJ7vPBOp5vnb8/WKJSxiQ1nA2XQqiGTxXyIUDaad1O7kigPQ2
r+Vu0UDa490RoXBfoLl/tX/WAGmWrzozVwBpncL/X1X9XztuStHWPJH/2vHS
KevPP4A0AFgUy2I=
  "]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"magposactpromec", "-", 
   RowBox[{"zmax", "[", "KXRIMD", "]"}]}], "/.", 
  RowBox[{"vals", "[", "KXRIMD", "]"}]}]], "Input",
 CellChangeTimes->{{3.631850926207306*^9, 3.631850980824053*^9}, {
   3.631851019732378*^9, 3.631851023974328*^9}, 3.661139094984755*^9, 
   3.6611392025019712`*^9, {3.661141258367827*^9, 3.661141258374606*^9}, {
   3.661141309758286*^9, 3.661141309762734*^9}, {3.664425968161345*^9, 
   3.664425968705267*^9}, {3.6824825560934763`*^9, 3.682482556573752*^9}}],

Cell[BoxData[
 RowBox[{"-", "0.00011933631746098051`"}]], "Output",
 CellChangeTimes->{{3.631850951545291*^9, 3.63185098135504*^9}, 
   3.631851024795751*^9, 3.633831562056611*^9, 3.6338341748264236`*^9, 
   3.649109159364168*^9, 3.6609653231946507`*^9, 3.6609691453050213`*^9, 
   3.661056226711844*^9, 3.6611186583295813`*^9, 3.66111905527409*^9, 
   3.6611396965979853`*^9, 3.6611431650138903`*^9, 3.6613415326304903`*^9, 
   3.66224654244606*^9, 3.6623283572045794`*^9, 3.662330101462863*^9, 
   3.662331989861638*^9, 3.6623386132889023`*^9, 3.664427158190177*^9, 
   3.6645047774111433`*^9, 3.66459412146596*^9, 3.6653751520391273`*^9, 
   3.682484553405921*^9, 3.682584473931514*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fmax", "[", "KXRIMD", "]"}], "  ", "=", " ", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"optdata", "[", "KXRIMD", "]"}], " ", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4789708091780043`*^9, 3.4789708248973703`*^9}, 
   3.479661922078005*^9, 3.4796619593447857`*^9, 3.479665787682528*^9, {
   3.481940805601218*^9, 3.481940806091435*^9}, {3.630208322616778*^9, 
   3.6302083244414253`*^9}, {3.63021060995541*^9, 3.63021061023507*^9}, {
   3.661141258380653*^9, 3.661141258387753*^9}, {3.661141309768797*^9, 
   3.661141309773177*^9}, {3.66442596917734*^9, 3.664425969691185*^9}, {
   3.682482557020494*^9, 3.682482557471601*^9}}],

Cell[BoxData["1.2469914875060015`"], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGAwAOKWPeu757x+6fjqVazFjDcvHYUybZLfAGlvBZGcd0Ca
KeVm53sgHccmNhlE2xwsO8L57qVjacnK00+AdOCkubn9H146Mm9SK3H7+NLx
yXfXahAtsEF2M4helpZ3HkS39VdzuQPp+Psbt1lzv3ZU+7UkUZjnteOEl99O
gejdWy88BdFOie/TRYD03WUSkyyB9I6mW288gHTHvG2bY4F06/nImklA+sN5
lTZN/teOZdO4boDoad27L+oB6cqJARd/C712rNC8Lf4XSE9yfjtF3uC146GL
6Tv3uAHtjdWevg9Ix4REyLwE0lOsAmawu792zG94eRJE394ick8QSD/wfdwv
DKQvnpmaXQKk25IvBOp5As2VW+ESBqQfnNogFw6k9XT3ckUA6SKj1W7RQFpq
9nGhcN/Xjotm6v2sAdIH5hnMXAGkHRuYv6n6v3a836GneSL/tWPYKofPP4A0
ALVfxVw=
  "]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"deriv2", "[", "KXRIMD", "]"}], " ", "=", "  ", 
  RowBox[{
   RowBox[{"-", "2"}], "*", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"fzi", "[", "KPR", "]"}], "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{"zmax", "[", "KPR", "]"}], ",", "2"}], "}"}]}], "]"}], 
      "]"}], ",", 
     RowBox[{"z", "^", "2"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479660163969679*^9, 3.479660203608347*^9}, {
   3.479660334457396*^9, 3.479660335305067*^9}, {3.4796611591764927`*^9, 
   3.479661208701754*^9}, {3.479661250977075*^9, 3.479661305176928*^9}, {
   3.479661346153286*^9, 3.479661372928776*^9}, {3.479661851029785*^9, 
   3.479661859051705*^9}, 3.4796619463263597`*^9, 3.479662725037703*^9, 
   3.479665672610339*^9, {3.481940806550991*^9, 3.48194080744361*^9}, {
   3.630208325888165*^9, 3.6302083289679956`*^9}, {3.630210610460196*^9, 
   3.630210610874337*^9}, 3.6611229758725023`*^9, {3.6611412583941383`*^9, 
   3.6611412584082737`*^9}, {3.661141309779232*^9, 3.661141309788487*^9}, {
   3.661143055996151*^9, 3.661143061547195*^9}, {3.661143129145129*^9, 
   3.661143150309849*^9}, 3.662253434311702*^9, 3.662262524114635*^9, 
   3.664425970211187*^9, 3.6824825579021997`*^9}],

Cell[BoxData["4723.921650343821`"], "Output",
 CellChangeTimes->{
  3.4796611607361183`*^9, 3.479661209333243*^9, {3.4796612702637243`*^9, 
   3.47966130570842*^9}, 3.479661373421825*^9, 3.479661471574224*^9, 
   3.479661860947604*^9, {3.479662726071348*^9, 3.47966274404876*^9}, 
   3.479663512851673*^9, 3.479665743087571*^9, 3.4796658169851303`*^9, 
   3.4802437481454697`*^9, 3.480692317637856*^9, 3.481566061244952*^9, 
   3.4819408972419558`*^9, 3.4819409542455378`*^9, 3.481941401101359*^9, 
   3.4819416276185503`*^9, 3.481942100030518*^9, 3.6297681177567453`*^9, 
   3.630209805425727*^9, 3.6302106479180737`*^9, 3.6302108627485523`*^9, 
   3.63021190367418*^9, 3.630288017033553*^9, 3.630319463059012*^9, 
   3.630362014021439*^9, 3.63047011514816*^9, 3.631828017512751*^9, 
   3.631828672853829*^9, 3.631838862188128*^9, 3.63383156257211*^9, 
   3.63383417516654*^9, 3.6491091597267933`*^9, 3.66096532357506*^9, 
   3.660969145695554*^9, 3.661056227053145*^9, 3.661118658556089*^9, 
   3.661119055617577*^9, 3.66112298417872*^9, 3.661139696737555*^9, {
   3.661143136068817*^9, 3.661143169405212*^9}, 3.661341532717312*^9, 
   3.662246542618259*^9, 3.662328357304565*^9, 3.66233010158547*^9, 
   3.662331989985965*^9, 3.662338613418449*^9, 3.6644271582742243`*^9, 
   3.664504777493836*^9, 3.664594121587071*^9, 3.665375152173341*^9, 
   3.682484553507306*^9, 3.682584474115281*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"z95plus", "[", "KXRIMD", "]"}], " ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{"FindRoot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"fz", "[", 
       RowBox[{"KXRIMD", ",", "z"}], "]"}], "-", 
      RowBox[{"0.95", "*", 
       RowBox[{"fmax", "[", "KXRIMD", "]"}]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", 
       RowBox[{
        RowBox[{"zmax", "[", "KXRIMD", "]"}], "+", "0.001"}], ",", 
       RowBox[{"zmax", "[", "KXRIMD", "]"}], ",", 
       RowBox[{
        RowBox[{"zmax", "[", "KXRIMD", "]"}], "+", "0.005"}]}], "}"}]}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479658613425561*^9, 3.4796587501410933`*^9}, {
   3.479658790462825*^9, 3.4796587993088913`*^9}, {3.479658852062684*^9, 
   3.479658891629363*^9}, {3.4796589431729183`*^9, 3.479658948798299*^9}, {
   3.479658987032153*^9, 3.47965898990287*^9}, {3.479659310386307*^9, 
   3.4796593125701933`*^9}, {3.479661624172262*^9, 3.479661679901505*^9}, {
   3.479661945541445*^9, 3.4796619594445953`*^9}, {3.4796656734658623`*^9, 
   3.479665674680963*^9}, 3.47966578778349*^9, {3.481940808072547*^9, 
   3.4819408112927933`*^9}, {3.630208331202548*^9, 3.630208340512887*^9}, {
   3.6302106111156588`*^9, 3.630210612620454*^9}, {3.631834272292122*^9, 
   3.631834275423791*^9}, {3.660964933550774*^9, 3.660964934686805*^9}, {
   3.662329034693089*^9, 3.662329042196556*^9}, 3.662334135563291*^9, {
   3.664425970779209*^9, 3.664425973583028*^9}, {3.682482558351726*^9, 
   3.682482560675799*^9}}],

Cell[BoxData["0.010201001695690555`"], "Output",
 CellChangeTimes->{{3.479659290207419*^9, 3.4796593177022877`*^9}, {
   3.479661644377719*^9, 3.4796616514833097`*^9}, 3.479661686065053*^9, 
   3.4796634593803263`*^9, 3.479665745824663*^9, 3.4796658197389708`*^9, 
   3.480243751933235*^9, 3.480692320796873*^9, 3.4815660640155077`*^9, 
   3.4819408973674994`*^9, 3.481940954361327*^9, 3.481941402301373*^9, 
   3.481941628781619*^9, 3.481942101498692*^9, 3.629768118581479*^9, 
   3.630209825967379*^9, 3.63021064809335*^9, 3.630210863735273*^9, 
   3.6302119044786863`*^9, 3.630288029600463*^9, 3.630319474859651*^9, 
   3.630362016214836*^9, 3.63047011744707*^9, 3.631828018334545*^9, 
   3.631828673603425*^9, 3.631835209527664*^9, 3.631839554443227*^9, 
   3.6338315761916437`*^9, 3.633834181637607*^9, 3.649109166248088*^9, 
   3.6609655749502296`*^9, 3.660965945562953*^9, 3.660968309694571*^9, 
   3.6609692385501957`*^9, 3.6609693505923347`*^9, 3.661056651074237*^9, 
   3.6611192956141233`*^9, 3.661130614471345*^9, 3.661130729128159*^9, 
   3.661139986045722*^9, 3.661219854453026*^9, 3.661231205656358*^9, 
   3.6613414423732347`*^9, 3.662246451691223*^9, 3.662328257276907*^9, 
   3.662329076444454*^9, 3.662330103708742*^9, 3.662331992000602*^9, 
   3.6623372437215033`*^9, 3.662338615581056*^9, 3.664427160593852*^9, 
   3.6645047798193502`*^9, 3.664594123762166*^9, 3.6653751543997917`*^9, 
   3.682484555566526*^9, 3.682584476066936*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"z95minus", "[", "KXRIMD", "]"}], " ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{"FindRoot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"fz", "[", 
       RowBox[{"KXRIMD", ",", "z"}], "]"}], "-", 
      RowBox[{"0.95", "*", 
       RowBox[{"fmax", "[", "KXRIMD", "]"}]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", 
       RowBox[{
        RowBox[{"zmax", "[", "KXRIMD", "]"}], "-", "0.001"}], ",", 
       RowBox[{
        RowBox[{"zmax", "[", "KXRIMD", "]"}], "-", "0.005"}], ",", 
       RowBox[{"zmax", "[", "KXRIMD", "]"}]}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479658613425561*^9, 3.4796587501410933`*^9}, {
   3.479658790462825*^9, 3.4796587993088913`*^9}, {3.479658852062684*^9, 
   3.479658891629363*^9}, {3.4796589431729183`*^9, 3.479658948798299*^9}, {
   3.479658997678957*^9, 3.4796590027188377`*^9}, {3.479659318794853*^9, 
   3.479659344898431*^9}, {3.479661657421668*^9, 3.4796616780054293`*^9}, {
   3.479661945775414*^9, 3.479661959545474*^9}, {3.479665675209929*^9, 
   3.479665676278386*^9}, 3.4796657878831253`*^9, {3.481940812147341*^9, 
   3.481940829419257*^9}, {3.6302083429611607`*^9, 3.6302083515364437`*^9}, {
   3.630210612999134*^9, 3.630210615553306*^9}, {3.6318342761199827`*^9, 
   3.631834277785796*^9}, {3.660964934904317*^9, 3.660964935954105*^9}, {
   3.660968688340294*^9, 3.660968693115794*^9}, {3.661220236123904*^9, 
   3.6612202369311447`*^9}, {3.6623290444123*^9, 3.662329072977393*^9}, 
   3.6623341355722446`*^9, {3.662337264381858*^9, 3.66233728414599*^9}, {
   3.664425974264805*^9, 3.664425976906748*^9}, {3.682482561139845*^9, 
   3.682482563486807*^9}}],

Cell[BoxData["0.006012357118462664`"], "Output",
 CellChangeTimes->{3.662337287443143*^9, 3.662338618554626*^9, 
  3.66442716364495*^9, 3.664504782842551*^9, 3.6645941265566683`*^9, 
  3.66537515719246*^9, 3.682484558196994*^9, 3.68258447862938*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"plot", "[", "KXRIMD", "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"plot1", "[", "KXRIMD", "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Graphics", "[", 
    RowBox[{"Line", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"zmax", "[", "KXRIMD", "]"}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"zmax", "[", "KXRIMD", "]"}], ",", 
         RowBox[{"1.1", "*", 
          RowBox[{"fmax", "[", "KXRIMD", "]"}]}]}], "}"}]}], "}"}], "]"}], 
    "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{"Gray", ",", 
      RowBox[{"Line", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"z95minus", "[", "KXRIMD", "]"}], ",", "0"}], "}"}], ",", 
          
          RowBox[{"{", 
           RowBox[{
            RowBox[{"z95minus", "[", "KXRIMD", "]"}], ",", 
            RowBox[{"1.1", "*", 
             RowBox[{"fmax", "[", "KXRIMD", "]"}]}]}], "}"}]}], "}"}], "/.", 
        RowBox[{"vals", "[", "KBS", "]"}]}], "]"}]}], "}"}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{"Gray", ",", 
      RowBox[{"Line", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"z95plus", "[", "KXRIMD", "]"}], ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"z95plus", "[", "KXRIMD", "]"}], ",", 
            RowBox[{"1.1", "*", 
             RowBox[{"fmax", "[", "KXRIMD", "]"}]}]}], "}"}]}], "}"}], "/.", 
        RowBox[{"vals", "[", "KBS", "]"}]}], "]"}]}], "}"}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<z (m)\>\"", ",", "\"\<F (N/A)\>\""}], "}"}]}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.453823397414776*^9, 3.453823397824687*^9}, {
   3.453838538440839*^9, 3.453838572806719*^9}, 3.463844247723119*^9, 
   3.478894943196905*^9, 3.4788950132010527`*^9, {3.478961709433363*^9, 
   3.47896175216029*^9}, {3.478961842569364*^9, 3.478961894377494*^9}, {
   3.4789619830038633`*^9, 3.478961984506156*^9}, {3.4789699280628653`*^9, 
   3.478969982243393*^9}, {3.478970021389124*^9, 3.478970165180615*^9}, {
   3.478970224319232*^9, 3.478970261501657*^9}, {3.4789703108875017`*^9, 
   3.478970348344078*^9}, 3.478970398020482*^9, {3.478970871122594*^9, 
   3.47897087265033*^9}, {3.478971414854863*^9, 3.4789714317583723`*^9}, {
   3.4789723334965277`*^9, 3.4789723911200447`*^9}, {3.478973525233735*^9, 
   3.47897352833882*^9}, {3.479495227181163*^9, 3.4794952662789087`*^9}, {
   3.4794954131043873`*^9, 3.4794954161349077`*^9}, {3.479497883443406*^9, 
   3.479497887306903*^9}, {3.4794980354692507`*^9, 3.479498036795588*^9}, 
   3.4794982488155937`*^9, {3.479662131489229*^9, 3.479662133377276*^9}, 
   3.479665540471899*^9, {3.4802459792714577`*^9, 3.480245981573744*^9}, {
   3.4802525542284737`*^9, 3.4802525884311867`*^9}, {3.48194087775911*^9, 
   3.481940886937986*^9}, 3.630208353429995*^9, 3.6302106162586517`*^9, 
   3.631834278469103*^9, {3.631835050283194*^9, 3.631835119871463*^9}, {
   3.631838204428006*^9, 3.631838423237857*^9}, {3.6318384686026077`*^9, 
   3.631838479273821*^9}, {3.6318392214551907`*^9, 3.631839229661147*^9}, {
   3.661139094999187*^9, 3.6611390950093946`*^9}, {3.661139202513871*^9, 
   3.661139202520485*^9}, {3.6611412584795847`*^9, 3.6611412584963713`*^9}, {
   3.6611413098586197`*^9, 3.661141309872466*^9}, {3.661143315366548*^9, 
   3.6611433270441647`*^9}, {3.662332301064869*^9, 3.662332380309093*^9}, {
   3.6623341355802917`*^9, 3.662334135592721*^9}, {3.662354326401864*^9, 
   3.662354329985043*^9}, {3.664425977645124*^9, 3.664425983190798*^9}, {
   3.682482564055793*^9, 3.682482572685994*^9}, 3.682583428856874*^9, {
   3.682583465012672*^9, 3.682583493650186*^9}}],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
      LineBox[CompressedData["
1:eJwV1nk4VF0cB/AhRSohkpIkkTYqbcTXUpKQtCClyJKyhsJsd8YSk0QhEQkh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       "]]}}, {}, {}}, {{{}, {}, 
     {RGBColor[1, 1, 0], AbsoluteThickness[1.6], Opacity[1.], 
      LineBox[CompressedData["
1:eJwV1nlYTdsbB/BKV4OQNP8SQkKlgRtR3zIkISfRSCVFs0al0zlnn1NSJ9yI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       "]]}}, {}, {}}, 
   LineBox[{{0.008019336317460981, 0}, {0.008019336317460981, 
     1.3716906362566017`}}], 
   {GrayLevel[0.5], 
    LineBox[{{0.006012357118462664, 0}, {0.006012357118462664, 
      1.3716906362566017`}}]}, 
   {GrayLevel[0.5], 
    LineBox[{{0.010201001695690555`, 0}, {0.010201001695690555`, 
      1.3716906362566017`}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"z (m)\"", TraditionalForm], 
    FormBox["\"F (N/A)\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 0.013}, {-0.03372807126330621, 1.2469914741994346`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.661143339013616*^9, 3.6613415331386127`*^9, 3.662246543123845*^9, 
   3.662328357735825*^9, 3.6623301043833427`*^9, 3.662331992642704*^9, 
   3.662332313093595*^9, {3.662332357700629*^9, 3.662332372084869*^9}, {
   3.662337270050414*^9, 3.6623372917742653`*^9}, 3.6623386186212387`*^9, 
   3.662354353022257*^9, 3.662354642187873*^9, 3.664427163774837*^9, 
   3.664504782944879*^9, 3.6645941266721478`*^9, 3.665375157293741*^9, 
   3.6824845582497997`*^9, 3.68258343701014*^9, 3.682584478733634*^9}]
}, Open  ]]
}, Open  ]],

Cell["Summary", "Section",
 CellChangeTimes->{{3.662334150420327*^9, 3.6623341513632793`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"l", "[", "tag_", "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1000", "*", "l"}], ",", 
     RowBox[{"1000", "*", "a"}], ",", 
     RowBox[{"1000", "*", "coillen"}], ",", 
     RowBox[{"1000", "*", "coilrad1"}], ",", 
     RowBox[{"1000", "*", "coilrad2"}], ",", "coilturns", ",", "mz", ",", 
     "dipole", ",", "coilsigma", ",", 
     RowBox[{"fmax", "[", "tag", "]"}], ",", 
     RowBox[{"1000", "*", 
      RowBox[{"zmax", "[", "tag", "]"}]}], ",", 
     RowBox[{"1000", "*", 
      RowBox[{"z95minus", "[", "tag", "]"}]}], ",", 
     RowBox[{"1000", "*", 
      RowBox[{"z95plus", "[", "tag", "]"}]}], ",", "pairoffset", ",", 
     RowBox[{"deriv2", "[", "tag", "]"}]}], "}"}], "/.", 
   RowBox[{"vals", "[", "tag", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.6623341717574244`*^9, 3.6623342428102827`*^9}, {
  3.662334323406145*^9, 3.662334326142558*^9}, {3.6623371502856827`*^9, 
  3.662337234634256*^9}, {3.662337461063096*^9, 3.662337471858719*^9}, {
  3.662344033193515*^9, 3.662344041872057*^9}, {3.662344632831909*^9, 
  3.662344640793481*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TableForm", "[", 
  RowBox[{
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"l", "[", "KPR", "]"}], ",", " ", 
      RowBox[{"l", "[", "KSR", "]"}], ",", 
      RowBox[{"l", "[", "KBS", "]"}], ",", 
      RowBox[{"l", "[", "KBSIM", "]"}], ",", 
      RowBox[{"l", "[", "KBSIMD", "]"}], ",", 
      RowBox[{"l", "[", "KXRIMD", "]"}]}], "}"}], "]"}], ",", 
   RowBox[{"TableHeadings", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "\"\<l\>\"", ",", "\"\<a\>\"", ",", "\"\<coillen\>\"", ",", 
        "\"\<coilrad1\>\"", ",", "\"\<coilrad2\>\"", ",", "\"\<coilturns\>\"",
         ",", "\"\<mz\>\"", ",", "\"\<dipole\>\"", ",", "\"\<coilsigma\>\"", 
        ",", "\"\<fmax\>\"", ",", "\"\<zmax\>\"", ",", "\"\<z95-\>\"", ",", 
        "\"\<z96+\>\"", ",", "\"\<pairoffset\>\"", ",", "\"\<deriv2\>\""}], 
       "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
       "PR", ",", "SR", ",", "BS", ",", "BSIM", ",", "BSIMD", ",", "XRIMD"}], 
       "}"}]}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6623373700178347`*^9, 3.662337442259871*^9}, {
   3.6644259906366*^9, 3.664425996855027*^9}, {3.665356899174008*^9, 
   3.665356903380023*^9}, {3.6653734378093967`*^9, 3.665373516065688*^9}, {
   3.665376068761075*^9, 3.6653762340539722`*^9}, {3.6824825998164473`*^9, 
   3.682482677408923*^9}, {3.682584642606309*^9, 3.682584672347856*^9}, 
   3.682623020556766*^9}],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      StyleBox["\[Null]",
       ShowStringCharacters->False], 
      TagBox["PR",
       HoldForm], 
      TagBox["SR",
       HoldForm], 
      TagBox["BS",
       HoldForm], 
      TagBox["BSIM",
       HoldForm], 
      TagBox["BSIMD",
       HoldForm], 
      TagBox["XRIMD",
       HoldForm]},
     {
      TagBox["\<\"l\"\>",
       HoldForm], "3.`", "5.`", "3.`", "10.`", "12.`", "12.`"},
     {
      TagBox["\<\"a\"\>",
       HoldForm], "3.`", "1.`", "1.`", "5.`", "5.`", "5.`"},
     {
      TagBox["\<\"coillen\"\>",
       HoldForm], "8.`", "8.`", "8.`", "8.`", "8.`", "8.`"},
     {
      TagBox["\<\"coilrad1\"\>",
       HoldForm], "9.000000000000002`", "9.000000000000002`", 
      "9.000000000000002`", "9.000000000000002`", "9.000000000000002`", 
      "9.000000000000002`"},
     {
      TagBox["\<\"coilrad2\"\>",
       HoldForm], "18.72`", "18.72`", "18.72`", "18.72`", "18.72`", 
      "18.72`"},
     {
      TagBox["\<\"coilturns\"\>",
       HoldForm], "600", "600", "600", "600", "600", "600"},
     {
      TagBox["\<\"mz\"\>",
       HoldForm], "878020.9598010788`", "878020.9598010788`", 
      "878020.9598010788`", "878020.9598010788`", "878020.9598010788`", 
      "878020.9598010788`"},
     {
      TagBox["\<\"dipole\"\>",
       HoldForm], "0.07447637331924106`", "0.01379192098504464`", 
      "0.008275152591026784`", "0.6895960492522322`", "0.6895960492522322`", 
      "0.6895960492522322`"},
     {
      TagBox["\<\"coilsigma\"\>",
       HoldForm], "7.716049382716049`*^6", "7.716049382716049`*^6", 
      "7.716049382716049`*^6", "7.716049382716049`*^6", 
      "7.716049382716049`*^6", "7.716049382716049`*^6"},
     {
      TagBox["\<\"fmax\"\>",
       HoldForm], "0.1288008845335968`", "0.02251089264362962`", 
      "0.013815486037444383`", "1.1119932085941195`", "1.2598187348550516`", 
      "1.2469914875060015`"},
     {
      TagBox["\<\"zmax\"\>",
       HoldForm], "6.718812869426184`", "7.150489898592264`", 
      "6.9739872962227585`", "7.4425388806711865`", "7.994036894390839`", 
      "8.019336317460981`"},
     {
      TagBox["\<\"z95-\"\>",
       HoldForm], "5.168826141405982`", "5.506713887423707`", 
      "5.366877513608371`", "5.7021787524498135`", "6.162673053098946`", 
      "6.012357118462663`"},
     {
      TagBox["\<\"z96+\"\>",
       HoldForm], "8.529888500699315`", "9.048096481669155`", 
      "8.838882166757347`", "9.391637619473093`", "10.012000527601394`", 
      "10.201001695690556`"},
     {
      TagBox["\<\"pairoffset\"\>",
       HoldForm], "pairoffset", "pairoffset", "pairoffset", "0.0652`", 
      "0.0652`", "0.046`"},
     {
      TagBox["\<\"deriv2\"\>",
       HoldForm], "4723.921650343821`", "738.5450415183287`", 
      "472.780089408755`", "4723.921650343821`", "4723.921650343821`", 
      "4723.921650343821`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {{
      "l", "a", "coillen", "coilrad1", "coilrad2", "coilturns", "mz", 
       "dipole", "coilsigma", "fmax", "zmax", "z95-", "z96+", "pairoffset", 
       "deriv2"}, {$CellContext`PR, $CellContext`SR, $CellContext`BS, \
$CellContext`BSIM, $CellContext`BSIMD, $CellContext`XRIMD}}]]]], "Output",
 CellChangeTimes->{{3.662337443382112*^9, 3.662337477737198*^9}, 
   3.662338618725416*^9, 3.662344046350726*^9, 3.6623446482320137`*^9, 
   3.664592524486356*^9, 3.664594126750083*^9, 3.6645954545748453`*^9, {
   3.665373517162915*^9, 3.665373538451583*^9}, 3.665375343520034*^9, {
   3.665376074962056*^9, 3.665376093976714*^9}, 3.665376235490819*^9, 
   3.682484558336656*^9, 3.682584574254233*^9, {3.682584646365472*^9, 
   3.682584673896181*^9}, 3.682585106255953*^9, 3.682623021234213*^9, 
   3.6826231961171637`*^9}]
}, Open  ]]
},
CellGrouping->Manual,
WindowSize->{1013, 1043},
WindowMargins->{{Automatic, 23}, {Automatic, 12}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
FrontEndVersion->"11.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (July 28, \
2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 236, 3, 125, "Title"],
Cell[806, 27, 809, 16, 31, "Input"],
Cell[CellGroupData[{
Cell[1640, 47, 31, 0, 68, "Section"],
Cell[1674, 49, 636, 11, 86, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2347, 65, 78, 2, 68, "Section",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[2450, 71, 34, 0, 35, "Subsection"],
Cell[CellGroupData[{
Cell[2509, 75, 225, 4, 37, "Subsubsection"],
Cell[2737, 81, 573, 13, 77, "Input"],
Cell[3313, 96, 34, 0, 28, "Input"],
Cell[3350, 98, 80, 1, 28, "Input"]
}, Open  ]]
}, Open  ]],
Cell[3457, 103, 83, 1, 28, "Input"],
Cell[CellGroupData[{
Cell[3565, 108, 44, 0, 35, "Subsection"],
Cell[3612, 110, 150, 4, 29, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3799, 119, 71, 0, 35, "Subsection"],
Cell[CellGroupData[{
Cell[3895, 123, 54, 0, 24, "Subsubsection"],
Cell[3952, 125, 552, 16, 29, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4541, 146, 168, 4, 24, "Subsubsection"],
Cell[4712, 152, 122, 4, 42, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4871, 161, 97, 1, 24, "Subsubsection"],
Cell[4971, 164, 166, 5, 42, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[5186, 175, 176, 3, 35, "Subsection"],
Cell[CellGroupData[{
Cell[5387, 182, 151, 13, 182, "Input"],
Cell[5541, 197, 1707, 35, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7285, 237, 84, 2, 28, "Input"],
Cell[7372, 241, 1418, 25, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8827, 271, 155, 12, 168, "Input"],
Cell[8985, 285, 1679, 34, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10701, 324, 113, 3, 28, "Input"],
Cell[10817, 329, 1354, 22, 70, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[12220, 357, 83, 2, 35, "Subsection",
 Evaluatable->False],
Cell[12306, 361, 887, 24, 294, "Input"]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[13254, 392, 752, 12, 68, "Section"],
Cell[CellGroupData[{
Cell[14031, 408, 3792, 72, 796, "Input"],
Cell[17826, 482, 2244, 42, 113, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[20107, 529, 1397, 29, 108, "Input"],
Cell[21507, 560, 847, 16, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[22391, 581, 1193, 21, 31, "Input"],
Cell[23587, 604, 13469, 267, 61, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[37093, 876, 9116, 161, 168, "Input"],
Cell[46212, 1039, 7547, 136, 232, "Output"]
}, Open  ]],
Cell[53774, 1178, 121, 1, 26, "Text"],
Cell[CellGroupData[{
Cell[53920, 1183, 524, 13, 31, "Input"],
Cell[54447, 1198, 12285, 217, 232, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[66769, 1420, 705, 13, 31, "Input"],
Cell[67477, 1435, 571, 10, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[68085, 1450, 416, 8, 31, "Input"],
Cell[68504, 1460, 558, 8, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[69099, 1473, 696, 13, 31, "Input"],
Cell[69798, 1488, 569, 10, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[70404, 1503, 1737, 33, 31, "Input"],
Cell[72144, 1538, 542, 8, 31, "Output"]
}, Open  ]],
Cell[72701, 1549, 105, 1, 26, "Text"],
Cell[72809, 1552, 163, 3, 31, "Input"],
Cell[CellGroupData[{
Cell[72997, 1559, 1547, 31, 31, "Input"],
Cell[74547, 1592, 12889, 225, 232, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[87473, 1822, 1455, 30, 31, "Input"],
Cell[88931, 1854, 1237, 17, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[90205, 1876, 1455, 29, 31, "Input"],
Cell[91663, 1907, 1235, 18, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[92935, 1930, 4195, 93, 165, "Input"],
Cell[97133, 2025, 7872, 145, 230, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[105054, 2176, 802, 10, 38, "Section"],
Cell[CellGroupData[{
Cell[105881, 2190, 3958, 75, 796, "Input"],
Cell[109842, 2267, 2286, 42, 113, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[112165, 2314, 1353, 29, 108, "Input"],
Cell[113521, 2345, 868, 16, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[114426, 2366, 1143, 20, 31, "Input"],
Cell[115572, 2388, 13496, 268, 61, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[129105, 2661, 8501, 150, 168, "Input"],
Cell[137609, 2813, 7539, 136, 229, "Output"]
}, Open  ]],
Cell[145163, 2952, 121, 1, 26, "Text"],
Cell[CellGroupData[{
Cell[145309, 2957, 471, 12, 31, "Input"],
Cell[145783, 2971, 12253, 216, 229, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[158073, 3192, 651, 12, 31, "Input"],
Cell[158727, 3206, 580, 11, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[159344, 3222, 366, 7, 31, "Input"],
Cell[159713, 3231, 583, 8, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[160333, 3244, 644, 12, 31, "Input"],
Cell[160980, 3258, 583, 11, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[161600, 3274, 1689, 32, 31, "Input"],
Cell[163292, 3308, 563, 8, 31, "Output"]
}, Open  ]],
Cell[163870, 3319, 105, 1, 26, "Text"],
Cell[163978, 3322, 163, 3, 31, "Input"],
Cell[CellGroupData[{
Cell[164166, 3329, 1496, 30, 31, "Input"],
Cell[165665, 3361, 12777, 224, 229, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[178479, 3590, 1405, 29, 31, "Input"],
Cell[179887, 3621, 1259, 17, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[181183, 3643, 1403, 28, 31, "Input"],
Cell[182589, 3673, 1259, 18, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[183885, 3696, 3624, 78, 146, "Input"],
Cell[187512, 3776, 7765, 142, 227, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[195326, 3924, 661, 8, 68, "Section"],
Cell[CellGroupData[{
Cell[196012, 3936, 4171, 78, 813, "Input"],
Cell[200186, 4016, 2389, 45, 132, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[202612, 4066, 1331, 28, 108, "Input"],
Cell[203946, 4096, 1068, 19, 31, "Output"]
}, Open  ]],
Cell[205029, 4118, 1235, 23, 31, "Input"],
Cell[CellGroupData[{
Cell[206289, 4145, 14077, 246, 168, "Input"],
Cell[220369, 4393, 13001, 228, 229, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[233407, 4626, 602, 12, 31, "Input"],
Cell[234012, 4640, 620, 11, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[234669, 4656, 322, 7, 31, "Input"],
Cell[234994, 4665, 714, 10, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[235745, 4680, 600, 12, 31, "Input"],
Cell[236348, 4694, 620, 11, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[237005, 4710, 1439, 29, 31, "Input"],
Cell[238447, 4741, 345, 5, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[238829, 4751, 1357, 29, 31, "Input"],
Cell[240189, 4782, 1382, 19, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[241608, 4806, 1506, 30, 31, "Input"],
Cell[243117, 4838, 1459, 21, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[244613, 4864, 4162, 93, 165, "Input"],
Cell[248778, 4959, 13526, 240, 227, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[262353, 5205, 729, 11, 68, "Section"],
Cell[CellGroupData[{
Cell[263107, 5220, 3768, 73, 796, "Input"],
Cell[266878, 5295, 2400, 45, 132, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[269315, 5345, 1771, 37, 108, "Input"],
Cell[271089, 5384, 396, 9, 31, "Output"]
}, Open  ]],
Cell[271500, 5396, 401, 8, 31, "Input"],
Cell[271904, 5406, 296, 5, 31, "Output"],
Cell[CellGroupData[{
Cell[272225, 5415, 1243, 25, 31, "Input"],
Cell[273471, 5442, 13586, 270, 61, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[287094, 5717, 9111, 162, 172, "Input"],
Cell[296208, 5881, 6891, 126, 233, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[303136, 6012, 9020, 158, 172, "Input"],
Cell[312159, 6172, 6795, 125, 235, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[318991, 6302, 219, 5, 31, "Input"],
Cell[319213, 6309, 12211, 215, 233, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[331461, 6529, 626, 12, 31, "Input"],
Cell[332090, 6543, 588, 11, 31, "Output"]
}, Open  ]],
Cell[332693, 6557, 87, 1, 26, "Text"],
Cell[332783, 6560, 535, 10, 31, "Output"],
Cell[CellGroupData[{
Cell[333343, 6574, 420, 8, 31, "Input"],
Cell[333766, 6584, 649, 9, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[334452, 6598, 600, 12, 31, "Input"],
Cell[335055, 6612, 578, 11, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[335670, 6628, 1321, 27, 31, "Input"],
Cell[336994, 6657, 1369, 20, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[338400, 6682, 1415, 29, 31, "Input"],
Cell[339818, 6713, 1433, 20, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[341288, 6738, 1562, 30, 31, "Input"],
Cell[342853, 6770, 234, 3, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[343124, 6778, 4443, 96, 184, "Input"],
Cell[347570, 6876, 12944, 230, 232, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[360563, 7112, 626, 8, 68, "Section"],
Cell[CellGroupData[{
Cell[361214, 7124, 3962, 75, 813, "Input"],
Cell[365179, 7201, 2459, 46, 132, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[367675, 7252, 1828, 38, 108, "Input"],
Cell[369506, 7292, 394, 9, 31, "Output"]
}, Open  ]],
Cell[369915, 7304, 447, 8, 31, "Input"],
Cell[370365, 7314, 440, 10, 31, "Output"],
Cell[CellGroupData[{
Cell[370830, 7328, 1297, 25, 31, "Input"],
Cell[372130, 7355, 13462, 268, 61, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[385629, 7628, 9156, 162, 173, "Input"],
Cell[394788, 7792, 6944, 127, 233, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[401769, 7924, 8996, 157, 173, "Input"],
Cell[410768, 8083, 6626, 122, 235, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[417431, 8210, 274, 6, 31, "Input"],
Cell[417708, 8218, 12023, 212, 233, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[429768, 8435, 680, 13, 31, "Input"],
Cell[430451, 8450, 584, 11, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[431072, 8466, 472, 9, 31, "Input"],
Cell[431547, 8477, 668, 10, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[432252, 8492, 647, 12, 31, "Input"],
Cell[432902, 8506, 578, 11, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[433517, 8522, 1348, 28, 31, "Input"],
Cell[434868, 8552, 1371, 20, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[436276, 8577, 1471, 30, 31, "Input"],
Cell[437750, 8609, 1432, 20, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[439219, 8634, 1618, 31, 31, "Input"],
Cell[440840, 8667, 228, 3, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[441105, 8675, 3992, 83, 165, "Input"],
Cell[445100, 8760, 12816, 228, 266, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[457965, 8994, 629, 8, 68, "Section"],
Cell[CellGroupData[{
Cell[458619, 9006, 4018, 76, 813, "Input"],
Cell[462640, 9084, 2480, 46, 132, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[465157, 9135, 1878, 39, 108, "Input"],
Cell[467038, 9176, 419, 10, 31, "Output"]
}, Open  ]],
Cell[467472, 9189, 449, 8, 31, "Input"],
Cell[467924, 9199, 464, 10, 31, "Output"],
Cell[CellGroupData[{
Cell[468413, 9213, 1349, 26, 31, "Input"],
Cell[469765, 9241, 13485, 269, 61, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[483287, 9515, 9208, 163, 173, "Input"],
Cell[492498, 9680, 6915, 127, 232, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[499450, 9812, 9050, 158, 173, "Input"],
Cell[508503, 9972, 6651, 123, 235, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[515191, 10100, 325, 7, 31, "Input"],
Cell[515519, 10109, 11994, 212, 232, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[527550, 10326, 726, 13, 31, "Input"],
Cell[528279, 10341, 596, 11, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[528912, 10357, 520, 9, 31, "Input"],
Cell[529435, 10368, 689, 10, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[530161, 10383, 697, 13, 31, "Input"],
Cell[530861, 10398, 586, 11, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[531484, 10414, 1372, 28, 31, "Input"],
Cell[532859, 10444, 1393, 20, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[534289, 10469, 1521, 31, 31, "Input"],
Cell[535813, 10502, 1454, 20, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[537304, 10527, 1668, 32, 31, "Input"],
Cell[538975, 10561, 249, 3, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[539261, 10569, 4062, 84, 165, "Input"],
Cell[543326, 10655, 12764, 227, 230, "Output"]
}, Open  ]]
}, Open  ]],
Cell[556117, 10886, 94, 1, 68, "Section"],
Cell[556214, 10889, 1123, 25, 45, "Input"],
Cell[CellGroupData[{
Cell[557362, 10918, 1463, 32, 70, "Input"],
Cell[558828, 10952, 4417, 113, 298, "Output"]
}, Open  ]]
}
]
*)

