(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[   1889612,      41399]
NotebookOptionsPosition[   1886088,      41268]
NotebookOutlinePosition[   1886500,      41286]
CellTagsIndexPosition[   1886457,      41283]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Coil theory for sweetspot calculation", "Section",
 InitializationCell->True,
 CellChangeTimes->{{3.453751003114501*^9, 3.4537510253033*^9}, {
  3.6318285298166122`*^9, 3.631828557324954*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"useprecomputedold", " ", "=", " ", "useprecomputed"}], 
  ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.633832278558338*^9, 3.63383228889774*^9}}],

Cell["\<\
useprecomputed=True; (* set to True to save a few time-consuming integrals *)\
\
\>", "Input",
 InitializationCell->True],

Cell[CellGroupData[{

Cell["Force off the axis in both r and z", "Subsection",
 InitializationCell->True],

Cell[CellGroupData[{

Cell["\<\
Element of force due to element of volume in coil and element of volume in \
magnet as function of r1, r2, theta1, theta2, z1, z2\
\>", "Text",
 InitializationCell->True],

Cell["\<\
fdr1dr2dtheta1dtheta2dz1dz2 = (
   -r1*r2*currentdipoleforce 
   /. dx -> r1*Cos[theta1] 
   /. dy -> r1*Sin[theta1] 
   /. dz -> z1 
   /. j1x -> coilsigma*Sin[theta1] 
   /. j1y -> -coilsigma*Cos[theta1] 
   /. j1z -> 0 
   /. Xx -> r2*Cos[theta2] 
   /. Yy -> r2*Sin[theta2] 
   /. Zz -> z2 
   /. m2x -> 0 
   /. m2y -> 0 
   /. m2z -> mz
); \
\>", "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.478888754037179*^9, 3.478888798683169*^9}, 
   3.6318285758873463`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell["Do z1 integral analytically", "Text",
 InitializationCell->True],

Cell[CellGroupData[{

Cell["Precomputed result", "Text",
 InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fdr1dr2dtheta1dtheta2dz2pre", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"1", "/", 
      RowBox[{"(", 
       RowBox[{"4", "*", "Pi"}], ")"}]}], "*", "mu0", "*", "mz", "*", "r1", 
     "*", "r2", "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], "*", "coilsigma", "*", 
             RowBox[{"coilz1", "^", "3"}], "*", 
             RowBox[{"r1", "^", "2"}], "*", 
             RowBox[{"Cos", "[", "theta1", "]"}]}], "-", 
            RowBox[{"4", "*", "coilsigma", "*", "coilz1", "*", 
             RowBox[{"r1", "^", "4"}], "*", 
             RowBox[{"Cos", "[", "theta1", "]"}]}], "-", 
            RowBox[{"5", "*", "coilsigma", "*", "coilz1", "*", 
             RowBox[{"r1", "^", "2"}], "*", 
             RowBox[{"r2", "^", "2"}], "*", 
             RowBox[{"Cos", "[", "theta1", "]"}]}], "-", 
            RowBox[{"coilsigma", "*", "coilz1", "*", 
             RowBox[{"r2", "^", "4"}], "*", 
             RowBox[{"Cos", "[", "theta1", "]"}]}], "+", 
            RowBox[{"6", "*", "coilsigma", "*", 
             RowBox[{"coilz1", "^", "2"}], "*", 
             RowBox[{"r1", "^", "2"}], "*", "z2", "*", 
             RowBox[{"Cos", "[", "theta1", "]"}]}], "+", 
            RowBox[{"4", "*", "coilsigma", "*", 
             RowBox[{"r1", "^", "4"}], "*", "z2", "*", 
             RowBox[{"Cos", "[", "theta1", "]"}]}], "+", 
            RowBox[{"5", "*", "coilsigma", "*", 
             RowBox[{"r1", "^", "2"}], "*", 
             RowBox[{"r2", "^", "2"}], "*", "z2", "*", 
             RowBox[{"Cos", "[", "theta1", "]"}]}], "+", 
            RowBox[{"coilsigma", "*", 
             RowBox[{"r2", "^", "4"}], "*", "z2", "*", 
             RowBox[{"Cos", "[", "theta1", "]"}]}], "-", 
            RowBox[{"6", "*", "coilsigma", "*", "coilz1", "*", 
             RowBox[{"r1", "^", "2"}], "*", 
             RowBox[{"z2", "^", "2"}], "*", 
             RowBox[{"Cos", "[", "theta1", "]"}]}], "+", 
            RowBox[{"2", "*", "coilsigma", "*", 
             RowBox[{"r1", "^", "2"}], "*", 
             RowBox[{"z2", "^", "3"}], "*", 
             RowBox[{"Cos", "[", "theta1", "]"}]}], "-", 
            RowBox[{"2", "*", "coilsigma", "*", 
             RowBox[{"coilz1", "^", "3"}], "*", 
             RowBox[{"r2", "^", "2"}], "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", 
               RowBox[{"2", "*", "theta2"}]}], "]"}]}], "-", 
            RowBox[{"3", "*", "coilsigma", "*", "coilz1", "*", 
             RowBox[{"r1", "^", "2"}], "*", 
             RowBox[{"r2", "^", "2"}], "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", 
               RowBox[{"2", "*", "theta2"}]}], "]"}]}], "-", 
            RowBox[{"3", "*", "coilsigma", "*", "coilz1", "*", 
             RowBox[{"r2", "^", "4"}], "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", 
               RowBox[{"2", "*", "theta2"}]}], "]"}]}], "+", 
            RowBox[{"6", "*", "coilsigma", "*", 
             RowBox[{"coilz1", "^", "2"}], "*", 
             RowBox[{"r2", "^", "2"}], "*", "z2", "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", 
               RowBox[{"2", "*", "theta2"}]}], "]"}]}], "+", 
            RowBox[{"3", "*", "coilsigma", "*", 
             RowBox[{"r1", "^", "2"}], "*", 
             RowBox[{"r2", "^", "2"}], "*", "z2", "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", 
               RowBox[{"2", "*", "theta2"}]}], "]"}]}], "+", 
            RowBox[{"3", "*", "coilsigma", "*", 
             RowBox[{"r2", "^", "4"}], "*", "z2", "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", 
               RowBox[{"2", "*", "theta2"}]}], "]"}]}], "-", 
            RowBox[{"6", "*", "coilsigma", "*", "coilz1", "*", 
             RowBox[{"r2", "^", "2"}], "*", 
             RowBox[{"z2", "^", "2"}], "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", 
               RowBox[{"2", "*", "theta2"}]}], "]"}]}], "+", 
            RowBox[{"2", "*", "coilsigma", "*", 
             RowBox[{"r2", "^", "2"}], "*", 
             RowBox[{"z2", "^", "3"}], "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", 
               RowBox[{"2", "*", "theta2"}]}], "]"}]}], "+", 
            RowBox[{"8", "*", "coilsigma", "*", "coilz1", "*", 
             RowBox[{"r1", "^", "3"}], "*", "r2", "*", 
             RowBox[{"Cos", "[", "theta1", "]"}], "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", "theta2"}], "]"}]}], "+", 
            RowBox[{"2", "*", "coilsigma", "*", "coilz1", "*", "r1", "*", 
             RowBox[{"r2", "^", "3"}], "*", 
             RowBox[{"Cos", "[", "theta1", "]"}], "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", "theta2"}], "]"}]}], "-", 
            RowBox[{"8", "*", "coilsigma", "*", 
             RowBox[{"r1", "^", "3"}], "*", "r2", "*", "z2", "*", 
             RowBox[{"Cos", "[", "theta1", "]"}], "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", "theta2"}], "]"}]}], "-", 
            RowBox[{"2", "*", "coilsigma", "*", "r1", "*", 
             RowBox[{"r2", "^", "3"}], "*", "z2", "*", 
             RowBox[{"Cos", "[", "theta1", "]"}], "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", "theta2"}], "]"}]}], "+", 
            RowBox[{"6", "*", "coilsigma", "*", "coilz1", "*", "r1", "*", 
             RowBox[{"r2", "^", "3"}], "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", 
               RowBox[{"2", "*", "theta2"}]}], "]"}], "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", "theta2"}], "]"}]}], "-", 
            RowBox[{"6", "*", "coilsigma", "*", "r1", "*", 
             RowBox[{"r2", "^", "3"}], "*", "z2", "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", 
               RowBox[{"2", "*", "theta2"}]}], "]"}], "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", "theta2"}], "]"}]}], "+", 
            RowBox[{"coilsigma", "*", "coilz1", "*", 
             RowBox[{"r1", "^", "3"}], "*", "r2", "*", 
             RowBox[{"Cos", "[", 
              RowBox[{
               RowBox[{"2", "*", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
            RowBox[{"coilsigma", "*", "coilz1", "*", "r1", "*", 
             RowBox[{"r2", "^", "3"}], "*", 
             RowBox[{"Cos", "[", 
              RowBox[{
               RowBox[{"2", "*", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
            RowBox[{"coilsigma", "*", 
             RowBox[{"r1", "^", "3"}], "*", "r2", "*", "z2", "*", 
             RowBox[{"Cos", "[", 
              RowBox[{
               RowBox[{"2", "*", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
            RowBox[{"coilsigma", "*", "r1", "*", 
             RowBox[{"r2", "^", "3"}], "*", "z2", "*", 
             RowBox[{"Cos", "[", 
              RowBox[{
               RowBox[{"2", "*", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
            RowBox[{"2", "*", "coilsigma", "*", "coilz1", "*", 
             RowBox[{"r1", "^", "2"}], "*", 
             RowBox[{"r2", "^", "2"}], "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", "theta2"}], "]"}], "*", 
             RowBox[{"Cos", "[", 
              RowBox[{
               RowBox[{"2", "*", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
            RowBox[{"2", "*", "coilsigma", "*", 
             RowBox[{"r1", "^", "2"}], "*", 
             RowBox[{"r2", "^", "2"}], "*", "z2", "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", "theta2"}], "]"}], "*", 
             RowBox[{"Cos", "[", 
              RowBox[{
               RowBox[{"2", "*", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
            RowBox[{"4", "*", "coilsigma", "*", 
             RowBox[{"coilz1", "^", "3"}], "*", "r1", "*", "r2", "*", 
             RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
            RowBox[{"7", "*", "coilsigma", "*", "coilz1", "*", 
             RowBox[{"r1", "^", "3"}], "*", "r2", "*", 
             RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
            RowBox[{"7", "*", "coilsigma", "*", "coilz1", "*", "r1", "*", 
             RowBox[{"r2", "^", "3"}], "*", 
             RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
            RowBox[{"12", "*", "coilsigma", "*", 
             RowBox[{"coilz1", "^", "2"}], "*", "r1", "*", "r2", "*", "z2", 
             "*", 
             RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
            RowBox[{"7", "*", "coilsigma", "*", 
             RowBox[{"r1", "^", "3"}], "*", "r2", "*", "z2", "*", 
             RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
            RowBox[{"7", "*", "coilsigma", "*", "r1", "*", 
             RowBox[{"r2", "^", "3"}], "*", "z2", "*", 
             RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
            RowBox[{
            "12", "*", "coilsigma", "*", "coilz1", "*", "r1", "*", "r2", "*", 
             
             RowBox[{"z2", "^", "2"}], "*", 
             RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
            RowBox[{"4", "*", "coilsigma", "*", "r1", "*", "r2", "*", 
             RowBox[{"z2", "^", "3"}], "*", 
             RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
            RowBox[{"14", "*", "coilsigma", "*", "coilz1", "*", 
             RowBox[{"r1", "^", "2"}], "*", 
             RowBox[{"r2", "^", "2"}], "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", "theta2"}], "]"}], "*", 
             RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
            RowBox[{"14", "*", "coilsigma", "*", 
             RowBox[{"r1", "^", "2"}], "*", 
             RowBox[{"r2", "^", "2"}], "*", "z2", "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", "theta2"}], "]"}], "*", 
             RowBox[{"Cos", "[", "theta2", "]"}]}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"2", "*", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"r1", "^", "2"}], "+", 
               RowBox[{"r2", "^", "2"}], "-", 
               RowBox[{"2", "*", "r1", "*", "r2", "*", 
                RowBox[{"Cos", "[", 
                 RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}], "^", 
             "2"}], "*", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"coilz1", "^", "2"}], "+", 
               RowBox[{"r1", "^", "2"}], "+", 
               RowBox[{"r2", "^", "2"}], "-", 
               RowBox[{"2", "*", "coilz1", "*", "z2"}], "+", 
               RowBox[{"z2", "^", "2"}], "-", 
               RowBox[{"2", "*", "r1", "*", "r2", "*", 
                RowBox[{"Cos", "[", 
                 RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}], "^", 
             RowBox[{"(", 
              RowBox[{"3", "/", "2"}], ")"}]}]}], ")"}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], "*", "coilsigma", "*", 
           RowBox[{"coilz2", "^", "3"}], "*", 
           RowBox[{"r1", "^", "2"}], "*", 
           RowBox[{"Cos", "[", "theta1", "]"}]}], "-", 
          RowBox[{"4", "*", "coilsigma", "*", "coilz2", "*", 
           RowBox[{"r1", "^", "4"}], "*", 
           RowBox[{"Cos", "[", "theta1", "]"}]}], "-", 
          RowBox[{"5", "*", "coilsigma", "*", "coilz2", "*", 
           RowBox[{"r1", "^", "2"}], "*", 
           RowBox[{"r2", "^", "2"}], "*", 
           RowBox[{"Cos", "[", "theta1", "]"}]}], "-", 
          RowBox[{"coilsigma", "*", "coilz2", "*", 
           RowBox[{"r2", "^", "4"}], "*", 
           RowBox[{"Cos", "[", "theta1", "]"}]}], "+", 
          RowBox[{"6", "*", "coilsigma", "*", 
           RowBox[{"coilz2", "^", "2"}], "*", 
           RowBox[{"r1", "^", "2"}], "*", "z2", "*", 
           RowBox[{"Cos", "[", "theta1", "]"}]}], "+", 
          RowBox[{"4", "*", "coilsigma", "*", 
           RowBox[{"r1", "^", "4"}], "*", "z2", "*", 
           RowBox[{"Cos", "[", "theta1", "]"}]}], "+", 
          RowBox[{"5", "*", "coilsigma", "*", 
           RowBox[{"r1", "^", "2"}], "*", 
           RowBox[{"r2", "^", "2"}], "*", "z2", "*", 
           RowBox[{"Cos", "[", "theta1", "]"}]}], "+", 
          RowBox[{"coilsigma", "*", 
           RowBox[{"r2", "^", "4"}], "*", "z2", "*", 
           RowBox[{"Cos", "[", "theta1", "]"}]}], "-", 
          RowBox[{"6", "*", "coilsigma", "*", "coilz2", "*", 
           RowBox[{"r1", "^", "2"}], "*", 
           RowBox[{"z2", "^", "2"}], "*", 
           RowBox[{"Cos", "[", "theta1", "]"}]}], "+", 
          RowBox[{"2", "*", "coilsigma", "*", 
           RowBox[{"r1", "^", "2"}], "*", 
           RowBox[{"z2", "^", "3"}], "*", 
           RowBox[{"Cos", "[", "theta1", "]"}]}], "-", 
          RowBox[{"2", "*", "coilsigma", "*", 
           RowBox[{"coilz2", "^", "3"}], "*", 
           RowBox[{"r2", "^", "2"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", "*", "theta2"}]}], "]"}]}], "-", 
          RowBox[{"3", "*", "coilsigma", "*", "coilz2", "*", 
           RowBox[{"r1", "^", "2"}], "*", 
           RowBox[{"r2", "^", "2"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", "*", "theta2"}]}], "]"}]}], "-", 
          RowBox[{"3", "*", "coilsigma", "*", "coilz2", "*", 
           RowBox[{"r2", "^", "4"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", "*", "theta2"}]}], "]"}]}], "+", 
          RowBox[{"6", "*", "coilsigma", "*", 
           RowBox[{"coilz2", "^", "2"}], "*", 
           RowBox[{"r2", "^", "2"}], "*", "z2", "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", "*", "theta2"}]}], "]"}]}], "+", 
          RowBox[{"3", "*", "coilsigma", "*", 
           RowBox[{"r1", "^", "2"}], "*", 
           RowBox[{"r2", "^", "2"}], "*", "z2", "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", "*", "theta2"}]}], "]"}]}], "+", 
          RowBox[{"3", "*", "coilsigma", "*", 
           RowBox[{"r2", "^", "4"}], "*", "z2", "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", "*", "theta2"}]}], "]"}]}], "-", 
          RowBox[{"6", "*", "coilsigma", "*", "coilz2", "*", 
           RowBox[{"r2", "^", "2"}], "*", 
           RowBox[{"z2", "^", "2"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", "*", "theta2"}]}], "]"}]}], "+", 
          RowBox[{"2", "*", "coilsigma", "*", 
           RowBox[{"r2", "^", "2"}], "*", 
           RowBox[{"z2", "^", "3"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", "*", "theta2"}]}], "]"}]}], "+", 
          RowBox[{"8", "*", "coilsigma", "*", "coilz2", "*", 
           RowBox[{"r1", "^", "3"}], "*", "r2", "*", 
           RowBox[{"Cos", "[", "theta1", "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}]}], "+", 
          RowBox[{"2", "*", "coilsigma", "*", "coilz2", "*", "r1", "*", 
           RowBox[{"r2", "^", "3"}], "*", 
           RowBox[{"Cos", "[", "theta1", "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}]}], "-", 
          RowBox[{"8", "*", "coilsigma", "*", 
           RowBox[{"r1", "^", "3"}], "*", "r2", "*", "z2", "*", 
           RowBox[{"Cos", "[", "theta1", "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}]}], "-", 
          RowBox[{"2", "*", "coilsigma", "*", "r1", "*", 
           RowBox[{"r2", "^", "3"}], "*", "z2", "*", 
           RowBox[{"Cos", "[", "theta1", "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}]}], "+", 
          RowBox[{"6", "*", "coilsigma", "*", "coilz2", "*", "r1", "*", 
           RowBox[{"r2", "^", "3"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", "*", "theta2"}]}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}]}], "-", 
          RowBox[{"6", "*", "coilsigma", "*", "r1", "*", 
           RowBox[{"r2", "^", "3"}], "*", "z2", "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", "*", "theta2"}]}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}]}], "+", 
          RowBox[{"coilsigma", "*", "coilz2", "*", 
           RowBox[{"r1", "^", "3"}], "*", "r2", "*", 
           RowBox[{"Cos", "[", 
            RowBox[{
             RowBox[{"2", "*", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
          RowBox[{"coilsigma", "*", "coilz2", "*", "r1", "*", 
           RowBox[{"r2", "^", "3"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{
             RowBox[{"2", "*", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
          RowBox[{"coilsigma", "*", 
           RowBox[{"r1", "^", "3"}], "*", "r2", "*", "z2", "*", 
           RowBox[{"Cos", "[", 
            RowBox[{
             RowBox[{"2", "*", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
          RowBox[{"coilsigma", "*", "r1", "*", 
           RowBox[{"r2", "^", "3"}], "*", "z2", "*", 
           RowBox[{"Cos", "[", 
            RowBox[{
             RowBox[{"2", "*", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
          RowBox[{"2", "*", "coilsigma", "*", "coilz2", "*", 
           RowBox[{"r1", "^", "2"}], "*", 
           RowBox[{"r2", "^", "2"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{
             RowBox[{"2", "*", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
          RowBox[{"2", "*", "coilsigma", "*", 
           RowBox[{"r1", "^", "2"}], "*", 
           RowBox[{"r2", "^", "2"}], "*", "z2", "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{
             RowBox[{"2", "*", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
          RowBox[{"4", "*", "coilsigma", "*", 
           RowBox[{"coilz2", "^", "3"}], "*", "r1", "*", "r2", "*", 
           RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
          RowBox[{"7", "*", "coilsigma", "*", "coilz2", "*", 
           RowBox[{"r1", "^", "3"}], "*", "r2", "*", 
           RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
          RowBox[{"7", "*", "coilsigma", "*", "coilz2", "*", "r1", "*", 
           RowBox[{"r2", "^", "3"}], "*", 
           RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
          RowBox[{"12", "*", "coilsigma", "*", 
           RowBox[{"coilz2", "^", "2"}], "*", "r1", "*", "r2", "*", "z2", "*", 
           RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
          RowBox[{"7", "*", "coilsigma", "*", 
           RowBox[{"r1", "^", "3"}], "*", "r2", "*", "z2", "*", 
           RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
          RowBox[{"7", "*", "coilsigma", "*", "r1", "*", 
           RowBox[{"r2", "^", "3"}], "*", "z2", "*", 
           RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
          RowBox[{
          "12", "*", "coilsigma", "*", "coilz2", "*", "r1", "*", "r2", "*", 
           RowBox[{"z2", "^", "2"}], "*", 
           RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
          RowBox[{"4", "*", "coilsigma", "*", "r1", "*", "r2", "*", 
           RowBox[{"z2", "^", "3"}], "*", 
           RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
          RowBox[{"14", "*", "coilsigma", "*", "coilz2", "*", 
           RowBox[{"r1", "^", "2"}], "*", 
           RowBox[{"r2", "^", "2"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}], "*", 
           RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
          RowBox[{"14", "*", "coilsigma", "*", 
           RowBox[{"r1", "^", "2"}], "*", 
           RowBox[{"r2", "^", "2"}], "*", "z2", "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}], "*", 
           RowBox[{"Cos", "[", "theta2", "]"}]}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"2", "*", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"r1", "^", "2"}], "+", 
             RowBox[{"r2", "^", "2"}], "-", 
             RowBox[{"2", "*", "r1", "*", "r2", "*", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}], "^", 
           "2"}], "*", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"coilz2", "^", "2"}], "+", 
             RowBox[{"r1", "^", "2"}], "+", 
             RowBox[{"r2", "^", "2"}], "-", 
             RowBox[{"2", "*", "coilz2", "*", "z2"}], "+", 
             RowBox[{"z2", "^", "2"}], "-", 
             RowBox[{"2", "*", "r1", "*", "r2", "*", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}], "^", 
           RowBox[{"(", 
            RowBox[{"3", "/", "2"}], ")"}]}]}], ")"}]}]}], ")"}]}], ",", 
    RowBox[{
     RowBox[{"1", "/", 
      RowBox[{"(", 
       RowBox[{"4", "*", "Pi"}], ")"}]}], "*", "mu0", "*", "mz", "*", "r1", 
     "*", "r2", "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], "*", "coilsigma", "*", 
             RowBox[{"coilz1", "^", "3"}], "*", 
             RowBox[{"r1", "^", "2"}], "*", 
             RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
            RowBox[{"4", "*", "coilsigma", "*", "coilz1", "*", 
             RowBox[{"r1", "^", "4"}], "*", 
             RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
            RowBox[{"5", "*", "coilsigma", "*", "coilz1", "*", 
             RowBox[{"r1", "^", "2"}], "*", 
             RowBox[{"r2", "^", "2"}], "*", 
             RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
            RowBox[{"coilsigma", "*", "coilz1", "*", 
             RowBox[{"r2", "^", "4"}], "*", 
             RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
            RowBox[{"6", "*", "coilsigma", "*", 
             RowBox[{"coilz1", "^", "2"}], "*", 
             RowBox[{"r1", "^", "2"}], "*", "z2", "*", 
             RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
            RowBox[{"4", "*", "coilsigma", "*", 
             RowBox[{"r1", "^", "4"}], "*", "z2", "*", 
             RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
            RowBox[{"5", "*", "coilsigma", "*", 
             RowBox[{"r1", "^", "2"}], "*", 
             RowBox[{"r2", "^", "2"}], "*", "z2", "*", 
             RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
            RowBox[{"coilsigma", "*", 
             RowBox[{"r2", "^", "4"}], "*", "z2", "*", 
             RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
            RowBox[{"6", "*", "coilsigma", "*", "coilz1", "*", 
             RowBox[{"r1", "^", "2"}], "*", 
             RowBox[{"z2", "^", "2"}], "*", 
             RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
            RowBox[{"2", "*", "coilsigma", "*", 
             RowBox[{"r1", "^", "2"}], "*", 
             RowBox[{"z2", "^", "3"}], "*", 
             RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
            RowBox[{"8", "*", "coilsigma", "*", "coilz1", "*", 
             RowBox[{"r1", "^", "3"}], "*", "r2", "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", "theta2"}], "]"}], "*", 
             RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
            RowBox[{"2", "*", "coilsigma", "*", "coilz1", "*", "r1", "*", 
             RowBox[{"r2", "^", "3"}], "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", "theta2"}], "]"}], "*", 
             RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
            RowBox[{"8", "*", "coilsigma", "*", 
             RowBox[{"r1", "^", "3"}], "*", "r2", "*", "z2", "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", "theta2"}], "]"}], "*", 
             RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
            RowBox[{"2", "*", "coilsigma", "*", "r1", "*", 
             RowBox[{"r2", "^", "3"}], "*", "z2", "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", "theta2"}], "]"}], "*", 
             RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
            RowBox[{"2", "*", "coilsigma", "*", 
             RowBox[{"coilz1", "^", "3"}], "*", 
             RowBox[{"r2", "^", "2"}], "*", 
             RowBox[{"Sin", "[", 
              RowBox[{"theta1", "-", 
               RowBox[{"2", "*", "theta2"}]}], "]"}]}], "+", 
            RowBox[{"3", "*", "coilsigma", "*", "coilz1", "*", 
             RowBox[{"r1", "^", "2"}], "*", 
             RowBox[{"r2", "^", "2"}], "*", 
             RowBox[{"Sin", "[", 
              RowBox[{"theta1", "-", 
               RowBox[{"2", "*", "theta2"}]}], "]"}]}], "+", 
            RowBox[{"3", "*", "coilsigma", "*", "coilz1", "*", 
             RowBox[{"r2", "^", "4"}], "*", 
             RowBox[{"Sin", "[", 
              RowBox[{"theta1", "-", 
               RowBox[{"2", "*", "theta2"}]}], "]"}]}], "-", 
            RowBox[{"6", "*", "coilsigma", "*", 
             RowBox[{"coilz1", "^", "2"}], "*", 
             RowBox[{"r2", "^", "2"}], "*", "z2", "*", 
             RowBox[{"Sin", "[", 
              RowBox[{"theta1", "-", 
               RowBox[{"2", "*", "theta2"}]}], "]"}]}], "-", 
            RowBox[{"3", "*", "coilsigma", "*", 
             RowBox[{"r1", "^", "2"}], "*", 
             RowBox[{"r2", "^", "2"}], "*", "z2", "*", 
             RowBox[{"Sin", "[", 
              RowBox[{"theta1", "-", 
               RowBox[{"2", "*", "theta2"}]}], "]"}]}], "-", 
            RowBox[{"3", "*", "coilsigma", "*", 
             RowBox[{"r2", "^", "4"}], "*", "z2", "*", 
             RowBox[{"Sin", "[", 
              RowBox[{"theta1", "-", 
               RowBox[{"2", "*", "theta2"}]}], "]"}]}], "+", 
            RowBox[{"6", "*", "coilsigma", "*", "coilz1", "*", 
             RowBox[{"r2", "^", "2"}], "*", 
             RowBox[{"z2", "^", "2"}], "*", 
             RowBox[{"Sin", "[", 
              RowBox[{"theta1", "-", 
               RowBox[{"2", "*", "theta2"}]}], "]"}]}], "-", 
            RowBox[{"2", "*", "coilsigma", "*", 
             RowBox[{"r2", "^", "2"}], "*", 
             RowBox[{"z2", "^", "3"}], "*", 
             RowBox[{"Sin", "[", 
              RowBox[{"theta1", "-", 
               RowBox[{"2", "*", "theta2"}]}], "]"}]}], "-", 
            RowBox[{"6", "*", "coilsigma", "*", "coilz1", "*", "r1", "*", 
             RowBox[{"r2", "^", "3"}], "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", "theta2"}], "]"}], "*", 
             RowBox[{"Sin", "[", 
              RowBox[{"theta1", "-", 
               RowBox[{"2", "*", "theta2"}]}], "]"}]}], "+", 
            RowBox[{"6", "*", "coilsigma", "*", "r1", "*", 
             RowBox[{"r2", "^", "3"}], "*", "z2", "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", "theta2"}], "]"}], "*", 
             RowBox[{"Sin", "[", 
              RowBox[{"theta1", "-", 
               RowBox[{"2", "*", "theta2"}]}], "]"}]}], "+", 
            RowBox[{"coilsigma", "*", "coilz1", "*", 
             RowBox[{"r1", "^", "3"}], "*", "r2", "*", 
             RowBox[{"Sin", "[", 
              RowBox[{
               RowBox[{"2", "*", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
            RowBox[{"coilsigma", "*", "coilz1", "*", "r1", "*", 
             RowBox[{"r2", "^", "3"}], "*", 
             RowBox[{"Sin", "[", 
              RowBox[{
               RowBox[{"2", "*", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
            RowBox[{"coilsigma", "*", 
             RowBox[{"r1", "^", "3"}], "*", "r2", "*", "z2", "*", 
             RowBox[{"Sin", "[", 
              RowBox[{
               RowBox[{"2", "*", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
            RowBox[{"coilsigma", "*", "r1", "*", 
             RowBox[{"r2", "^", "3"}], "*", "z2", "*", 
             RowBox[{"Sin", "[", 
              RowBox[{
               RowBox[{"2", "*", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
            RowBox[{"2", "*", "coilsigma", "*", "coilz1", "*", 
             RowBox[{"r1", "^", "2"}], "*", 
             RowBox[{"r2", "^", "2"}], "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", "theta2"}], "]"}], "*", 
             RowBox[{"Sin", "[", 
              RowBox[{
               RowBox[{"2", "*", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
            RowBox[{"2", "*", "coilsigma", "*", 
             RowBox[{"r1", "^", "2"}], "*", 
             RowBox[{"r2", "^", "2"}], "*", "z2", "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", "theta2"}], "]"}], "*", 
             RowBox[{"Sin", "[", 
              RowBox[{
               RowBox[{"2", "*", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
            RowBox[{"4", "*", "coilsigma", "*", 
             RowBox[{"coilz1", "^", "3"}], "*", "r1", "*", "r2", "*", 
             RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
            RowBox[{"7", "*", "coilsigma", "*", "coilz1", "*", 
             RowBox[{"r1", "^", "3"}], "*", "r2", "*", 
             RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
            RowBox[{"7", "*", "coilsigma", "*", "coilz1", "*", "r1", "*", 
             RowBox[{"r2", "^", "3"}], "*", 
             RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
            RowBox[{"12", "*", "coilsigma", "*", 
             RowBox[{"coilz1", "^", "2"}], "*", "r1", "*", "r2", "*", "z2", 
             "*", 
             RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
            RowBox[{"7", "*", "coilsigma", "*", 
             RowBox[{"r1", "^", "3"}], "*", "r2", "*", "z2", "*", 
             RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
            RowBox[{"7", "*", "coilsigma", "*", "r1", "*", 
             RowBox[{"r2", "^", "3"}], "*", "z2", "*", 
             RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
            RowBox[{
            "12", "*", "coilsigma", "*", "coilz1", "*", "r1", "*", "r2", "*", 
             
             RowBox[{"z2", "^", "2"}], "*", 
             RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
            RowBox[{"4", "*", "coilsigma", "*", "r1", "*", "r2", "*", 
             RowBox[{"z2", "^", "3"}], "*", 
             RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
            RowBox[{"14", "*", "coilsigma", "*", "coilz1", "*", 
             RowBox[{"r1", "^", "2"}], "*", 
             RowBox[{"r2", "^", "2"}], "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", "theta2"}], "]"}], "*", 
             RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
            RowBox[{"14", "*", "coilsigma", "*", 
             RowBox[{"r1", "^", "2"}], "*", 
             RowBox[{"r2", "^", "2"}], "*", "z2", "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", "theta2"}], "]"}], "*", 
             RowBox[{"Sin", "[", "theta2", "]"}]}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"2", "*", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"r1", "^", "2"}], "+", 
               RowBox[{"r2", "^", "2"}], "-", 
               RowBox[{"2", "*", "r1", "*", "r2", "*", 
                RowBox[{"Cos", "[", 
                 RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}], "^", 
             "2"}], "*", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"coilz1", "^", "2"}], "+", 
               RowBox[{"r1", "^", "2"}], "+", 
               RowBox[{"r2", "^", "2"}], "-", 
               RowBox[{"2", "*", "coilz1", "*", "z2"}], "+", 
               RowBox[{"z2", "^", "2"}], "-", 
               RowBox[{"2", "*", "r1", "*", "r2", "*", 
                RowBox[{"Cos", "[", 
                 RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}], "^", 
             RowBox[{"(", 
              RowBox[{"3", "/", "2"}], ")"}]}]}], ")"}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], "*", "coilsigma", "*", 
           RowBox[{"coilz2", "^", "3"}], "*", 
           RowBox[{"r1", "^", "2"}], "*", 
           RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
          RowBox[{"4", "*", "coilsigma", "*", "coilz2", "*", 
           RowBox[{"r1", "^", "4"}], "*", 
           RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
          RowBox[{"5", "*", "coilsigma", "*", "coilz2", "*", 
           RowBox[{"r1", "^", "2"}], "*", 
           RowBox[{"r2", "^", "2"}], "*", 
           RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
          RowBox[{"coilsigma", "*", "coilz2", "*", 
           RowBox[{"r2", "^", "4"}], "*", 
           RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
          RowBox[{"6", "*", "coilsigma", "*", 
           RowBox[{"coilz2", "^", "2"}], "*", 
           RowBox[{"r1", "^", "2"}], "*", "z2", "*", 
           RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
          RowBox[{"4", "*", "coilsigma", "*", 
           RowBox[{"r1", "^", "4"}], "*", "z2", "*", 
           RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
          RowBox[{"5", "*", "coilsigma", "*", 
           RowBox[{"r1", "^", "2"}], "*", 
           RowBox[{"r2", "^", "2"}], "*", "z2", "*", 
           RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
          RowBox[{"coilsigma", "*", 
           RowBox[{"r2", "^", "4"}], "*", "z2", "*", 
           RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
          RowBox[{"6", "*", "coilsigma", "*", "coilz2", "*", 
           RowBox[{"r1", "^", "2"}], "*", 
           RowBox[{"z2", "^", "2"}], "*", 
           RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
          RowBox[{"2", "*", "coilsigma", "*", 
           RowBox[{"r1", "^", "2"}], "*", 
           RowBox[{"z2", "^", "3"}], "*", 
           RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
          RowBox[{"8", "*", "coilsigma", "*", "coilz2", "*", 
           RowBox[{"r1", "^", "3"}], "*", "r2", "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}], "*", 
           RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
          RowBox[{"2", "*", "coilsigma", "*", "coilz2", "*", "r1", "*", 
           RowBox[{"r2", "^", "3"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}], "*", 
           RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
          RowBox[{"8", "*", "coilsigma", "*", 
           RowBox[{"r1", "^", "3"}], "*", "r2", "*", "z2", "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}], "*", 
           RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
          RowBox[{"2", "*", "coilsigma", "*", "r1", "*", 
           RowBox[{"r2", "^", "3"}], "*", "z2", "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}], "*", 
           RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
          RowBox[{"2", "*", "coilsigma", "*", 
           RowBox[{"coilz2", "^", "3"}], "*", 
           RowBox[{"r2", "^", "2"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", "*", "theta2"}]}], "]"}]}], "+", 
          RowBox[{"3", "*", "coilsigma", "*", "coilz2", "*", 
           RowBox[{"r1", "^", "2"}], "*", 
           RowBox[{"r2", "^", "2"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", "*", "theta2"}]}], "]"}]}], "+", 
          RowBox[{"3", "*", "coilsigma", "*", "coilz2", "*", 
           RowBox[{"r2", "^", "4"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", "*", "theta2"}]}], "]"}]}], "-", 
          RowBox[{"6", "*", "coilsigma", "*", 
           RowBox[{"coilz2", "^", "2"}], "*", 
           RowBox[{"r2", "^", "2"}], "*", "z2", "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", "*", "theta2"}]}], "]"}]}], "-", 
          RowBox[{"3", "*", "coilsigma", "*", 
           RowBox[{"r1", "^", "2"}], "*", 
           RowBox[{"r2", "^", "2"}], "*", "z2", "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", "*", "theta2"}]}], "]"}]}], "-", 
          RowBox[{"3", "*", "coilsigma", "*", 
           RowBox[{"r2", "^", "4"}], "*", "z2", "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", "*", "theta2"}]}], "]"}]}], "+", 
          RowBox[{"6", "*", "coilsigma", "*", "coilz2", "*", 
           RowBox[{"r2", "^", "2"}], "*", 
           RowBox[{"z2", "^", "2"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", "*", "theta2"}]}], "]"}]}], "-", 
          RowBox[{"2", "*", "coilsigma", "*", 
           RowBox[{"r2", "^", "2"}], "*", 
           RowBox[{"z2", "^", "3"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", "*", "theta2"}]}], "]"}]}], "-", 
          RowBox[{"6", "*", "coilsigma", "*", "coilz2", "*", "r1", "*", 
           RowBox[{"r2", "^", "3"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", "*", "theta2"}]}], "]"}]}], "+", 
          RowBox[{"6", "*", "coilsigma", "*", "r1", "*", 
           RowBox[{"r2", "^", "3"}], "*", "z2", "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", "*", "theta2"}]}], "]"}]}], "+", 
          RowBox[{"coilsigma", "*", "coilz2", "*", 
           RowBox[{"r1", "^", "3"}], "*", "r2", "*", 
           RowBox[{"Sin", "[", 
            RowBox[{
             RowBox[{"2", "*", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
          RowBox[{"coilsigma", "*", "coilz2", "*", "r1", "*", 
           RowBox[{"r2", "^", "3"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{
             RowBox[{"2", "*", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
          RowBox[{"coilsigma", "*", 
           RowBox[{"r1", "^", "3"}], "*", "r2", "*", "z2", "*", 
           RowBox[{"Sin", "[", 
            RowBox[{
             RowBox[{"2", "*", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
          RowBox[{"coilsigma", "*", "r1", "*", 
           RowBox[{"r2", "^", "3"}], "*", "z2", "*", 
           RowBox[{"Sin", "[", 
            RowBox[{
             RowBox[{"2", "*", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
          RowBox[{"2", "*", "coilsigma", "*", "coilz2", "*", 
           RowBox[{"r1", "^", "2"}], "*", 
           RowBox[{"r2", "^", "2"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{
             RowBox[{"2", "*", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
          RowBox[{"2", "*", "coilsigma", "*", 
           RowBox[{"r1", "^", "2"}], "*", 
           RowBox[{"r2", "^", "2"}], "*", "z2", "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{
             RowBox[{"2", "*", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
          RowBox[{"4", "*", "coilsigma", "*", 
           RowBox[{"coilz2", "^", "3"}], "*", "r1", "*", "r2", "*", 
           RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
          RowBox[{"7", "*", "coilsigma", "*", "coilz2", "*", 
           RowBox[{"r1", "^", "3"}], "*", "r2", "*", 
           RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
          RowBox[{"7", "*", "coilsigma", "*", "coilz2", "*", "r1", "*", 
           RowBox[{"r2", "^", "3"}], "*", 
           RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
          RowBox[{"12", "*", "coilsigma", "*", 
           RowBox[{"coilz2", "^", "2"}], "*", "r1", "*", "r2", "*", "z2", "*", 
           RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
          RowBox[{"7", "*", "coilsigma", "*", 
           RowBox[{"r1", "^", "3"}], "*", "r2", "*", "z2", "*", 
           RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
          RowBox[{"7", "*", "coilsigma", "*", "r1", "*", 
           RowBox[{"r2", "^", "3"}], "*", "z2", "*", 
           RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
          RowBox[{
          "12", "*", "coilsigma", "*", "coilz2", "*", "r1", "*", "r2", "*", 
           RowBox[{"z2", "^", "2"}], "*", 
           RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
          RowBox[{"4", "*", "coilsigma", "*", "r1", "*", "r2", "*", 
           RowBox[{"z2", "^", "3"}], "*", 
           RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
          RowBox[{"14", "*", "coilsigma", "*", "coilz2", "*", 
           RowBox[{"r1", "^", "2"}], "*", 
           RowBox[{"r2", "^", "2"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}], "*", 
           RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
          RowBox[{"14", "*", "coilsigma", "*", 
           RowBox[{"r1", "^", "2"}], "*", 
           RowBox[{"r2", "^", "2"}], "*", "z2", "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}], "*", 
           RowBox[{"Sin", "[", "theta2", "]"}]}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"2", "*", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"r1", "^", "2"}], "+", 
             RowBox[{"r2", "^", "2"}], "-", 
             RowBox[{"2", "*", "r1", "*", "r2", "*", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}], "^", 
           "2"}], "*", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"coilz2", "^", "2"}], "+", 
             RowBox[{"r1", "^", "2"}], "+", 
             RowBox[{"r2", "^", "2"}], "-", 
             RowBox[{"2", "*", "coilz2", "*", "z2"}], "+", 
             RowBox[{"z2", "^", "2"}], "-", 
             RowBox[{"2", "*", "r1", "*", "r2", "*", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}], "^", 
           RowBox[{"(", 
            RowBox[{"3", "/", "2"}], ")"}]}]}], ")"}]}]}], ")"}]}], ",", 
    RowBox[{
     RowBox[{"1", "/", 
      RowBox[{"(", 
       RowBox[{"4", "*", "Pi"}], ")"}]}], "*", "mu0", "*", "mz", "*", "r1", 
     "*", "r2", "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"coilsigma", "*", 
            RowBox[{"(", 
             RowBox[{"r1", "-", 
              RowBox[{"r2", "*", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}]}], ")"}], 
          "/", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"coilz1", "^", "2"}], "+", 
             RowBox[{"r1", "^", "2"}], "+", 
             RowBox[{"r2", "^", "2"}], "-", 
             RowBox[{"2", "*", "coilz1", "*", "z2"}], "+", 
             RowBox[{"z2", "^", "2"}], "-", 
             RowBox[{"2", "*", "r1", "*", "r2", "*", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}], "^", 
           RowBox[{"(", 
            RowBox[{"3", "/", "2"}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"coilsigma", "*", 
          RowBox[{"(", 
           RowBox[{"r1", "-", 
            RowBox[{"r2", "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}]}], ")"}], 
        "/", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"coilz2", "^", "2"}], "+", 
           RowBox[{"r1", "^", "2"}], "+", 
           RowBox[{"r2", "^", "2"}], "-", 
           RowBox[{"2", "*", "coilz2", "*", "z2"}], "+", 
           RowBox[{"z2", "^", "2"}], "-", 
           RowBox[{"2", "*", "r1", "*", "r2", "*", 
            RowBox[{"Cos", "[", 
             RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}], "^", 
         RowBox[{"(", 
          RowBox[{"3", "/", "2"}], ")"}]}]}]}], ")"}]}]}], "}"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["1", 
     RowBox[{"4", " ", "\[Pi]"}]], 
    RowBox[{"mu0", " ", "mz", " ", "r1", " ", "r2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", "coilsigma", " ", 
             SuperscriptBox["coilz1", "3"], " ", 
             SuperscriptBox["r1", "2"], " ", 
             RowBox[{"Cos", "[", "theta1", "]"}]}], "-", 
            RowBox[{"4", " ", "coilsigma", " ", "coilz1", " ", 
             SuperscriptBox["r1", "4"], " ", 
             RowBox[{"Cos", "[", "theta1", "]"}]}], "-", 
            RowBox[{"5", " ", "coilsigma", " ", "coilz1", " ", 
             SuperscriptBox["r1", "2"], " ", 
             SuperscriptBox["r2", "2"], " ", 
             RowBox[{"Cos", "[", "theta1", "]"}]}], "-", 
            RowBox[{"coilsigma", " ", "coilz1", " ", 
             SuperscriptBox["r2", "4"], " ", 
             RowBox[{"Cos", "[", "theta1", "]"}]}], "+", 
            RowBox[{"6", " ", "coilsigma", " ", 
             SuperscriptBox["coilz1", "2"], " ", 
             SuperscriptBox["r1", "2"], " ", "z2", " ", 
             RowBox[{"Cos", "[", "theta1", "]"}]}], "+", 
            RowBox[{"4", " ", "coilsigma", " ", 
             SuperscriptBox["r1", "4"], " ", "z2", " ", 
             RowBox[{"Cos", "[", "theta1", "]"}]}], "+", 
            RowBox[{"5", " ", "coilsigma", " ", 
             SuperscriptBox["r1", "2"], " ", 
             SuperscriptBox["r2", "2"], " ", "z2", " ", 
             RowBox[{"Cos", "[", "theta1", "]"}]}], "+", 
            RowBox[{"coilsigma", " ", 
             SuperscriptBox["r2", "4"], " ", "z2", " ", 
             RowBox[{"Cos", "[", "theta1", "]"}]}], "-", 
            RowBox[{"6", " ", "coilsigma", " ", "coilz1", " ", 
             SuperscriptBox["r1", "2"], " ", 
             SuperscriptBox["z2", "2"], " ", 
             RowBox[{"Cos", "[", "theta1", "]"}]}], "+", 
            RowBox[{"2", " ", "coilsigma", " ", 
             SuperscriptBox["r1", "2"], " ", 
             SuperscriptBox["z2", "3"], " ", 
             RowBox[{"Cos", "[", "theta1", "]"}]}], "-", 
            RowBox[{"2", " ", "coilsigma", " ", 
             SuperscriptBox["coilz1", "3"], " ", 
             SuperscriptBox["r2", "2"], " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", 
               RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
            RowBox[{"3", " ", "coilsigma", " ", "coilz1", " ", 
             SuperscriptBox["r1", "2"], " ", 
             SuperscriptBox["r2", "2"], " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", 
               RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
            RowBox[{"3", " ", "coilsigma", " ", "coilz1", " ", 
             SuperscriptBox["r2", "4"], " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", 
               RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
            RowBox[{"6", " ", "coilsigma", " ", 
             SuperscriptBox["coilz1", "2"], " ", 
             SuperscriptBox["r2", "2"], " ", "z2", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", 
               RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
            RowBox[{"3", " ", "coilsigma", " ", 
             SuperscriptBox["r1", "2"], " ", 
             SuperscriptBox["r2", "2"], " ", "z2", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", 
               RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
            RowBox[{"3", " ", "coilsigma", " ", 
             SuperscriptBox["r2", "4"], " ", "z2", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", 
               RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
            RowBox[{"6", " ", "coilsigma", " ", "coilz1", " ", 
             SuperscriptBox["r2", "2"], " ", 
             SuperscriptBox["z2", "2"], " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", 
               RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
            RowBox[{"2", " ", "coilsigma", " ", 
             SuperscriptBox["r2", "2"], " ", 
             SuperscriptBox["z2", "3"], " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", 
               RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
            RowBox[{"8", " ", "coilsigma", " ", "coilz1", " ", 
             SuperscriptBox["r1", "3"], " ", "r2", " ", 
             RowBox[{"Cos", "[", "theta1", "]"}], " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", "theta2"}], "]"}]}], "+", 
            RowBox[{"2", " ", "coilsigma", " ", "coilz1", " ", "r1", " ", 
             SuperscriptBox["r2", "3"], " ", 
             RowBox[{"Cos", "[", "theta1", "]"}], " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", "theta2"}], "]"}]}], "-", 
            RowBox[{"8", " ", "coilsigma", " ", 
             SuperscriptBox["r1", "3"], " ", "r2", " ", "z2", " ", 
             RowBox[{"Cos", "[", "theta1", "]"}], " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", "theta2"}], "]"}]}], "-", 
            RowBox[{"2", " ", "coilsigma", " ", "r1", " ", 
             SuperscriptBox["r2", "3"], " ", "z2", " ", 
             RowBox[{"Cos", "[", "theta1", "]"}], " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", "theta2"}], "]"}]}], "+", 
            RowBox[{"6", " ", "coilsigma", " ", "coilz1", " ", "r1", " ", 
             SuperscriptBox["r2", "3"], " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", 
               RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", "theta2"}], "]"}]}], "-", 
            RowBox[{"6", " ", "coilsigma", " ", "r1", " ", 
             SuperscriptBox["r2", "3"], " ", "z2", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", 
               RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", "theta2"}], "]"}]}], "+", 
            RowBox[{"coilsigma", " ", "coilz1", " ", 
             SuperscriptBox["r1", "3"], " ", "r2", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{
               RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
            RowBox[{"coilsigma", " ", "coilz1", " ", "r1", " ", 
             SuperscriptBox["r2", "3"], " ", 
             RowBox[{"Cos", "[", 
              RowBox[{
               RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
            RowBox[{"coilsigma", " ", 
             SuperscriptBox["r1", "3"], " ", "r2", " ", "z2", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{
               RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
            RowBox[{"coilsigma", " ", "r1", " ", 
             SuperscriptBox["r2", "3"], " ", "z2", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{
               RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
            RowBox[{"2", " ", "coilsigma", " ", "coilz1", " ", 
             SuperscriptBox["r1", "2"], " ", 
             SuperscriptBox["r2", "2"], " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
             RowBox[{"Cos", "[", 
              RowBox[{
               RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
            RowBox[{"2", " ", "coilsigma", " ", 
             SuperscriptBox["r1", "2"], " ", 
             SuperscriptBox["r2", "2"], " ", "z2", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
             RowBox[{"Cos", "[", 
              RowBox[{
               RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
            RowBox[{"4", " ", "coilsigma", " ", 
             SuperscriptBox["coilz1", "3"], " ", "r1", " ", "r2", " ", 
             RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
            RowBox[{"7", " ", "coilsigma", " ", "coilz1", " ", 
             SuperscriptBox["r1", "3"], " ", "r2", " ", 
             RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
            RowBox[{"7", " ", "coilsigma", " ", "coilz1", " ", "r1", " ", 
             SuperscriptBox["r2", "3"], " ", 
             RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
            RowBox[{"12", " ", "coilsigma", " ", 
             SuperscriptBox["coilz1", "2"], " ", "r1", " ", "r2", " ", "z2", 
             " ", 
             RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
            RowBox[{"7", " ", "coilsigma", " ", 
             SuperscriptBox["r1", "3"], " ", "r2", " ", "z2", " ", 
             RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
            RowBox[{"7", " ", "coilsigma", " ", "r1", " ", 
             SuperscriptBox["r2", "3"], " ", "z2", " ", 
             RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
            RowBox[{
            "12", " ", "coilsigma", " ", "coilz1", " ", "r1", " ", "r2", " ", 
             
             SuperscriptBox["z2", "2"], " ", 
             RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
            RowBox[{"4", " ", "coilsigma", " ", "r1", " ", "r2", " ", 
             SuperscriptBox["z2", "3"], " ", 
             RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
            RowBox[{"14", " ", "coilsigma", " ", "coilz1", " ", 
             SuperscriptBox["r1", "2"], " ", 
             SuperscriptBox["r2", "2"], " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
             RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
            RowBox[{"14", " ", "coilsigma", " ", 
             SuperscriptBox["r1", "2"], " ", 
             SuperscriptBox["r2", "2"], " ", "z2", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
             RowBox[{"Cos", "[", "theta2", "]"}]}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"2", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["r1", "2"], "+", 
               SuperscriptBox["r2", "2"], "-", 
               RowBox[{"2", " ", "r1", " ", "r2", " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}], "2"], 
            " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["coilz1", "2"], "+", 
               SuperscriptBox["r1", "2"], "+", 
               SuperscriptBox["r2", "2"], "-", 
               RowBox[{"2", " ", "coilz1", " ", "z2"}], "+", 
               SuperscriptBox["z2", "2"], "-", 
               RowBox[{"2", " ", "r1", " ", "r2", " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}], 
             RowBox[{"3", "/", "2"}]]}], ")"}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", "coilsigma", " ", 
           SuperscriptBox["coilz2", "3"], " ", 
           SuperscriptBox["r1", "2"], " ", 
           RowBox[{"Cos", "[", "theta1", "]"}]}], "-", 
          RowBox[{"4", " ", "coilsigma", " ", "coilz2", " ", 
           SuperscriptBox["r1", "4"], " ", 
           RowBox[{"Cos", "[", "theta1", "]"}]}], "-", 
          RowBox[{"5", " ", "coilsigma", " ", "coilz2", " ", 
           SuperscriptBox["r1", "2"], " ", 
           SuperscriptBox["r2", "2"], " ", 
           RowBox[{"Cos", "[", "theta1", "]"}]}], "-", 
          RowBox[{"coilsigma", " ", "coilz2", " ", 
           SuperscriptBox["r2", "4"], " ", 
           RowBox[{"Cos", "[", "theta1", "]"}]}], "+", 
          RowBox[{"6", " ", "coilsigma", " ", 
           SuperscriptBox["coilz2", "2"], " ", 
           SuperscriptBox["r1", "2"], " ", "z2", " ", 
           RowBox[{"Cos", "[", "theta1", "]"}]}], "+", 
          RowBox[{"4", " ", "coilsigma", " ", 
           SuperscriptBox["r1", "4"], " ", "z2", " ", 
           RowBox[{"Cos", "[", "theta1", "]"}]}], "+", 
          RowBox[{"5", " ", "coilsigma", " ", 
           SuperscriptBox["r1", "2"], " ", 
           SuperscriptBox["r2", "2"], " ", "z2", " ", 
           RowBox[{"Cos", "[", "theta1", "]"}]}], "+", 
          RowBox[{"coilsigma", " ", 
           SuperscriptBox["r2", "4"], " ", "z2", " ", 
           RowBox[{"Cos", "[", "theta1", "]"}]}], "-", 
          RowBox[{"6", " ", "coilsigma", " ", "coilz2", " ", 
           SuperscriptBox["r1", "2"], " ", 
           SuperscriptBox["z2", "2"], " ", 
           RowBox[{"Cos", "[", "theta1", "]"}]}], "+", 
          RowBox[{"2", " ", "coilsigma", " ", 
           SuperscriptBox["r1", "2"], " ", 
           SuperscriptBox["z2", "3"], " ", 
           RowBox[{"Cos", "[", "theta1", "]"}]}], "-", 
          RowBox[{"2", " ", "coilsigma", " ", 
           SuperscriptBox["coilz2", "3"], " ", 
           SuperscriptBox["r2", "2"], " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
          RowBox[{"3", " ", "coilsigma", " ", "coilz2", " ", 
           SuperscriptBox["r1", "2"], " ", 
           SuperscriptBox["r2", "2"], " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
          RowBox[{"3", " ", "coilsigma", " ", "coilz2", " ", 
           SuperscriptBox["r2", "4"], " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
          RowBox[{"6", " ", "coilsigma", " ", 
           SuperscriptBox["coilz2", "2"], " ", 
           SuperscriptBox["r2", "2"], " ", "z2", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
          RowBox[{"3", " ", "coilsigma", " ", 
           SuperscriptBox["r1", "2"], " ", 
           SuperscriptBox["r2", "2"], " ", "z2", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
          RowBox[{"3", " ", "coilsigma", " ", 
           SuperscriptBox["r2", "4"], " ", "z2", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
          RowBox[{"6", " ", "coilsigma", " ", "coilz2", " ", 
           SuperscriptBox["r2", "2"], " ", 
           SuperscriptBox["z2", "2"], " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
          RowBox[{"2", " ", "coilsigma", " ", 
           SuperscriptBox["r2", "2"], " ", 
           SuperscriptBox["z2", "3"], " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
          RowBox[{"8", " ", "coilsigma", " ", "coilz2", " ", 
           SuperscriptBox["r1", "3"], " ", "r2", " ", 
           RowBox[{"Cos", "[", "theta1", "]"}], " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}]}], "+", 
          RowBox[{"2", " ", "coilsigma", " ", "coilz2", " ", "r1", " ", 
           SuperscriptBox["r2", "3"], " ", 
           RowBox[{"Cos", "[", "theta1", "]"}], " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}]}], "-", 
          RowBox[{"8", " ", "coilsigma", " ", 
           SuperscriptBox["r1", "3"], " ", "r2", " ", "z2", " ", 
           RowBox[{"Cos", "[", "theta1", "]"}], " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}]}], "-", 
          RowBox[{"2", " ", "coilsigma", " ", "r1", " ", 
           SuperscriptBox["r2", "3"], " ", "z2", " ", 
           RowBox[{"Cos", "[", "theta1", "]"}], " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}]}], "+", 
          RowBox[{"6", " ", "coilsigma", " ", "coilz2", " ", "r1", " ", 
           SuperscriptBox["r2", "3"], " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}]}], "-", 
          RowBox[{"6", " ", "coilsigma", " ", "r1", " ", 
           SuperscriptBox["r2", "3"], " ", "z2", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}]}], "+", 
          RowBox[{"coilsigma", " ", "coilz2", " ", 
           SuperscriptBox["r1", "3"], " ", "r2", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{
             RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
          RowBox[{"coilsigma", " ", "coilz2", " ", "r1", " ", 
           SuperscriptBox["r2", "3"], " ", 
           RowBox[{"Cos", "[", 
            RowBox[{
             RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
          RowBox[{"coilsigma", " ", 
           SuperscriptBox["r1", "3"], " ", "r2", " ", "z2", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{
             RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
          RowBox[{"coilsigma", " ", "r1", " ", 
           SuperscriptBox["r2", "3"], " ", "z2", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{
             RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
          RowBox[{"2", " ", "coilsigma", " ", "coilz2", " ", 
           SuperscriptBox["r1", "2"], " ", 
           SuperscriptBox["r2", "2"], " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
           RowBox[{"Cos", "[", 
            RowBox[{
             RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
          RowBox[{"2", " ", "coilsigma", " ", 
           SuperscriptBox["r1", "2"], " ", 
           SuperscriptBox["r2", "2"], " ", "z2", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
           RowBox[{"Cos", "[", 
            RowBox[{
             RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
          RowBox[{"4", " ", "coilsigma", " ", 
           SuperscriptBox["coilz2", "3"], " ", "r1", " ", "r2", " ", 
           RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
          RowBox[{"7", " ", "coilsigma", " ", "coilz2", " ", 
           SuperscriptBox["r1", "3"], " ", "r2", " ", 
           RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
          RowBox[{"7", " ", "coilsigma", " ", "coilz2", " ", "r1", " ", 
           SuperscriptBox["r2", "3"], " ", 
           RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
          RowBox[{"12", " ", "coilsigma", " ", 
           SuperscriptBox["coilz2", "2"], " ", "r1", " ", "r2", " ", "z2", 
           " ", 
           RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
          RowBox[{"7", " ", "coilsigma", " ", 
           SuperscriptBox["r1", "3"], " ", "r2", " ", "z2", " ", 
           RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
          RowBox[{"7", " ", "coilsigma", " ", "r1", " ", 
           SuperscriptBox["r2", "3"], " ", "z2", " ", 
           RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
          RowBox[{
          "12", " ", "coilsigma", " ", "coilz2", " ", "r1", " ", "r2", " ", 
           SuperscriptBox["z2", "2"], " ", 
           RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
          RowBox[{"4", " ", "coilsigma", " ", "r1", " ", "r2", " ", 
           SuperscriptBox["z2", "3"], " ", 
           RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
          RowBox[{"14", " ", "coilsigma", " ", "coilz2", " ", 
           SuperscriptBox["r1", "2"], " ", 
           SuperscriptBox["r2", "2"], " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
           RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
          RowBox[{"14", " ", "coilsigma", " ", 
           SuperscriptBox["r1", "2"], " ", 
           SuperscriptBox["r2", "2"], " ", "z2", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
           RowBox[{"Cos", "[", "theta2", "]"}]}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["r1", "2"], "+", 
             SuperscriptBox["r2", "2"], "-", 
             RowBox[{"2", " ", "r1", " ", "r2", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["coilz2", "2"], "+", 
             SuperscriptBox["r1", "2"], "+", 
             SuperscriptBox["r2", "2"], "-", 
             RowBox[{"2", " ", "coilz2", " ", "z2"}], "+", 
             SuperscriptBox["z2", "2"], "-", 
             RowBox[{"2", " ", "r1", " ", "r2", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}], 
           RowBox[{"3", "/", "2"}]]}], ")"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"4", " ", "\[Pi]"}]], 
    RowBox[{"mu0", " ", "mz", " ", "r1", " ", "r2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", "coilsigma", " ", 
             SuperscriptBox["coilz1", "3"], " ", 
             SuperscriptBox["r1", "2"], " ", 
             RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
            RowBox[{"4", " ", "coilsigma", " ", "coilz1", " ", 
             SuperscriptBox["r1", "4"], " ", 
             RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
            RowBox[{"5", " ", "coilsigma", " ", "coilz1", " ", 
             SuperscriptBox["r1", "2"], " ", 
             SuperscriptBox["r2", "2"], " ", 
             RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
            RowBox[{"coilsigma", " ", "coilz1", " ", 
             SuperscriptBox["r2", "4"], " ", 
             RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
            RowBox[{"6", " ", "coilsigma", " ", 
             SuperscriptBox["coilz1", "2"], " ", 
             SuperscriptBox["r1", "2"], " ", "z2", " ", 
             RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
            RowBox[{"4", " ", "coilsigma", " ", 
             SuperscriptBox["r1", "4"], " ", "z2", " ", 
             RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
            RowBox[{"5", " ", "coilsigma", " ", 
             SuperscriptBox["r1", "2"], " ", 
             SuperscriptBox["r2", "2"], " ", "z2", " ", 
             RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
            RowBox[{"coilsigma", " ", 
             SuperscriptBox["r2", "4"], " ", "z2", " ", 
             RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
            RowBox[{"6", " ", "coilsigma", " ", "coilz1", " ", 
             SuperscriptBox["r1", "2"], " ", 
             SuperscriptBox["z2", "2"], " ", 
             RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
            RowBox[{"2", " ", "coilsigma", " ", 
             SuperscriptBox["r1", "2"], " ", 
             SuperscriptBox["z2", "3"], " ", 
             RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
            RowBox[{"8", " ", "coilsigma", " ", "coilz1", " ", 
             SuperscriptBox["r1", "3"], " ", "r2", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
             RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
            RowBox[{"2", " ", "coilsigma", " ", "coilz1", " ", "r1", " ", 
             SuperscriptBox["r2", "3"], " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
             RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
            RowBox[{"8", " ", "coilsigma", " ", 
             SuperscriptBox["r1", "3"], " ", "r2", " ", "z2", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
             RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
            RowBox[{"2", " ", "coilsigma", " ", "r1", " ", 
             SuperscriptBox["r2", "3"], " ", "z2", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
             RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
            RowBox[{"2", " ", "coilsigma", " ", 
             SuperscriptBox["coilz1", "3"], " ", 
             SuperscriptBox["r2", "2"], " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"theta1", "-", 
               RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
            RowBox[{"3", " ", "coilsigma", " ", "coilz1", " ", 
             SuperscriptBox["r1", "2"], " ", 
             SuperscriptBox["r2", "2"], " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"theta1", "-", 
               RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
            RowBox[{"3", " ", "coilsigma", " ", "coilz1", " ", 
             SuperscriptBox["r2", "4"], " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"theta1", "-", 
               RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
            RowBox[{"6", " ", "coilsigma", " ", 
             SuperscriptBox["coilz1", "2"], " ", 
             SuperscriptBox["r2", "2"], " ", "z2", " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"theta1", "-", 
               RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
            RowBox[{"3", " ", "coilsigma", " ", 
             SuperscriptBox["r1", "2"], " ", 
             SuperscriptBox["r2", "2"], " ", "z2", " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"theta1", "-", 
               RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
            RowBox[{"3", " ", "coilsigma", " ", 
             SuperscriptBox["r2", "4"], " ", "z2", " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"theta1", "-", 
               RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
            RowBox[{"6", " ", "coilsigma", " ", "coilz1", " ", 
             SuperscriptBox["r2", "2"], " ", 
             SuperscriptBox["z2", "2"], " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"theta1", "-", 
               RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
            RowBox[{"2", " ", "coilsigma", " ", 
             SuperscriptBox["r2", "2"], " ", 
             SuperscriptBox["z2", "3"], " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"theta1", "-", 
               RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
            RowBox[{"6", " ", "coilsigma", " ", "coilz1", " ", "r1", " ", 
             SuperscriptBox["r2", "3"], " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"theta1", "-", 
               RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
            RowBox[{"6", " ", "coilsigma", " ", "r1", " ", 
             SuperscriptBox["r2", "3"], " ", "z2", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"theta1", "-", 
               RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
            RowBox[{"coilsigma", " ", "coilz1", " ", 
             SuperscriptBox["r1", "3"], " ", "r2", " ", 
             RowBox[{"Sin", "[", 
              RowBox[{
               RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
            RowBox[{"coilsigma", " ", "coilz1", " ", "r1", " ", 
             SuperscriptBox["r2", "3"], " ", 
             RowBox[{"Sin", "[", 
              RowBox[{
               RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
            RowBox[{"coilsigma", " ", 
             SuperscriptBox["r1", "3"], " ", "r2", " ", "z2", " ", 
             RowBox[{"Sin", "[", 
              RowBox[{
               RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
            RowBox[{"coilsigma", " ", "r1", " ", 
             SuperscriptBox["r2", "3"], " ", "z2", " ", 
             RowBox[{"Sin", "[", 
              RowBox[{
               RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
            RowBox[{"2", " ", "coilsigma", " ", "coilz1", " ", 
             SuperscriptBox["r1", "2"], " ", 
             SuperscriptBox["r2", "2"], " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
             RowBox[{"Sin", "[", 
              RowBox[{
               RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
            RowBox[{"2", " ", "coilsigma", " ", 
             SuperscriptBox["r1", "2"], " ", 
             SuperscriptBox["r2", "2"], " ", "z2", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
             RowBox[{"Sin", "[", 
              RowBox[{
               RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
            RowBox[{"4", " ", "coilsigma", " ", 
             SuperscriptBox["coilz1", "3"], " ", "r1", " ", "r2", " ", 
             RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
            RowBox[{"7", " ", "coilsigma", " ", "coilz1", " ", 
             SuperscriptBox["r1", "3"], " ", "r2", " ", 
             RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
            RowBox[{"7", " ", "coilsigma", " ", "coilz1", " ", "r1", " ", 
             SuperscriptBox["r2", "3"], " ", 
             RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
            RowBox[{"12", " ", "coilsigma", " ", 
             SuperscriptBox["coilz1", "2"], " ", "r1", " ", "r2", " ", "z2", 
             " ", 
             RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
            RowBox[{"7", " ", "coilsigma", " ", 
             SuperscriptBox["r1", "3"], " ", "r2", " ", "z2", " ", 
             RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
            RowBox[{"7", " ", "coilsigma", " ", "r1", " ", 
             SuperscriptBox["r2", "3"], " ", "z2", " ", 
             RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
            RowBox[{
            "12", " ", "coilsigma", " ", "coilz1", " ", "r1", " ", "r2", " ", 
             
             SuperscriptBox["z2", "2"], " ", 
             RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
            RowBox[{"4", " ", "coilsigma", " ", "r1", " ", "r2", " ", 
             SuperscriptBox["z2", "3"], " ", 
             RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
            RowBox[{"14", " ", "coilsigma", " ", "coilz1", " ", 
             SuperscriptBox["r1", "2"], " ", 
             SuperscriptBox["r2", "2"], " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
             RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
            RowBox[{"14", " ", "coilsigma", " ", 
             SuperscriptBox["r1", "2"], " ", 
             SuperscriptBox["r2", "2"], " ", "z2", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
             RowBox[{"Sin", "[", "theta2", "]"}]}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"2", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["r1", "2"], "+", 
               SuperscriptBox["r2", "2"], "-", 
               RowBox[{"2", " ", "r1", " ", "r2", " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}], "2"], 
            " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["coilz1", "2"], "+", 
               SuperscriptBox["r1", "2"], "+", 
               SuperscriptBox["r2", "2"], "-", 
               RowBox[{"2", " ", "coilz1", " ", "z2"}], "+", 
               SuperscriptBox["z2", "2"], "-", 
               RowBox[{"2", " ", "r1", " ", "r2", " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}], 
             RowBox[{"3", "/", "2"}]]}], ")"}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", "coilsigma", " ", 
           SuperscriptBox["coilz2", "3"], " ", 
           SuperscriptBox["r1", "2"], " ", 
           RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
          RowBox[{"4", " ", "coilsigma", " ", "coilz2", " ", 
           SuperscriptBox["r1", "4"], " ", 
           RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
          RowBox[{"5", " ", "coilsigma", " ", "coilz2", " ", 
           SuperscriptBox["r1", "2"], " ", 
           SuperscriptBox["r2", "2"], " ", 
           RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
          RowBox[{"coilsigma", " ", "coilz2", " ", 
           SuperscriptBox["r2", "4"], " ", 
           RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
          RowBox[{"6", " ", "coilsigma", " ", 
           SuperscriptBox["coilz2", "2"], " ", 
           SuperscriptBox["r1", "2"], " ", "z2", " ", 
           RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
          RowBox[{"4", " ", "coilsigma", " ", 
           SuperscriptBox["r1", "4"], " ", "z2", " ", 
           RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
          RowBox[{"5", " ", "coilsigma", " ", 
           SuperscriptBox["r1", "2"], " ", 
           SuperscriptBox["r2", "2"], " ", "z2", " ", 
           RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
          RowBox[{"coilsigma", " ", 
           SuperscriptBox["r2", "4"], " ", "z2", " ", 
           RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
          RowBox[{"6", " ", "coilsigma", " ", "coilz2", " ", 
           SuperscriptBox["r1", "2"], " ", 
           SuperscriptBox["z2", "2"], " ", 
           RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
          RowBox[{"2", " ", "coilsigma", " ", 
           SuperscriptBox["r1", "2"], " ", 
           SuperscriptBox["z2", "3"], " ", 
           RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
          RowBox[{"8", " ", "coilsigma", " ", "coilz2", " ", 
           SuperscriptBox["r1", "3"], " ", "r2", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
           RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
          RowBox[{"2", " ", "coilsigma", " ", "coilz2", " ", "r1", " ", 
           SuperscriptBox["r2", "3"], " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
           RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
          RowBox[{"8", " ", "coilsigma", " ", 
           SuperscriptBox["r1", "3"], " ", "r2", " ", "z2", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
           RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
          RowBox[{"2", " ", "coilsigma", " ", "r1", " ", 
           SuperscriptBox["r2", "3"], " ", "z2", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
           RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
          RowBox[{"2", " ", "coilsigma", " ", 
           SuperscriptBox["coilz2", "3"], " ", 
           SuperscriptBox["r2", "2"], " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
          RowBox[{"3", " ", "coilsigma", " ", "coilz2", " ", 
           SuperscriptBox["r1", "2"], " ", 
           SuperscriptBox["r2", "2"], " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
          RowBox[{"3", " ", "coilsigma", " ", "coilz2", " ", 
           SuperscriptBox["r2", "4"], " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
          RowBox[{"6", " ", "coilsigma", " ", 
           SuperscriptBox["coilz2", "2"], " ", 
           SuperscriptBox["r2", "2"], " ", "z2", " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
          RowBox[{"3", " ", "coilsigma", " ", 
           SuperscriptBox["r1", "2"], " ", 
           SuperscriptBox["r2", "2"], " ", "z2", " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
          RowBox[{"3", " ", "coilsigma", " ", 
           SuperscriptBox["r2", "4"], " ", "z2", " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
          RowBox[{"6", " ", "coilsigma", " ", "coilz2", " ", 
           SuperscriptBox["r2", "2"], " ", 
           SuperscriptBox["z2", "2"], " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
          RowBox[{"2", " ", "coilsigma", " ", 
           SuperscriptBox["r2", "2"], " ", 
           SuperscriptBox["z2", "3"], " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
          RowBox[{"6", " ", "coilsigma", " ", "coilz2", " ", "r1", " ", 
           SuperscriptBox["r2", "3"], " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
          RowBox[{"6", " ", "coilsigma", " ", "r1", " ", 
           SuperscriptBox["r2", "3"], " ", "z2", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"theta1", "-", 
             RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
          RowBox[{"coilsigma", " ", "coilz2", " ", 
           SuperscriptBox["r1", "3"], " ", "r2", " ", 
           RowBox[{"Sin", "[", 
            RowBox[{
             RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
          RowBox[{"coilsigma", " ", "coilz2", " ", "r1", " ", 
           SuperscriptBox["r2", "3"], " ", 
           RowBox[{"Sin", "[", 
            RowBox[{
             RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
          RowBox[{"coilsigma", " ", 
           SuperscriptBox["r1", "3"], " ", "r2", " ", "z2", " ", 
           RowBox[{"Sin", "[", 
            RowBox[{
             RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
          RowBox[{"coilsigma", " ", "r1", " ", 
           SuperscriptBox["r2", "3"], " ", "z2", " ", 
           RowBox[{"Sin", "[", 
            RowBox[{
             RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
          RowBox[{"2", " ", "coilsigma", " ", "coilz2", " ", 
           SuperscriptBox["r1", "2"], " ", 
           SuperscriptBox["r2", "2"], " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
           RowBox[{"Sin", "[", 
            RowBox[{
             RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
          RowBox[{"2", " ", "coilsigma", " ", 
           SuperscriptBox["r1", "2"], " ", 
           SuperscriptBox["r2", "2"], " ", "z2", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
           RowBox[{"Sin", "[", 
            RowBox[{
             RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
          RowBox[{"4", " ", "coilsigma", " ", 
           SuperscriptBox["coilz2", "3"], " ", "r1", " ", "r2", " ", 
           RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
          RowBox[{"7", " ", "coilsigma", " ", "coilz2", " ", 
           SuperscriptBox["r1", "3"], " ", "r2", " ", 
           RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
          RowBox[{"7", " ", "coilsigma", " ", "coilz2", " ", "r1", " ", 
           SuperscriptBox["r2", "3"], " ", 
           RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
          RowBox[{"12", " ", "coilsigma", " ", 
           SuperscriptBox["coilz2", "2"], " ", "r1", " ", "r2", " ", "z2", 
           " ", 
           RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
          RowBox[{"7", " ", "coilsigma", " ", 
           SuperscriptBox["r1", "3"], " ", "r2", " ", "z2", " ", 
           RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
          RowBox[{"7", " ", "coilsigma", " ", "r1", " ", 
           SuperscriptBox["r2", "3"], " ", "z2", " ", 
           RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
          RowBox[{
          "12", " ", "coilsigma", " ", "coilz2", " ", "r1", " ", "r2", " ", 
           SuperscriptBox["z2", "2"], " ", 
           RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
          RowBox[{"4", " ", "coilsigma", " ", "r1", " ", "r2", " ", 
           SuperscriptBox["z2", "3"], " ", 
           RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
          RowBox[{"14", " ", "coilsigma", " ", "coilz2", " ", 
           SuperscriptBox["r1", "2"], " ", 
           SuperscriptBox["r2", "2"], " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
           RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
          RowBox[{"14", " ", "coilsigma", " ", 
           SuperscriptBox["r1", "2"], " ", 
           SuperscriptBox["r2", "2"], " ", "z2", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
           RowBox[{"Sin", "[", "theta2", "]"}]}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["r1", "2"], "+", 
             SuperscriptBox["r2", "2"], "-", 
             RowBox[{"2", " ", "r1", " ", "r2", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["coilz2", "2"], "+", 
             SuperscriptBox["r1", "2"], "+", 
             SuperscriptBox["r2", "2"], "-", 
             RowBox[{"2", " ", "coilz2", " ", "z2"}], "+", 
             SuperscriptBox["z2", "2"], "-", 
             RowBox[{"2", " ", "r1", " ", "r2", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}], 
           RowBox[{"3", "/", "2"}]]}], ")"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"4", " ", "\[Pi]"}]], 
    RowBox[{"mu0", " ", "mz", " ", "r1", " ", "r2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"coilsigma", " ", 
          RowBox[{"(", 
           RowBox[{"r1", "-", 
            RowBox[{"r2", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["coilz1", "2"], "+", 
            SuperscriptBox["r1", "2"], "+", 
            SuperscriptBox["r2", "2"], "-", 
            RowBox[{"2", " ", "coilz1", " ", "z2"}], "+", 
            SuperscriptBox["z2", "2"], "-", 
            RowBox[{"2", " ", "r1", " ", "r2", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}], 
          RowBox[{"3", "/", "2"}]]]}], "+", 
       FractionBox[
        RowBox[{"coilsigma", " ", 
         RowBox[{"(", 
          RowBox[{"r1", "-", 
           RowBox[{"r2", " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}]}], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["coilz2", "2"], "+", 
           SuperscriptBox["r1", "2"], "+", 
           SuperscriptBox["r2", "2"], "-", 
           RowBox[{"2", " ", "coilz2", " ", "z2"}], "+", 
           SuperscriptBox["z2", "2"], "-", 
           RowBox[{"2", " ", "r1", " ", "r2", " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}], 
         RowBox[{"3", "/", "2"}]]]}], ")"}]}]}]}], "}"}]], "Output",
 InitializationCell->True,
 CellChangeTimes->{
  3.4537496006556683`*^9, 3.453749665383189*^9, 3.4638444826352386`*^9, {
   3.47889440630746*^9, 3.478894421499799*^9}, 3.47896034120792*^9, 
   3.479485741522573*^9, 3.479486053209323*^9, 3.479658382577471*^9, 
   3.48008256522371*^9, 3.480243676559482*^9, 3.480692247239079*^9, 
   3.481566006301805*^9, 3.481940914621936*^9, 3.481941021808659*^9, 
   3.481941923682448*^9, 3.6297594154318953`*^9, 3.6297679613716927`*^9, 
   3.630209797234396*^9, 3.630288014794797*^9, 3.6302982173209333`*^9, 
   3.630319401576219*^9, 3.6304697925211573`*^9, 3.631828015053546*^9, 
   3.6338335372930737`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Actual calculation", "Text",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"fdr1dr2dtheta1dtheta2dz2", " ", "=", " ", 
   RowBox[{"If", "[", "\[InvisibleSpace]", 
    RowBox[{
     RowBox[{"!", "useprecomputed"}], ",", 
     RowBox[{"Integrate", "[", 
      RowBox[{"fdr1dr2dtheta1dtheta2dz1dz2", ",", 
       RowBox[{"{", 
        RowBox[{"z1", ",", "coilz1", ",", "coilz2"}], "}"}]}], "]"}], ",", 
     "fdr1dr2dtheta1dtheta2dz2pre"}], "]"}]}], ";"}]], "Input",
 InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Do z2 integral analytically", "Text",
 InitializationCell->True],

Cell[CellGroupData[{

Cell["Precomputed result (HUGE!!!)", "Text",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"fdr1dr2dtheta1dtheta2pre", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", 
       RowBox[{"4", " ", "\[Pi]"}]], 
      RowBox[{"(", 
       RowBox[{"mu0", " ", "mz", " ", "r1", " ", "r2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "16"}], " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["coilz2", "2"], " ", "l", " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"4", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"4", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"4", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["l", "3"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"4", " ", "coilsigma", " ", "coilz2", " ", 
               SuperscriptBox["l", "3"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"coilsigma", " ", 
               SuperscriptBox["l", "4"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "pos", " ", 
               
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["coilz2", "2"], " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{
              "64", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", "l", 
               " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"24", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["l", "2"], " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"24", " ", "coilsigma", " ", "coilz2", " ", 
               SuperscriptBox["l", "2"], " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["l", "3"], " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{
              "64", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"48", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"48", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"24", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["pos", "3"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", "coilz2", " ", 
               SuperscriptBox["pos", "3"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", "l", " ", 
               SuperscriptBox["pos", "3"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "4"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["r1", "4"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["r1", "4"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"4", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "4"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
               SuperscriptBox["r1", "4"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "4"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "4"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"2", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "4"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"2", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["r2", "6"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["coilz2", "2"], " ", "l", " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"4", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"4", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"4", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["l", "3"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"4", " ", "coilsigma", " ", "coilz2", " ", 
               SuperscriptBox["l", "3"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"coilsigma", " ", 
               SuperscriptBox["l", "4"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "pos", " ", 
               
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["coilz2", "2"], " ", "pos", " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "l", " ", "pos", " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{
              "64", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", "l", 
               " ", "pos", " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", "l", " ", "pos", " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"24", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["l", "2"], " ", "pos", " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"24", " ", "coilsigma", " ", "coilz2", " ", 
               SuperscriptBox["l", "2"], " ", "pos", " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["l", "3"], " ", "pos", " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{
              "64", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"48", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"48", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"24", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["pos", "3"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", "coilz2", " ", 
               SuperscriptBox["pos", "3"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", "l", " ", 
               SuperscriptBox["pos", "3"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "4"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"6", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"24", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"24", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "4"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"6", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"24", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"24", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["r2", "6"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{
              "64", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz2", " ", "l", " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"4", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", "r1", 
               " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{
              "16", " ", "coilsigma", " ", "l", " ", "pos", " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "3"], " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", "r1", " ", 
               SuperscriptBox["r2", "5"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz1", " ", "l", " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz2", " ", "l", " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"12", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{
              "64", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", "r1", 
               " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", "r1", 
               " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{
              "48", " ", "coilsigma", " ", "l", " ", "pos", " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"48", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "3"], " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", "r1", " ", 
               SuperscriptBox["r2", "5"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                 RowBox[{"theta1", "-", "theta2"}], "]"}], "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                 RowBox[{"theta1", "-", "theta2"}], "]"}], "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["coilz2", "2"], " ", "l", " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"4", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"4", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"4", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["l", "3"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"4", " ", "coilsigma", " ", "coilz2", " ", 
               SuperscriptBox["l", "3"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"coilsigma", " ", 
               SuperscriptBox["l", "4"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "pos", " ", 
               
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["coilz2", "2"], " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{
              "64", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", "l", 
               " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"24", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["l", "2"], " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"24", " ", "coilsigma", " ", "coilz2", " ", 
               SuperscriptBox["l", "2"], " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["l", "3"], " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{
              "64", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"48", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"48", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"24", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["pos", "3"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", "coilz2", " ", 
               SuperscriptBox["pos", "3"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", "l", " ", 
               SuperscriptBox["pos", "3"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "4"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r1", "4"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r1", "4"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"4", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "4"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
               SuperscriptBox["r1", "4"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "4"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "4"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"2", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "4"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"2", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["r2", "6"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["coilz2", "2"], " ", "l", " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"4", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"4", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"4", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["l", "3"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"4", " ", "coilsigma", " ", "coilz2", " ", 
               SuperscriptBox["l", "3"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"coilsigma", " ", 
               SuperscriptBox["l", "4"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "pos", " ", 
               
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["coilz2", "2"], " ", "pos", " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "l", " ", "pos", " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{
              "64", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", "l", 
               " ", "pos", " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", "l", " ", "pos", " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"24", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["l", "2"], " ", "pos", " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"24", " ", "coilsigma", " ", "coilz2", " ", 
               SuperscriptBox["l", "2"], " ", "pos", " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["l", "3"], " ", "pos", " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{
              "64", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"48", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"48", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"24", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["pos", "3"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", "coilz2", " ", 
               SuperscriptBox["pos", "3"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", "l", " ", 
               SuperscriptBox["pos", "3"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "4"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"6", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"24", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"24", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "4"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"6", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"24", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"24", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["r2", "6"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{
              "64", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz1", " ", "l", " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"4", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", "r1", 
               " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{
              "16", " ", "coilsigma", " ", "l", " ", "pos", " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "3"], " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", "r1", " ", 
               SuperscriptBox["r2", "5"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz1", " ", "l", " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz2", " ", "l", " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"12", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", "r1", 
               " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{
              "64", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", "r1", 
               " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{
              "48", " ", "coilsigma", " ", "l", " ", "pos", " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"48", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "3"], " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", "r1", " ", 
               SuperscriptBox["r2", "5"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", "theta1", "]"}], " ", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                 RowBox[{"theta1", "-", "theta2"}], "]"}], "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                 RowBox[{"theta1", "-", "theta2"}], "]"}], "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{"8", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{"2", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"8", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "5"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{
              "8", " ", "coilsigma", " ", "coilz2", " ", "l", " ", "r1", " ", 
               
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{"2", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", "r1", 
               " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{
              "8", " ", "coilsigma", " ", "l", " ", "pos", " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "3"], " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{"8", " ", "coilsigma", " ", "r1", " ", 
               SuperscriptBox["r2", "5"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"16", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"4", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{"16", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "4"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "3"], " ", 
               SuperscriptBox["r2", "3"], " ", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                 RowBox[{"theta1", "-", "theta2"}], "]"}], "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"8", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"2", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{"8", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "5"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{
              "8", " ", "coilsigma", " ", "coilz1", " ", "l", " ", "r1", " ", 
               
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"2", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", "r1", 
               " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{
              "8", " ", "coilsigma", " ", "l", " ", "pos", " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "3"], " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"8", " ", "coilsigma", " ", "r1", " ", 
               SuperscriptBox["r2", "5"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{"4", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"16", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "4"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "3"], " ", 
               SuperscriptBox["r2", "3"], " ", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                 RowBox[{"theta1", "-", "theta2"}], "]"}], "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["coilz2", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "l", " ", 
               "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["coilz2", "2"], " ", "l", " ", "r1", " ", "r2", 
               " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["l", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
               SuperscriptBox["l", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["l", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["l", "3"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", "coilz2", " ", 
               SuperscriptBox["l", "3"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"2", " ", "coilsigma", " ", 
               SuperscriptBox["l", "4"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"64", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "pos", " ", 
               "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"64", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["coilz2", "2"], " ", "pos", " ", "r1", " ", 
               "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "l", " ", "pos", " ", "r1",
                " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{
              "128", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", "l",
                " ", "pos", " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", "l", " ", "pos", " ", "r1",
                " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"48", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["l", "2"], " ", "pos", " ", "r1", " ", "r2", 
               " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"48", " ", "coilsigma", " ", "coilz2", " ", 
               SuperscriptBox["l", "2"], " ", "pos", " ", "r1", " ", "r2", 
               " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["l", "3"], " ", "pos", " ", "r1", " ", "r2", 
               " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{
              "128", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"96", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"96", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"48", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"64", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["pos", "3"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"64", " ", "coilsigma", " ", "coilz2", " ", 
               SuperscriptBox["pos", "3"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"64", " ", "coilsigma", " ", "l", " ", 
               SuperscriptBox["pos", "3"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "4"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"10", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{
              "64", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"40", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"40", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "5"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz1", " ", "l", " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{
              "8", " ", "coilsigma", " ", "coilz2", " ", "l", " ", "r1", " ", 
               
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"10", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{
              "64", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", "r1", 
               " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", "r1", 
               " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{
              "40", " ", "coilsigma", " ", "l", " ", "pos", " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"40", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "3"], " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", "r1", " ", 
               SuperscriptBox["r2", "5"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"64", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"64", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"20", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"128", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"80", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"80", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "4"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "3"], " ", 
               SuperscriptBox["r2", "3"], " ", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                 RowBox[{"theta1", "-", "theta2"}], "]"}], "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["coilz2", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "l", " ", 
               "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["coilz2", "2"], " ", "l", " ", "r1", " ", "r2", 
               " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["l", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
               SuperscriptBox["l", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["l", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["l", "3"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", "coilz2", " ", 
               SuperscriptBox["l", "3"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"2", " ", "coilsigma", " ", 
               SuperscriptBox["l", "4"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"64", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "pos", " ", 
               "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"64", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["coilz2", "2"], " ", "pos", " ", "r1", " ", 
               "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "l", " ", "pos", " ", "r1",
                " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{
              "128", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", "l",
                " ", "pos", " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", "l", " ", "pos", " ", "r1",
                " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"48", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["l", "2"], " ", "pos", " ", "r1", " ", "r2", 
               " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"48", " ", "coilsigma", " ", "coilz2", " ", 
               SuperscriptBox["l", "2"], " ", "pos", " ", "r1", " ", "r2", 
               " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["l", "3"], " ", "pos", " ", "r1", " ", "r2", 
               " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{
              "128", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"96", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"96", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"48", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"64", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["pos", "3"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"64", " ", "coilsigma", " ", "coilz2", " ", 
               SuperscriptBox["pos", "3"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"64", " ", "coilsigma", " ", "l", " ", 
               SuperscriptBox["pos", "3"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "4"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"10", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{
              "64", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"40", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"40", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "5"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{
              "8", " ", "coilsigma", " ", "coilz1", " ", "l", " ", "r1", " ", 
               
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz2", " ", "l", " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"10", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", "r1", 
               " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{
              "64", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", "r1", 
               " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{
              "40", " ", "coilsigma", " ", "l", " ", "pos", " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"40", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "3"], " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", "r1", " ", 
               SuperscriptBox["r2", "5"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"64", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"64", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"20", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"128", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"80", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"80", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "4"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "3"], " ", 
               SuperscriptBox["r2", "3"], " ", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                 RowBox[{"theta1", "-", "theta2"}], "]"}], "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Cos", "[", "theta2", "]"}]}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"4", " ", 
                 SuperscriptBox["coilz1", "2"]}], "+", 
                RowBox[{"4", " ", "coilz1", " ", "l"}], "+", 
                SuperscriptBox["l", "2"], "-", 
                RowBox[{"8", " ", "coilz1", " ", "pos"}], "-", 
                RowBox[{"4", " ", "l", " ", "pos"}], "+", 
                RowBox[{"4", " ", 
                 SuperscriptBox["pos", "2"]}], "+", 
                RowBox[{"4", " ", 
                 SuperscriptBox["r1", "2"]}], "+", 
                RowBox[{"4", " ", 
                 SuperscriptBox["r2", "2"]}], "-", 
                RowBox[{"8", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"4", " ", 
                 SuperscriptBox["coilz2", "2"]}], "+", 
                RowBox[{"4", " ", "coilz2", " ", "l"}], "+", 
                SuperscriptBox["l", "2"], "-", 
                RowBox[{"8", " ", "coilz2", " ", "pos"}], "-", 
                RowBox[{"4", " ", "l", " ", "pos"}], "+", 
                RowBox[{"4", " ", 
                 SuperscriptBox["pos", "2"]}], "+", 
                RowBox[{"4", " ", 
                 SuperscriptBox["r1", "2"]}], "+", 
                RowBox[{"4", " ", 
                 SuperscriptBox["r2", "2"]}], "-", 
                RowBox[{"8", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}], " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}], 
               "2"]}], ")"}]}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "16"}], " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["coilz2", "2"], " ", "l", " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"4", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{
             "16", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"4", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"4", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["l", "3"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"4", " ", "coilsigma", " ", "coilz2", " ", 
              SuperscriptBox["l", "3"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"coilsigma", " ", 
              SuperscriptBox["l", "4"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["coilz2", "2"], " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{
             "64", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", "l", 
              " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"24", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["l", "2"], " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"24", " ", "coilsigma", " ", "coilz2", " ", 
              SuperscriptBox["l", "2"], " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["l", "3"], " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{
             "64", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"48", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"48", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"24", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["pos", "3"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz2", " ", 
              SuperscriptBox["pos", "3"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "l", " ", 
              SuperscriptBox["pos", "3"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "4"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["r1", "4"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["r1", "4"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"4", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "4"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
              SuperscriptBox["r1", "4"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "4"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "4"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"2", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "4"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"2", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["r2", "6"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["coilz2", "2"], " ", "l", " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"4", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{
             "16", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"4", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"4", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["l", "3"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"4", " ", "coilsigma", " ", "coilz2", " ", 
              SuperscriptBox["l", "3"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"coilsigma", " ", 
              SuperscriptBox["l", "4"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["coilz2", "2"], " ", "pos", " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "l", " ", "pos", " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{
             "64", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", "l", 
              " ", "pos", " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", "l", " ", "pos", " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"24", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["l", "2"], " ", "pos", " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"24", " ", "coilsigma", " ", "coilz2", " ", 
              SuperscriptBox["l", "2"], " ", "pos", " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["l", "3"], " ", "pos", " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{
             "64", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"48", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"48", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"24", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["pos", "3"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz2", " ", 
              SuperscriptBox["pos", "3"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "l", " ", 
              SuperscriptBox["pos", "3"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "4"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"6", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"24", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"24", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "4"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"6", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"24", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"24", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["r2", "6"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"64", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{
             "16", " ", "coilsigma", " ", "coilz2", " ", "l", " ", "r1", " ", 
              
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"4", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{
             "32", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", "r1", 
              " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{
             "16", " ", "coilsigma", " ", "l", " ", "pos", " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "3"], " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "r1", " ", 
              SuperscriptBox["r2", "5"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{
             "32", " ", "coilsigma", " ", "coilz1", " ", "l", " ", "r1", " ", 
              
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{
             "16", " ", "coilsigma", " ", "coilz2", " ", "l", " ", "r1", " ", 
              
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"12", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{
             "64", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", "r1", 
              " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{
             "32", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", "r1", 
              " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{
             "48", " ", "coilsigma", " ", "l", " ", "pos", " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"48", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "3"], " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "r1", " ", 
              SuperscriptBox["r2", "5"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["coilz2", "2"], " ", "l", " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"4", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{
             "16", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"4", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"4", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["l", "3"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"4", " ", "coilsigma", " ", "coilz2", " ", 
              SuperscriptBox["l", "3"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"coilsigma", " ", 
              SuperscriptBox["l", "4"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["coilz2", "2"], " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{
             "64", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", "l", 
              " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"24", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["l", "2"], " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"24", " ", "coilsigma", " ", "coilz2", " ", 
              SuperscriptBox["l", "2"], " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["l", "3"], " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{
             "64", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"48", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"48", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"24", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["pos", "3"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz2", " ", 
              SuperscriptBox["pos", "3"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "l", " ", 
              SuperscriptBox["pos", "3"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "4"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r1", "4"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r1", "4"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"4", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "4"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r1", "4"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "4"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "4"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"2", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "4"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"2", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["r2", "6"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["coilz2", "2"], " ", "l", " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"4", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{
             "16", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"4", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"4", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["l", "3"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"4", " ", "coilsigma", " ", "coilz2", " ", 
              SuperscriptBox["l", "3"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"coilsigma", " ", 
              SuperscriptBox["l", "4"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["coilz2", "2"], " ", "pos", " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "l", " ", "pos", " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{
             "64", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", "l", 
              " ", "pos", " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", "l", " ", "pos", " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"24", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["l", "2"], " ", "pos", " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"24", " ", "coilsigma", " ", "coilz2", " ", 
              SuperscriptBox["l", "2"], " ", "pos", " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["l", "3"], " ", "pos", " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{
             "64", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"48", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"48", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"24", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["pos", "3"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz2", " ", 
              SuperscriptBox["pos", "3"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "l", " ", 
              SuperscriptBox["pos", "3"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "4"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"6", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"24", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"24", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "4"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"6", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"24", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"24", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["r2", "6"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"64", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{
             "16", " ", "coilsigma", " ", "coilz1", " ", "l", " ", "r1", " ", 
              
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"4", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{
             "32", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", "r1", 
              " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{
             "16", " ", "coilsigma", " ", "l", " ", "pos", " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "3"], " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "r1", " ", 
              SuperscriptBox["r2", "5"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{
             "16", " ", "coilsigma", " ", "coilz1", " ", "l", " ", "r1", " ", 
              
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{
             "32", " ", "coilsigma", " ", "coilz2", " ", "l", " ", "r1", " ", 
              
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"12", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{
             "32", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", "r1", 
              " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{
             "64", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", "r1", 
              " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{
             "48", " ", "coilsigma", " ", "l", " ", "pos", " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"48", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "3"], " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "r1", " ", 
              SuperscriptBox["r2", "5"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", "theta1", "]"}], " ", 
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}], " ", 
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"2", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "5"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{
             "8", " ", "coilsigma", " ", "coilz2", " ", "l", " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"2", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{
             "16", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", "r1", 
              " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{
             "8", " ", "coilsigma", " ", "l", " ", "pos", " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "3"], " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", "r1", " ", 
              SuperscriptBox["r2", "5"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"4", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "4"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "3"], " ", 
              SuperscriptBox["r2", "3"], " ", 
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"2", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "5"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{
             "8", " ", "coilsigma", " ", "coilz1", " ", "l", " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"2", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{
             "16", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", "r1", 
              " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{
             "8", " ", "coilsigma", " ", "l", " ", "pos", " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "3"], " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", "r1", " ", 
              SuperscriptBox["r2", "5"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"4", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "4"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "3"], " ", 
              SuperscriptBox["r2", "3"], " ", 
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["coilz2", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "l", " ", 
              "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["coilz2", "2"], " ", "l", " ", "r1", " ", "r2", 
              " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["l", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{
             "32", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
              SuperscriptBox["l", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["l", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["l", "3"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", "coilz2", " ", 
              SuperscriptBox["l", "3"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"2", " ", "coilsigma", " ", 
              SuperscriptBox["l", "4"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"64", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "pos", " ", 
              "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"64", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["coilz2", "2"], " ", "pos", " ", "r1", " ", "r2",
               " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "l", " ", "pos", " ", "r1", 
              " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{
             "128", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", "l", 
              " ", "pos", " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", "l", " ", "pos", " ", "r1", 
              " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"48", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["l", "2"], " ", "pos", " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"48", " ", "coilsigma", " ", "coilz2", " ", 
              SuperscriptBox["l", "2"], " ", "pos", " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["l", "3"], " ", "pos", " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{
             "128", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"96", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"96", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"48", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"64", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["pos", "3"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"64", " ", "coilsigma", " ", "coilz2", " ", 
              SuperscriptBox["pos", "3"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"64", " ", "coilsigma", " ", "l", " ", 
              SuperscriptBox["pos", "3"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "4"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"10", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"64", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"40", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"40", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "5"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{
             "32", " ", "coilsigma", " ", "coilz1", " ", "l", " ", "r1", " ", 
              
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{
             "8", " ", "coilsigma", " ", "coilz2", " ", "l", " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"10", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{
             "64", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", "r1", 
              " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{
             "16", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", "r1", 
              " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{
             "40", " ", "coilsigma", " ", "l", " ", "pos", " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"40", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "3"], " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", "r1", " ", 
              SuperscriptBox["r2", "5"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"64", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"64", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"20", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{
             "128", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"80", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"80", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "4"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "3"], " ", 
              SuperscriptBox["r2", "3"], " ", 
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["coilz2", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "l", " ", 
              "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["coilz2", "2"], " ", "l", " ", "r1", " ", "r2", 
              " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["l", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{
             "32", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
              SuperscriptBox["l", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["l", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["l", "3"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", "coilz2", " ", 
              SuperscriptBox["l", "3"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"2", " ", "coilsigma", " ", 
              SuperscriptBox["l", "4"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"64", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "pos", " ", 
              "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"64", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["coilz2", "2"], " ", "pos", " ", "r1", " ", "r2",
               " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "l", " ", "pos", " ", "r1", 
              " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{
             "128", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", "l", 
              " ", "pos", " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", "l", " ", "pos", " ", "r1", 
              " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"48", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["l", "2"], " ", "pos", " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"48", " ", "coilsigma", " ", "coilz2", " ", 
              SuperscriptBox["l", "2"], " ", "pos", " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["l", "3"], " ", "pos", " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{
             "128", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"96", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"96", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"48", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"64", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["pos", "3"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"64", " ", "coilsigma", " ", "coilz2", " ", 
              SuperscriptBox["pos", "3"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"64", " ", "coilsigma", " ", "l", " ", 
              SuperscriptBox["pos", "3"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "4"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"10", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"64", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"40", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"40", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "5"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{
             "8", " ", "coilsigma", " ", "coilz1", " ", "l", " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{
             "32", " ", "coilsigma", " ", "coilz2", " ", "l", " ", "r1", " ", 
              
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"10", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{
             "16", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", "r1", 
              " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{
             "64", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", "r1", 
              " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{
             "40", " ", "coilsigma", " ", "l", " ", "pos", " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"40", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "3"], " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", "r1", " ", 
              SuperscriptBox["r2", "5"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"64", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"64", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"20", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{
             "128", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"80", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"80", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "4"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "3"], " ", 
              SuperscriptBox["r2", "3"], " ", 
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Cos", "[", "theta2", "]"}]}]}], ")"}], "/", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", " ", 
                SuperscriptBox["coilz1", "2"]}], "-", 
               RowBox[{"4", " ", "coilz1", " ", "l"}], "+", 
               SuperscriptBox["l", "2"], "-", 
               RowBox[{"8", " ", "coilz1", " ", "pos"}], "+", 
               RowBox[{"4", " ", "l", " ", "pos"}], "+", 
               RowBox[{"4", " ", 
                SuperscriptBox["pos", "2"]}], "+", 
               RowBox[{"4", " ", 
                SuperscriptBox["r1", "2"]}], "+", 
               RowBox[{"4", " ", 
                SuperscriptBox["r2", "2"]}], "-", 
               RowBox[{"8", " ", "r1", " ", "r2", " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", " ", 
                SuperscriptBox["coilz2", "2"]}], "-", 
               RowBox[{"4", " ", "coilz2", " ", "l"}], "+", 
               SuperscriptBox["l", "2"], "-", 
               RowBox[{"8", " ", "coilz2", " ", "pos"}], "+", 
               RowBox[{"4", " ", "l", " ", "pos"}], "+", 
               RowBox[{"4", " ", 
                SuperscriptBox["pos", "2"]}], "+", 
               RowBox[{"4", " ", 
                SuperscriptBox["r1", "2"]}], "+", 
               RowBox[{"4", " ", 
                SuperscriptBox["r2", "2"]}], "-", 
               RowBox[{"8", " ", "r1", " ", "r2", " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}], "2"]}],
             ")"}]}]}], ")"}]}], ")"}]}], ",", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"4", " ", "\[Pi]"}]], 
      RowBox[{"(", 
       RowBox[{"mu0", " ", "mz", " ", "r1", " ", "r2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "16"}], " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["coilz2", "2"], " ", "l", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"4", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"4", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"4", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["l", "3"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"4", " ", "coilsigma", " ", "coilz2", " ", 
               SuperscriptBox["l", "3"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"coilsigma", " ", 
               SuperscriptBox["l", "4"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "pos", " ", 
               
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["coilz2", "2"], " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{
              "64", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", "l", 
               " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"24", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["l", "2"], " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"24", " ", "coilsigma", " ", "coilz2", " ", 
               SuperscriptBox["l", "2"], " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["l", "3"], " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{
              "64", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"48", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"48", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"24", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["pos", "3"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", "coilz2", " ", 
               SuperscriptBox["pos", "3"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", "l", " ", 
               SuperscriptBox["pos", "3"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "4"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["r1", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["r1", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"4", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
               SuperscriptBox["r1", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"2", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "4"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r2", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"2", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
               SuperscriptBox["r2", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r2", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["r2", "6"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{
              "64", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz2", " ", "l", " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"4", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", "r1", 
               " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{
              "16", " ", "coilsigma", " ", "l", " ", "pos", " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "3"], " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", "r1", " ", 
               SuperscriptBox["r2", "5"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                 RowBox[{"theta1", "-", "theta2"}], "]"}], "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["coilz2", "2"], " ", "l", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"4", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"4", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"4", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["l", "3"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"4", " ", "coilsigma", " ", "coilz2", " ", 
               SuperscriptBox["l", "3"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"coilsigma", " ", 
               SuperscriptBox["l", "4"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "pos", " ", 
               
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["coilz2", "2"], " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{
              "64", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", "l", 
               " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"24", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["l", "2"], " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"24", " ", "coilsigma", " ", "coilz2", " ", 
               SuperscriptBox["l", "2"], " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["l", "3"], " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{
              "64", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"48", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"48", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"24", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["pos", "3"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", "coilz2", " ", 
               SuperscriptBox["pos", "3"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", "l", " ", 
               SuperscriptBox["pos", "3"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "4"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r1", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r1", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"4", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
               SuperscriptBox["r1", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"2", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "4"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["r2", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"2", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
               SuperscriptBox["r2", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r2", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["r2", "6"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{
              "64", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz1", " ", "l", " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"4", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", "r1", 
               " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{
              "16", " ", "coilsigma", " ", "l", " ", "pos", " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "3"], " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", "r1", " ", 
               SuperscriptBox["r2", "5"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                 RowBox[{"theta1", "-", "theta2"}], "]"}], "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["coilz2", "2"], " ", "l", " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"4", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"4", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"4", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["l", "3"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"4", " ", "coilsigma", " ", "coilz2", " ", 
               SuperscriptBox["l", "3"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"coilsigma", " ", 
               SuperscriptBox["l", "4"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "pos", " ", 
               
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["coilz2", "2"], " ", "pos", " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "l", " ", "pos", " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{
              "64", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", "l", 
               " ", "pos", " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", "l", " ", "pos", " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"24", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["l", "2"], " ", "pos", " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"24", " ", "coilsigma", " ", "coilz2", " ", 
               SuperscriptBox["l", "2"], " ", "pos", " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["l", "3"], " ", "pos", " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{
              "64", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"48", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"48", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"24", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["pos", "3"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", "coilz2", " ", 
               SuperscriptBox["pos", "3"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", "l", " ", 
               SuperscriptBox["pos", "3"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "4"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"6", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"24", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"24", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "4"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["r2", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r2", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"6", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
               SuperscriptBox["r2", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
               SuperscriptBox["r2", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"24", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r2", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"24", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["r2", "6"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz1", " ", "l", " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz2", " ", "l", " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"12", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{
              "64", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", "r1", 
               " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", "r1", 
               " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{
              "48", " ", "coilsigma", " ", "l", " ", "pos", " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"48", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "3"], " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", "r1", " ", 
               SuperscriptBox["r2", "5"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                 RowBox[{"theta1", "-", "theta2"}], "]"}], "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["coilz2", "2"], " ", "l", " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"4", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"4", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"4", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["l", "3"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"4", " ", "coilsigma", " ", "coilz2", " ", 
               SuperscriptBox["l", "3"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"coilsigma", " ", 
               SuperscriptBox["l", "4"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "pos", " ", 
               
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["coilz2", "2"], " ", "pos", " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "l", " ", "pos", " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{
              "64", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", "l", 
               " ", "pos", " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", "l", " ", "pos", " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"24", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["l", "2"], " ", "pos", " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"24", " ", "coilsigma", " ", "coilz2", " ", 
               SuperscriptBox["l", "2"], " ", "pos", " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["l", "3"], " ", "pos", " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{
              "64", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"48", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"48", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"24", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["pos", "3"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", "coilz2", " ", 
               SuperscriptBox["pos", "3"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", "l", " ", 
               SuperscriptBox["pos", "3"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "4"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"6", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"24", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"24", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "4"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["r2", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r2", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"6", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
               SuperscriptBox["r2", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
               SuperscriptBox["r2", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"24", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r2", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"24", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["r2", "6"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz1", " ", "l", " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz2", " ", "l", " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"12", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", "r1", 
               " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{
              "64", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", "r1", 
               " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{
              "48", " ", "coilsigma", " ", "l", " ", "pos", " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"48", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "3"], " ", 
               SuperscriptBox["r2", "3"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", "r1", " ", 
               SuperscriptBox["r2", "5"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                 RowBox[{"theta1", "-", "theta2"}], "]"}], "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"theta1", "-", 
                 RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{"8", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{"2", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"8", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "5"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{
              "8", " ", "coilsigma", " ", "coilz2", " ", "l", " ", "r1", " ", 
               
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{"2", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", "r1", 
               " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{
              "8", " ", "coilsigma", " ", "l", " ", "pos", " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "3"], " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{"8", " ", "coilsigma", " ", "r1", " ", 
               SuperscriptBox["r2", "5"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"16", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"4", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{"16", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "4"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "3"], " ", 
               SuperscriptBox["r2", "3"], " ", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                 RowBox[{"theta1", "-", "theta2"}], "]"}], "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"8", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"2", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{"8", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "5"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{
              "8", " ", "coilsigma", " ", "coilz1", " ", "l", " ", "r1", " ", 
               
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"2", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", "r1", 
               " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{
              "8", " ", "coilsigma", " ", "l", " ", "pos", " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "3"], " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"8", " ", "coilsigma", " ", "r1", " ", 
               SuperscriptBox["r2", "5"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{"4", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"16", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "4"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
              
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "3"], " ", 
               SuperscriptBox["r2", "3"], " ", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                 RowBox[{"theta1", "-", "theta2"}], "]"}], "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
              
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["coilz2", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "l", " ", 
               "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["coilz2", "2"], " ", "l", " ", "r1", " ", "r2", 
               " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["l", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
               SuperscriptBox["l", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["l", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["l", "3"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", "coilz2", " ", 
               SuperscriptBox["l", "3"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"2", " ", "coilsigma", " ", 
               SuperscriptBox["l", "4"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"64", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "pos", " ", 
               "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"64", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["coilz2", "2"], " ", "pos", " ", "r1", " ", 
               "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "l", " ", "pos", " ", "r1",
                " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{
              "128", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", "l",
                " ", "pos", " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", "l", " ", "pos", " ", "r1",
                " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"48", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["l", "2"], " ", "pos", " ", "r1", " ", "r2", 
               " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"48", " ", "coilsigma", " ", "coilz2", " ", 
               SuperscriptBox["l", "2"], " ", "pos", " ", "r1", " ", "r2", 
               " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["l", "3"], " ", "pos", " ", "r1", " ", "r2", 
               " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{
              "128", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"96", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"96", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"48", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"64", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["pos", "3"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"64", " ", "coilsigma", " ", "coilz2", " ", 
               SuperscriptBox["pos", "3"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"64", " ", "coilsigma", " ", "l", " ", 
               SuperscriptBox["pos", "3"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "4"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"10", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{
              "64", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"40", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"40", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "5"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz1", " ", "l", " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{
              "8", " ", "coilsigma", " ", "coilz2", " ", "l", " ", "r1", " ", 
               
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"10", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{
              "64", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", "r1", 
               " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", "r1", 
               " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{
              "40", " ", "coilsigma", " ", "l", " ", "pos", " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"40", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "3"], " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"8", " ", "coilsigma", " ", "r1", " ", 
               SuperscriptBox["r2", "5"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"64", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"64", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"20", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"128", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"80", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"80", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "4"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "3"], " ", 
               SuperscriptBox["r2", "3"], " ", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                 RowBox[{"theta1", "-", "theta2"}], "]"}], "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["coilz2", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "l", " ", 
               "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["coilz2", "2"], " ", "l", " ", "r1", " ", "r2", 
               " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["l", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
               SuperscriptBox["l", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["l", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["l", "3"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", "coilz2", " ", 
               SuperscriptBox["l", "3"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"2", " ", "coilsigma", " ", 
               SuperscriptBox["l", "4"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"64", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "pos", " ", 
               "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"64", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["coilz2", "2"], " ", "pos", " ", "r1", " ", 
               "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "l", " ", "pos", " ", "r1",
                " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{
              "128", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", "l",
                " ", "pos", " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", "l", " ", "pos", " ", "r1",
                " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"48", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["l", "2"], " ", "pos", " ", "r1", " ", "r2", 
               " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"48", " ", "coilsigma", " ", "coilz2", " ", 
               SuperscriptBox["l", "2"], " ", "pos", " ", "r1", " ", "r2", 
               " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["l", "3"], " ", "pos", " ", "r1", " ", "r2", 
               " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{
              "128", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"96", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"96", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"48", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"64", " ", "coilsigma", " ", "coilz1", " ", 
               SuperscriptBox["pos", "3"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"64", " ", "coilsigma", " ", "coilz2", " ", 
               SuperscriptBox["pos", "3"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"64", " ", "coilsigma", " ", "l", " ", 
               SuperscriptBox["pos", "3"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "4"], " ", "r1", " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"10", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{
              "64", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"40", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"40", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "3"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "5"], " ", "r2", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{
              "8", " ", "coilsigma", " ", "coilz1", " ", "l", " ", "r1", " ", 
               
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz2", " ", "l", " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"10", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{
              "16", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", "r1", 
               " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{
              "64", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", "r1", 
               " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{
              "40", " ", "coilsigma", " ", "l", " ", "pos", " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"40", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", "r1", " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "3"], " ", 
               SuperscriptBox["r2", "3"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"8", " ", "coilsigma", " ", "r1", " ", 
               SuperscriptBox["r2", "5"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", 
               SuperscriptBox["coilz1", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"64", " ", "coilsigma", " ", 
               SuperscriptBox["coilz2", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"64", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"20", " ", "coilsigma", " ", 
               SuperscriptBox["l", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{
              "32", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"128", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"80", " ", "coilsigma", " ", "l", " ", "pos", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"80", " ", "coilsigma", " ", 
               SuperscriptBox["pos", "2"], " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "4"], " ", 
               SuperscriptBox["r2", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "2"], " ", 
               SuperscriptBox["r2", "4"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
              RowBox[{"32", " ", "coilsigma", " ", 
               SuperscriptBox["r1", "3"], " ", 
               SuperscriptBox["r2", "3"], " ", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                 RowBox[{"theta1", "-", "theta2"}], "]"}], "2"], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
               RowBox[{"Sin", "[", "theta2", "]"}]}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"4", " ", 
                 SuperscriptBox["coilz1", "2"]}], "+", 
                RowBox[{"4", " ", "coilz1", " ", "l"}], "+", 
                SuperscriptBox["l", "2"], "-", 
                RowBox[{"8", " ", "coilz1", " ", "pos"}], "-", 
                RowBox[{"4", " ", "l", " ", "pos"}], "+", 
                RowBox[{"4", " ", 
                 SuperscriptBox["pos", "2"]}], "+", 
                RowBox[{"4", " ", 
                 SuperscriptBox["r1", "2"]}], "+", 
                RowBox[{"4", " ", 
                 SuperscriptBox["r2", "2"]}], "-", 
                RowBox[{"8", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"4", " ", 
                 SuperscriptBox["coilz2", "2"]}], "+", 
                RowBox[{"4", " ", "coilz2", " ", "l"}], "+", 
                SuperscriptBox["l", "2"], "-", 
                RowBox[{"8", " ", "coilz2", " ", "pos"}], "-", 
                RowBox[{"4", " ", "l", " ", "pos"}], "+", 
                RowBox[{"4", " ", 
                 SuperscriptBox["pos", "2"]}], "+", 
                RowBox[{"4", " ", 
                 SuperscriptBox["r1", "2"]}], "+", 
                RowBox[{"4", " ", 
                 SuperscriptBox["r2", "2"]}], "-", 
                RowBox[{"8", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}], " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}], 
               "2"]}], ")"}]}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "16"}], " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["coilz2", "2"], " ", "l", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"4", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{
             "16", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"4", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"4", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["l", "3"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"4", " ", "coilsigma", " ", "coilz2", " ", 
              SuperscriptBox["l", "3"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"coilsigma", " ", 
              SuperscriptBox["l", "4"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["coilz2", "2"], " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{
             "64", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", "l", 
              " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"24", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["l", "2"], " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"24", " ", "coilsigma", " ", "coilz2", " ", 
              SuperscriptBox["l", "2"], " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["l", "3"], " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{
             "64", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"48", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"48", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"24", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["pos", "3"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz2", " ", 
              SuperscriptBox["pos", "3"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "l", " ", 
              SuperscriptBox["pos", "3"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "4"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["r1", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["r1", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"4", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
              SuperscriptBox["r1", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"2", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "4"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r2", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"2", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r2", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r2", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["r2", "6"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"64", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{
             "16", " ", "coilsigma", " ", "coilz2", " ", "l", " ", "r1", " ", 
              
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"4", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{
             "32", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", "r1", 
              " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{
             "16", " ", "coilsigma", " ", "l", " ", "pos", " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "3"], " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "r1", " ", 
              SuperscriptBox["r2", "5"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["coilz2", "2"], " ", "l", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"4", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{
             "16", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"4", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"4", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["l", "3"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"4", " ", "coilsigma", " ", "coilz2", " ", 
              SuperscriptBox["l", "3"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"coilsigma", " ", 
              SuperscriptBox["l", "4"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["coilz2", "2"], " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{
             "64", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", "l", 
              " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"24", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["l", "2"], " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"24", " ", "coilsigma", " ", "coilz2", " ", 
              SuperscriptBox["l", "2"], " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["l", "3"], " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{
             "64", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"48", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"48", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"24", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["pos", "3"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz2", " ", 
              SuperscriptBox["pos", "3"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "l", " ", 
              SuperscriptBox["pos", "3"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "4"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r1", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r1", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"4", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r1", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"2", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "4"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["r2", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"2", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
              SuperscriptBox["r2", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r2", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["r2", "6"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"64", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{
             "16", " ", "coilsigma", " ", "coilz1", " ", "l", " ", "r1", " ", 
              
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"4", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{
             "32", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", "r1", 
              " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{
             "16", " ", "coilsigma", " ", "l", " ", "pos", " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "3"], " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "r1", " ", 
              SuperscriptBox["r2", "5"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta1", "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["coilz2", "2"], " ", "l", " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"4", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{
             "16", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"4", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"4", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["l", "3"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"4", " ", "coilsigma", " ", "coilz2", " ", 
              SuperscriptBox["l", "3"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"coilsigma", " ", 
              SuperscriptBox["l", "4"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["coilz2", "2"], " ", "pos", " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "l", " ", "pos", " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{
             "64", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", "l", 
              " ", "pos", " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", "l", " ", "pos", " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"24", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["l", "2"], " ", "pos", " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"24", " ", "coilsigma", " ", "coilz2", " ", 
              SuperscriptBox["l", "2"], " ", "pos", " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["l", "3"], " ", "pos", " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{
             "64", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"48", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"48", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"24", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["pos", "3"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz2", " ", 
              SuperscriptBox["pos", "3"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "l", " ", 
              SuperscriptBox["pos", "3"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "4"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"6", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"24", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"24", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "4"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["r2", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r2", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"6", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
              SuperscriptBox["r2", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r2", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"24", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r2", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"24", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["r2", "6"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{
             "32", " ", "coilsigma", " ", "coilz1", " ", "l", " ", "r1", " ", 
              
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{
             "16", " ", "coilsigma", " ", "coilz2", " ", "l", " ", "r1", " ", 
              
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"12", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{
             "64", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", "r1", 
              " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{
             "32", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", "r1", 
              " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{
             "48", " ", "coilsigma", " ", "l", " ", "pos", " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"48", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "3"], " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "r1", " ", 
              SuperscriptBox["r2", "5"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["coilz2", "2"], " ", "l", " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"4", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{
             "16", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"4", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"4", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["l", "3"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"4", " ", "coilsigma", " ", "coilz2", " ", 
              SuperscriptBox["l", "3"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"coilsigma", " ", 
              SuperscriptBox["l", "4"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["coilz2", "2"], " ", "pos", " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "l", " ", "pos", " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{
             "64", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", "l", 
              " ", "pos", " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", "l", " ", "pos", " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"24", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["l", "2"], " ", "pos", " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"24", " ", "coilsigma", " ", "coilz2", " ", 
              SuperscriptBox["l", "2"], " ", "pos", " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["l", "3"], " ", "pos", " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{
             "64", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"48", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"48", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"24", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["pos", "3"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz2", " ", 
              SuperscriptBox["pos", "3"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "l", " ", 
              SuperscriptBox["pos", "3"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "4"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"6", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"24", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"24", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "4"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["r2", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r2", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"6", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
              SuperscriptBox["r2", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r2", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"24", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r2", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"24", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["r2", "6"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{
             "16", " ", "coilsigma", " ", "coilz1", " ", "l", " ", "r1", " ", 
              
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{
             "32", " ", "coilsigma", " ", "coilz2", " ", "l", " ", "r1", " ", 
              
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"12", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{
             "32", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", "r1", 
              " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{
             "64", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", "r1", 
              " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{
             "48", " ", "coilsigma", " ", "l", " ", "pos", " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"48", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "3"], " ", 
              SuperscriptBox["r2", "3"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "r1", " ", 
              SuperscriptBox["r2", "5"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"theta1", "-", 
                RowBox[{"2", " ", "theta2"}]}], "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"2", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "5"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{
             "8", " ", "coilsigma", " ", "coilz2", " ", "l", " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"2", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{
             "16", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", "r1", 
              " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{
             "8", " ", "coilsigma", " ", "l", " ", "pos", " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "3"], " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", "r1", " ", 
              SuperscriptBox["r2", "5"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"4", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "4"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "3"], " ", 
              SuperscriptBox["r2", "3"], " ", 
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"2", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "5"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{
             "8", " ", "coilsigma", " ", "coilz1", " ", "l", " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"2", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{
             "16", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", "r1", 
              " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{
             "8", " ", "coilsigma", " ", "l", " ", "pos", " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "3"], " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", "r1", " ", 
              SuperscriptBox["r2", "5"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"4", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "4"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "3"], " ", 
              SuperscriptBox["r2", "3"], " ", 
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"2", " ", "theta1"}], "-", "theta2"}], "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["coilz2", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "l", " ", 
              "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["coilz2", "2"], " ", "l", " ", "r1", " ", "r2", 
              " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["l", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{
             "32", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
              SuperscriptBox["l", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["l", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["l", "3"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", "coilz2", " ", 
              SuperscriptBox["l", "3"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"2", " ", "coilsigma", " ", 
              SuperscriptBox["l", "4"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"64", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "pos", " ", 
              "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"64", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["coilz2", "2"], " ", "pos", " ", "r1", " ", "r2",
               " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "l", " ", "pos", " ", "r1", 
              " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{
             "128", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", "l", 
              " ", "pos", " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", "l", " ", "pos", " ", "r1", 
              " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"48", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["l", "2"], " ", "pos", " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"48", " ", "coilsigma", " ", "coilz2", " ", 
              SuperscriptBox["l", "2"], " ", "pos", " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["l", "3"], " ", "pos", " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{
             "128", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"96", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"96", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"48", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"64", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["pos", "3"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"64", " ", "coilsigma", " ", "coilz2", " ", 
              SuperscriptBox["pos", "3"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"64", " ", "coilsigma", " ", "l", " ", 
              SuperscriptBox["pos", "3"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "4"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"10", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"64", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"40", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"40", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "5"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{
             "32", " ", "coilsigma", " ", "coilz1", " ", "l", " ", "r1", " ", 
              
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{
             "8", " ", "coilsigma", " ", "coilz2", " ", "l", " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"10", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{
             "64", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", "r1", 
              " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{
             "16", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", "r1", 
              " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{
             "40", " ", "coilsigma", " ", "l", " ", "pos", " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"40", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "3"], " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", "r1", " ", 
              SuperscriptBox["r2", "5"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"64", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"64", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"20", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{
             "128", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"80", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"80", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "4"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "3"], " ", 
              SuperscriptBox["r2", "3"], " ", 
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["coilz2", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "l", " ", 
              "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["coilz2", "2"], " ", "l", " ", "r1", " ", "r2", 
              " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["l", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{
             "32", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
              SuperscriptBox["l", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["l", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["l", "3"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", "coilz2", " ", 
              SuperscriptBox["l", "3"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"2", " ", "coilsigma", " ", 
              SuperscriptBox["l", "4"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"64", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "coilz2", " ", "pos", " ", 
              "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"64", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["coilz2", "2"], " ", "pos", " ", "r1", " ", "r2",
               " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "l", " ", "pos", " ", "r1", 
              " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{
             "128", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", "l", 
              " ", "pos", " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", "l", " ", "pos", " ", "r1", 
              " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"48", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["l", "2"], " ", "pos", " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"48", " ", "coilsigma", " ", "coilz2", " ", 
              SuperscriptBox["l", "2"], " ", "pos", " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["l", "3"], " ", "pos", " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{
             "128", " ", "coilsigma", " ", "coilz1", " ", "coilz2", " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"96", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"96", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"48", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"64", " ", "coilsigma", " ", "coilz1", " ", 
              SuperscriptBox["pos", "3"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"64", " ", "coilsigma", " ", "coilz2", " ", 
              SuperscriptBox["pos", "3"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"64", " ", "coilsigma", " ", "l", " ", 
              SuperscriptBox["pos", "3"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "4"], " ", "r1", " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"8", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"10", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"64", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"40", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"40", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "3"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "5"], " ", "r2", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{
             "8", " ", "coilsigma", " ", "coilz1", " ", "l", " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{
             "32", " ", "coilsigma", " ", "coilz2", " ", "l", " ", "r1", " ", 
              
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"10", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{
             "16", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", "r1", 
              " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{
             "64", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", "r1", 
              " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{
             "40", " ", "coilsigma", " ", "l", " ", "pos", " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"40", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", "r1", " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "3"], " ", 
              SuperscriptBox["r2", "3"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"8", " ", "coilsigma", " ", "r1", " ", 
              SuperscriptBox["r2", "5"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"16", " ", "coilsigma", " ", 
              SuperscriptBox["coilz1", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"64", " ", "coilsigma", " ", 
              SuperscriptBox["coilz2", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"16", " ", "coilsigma", " ", "coilz1", " ", "l", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"64", " ", "coilsigma", " ", "coilz2", " ", "l", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"20", " ", "coilsigma", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", "coilz1", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{
             "128", " ", "coilsigma", " ", "coilz2", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"80", " ", "coilsigma", " ", "l", " ", "pos", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"80", " ", "coilsigma", " ", 
              SuperscriptBox["pos", "2"], " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "4"], " ", 
              SuperscriptBox["r2", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "+", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "4"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}], "-", 
             RowBox[{"32", " ", "coilsigma", " ", 
              SuperscriptBox["r1", "3"], " ", 
              SuperscriptBox["r2", "3"], " ", 
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], "2"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              RowBox[{"Sin", "[", "theta2", "]"}]}]}], ")"}], "/", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", " ", 
                SuperscriptBox["coilz1", "2"]}], "-", 
               RowBox[{"4", " ", "coilz1", " ", "l"}], "+", 
               SuperscriptBox["l", "2"], "-", 
               RowBox[{"8", " ", "coilz1", " ", "pos"}], "+", 
               RowBox[{"4", " ", "l", " ", "pos"}], "+", 
               RowBox[{"4", " ", 
                SuperscriptBox["pos", "2"]}], "+", 
               RowBox[{"4", " ", 
                SuperscriptBox["r1", "2"]}], "+", 
               RowBox[{"4", " ", 
                SuperscriptBox["r2", "2"]}], "-", 
               RowBox[{"8", " ", "r1", " ", "r2", " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", " ", 
                SuperscriptBox["coilz2", "2"]}], "-", 
               RowBox[{"4", " ", "coilz2", " ", "l"}], "+", 
               SuperscriptBox["l", "2"], "-", 
               RowBox[{"8", " ", "coilz2", " ", "pos"}], "+", 
               RowBox[{"4", " ", "l", " ", "pos"}], "+", 
               RowBox[{"4", " ", 
                SuperscriptBox["pos", "2"]}], "+", 
               RowBox[{"4", " ", 
                SuperscriptBox["r1", "2"]}], "+", 
               RowBox[{"4", " ", 
                SuperscriptBox["r2", "2"]}], "-", 
               RowBox[{"8", " ", "r1", " ", "r2", " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}], "2"]}],
             ")"}]}]}], ")"}]}], ")"}]}], ",", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"4", " ", "\[Pi]"}]], 
      RowBox[{"(", 
       RowBox[{"mu0", " ", "mz", " ", "r1", " ", "r2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", "coilsigma", " ", "coilz2", " ", "r1",
                " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"coilsigma", " ", "l", " ", "r1", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"2", " ", "coilsigma", " ", "pos", " ", "r1", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"2", " ", "coilsigma", " ", "coilz2", " ", "r2", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"coilsigma", " ", "l", " ", "r2", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"2", " ", "coilsigma", " ", "pos", " ", "r2", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz1", "2"], "-", 
                 RowBox[{"2", " ", "coilz1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"2", " ", "coilsigma", " ", "coilz1", " ", "r1", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"coilsigma", " ", "l", " ", "r1", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"2", " ", "coilsigma", " ", "pos", " ", "r1", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"2", " ", "coilsigma", " ", "coilz1", " ", "r2", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
              RowBox[{"coilsigma", " ", "l", " ", "r2", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
              RowBox[{"2", " ", "coilsigma", " ", "pos", " ", "r2", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["coilz2", "2"], "-", 
                 RowBox[{"2", " ", "coilz2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                 SuperscriptBox["r1", "2"], "+", 
                 SuperscriptBox["r2", "2"], "-", 
                 RowBox[{"2", " ", "r1", " ", "r2", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}]}], ")"}], 
            "/", 
            RowBox[{"(", 
             RowBox[{"2", " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", 
                    FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], ")"}]}]}], 
          "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "2"}], " ", "coilsigma", " ", "coilz2", " ", "r1", 
              " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"coilsigma", " ", "l", " ", "r1", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"2", " ", "coilsigma", " ", "pos", " ", "r1", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"2", " ", "coilsigma", " ", "coilz2", " ", "r2", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"coilsigma", " ", "l", " ", "r2", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"2", " ", "coilsigma", " ", "pos", " ", "r2", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz1", "2"], "-", 
                RowBox[{"2", " ", "coilz1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"2", " ", "coilsigma", " ", "coilz1", " ", "r1", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"coilsigma", " ", "l", " ", "r1", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"2", " ", "coilsigma", " ", "pos", " ", "r1", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "-", 
             RowBox[{"2", " ", "coilsigma", " ", "coilz1", " ", "r2", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"coilsigma", " ", "l", " ", "r2", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], "+", 
             RowBox[{"2", " ", "coilsigma", " ", "pos", " ", "r2", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"theta1", "-", "theta2"}], "]"}], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["coilz2", "2"], "-", 
                RowBox[{"2", " ", "coilz2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
                SuperscriptBox["r1", "2"], "+", 
                SuperscriptBox["r2", "2"], "-", 
                RowBox[{"2", " ", "r1", " ", "r2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}]}], ")"}], 
           "/", 
           RowBox[{"(", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["r1", "2"], "+", 
               SuperscriptBox["r2", "2"], "-", 
               RowBox[{"2", " ", "r1", " ", "r2", " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"theta1", "-", "theta2"}], "]"}]}]}], ")"}], " ", 
             SqrtBox[
              RowBox[{
               SuperscriptBox["coilz1", "2"], "-", 
               RowBox[{"2", " ", "coilz1", " ", 
                RowBox[{"(", 
                 RowBox[{
                  FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
               SuperscriptBox["r1", "2"], "+", 
               SuperscriptBox["r2", "2"], "-", 
               RowBox[{"2", " ", "r1", " ", "r2", " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]], " ", 
             SqrtBox[
              RowBox[{
               SuperscriptBox["coilz2", "2"], "-", 
               RowBox[{"2", " ", "coilz2", " ", 
                RowBox[{"(", 
                 RowBox[{
                  FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
               SuperscriptBox["r1", "2"], "+", 
               SuperscriptBox["r2", "2"], "-", 
               RowBox[{"2", " ", "r1", " ", "r2", " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"theta1", "-", "theta2"}], "]"}]}]}]]}], ")"}]}]}], 
         ")"}]}], ")"}]}]}], "}"}]}], ";"}]], "Input",
 InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Actual calculation", "Text",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"fdr1dr2dtheta1dtheta2", " ", "=", " ", 
   RowBox[{"If", "[", "\[InvisibleSpace]", 
    RowBox[{
     RowBox[{"!", "useprecomputed"}], ",", 
     RowBox[{"Integrate", "[", 
      RowBox[{"fdr1dr2dtheta1dtheta2dz2", ",", 
       RowBox[{"{", 
        RowBox[{"z2", ",", 
         RowBox[{"pos", "-", 
          RowBox[{"l", "/", "2"}]}], ",", 
         RowBox[{"pos", "+", 
          RowBox[{"l", "/", "2"}]}]}], "}"}]}], "]"}], ",", 
     "fdr1dr2dtheta1dtheta2pre"}], "]"}]}], ";"}]], "Input",
 InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Use symmetry to combine theta1 and theta2 integrals into an integral over \
deltatheta (and multiplication by 2 Pi) for longitudinal (z) component\
\>", "Text",
 InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fdr1dr2ddeltatheta", "=", 
  RowBox[{
   RowBox[{"2", " ", "Pi", " ", 
    RowBox[{"fdr1dr2dtheta1dtheta2", "[", 
     RowBox[{"[", "3", "]"}], "]"}]}], "/.", 
   RowBox[{
    RowBox[{"theta1", "-", "theta2"}], "\[Rule]", "deltatheta"}]}]}]], "Input",\

 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", "mu0", " ", "mz", " ", "r1", " ", "r2", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", "coilsigma", " ", "coilz2", " ", "r1", " ", 
          SqrtBox[
           RowBox[{
            SuperscriptBox["coilz1", "2"], "-", 
            RowBox[{"2", " ", "coilz1", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
            SuperscriptBox["r1", "2"], "+", 
            SuperscriptBox["r2", "2"], "-", 
            RowBox[{"2", " ", "r1", " ", "r2", " ", 
             RowBox[{"Cos", "[", "deltatheta", "]"}]}]}]]}], "-", 
         RowBox[{"coilsigma", " ", "l", " ", "r1", " ", 
          SqrtBox[
           RowBox[{
            SuperscriptBox["coilz1", "2"], "-", 
            RowBox[{"2", " ", "coilz1", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
            SuperscriptBox["r1", "2"], "+", 
            SuperscriptBox["r2", "2"], "-", 
            RowBox[{"2", " ", "r1", " ", "r2", " ", 
             RowBox[{"Cos", "[", "deltatheta", "]"}]}]}]]}], "+", 
         RowBox[{"2", " ", "coilsigma", " ", "pos", " ", "r1", " ", 
          SqrtBox[
           RowBox[{
            SuperscriptBox["coilz1", "2"], "-", 
            RowBox[{"2", " ", "coilz1", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
            SuperscriptBox["r1", "2"], "+", 
            SuperscriptBox["r2", "2"], "-", 
            RowBox[{"2", " ", "r1", " ", "r2", " ", 
             RowBox[{"Cos", "[", "deltatheta", "]"}]}]}]]}], "+", 
         RowBox[{"2", " ", "coilsigma", " ", "coilz2", " ", "r2", " ", 
          RowBox[{"Cos", "[", "deltatheta", "]"}], " ", 
          SqrtBox[
           RowBox[{
            SuperscriptBox["coilz1", "2"], "-", 
            RowBox[{"2", " ", "coilz1", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
            SuperscriptBox["r1", "2"], "+", 
            SuperscriptBox["r2", "2"], "-", 
            RowBox[{"2", " ", "r1", " ", "r2", " ", 
             RowBox[{"Cos", "[", "deltatheta", "]"}]}]}]]}], "+", 
         RowBox[{"coilsigma", " ", "l", " ", "r2", " ", 
          RowBox[{"Cos", "[", "deltatheta", "]"}], " ", 
          SqrtBox[
           RowBox[{
            SuperscriptBox["coilz1", "2"], "-", 
            RowBox[{"2", " ", "coilz1", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
            SuperscriptBox["r1", "2"], "+", 
            SuperscriptBox["r2", "2"], "-", 
            RowBox[{"2", " ", "r1", " ", "r2", " ", 
             RowBox[{"Cos", "[", "deltatheta", "]"}]}]}]]}], "-", 
         RowBox[{"2", " ", "coilsigma", " ", "pos", " ", "r2", " ", 
          RowBox[{"Cos", "[", "deltatheta", "]"}], " ", 
          SqrtBox[
           RowBox[{
            SuperscriptBox["coilz1", "2"], "-", 
            RowBox[{"2", " ", "coilz1", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
            SuperscriptBox["r1", "2"], "+", 
            SuperscriptBox["r2", "2"], "-", 
            RowBox[{"2", " ", "r1", " ", "r2", " ", 
             RowBox[{"Cos", "[", "deltatheta", "]"}]}]}]]}], "+", 
         RowBox[{"2", " ", "coilsigma", " ", "coilz1", " ", "r1", " ", 
          SqrtBox[
           RowBox[{
            SuperscriptBox["coilz2", "2"], "-", 
            RowBox[{"2", " ", "coilz2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
            SuperscriptBox["r1", "2"], "+", 
            SuperscriptBox["r2", "2"], "-", 
            RowBox[{"2", " ", "r1", " ", "r2", " ", 
             RowBox[{"Cos", "[", "deltatheta", "]"}]}]}]]}], "+", 
         RowBox[{"coilsigma", " ", "l", " ", "r1", " ", 
          SqrtBox[
           RowBox[{
            SuperscriptBox["coilz2", "2"], "-", 
            RowBox[{"2", " ", "coilz2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
            SuperscriptBox["r1", "2"], "+", 
            SuperscriptBox["r2", "2"], "-", 
            RowBox[{"2", " ", "r1", " ", "r2", " ", 
             RowBox[{"Cos", "[", "deltatheta", "]"}]}]}]]}], "-", 
         RowBox[{"2", " ", "coilsigma", " ", "pos", " ", "r1", " ", 
          SqrtBox[
           RowBox[{
            SuperscriptBox["coilz2", "2"], "-", 
            RowBox[{"2", " ", "coilz2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
            SuperscriptBox["r1", "2"], "+", 
            SuperscriptBox["r2", "2"], "-", 
            RowBox[{"2", " ", "r1", " ", "r2", " ", 
             RowBox[{"Cos", "[", "deltatheta", "]"}]}]}]]}], "-", 
         RowBox[{"2", " ", "coilsigma", " ", "coilz1", " ", "r2", " ", 
          RowBox[{"Cos", "[", "deltatheta", "]"}], " ", 
          SqrtBox[
           RowBox[{
            SuperscriptBox["coilz2", "2"], "-", 
            RowBox[{"2", " ", "coilz2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
            SuperscriptBox["r1", "2"], "+", 
            SuperscriptBox["r2", "2"], "-", 
            RowBox[{"2", " ", "r1", " ", "r2", " ", 
             RowBox[{"Cos", "[", "deltatheta", "]"}]}]}]]}], "-", 
         RowBox[{"coilsigma", " ", "l", " ", "r2", " ", 
          RowBox[{"Cos", "[", "deltatheta", "]"}], " ", 
          SqrtBox[
           RowBox[{
            SuperscriptBox["coilz2", "2"], "-", 
            RowBox[{"2", " ", "coilz2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
            SuperscriptBox["r1", "2"], "+", 
            SuperscriptBox["r2", "2"], "-", 
            RowBox[{"2", " ", "r1", " ", "r2", " ", 
             RowBox[{"Cos", "[", "deltatheta", "]"}]}]}]]}], "+", 
         RowBox[{"2", " ", "coilsigma", " ", "pos", " ", "r2", " ", 
          RowBox[{"Cos", "[", "deltatheta", "]"}], " ", 
          SqrtBox[
           RowBox[{
            SuperscriptBox["coilz2", "2"], "-", 
            RowBox[{"2", " ", "coilz2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
            SuperscriptBox["r1", "2"], "+", 
            SuperscriptBox["r2", "2"], "-", 
            RowBox[{"2", " ", "r1", " ", "r2", " ", 
             RowBox[{"Cos", "[", "deltatheta", "]"}]}]}]]}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["r1", "2"], "+", 
           SuperscriptBox["r2", "2"], "-", 
           RowBox[{"2", " ", "r1", " ", "r2", " ", 
            RowBox[{"Cos", "[", "deltatheta", "]"}]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox["coilz1", "2"], "-", 
           RowBox[{"2", " ", "coilz1", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
           SuperscriptBox["r1", "2"], "+", 
           SuperscriptBox["r2", "2"], "-", 
           RowBox[{"2", " ", "r1", " ", "r2", " ", 
            RowBox[{"Cos", "[", "deltatheta", "]"}]}]}]], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox["coilz2", "2"], "-", 
           RowBox[{"2", " ", "coilz2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               FractionBox["l", "2"]}], "+", "pos"}], ")"}]}], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               FractionBox["l", "2"]}], "+", "pos"}], ")"}], "2"], "+", 
           SuperscriptBox["r1", "2"], "+", 
           SuperscriptBox["r2", "2"], "-", 
           RowBox[{"2", " ", "r1", " ", "r2", " ", 
            RowBox[{"Cos", "[", "deltatheta", "]"}]}]}]]}], ")"}]}], ")"}]}], 
    "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", "coilsigma", " ", "coilz2", " ", "r1", " ", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["coilz1", "2"], "-", 
          RowBox[{"2", " ", "coilz1", " ", 
           RowBox[{"(", 
            RowBox[{
             FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
          SuperscriptBox["r1", "2"], "+", 
          SuperscriptBox["r2", "2"], "-", 
          RowBox[{"2", " ", "r1", " ", "r2", " ", 
           RowBox[{"Cos", "[", "deltatheta", "]"}]}]}]]}], "+", 
       RowBox[{"coilsigma", " ", "l", " ", "r1", " ", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["coilz1", "2"], "-", 
          RowBox[{"2", " ", "coilz1", " ", 
           RowBox[{"(", 
            RowBox[{
             FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
          SuperscriptBox["r1", "2"], "+", 
          SuperscriptBox["r2", "2"], "-", 
          RowBox[{"2", " ", "r1", " ", "r2", " ", 
           RowBox[{"Cos", "[", "deltatheta", "]"}]}]}]]}], "+", 
       RowBox[{"2", " ", "coilsigma", " ", "pos", " ", "r1", " ", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["coilz1", "2"], "-", 
          RowBox[{"2", " ", "coilz1", " ", 
           RowBox[{"(", 
            RowBox[{
             FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
          SuperscriptBox["r1", "2"], "+", 
          SuperscriptBox["r2", "2"], "-", 
          RowBox[{"2", " ", "r1", " ", "r2", " ", 
           RowBox[{"Cos", "[", "deltatheta", "]"}]}]}]]}], "+", 
       RowBox[{"2", " ", "coilsigma", " ", "coilz2", " ", "r2", " ", 
        RowBox[{"Cos", "[", "deltatheta", "]"}], " ", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["coilz1", "2"], "-", 
          RowBox[{"2", " ", "coilz1", " ", 
           RowBox[{"(", 
            RowBox[{
             FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
          SuperscriptBox["r1", "2"], "+", 
          SuperscriptBox["r2", "2"], "-", 
          RowBox[{"2", " ", "r1", " ", "r2", " ", 
           RowBox[{"Cos", "[", "deltatheta", "]"}]}]}]]}], "-", 
       RowBox[{"coilsigma", " ", "l", " ", "r2", " ", 
        RowBox[{"Cos", "[", "deltatheta", "]"}], " ", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["coilz1", "2"], "-", 
          RowBox[{"2", " ", "coilz1", " ", 
           RowBox[{"(", 
            RowBox[{
             FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
          SuperscriptBox["r1", "2"], "+", 
          SuperscriptBox["r2", "2"], "-", 
          RowBox[{"2", " ", "r1", " ", "r2", " ", 
           RowBox[{"Cos", "[", "deltatheta", "]"}]}]}]]}], "-", 
       RowBox[{"2", " ", "coilsigma", " ", "pos", " ", "r2", " ", 
        RowBox[{"Cos", "[", "deltatheta", "]"}], " ", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["coilz1", "2"], "-", 
          RowBox[{"2", " ", "coilz1", " ", 
           RowBox[{"(", 
            RowBox[{
             FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
          SuperscriptBox["r1", "2"], "+", 
          SuperscriptBox["r2", "2"], "-", 
          RowBox[{"2", " ", "r1", " ", "r2", " ", 
           RowBox[{"Cos", "[", "deltatheta", "]"}]}]}]]}], "+", 
       RowBox[{"2", " ", "coilsigma", " ", "coilz1", " ", "r1", " ", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["coilz2", "2"], "-", 
          RowBox[{"2", " ", "coilz2", " ", 
           RowBox[{"(", 
            RowBox[{
             FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
          SuperscriptBox["r1", "2"], "+", 
          SuperscriptBox["r2", "2"], "-", 
          RowBox[{"2", " ", "r1", " ", "r2", " ", 
           RowBox[{"Cos", "[", "deltatheta", "]"}]}]}]]}], "-", 
       RowBox[{"coilsigma", " ", "l", " ", "r1", " ", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["coilz2", "2"], "-", 
          RowBox[{"2", " ", "coilz2", " ", 
           RowBox[{"(", 
            RowBox[{
             FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
          SuperscriptBox["r1", "2"], "+", 
          SuperscriptBox["r2", "2"], "-", 
          RowBox[{"2", " ", "r1", " ", "r2", " ", 
           RowBox[{"Cos", "[", "deltatheta", "]"}]}]}]]}], "-", 
       RowBox[{"2", " ", "coilsigma", " ", "pos", " ", "r1", " ", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["coilz2", "2"], "-", 
          RowBox[{"2", " ", "coilz2", " ", 
           RowBox[{"(", 
            RowBox[{
             FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
          SuperscriptBox["r1", "2"], "+", 
          SuperscriptBox["r2", "2"], "-", 
          RowBox[{"2", " ", "r1", " ", "r2", " ", 
           RowBox[{"Cos", "[", "deltatheta", "]"}]}]}]]}], "-", 
       RowBox[{"2", " ", "coilsigma", " ", "coilz1", " ", "r2", " ", 
        RowBox[{"Cos", "[", "deltatheta", "]"}], " ", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["coilz2", "2"], "-", 
          RowBox[{"2", " ", "coilz2", " ", 
           RowBox[{"(", 
            RowBox[{
             FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
          SuperscriptBox["r1", "2"], "+", 
          SuperscriptBox["r2", "2"], "-", 
          RowBox[{"2", " ", "r1", " ", "r2", " ", 
           RowBox[{"Cos", "[", "deltatheta", "]"}]}]}]]}], "+", 
       RowBox[{"coilsigma", " ", "l", " ", "r2", " ", 
        RowBox[{"Cos", "[", "deltatheta", "]"}], " ", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["coilz2", "2"], "-", 
          RowBox[{"2", " ", "coilz2", " ", 
           RowBox[{"(", 
            RowBox[{
             FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
          SuperscriptBox["r1", "2"], "+", 
          SuperscriptBox["r2", "2"], "-", 
          RowBox[{"2", " ", "r1", " ", "r2", " ", 
           RowBox[{"Cos", "[", "deltatheta", "]"}]}]}]]}], "+", 
       RowBox[{"2", " ", "coilsigma", " ", "pos", " ", "r2", " ", 
        RowBox[{"Cos", "[", "deltatheta", "]"}], " ", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["coilz2", "2"], "-", 
          RowBox[{"2", " ", "coilz2", " ", 
           RowBox[{"(", 
            RowBox[{
             FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
          SuperscriptBox["r1", "2"], "+", 
          SuperscriptBox["r2", "2"], "-", 
          RowBox[{"2", " ", "r1", " ", "r2", " ", 
           RowBox[{"Cos", "[", "deltatheta", "]"}]}]}]]}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["r1", "2"], "+", 
         SuperscriptBox["r2", "2"], "-", 
         RowBox[{"2", " ", "r1", " ", "r2", " ", 
          RowBox[{"Cos", "[", "deltatheta", "]"}]}]}], ")"}], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["coilz1", "2"], "-", 
         RowBox[{"2", " ", "coilz1", " ", 
          RowBox[{"(", 
           RowBox[{
            FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
         SuperscriptBox["r1", "2"], "+", 
         SuperscriptBox["r2", "2"], "-", 
         RowBox[{"2", " ", "r1", " ", "r2", " ", 
          RowBox[{"Cos", "[", "deltatheta", "]"}]}]}]], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["coilz2", "2"], "-", 
         RowBox[{"2", " ", "coilz2", " ", 
          RowBox[{"(", 
           RowBox[{
            FractionBox["l", "2"], "+", "pos"}], ")"}]}], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            FractionBox["l", "2"], "+", "pos"}], ")"}], "2"], "+", 
         SuperscriptBox["r1", "2"], "+", 
         SuperscriptBox["r2", "2"], "-", 
         RowBox[{"2", " ", "r1", " ", "r2", " ", 
          RowBox[{"Cos", "[", "deltatheta", "]"}]}]}]]}], ")"}]}]}], 
   ")"}]}]], "Output",
 InitializationCell->True,
 CellChangeTimes->{
  3.453749602489585*^9, 3.453749666250413*^9, 3.46384466353118*^9, {
   3.478894407013402*^9, 3.4788944222059526`*^9}, 3.478960342737445*^9, 
   3.479485743183877*^9, 3.4794860539930687`*^9, 3.4796583835628853`*^9, 
   3.4800825686169987`*^9, 3.4802436780596313`*^9, 3.480692248023052*^9, 
   3.4815660071019783`*^9, 3.481940916508472*^9, 3.481941022615478*^9, 
   3.481941924564169*^9, 3.629759416479054*^9, 3.629767963319037*^9, 
   3.6302097983724937`*^9, 3.630288016288656*^9, 3.6302982188111067`*^9, 
   3.630319403506625*^9, 3.630469794027714*^9, 3.631828016624824*^9, 
   3.6338335383359013`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["A function to do the last three integrals numerically", "Text",
 InitializationCell->True,
 CellChangeTimes->{{3.453752791124783*^9, 3.453752795898744*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"fz", "[", 
    RowBox[{"tag_", ",", "p_"}], "]"}], " ", ":=", 
   RowBox[{
    RowBox[{"Block", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"fdr1dr2ddeltathetaN", "=", 
        RowBox[{"fdr1dr2ddeltatheta", "/.", 
         RowBox[{"vals", "[", "tag", "]"}]}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"NIntegrate", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"fdr1dr2ddeltathetaN", "/.", 
         RowBox[{"pos", "\[Rule]", "p"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"r1", ",", 
          RowBox[{"coilrad1", "/.", 
           RowBox[{"vals", "[", "tag", "]"}]}], ",", 
          RowBox[{"coilrad2", "/.", 
           RowBox[{"vals", "[", "tag", "]"}]}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"r2", ",", "0", ",", 
          RowBox[{"a", "/.", 
           RowBox[{"vals", "[", "tag", "]"}]}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"deltatheta", ",", "0", ",", 
          RowBox[{"2", "Pi"}]}], "}"}]}], "]"}]}], "\[IndentingNewLine]", 
     "]"}], "/;", 
    RowBox[{"NumericQ", "[", "p", "]"}]}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.453750837572444*^9, 3.453750866946459*^9}, {
  3.453752644867671*^9, 3.45375269653437*^9}, {3.45382373167922*^9, 
  3.453823755073104*^9}, {3.453839497459736*^9, 3.4538395070562553`*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Field at a general point", "Subsection",
 InitializationCell->True,
 CellChangeTimes->{{3.630226140867004*^9, 3.630226148969727*^9}}],

Cell[CellGroupData[{

Cell["\<\
Element of field due to element of volume in coil and element of volume in \
magnet as function of r1, r2, theta1, theta2, z1, z2\
\>", "Text",
 InitializationCell->True,
 CellChangeTimes->{{3.630629066017816*^9, 3.6306290665935*^9}}],

Cell[CellGroupData[{

Cell["\<\
Bdr1dtheta1dz1 = (
   currentB 
   /. dx -> r1*Cos[theta1] 
   /. dy -> r1*Sin[theta1] 
   /. dz -> z1 
   /. j1x -> coilsigma*Sin[theta1] 
   /. j1y -> -coilsigma*Cos[theta1]
   /. j1z -> 0 
   /. Xx -> x2 
   /. Yy -> y2 
   /. Zz -> z2
)\
\>", "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.478888754037179*^9, 3.478888798683169*^9}, {
   3.6302139448874273`*^9, 3.6302140350427437`*^9}, {3.630214372576086*^9, 
   3.6302143880608683`*^9}, 3.630224879459896*^9, 3.630224935812059*^9, {
   3.630225011007758*^9, 3.6302250115581703`*^9}, {3.63062905994626*^9, 
   3.630629060537807*^9}}],

Cell[BoxData["currentB"], "Output",
 InitializationCell->True,
 CellChangeTimes->{3.630225012703315*^9, 3.630225123322207*^9, 
  3.6302880164392977`*^9, 3.6302982194310293`*^9, 3.6303194079152*^9, 
  3.630469794126807*^9, 3.631828016713489*^9, 3.633833538446497*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Numerically integrate", "Text",
 InitializationCell->True,
 CellChangeTimes->{{3.631828472423794*^9, 3.631828491871481*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Default", "[", "Bcoil", "]"}], "=", 
  RowBox[{"Sequence", "[", "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.633833780628296*^9, 3.633833796805808*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Bcoil", "[", 
   RowBox[{"tag_", ",", "x_", ",", "y_", ",", "z_", ",", "part_."}], "]"}], ":=", 
  RowBox[{
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"Bdr1dtheta1dz1N", "=", 
       RowBox[{"Bdr1dtheta1dz1", "/.", 
        RowBox[{"vals", "[", "tag", "]"}]}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"NIntegrate", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Bdr1dtheta1dz1N", "[", 
           RowBox[{"[", "part", "]"}], "]"}], "/.", 
          RowBox[{"x2", "\[Rule]", "x"}]}], "/.", 
         RowBox[{"y2", "\[Rule]", "y"}]}], "/.", 
        RowBox[{"z2", "\[Rule]", "z"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"r1", ",", 
         RowBox[{"coilrad1", "/.", 
          RowBox[{"vals", "[", "tag", "]"}]}], ",", 
         RowBox[{"coilrad2", "/.", 
          RowBox[{"vals", "[", "tag", "]"}]}]}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"z1", ",", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "a"}], "/", "2"}], "/.", 
          RowBox[{"vals", "[", "tag", "]"}]}], ",", 
         RowBox[{
          RowBox[{"a", "/", "2"}], "/.", 
          RowBox[{"vals", "[", "tag", "]"}]}]}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"theta1", ",", "0", ",", 
         RowBox[{"2", "Pi"}]}], "}"}]}], "\[IndentingNewLine]", "]"}]}], 
    "\[IndentingNewLine]", "]"}], "/;", 
   RowBox[{
    RowBox[{"NumericQ", "[", "x", "]"}], "&&", 
    RowBox[{"NumericQ", "[", "y", "]"}], "&&", 
    RowBox[{"NumericQ", "[", "z", "]"}]}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.630224447265543*^9, 3.63022461011596*^9}, {
   3.630224671342649*^9, 3.630224691618376*^9}, {3.630224728466639*^9, 
   3.63022475768001*^9}, 3.6302249648352757`*^9, {3.630288004705719*^9, 
   3.630288005320077*^9}, {3.630464923765663*^9, 3.630464932850265*^9}, 
   3.63383344494221*^9, 3.633833504454693*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Force at a general point", "Subsection",
 InitializationCell->True,
 CellChangeTimes->{{3.630226140867004*^9, 3.630226148969727*^9}, {
  3.630629050961987*^9, 3.6306290517139273`*^9}}],

Cell[CellGroupData[{

Cell["\<\
Element of force due to element of volume in coil and element of volume in \
magnet as function of r1, r2, theta1, theta2, z1, z2\
\>", "Text",
 InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Fdr1dtheta1dz1", " ", "=", 
  RowBox[{"(", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"currentdipoleforce", "\[IndentingNewLine]", "/.", 
            RowBox[{"dx", "\[Rule]", 
             RowBox[{"r1", "*", 
              RowBox[{"Cos", "[", "theta1", "]"}]}]}]}], "\n", "   ", "/.", 
           RowBox[{"dy", "\[Rule]", 
            RowBox[{"r1", "*", 
             RowBox[{"Sin", "[", "theta1", "]"}]}]}]}], "\n", "   ", "/.", 
          RowBox[{"dz", "\[Rule]", "z1"}]}], "\n", "   ", "/.", 
         RowBox[{"j1x", "\[Rule]", 
          RowBox[{"coilsigma", "*", 
           RowBox[{"Sin", "[", "theta1", "]"}]}]}]}], "\n", "   ", "/.", 
        RowBox[{"j1y", "\[Rule]", 
         RowBox[{
          RowBox[{"-", "coilsigma"}], "*", 
          RowBox[{"Cos", "[", "theta1", "]"}]}]}]}], "\n", "   ", "/.", 
       RowBox[{"j1z", "\[Rule]", "0"}]}], "\n", "   ", "/.", 
      RowBox[{"Xx", "\[Rule]", "x2"}]}], "\n", "   ", "/.", 
     RowBox[{"Yy", "\[Rule]", "y2"}]}], "\n", "   ", "/.", 
    RowBox[{"Zz", "\[Rule]", "z2"}]}], "\[IndentingNewLine]", 
   ")"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6303627968517647`*^9, 3.63036283909415*^9}}],

Cell[BoxData["currentdipoleforce"], "Output",
 InitializationCell->True,
 CellChangeTimes->{3.630469794272977*^9, 3.63182801684661*^9, 
  3.633833538556202*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Numerically integrate", "Text",
 InitializationCell->True,
 CellChangeTimes->{{3.631828472423794*^9, 3.631828491871481*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Default", "[", "Fcoil", "]"}], "=", 
  RowBox[{"Sequence", "[", "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.633833780628296*^9, 3.6338338161246157`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Fcoil", "[", 
   RowBox[{"tag_", ",", "x_", ",", "y_", ",", "z_", ",", "part_."}], "]"}], ":=", 
  RowBox[{
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"Fdr1dtheta1dz1N", "=", 
       RowBox[{"Fdr1dtheta1dz1", "/.", 
        RowBox[{"vals", "[", "tag", "]"}]}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"NIntegrate", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Bdr1dtheta1dz1N", "[", 
           RowBox[{"[", "part", "]"}], "]"}], "/.", 
          RowBox[{"x2", "\[Rule]", "x"}]}], "/.", 
         RowBox[{"y2", "\[Rule]", "y"}]}], "/.", 
        RowBox[{"z2", "\[Rule]", "z"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"r1", ",", 
         RowBox[{"coilrad1", "/.", 
          RowBox[{"vals", "[", "tag", "]"}]}], ",", 
         RowBox[{"coilrad2", "/.", 
          RowBox[{"vals", "[", "tag", "]"}]}]}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"z1", ",", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "a"}], "/", "2"}], "/.", 
          RowBox[{"vals", "[", "tag", "]"}]}], ",", 
         RowBox[{
          RowBox[{"a", "/", "2"}], "/.", 
          RowBox[{"vals", "[", "tag", "]"}]}]}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"theta1", ",", "0", ",", 
         RowBox[{"2", "Pi"}]}], "}"}]}], "\[IndentingNewLine]", "]"}]}], 
    "\[IndentingNewLine]", "]"}], "/;", 
   RowBox[{
    RowBox[{"NumericQ", "[", "x", "]"}], "&&", 
    RowBox[{"NumericQ", "[", "y", "]"}], "&&", 
    RowBox[{"NumericQ", "[", "z", "]"}]}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.630224447265543*^9, 3.63022461011596*^9}, {
   3.630224671342649*^9, 3.630224691618376*^9}, {3.630224728466639*^9, 
   3.63022475768001*^9}, 3.6302249648352757`*^9, {3.630288004705719*^9, 
   3.630288005320077*^9}, {3.6303628748566847`*^9, 3.630362897494132*^9}, 
   3.630464731530492*^9, {3.630464817230157*^9, 3.6304648233744507`*^9}, {
   3.6304648875917883`*^9, 3.630464906627293*^9}, 3.633833529739012*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"useprecomputed", " ", "=", " ", "useprecomputedold"}], 
  ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.633832278558338*^9, 3.633832301548463*^9}}]
},
AutoGeneratedPackage->Automatic,
CellGrouping->Manual,
WindowSize->{808, 911},
WindowMargins->{{12, Automatic}, {Automatic, 24}},
FrontEndVersion->"10.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (December 4, \
2014)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 198, 3, 68, "Section",
 InitializationCell->True],
Cell[781, 27, 201, 5, 29, "Input",
 InitializationCell->True],
Cell[985, 34, 131, 4, 28, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[1141, 42, 83, 1, 35, "Subsection",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[1249, 47, 180, 4, 26, "Text",
 InitializationCell->True],
Cell[1432, 53, 492, 19, 224, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[1961, 77, 70, 1, 23, "Text",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[2056, 82, 61, 1, 26, "Text",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[2142, 87, 44716, 947, 2439, "Input",
 InitializationCell->True],
Cell[46861, 1036, 45117, 942, 70, "Output",
 InitializationCell->True]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[92027, 1984, 61, 1, 26, "Text",
 InitializationCell->True],
Cell[92091, 1987, 449, 11, 61, "Input",
 InitializationCell->True]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[92589, 2004, 70, 1, 23, "Text",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[92684, 2009, 71, 1, 26, "Text",
 InitializationCell->True],
Cell[92758, 2012, 1760545, 38381, 134466, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[1853340, 40398, 61, 1, 23, "Text",
 InitializationCell->True],
Cell[1853404, 40401, 556, 15, 61, "Input",
 InitializationCell->True]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[1854009, 40422, 197, 4, 38, "Text",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[1854231, 40430, 304, 9, 28, "Input",
 InitializationCell->True],
Cell[1854538, 40441, 21339, 527, 70, "Output",
 InitializationCell->True]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1875926, 40974, 162, 2, 23, "Text",
 InitializationCell->True],
Cell[1876091, 40978, 1407, 35, 109, "Input",
 InitializationCell->True]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1877547, 41019, 139, 2, 35, "Subsection",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[1877711, 41025, 244, 5, 26, "Text",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[1877980, 41034, 609, 19, 182, "Input",
 InitializationCell->True],
Cell[1878592, 41055, 266, 4, 70, "Output",
 InitializationCell->True]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1878907, 41065, 130, 2, 23, "Text",
 InitializationCell->True],
Cell[1879040, 41069, 210, 5, 29, "Input",
 InitializationCell->True],
Cell[1879253, 41076, 2068, 52, 140, "Input",
 InitializationCell->True]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1881370, 41134, 190, 3, 35, "Subsection",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[1881585, 41141, 180, 4, 26, "Text",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[1881790, 41149, 1322, 32, 204, "Input",
 InitializationCell->True],
Cell[1883115, 41183, 160, 3, 70, "Output",
 InitializationCell->True]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1883324, 41192, 130, 2, 23, "Text",
 InitializationCell->True],
Cell[1883457, 41196, 212, 5, 29, "Input",
 InitializationCell->True],
Cell[1883672, 41203, 2171, 53, 140, "Input",
 InitializationCell->True]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[1885882, 41261, 202, 5, 29, "Input",
 InitializationCell->True]
}
]
*)

(* End of internal cache information *)
